==============================
Salt 2015.8.0rc2 Release Notes
==============================

Extended changelog courtesy of Todd Stansell (https://github.com/tjstansell/salt-changelogs):

*Generated at: 2015-07-23T17:03:24Z*

Statistics:

- Total Merges: **1887**
- Total Issue references: **451**
- Total PR references: **2080**

Changes:


- **PR** `#25639`_: (*terminalmage*) Don't do pre-flight check on git_pillar if it is not configured
  @ *2015-07-22T22:54:36Z*

  * 76c28da Merge pull request `#25639`_ from terminalmage/fix-git_pillar-init
  * c492baa Don't do pre-flight check on git_pillar if it is not configured

- **PR** `#25587`_: (*cachedout*) Fix prereq in salt.state
  @ *2015-07-22T20:05:02Z*

  - **ISSUE** `#16969`_: (*amendlik*) Prereq requisite does not work in orchestrations
    | refs: `#25587`_
  * 41b7604 Merge pull request `#25587`_ from cachedout/issue_16969
  * 6f65fbd Fix test

  * 02d70fc Fix prereq in salt.state

- **PR** `#25628`_: (*anlutro*) Highstate output: show duration in seconds instead of milliseconds when appropriate
  @ *2015-07-22T20:03:51Z*

  * 9004ce2 Merge pull request `#25628`_ from alprs/fix-highstate_duration_output
  * 4fd4a0c show duration in seconds instead of milliseconds when appropriate

- **PR** `#25631`_: (*basepi*) Remove trailing whitespace
  @ *2015-07-22T19:16:06Z*

  * 2685953 Merge pull request `#25631`_ from basepi/2015.8lint
  * f94fe41 Remove trailing whitespace

- **PR** `#25627`_: (*basepi*) [2015.8] Merge forward from 2015.5 to 2015.8
  @ *2015-07-22T19:11:32Z*

  - **ISSUE** `#25560`_: (*dennisjac*) scheduled highstate runs don't return results to the job cache
    | refs: `#25590`_ `#25591`_
  - **ISSUE** `#25532`_: (*attiasr*) salt/modules/win_pkg.py list_pkgs is broken (encoding issues)
    | refs: `#25556`_ `#25580`_
  - **ISSUE** `#25437`_: (*lorengordon*) Stacktrace on Windows when running pkg.list_pkgs
    | refs: `#25598`_
  - **ISSUE** `#25323`_: (*terminalmage*) unit.modules.tls_test fails with older mock
    | refs: `#25604`_
  - **ISSUE** `#25206`_: (*jfindlay*) fullname issues with user.add state on windows
    | refs: `#25568`_
  - **ISSUE** `#23626`_: (*mirko*) salt state 'ssh_known_hosts' doesn't take 'port' into account
    | refs: `#25589`_
  - **ISSUE** `#21912`_: (*rvora*) pkg.latest not updating the package on CentOS though yum reports an update available
    | refs: `#25603`_
  - **ISSUE** `#21041`_: (*deuscapturus*) state module gem.installed not working on Windows.
    | refs: `#25430`_ `#25561`_ `#25428`_
  - **ISSUE** `#630`_: (*syphernl*) Allow for an include statement in config files
    | refs: `#25609`_ `#25610`_
  - **PR** `#25609`_: (*s0undt3ch*) [2015.5] Update the bootstrap script to latest release v2015.07.22
  - **PR** `#25604`_: (*terminalmage*) Move patching of mock_open to within test
  - **PR** `#25603`_: (*terminalmage*) Add version_cmp function to yumpkg.py
  - **PR** `#25598`_: (*twangboy*) Fixed problem trying to load file with name of boolean type
  - **PR** `#25590`_: (*garethgreenaway*) 2015.5 scheduled jobs return data
  - **PR** `#25589`_: (*jahamn*) Fixes ssh_known_host not taking port into account
  - **PR** `#25584`_: (*rallytime*) Back-port `#24054`_ and `#25576`_ to 2015.5
  - **PR** `#25580`_: (*attiasr*) use explicit utf-8 decoding (`#25532`_)
  - **PR** `#25576`_: (*pcn*) s3fs breaks when fetching files from s3
    | refs: `#25584`_
  - **PR** `#25573`_: (*EvaSDK*) Do not execute bootstrap script twice
  - **PR** `#25568`_: (*twangboy*) Fixed win_useradd module to add fullname
  - **PR** `#25561`_: (*twangboy*) Fixed the gem module to work on windows... without injection
  - **PR** `#25521`_: (*cachedout*) Fix outputter for state.orch
  - **PR** `#25465`_: (*EvaSDK*) 2015.5.3 LXC module fixes
    | refs: `#25573`_
  - **PR** `#25428`_: (*twangboy*) Fixed the gem module to work on windows
    | refs: `#25561`_
  - **PR** `#24054`_: (*mgwilliams*) s3.head: return useful data
    | refs: `#25584`_
  - **PR** `#627`_: (*chjohnst*) add saltversion grain
    | refs: `#25609`_ `#25610`_
  * 079a15c Merge pull request `#25627`_ from basepi/merge-forward-2015.8
  * c63ef2c Merge remote-tracking branch 'upstream/2015.5' into merge-forward-2015.8

    * 7b79e433 Merge pull request `#25598`_ from twangboy/fix_25437

      * c53e11d Fixed problem trying to load file with name of boolean type

    * f4a38a8 Merge pull request `#25604`_ from terminalmage/fix-mock_open

      * 123b8ee Fix mock_open patch

      * af82835 Move patching of mock_open to within test

    * 224484d Merge pull request `#25609`_ from s0undt3ch/hotfix/bootstrap-script-2015.5

      * 96a8568 Update the bootstrap script to latest release v2015.07.22

    * 07eb78c Merge pull request `#25603`_ from terminalmage/issue21912

      * 99e532b Add versionadded directive

      * 8a1765f Add version_cmp function to yumpkg.py

      * 457e72e Fix refernces to __salt__['version_cmp']

      * a19fa22 Avoid using single-letter variable

    * 69ef81c Merge pull request `#25590`_ from garethgreenaway/25560_2015_5_schedule_return_data

      * 19ca0c0 Switching default in 2015.5 for whether job data in returned to the mater job_cache.

    * 9ffefc8 Merge pull request `#25584`_ from rallytime/`bp-24054`_-and-25576

      * aa9598e s3fs breaks when fetching files from s3

      * 1667d67 s3.head: return useful data

    * a966e43 Merge pull request `#25589`_ from jahamn/Fix-ssh_known_host-not-taking-port-into-account

      * 8db7ada Fixed pylint e8303 errors

      * 6abad29 Fixed pylint errors

      * 8ae6ba1 Merge branch '2015.5' of https://github.com/saltstack/salt into Fix-ssh_known_host-not-taking-port-into-account

    * df74f2c Merge pull request `#25573`_ from EvaSDK/2015.5.3-lxc-fixes

      * 49cec9f Use a more persistent tmp directory

      * 96a672f Do not execute bootstrap script twice

    * 79a809d Merge pull request `#25580`_ from attiasr/patch-1

      * 4b7dc96 use explicit utf-8 decoding (`#25532`_)

    * 6edf196 Merge pull request `#25568`_ from twangboy/fix_25206

      * fbee445 Commented out a pylint error

      * 4b56dc3 Fixed win_useradd module to add fullname

    * 3c32b0b Merge pull request `#25561`_ from twangboy/fix_21041_again

      * aaf3f3d Fixed some line and style issues

      * e6d0e5c Merge branch '2015.5' of https://github.com/saltstack/salt into fix_21041_again

    * 9e19142 Merge pull request `#25521`_ from cachedout/orch_outputter

      * ea40816 Try/except

      * dd609eb Fix outputter for state.orch

        * d67491b Removed the logger as it's not used anymore

        * 5008bfe Merge branch '2015.5' of https://github.com/saltstack/salt into fix_21041_again

        * 8b2dc68 Fixed the gem module to work on windows... without injection

              * c7466e7 Fixes ssh_known_host to take port into account

- **PR** `#25626`_: (*basepi*) Fix the highstate outputter if 'duration' is not present
  @ *2015-07-22T19:10:57Z*

  - **ISSUE** `#25368`_: (*anlutro*) salt-ssh highstate output in 2015.8
    | refs: `#25626`_
  * 0722694 Merge pull request `#25626`_ from basepi/salt.ssh.highstate.outputter.25368
  * 940c798 Fix the highstate outputter if duration is not present

- **PR** `#25601`_: (*terminalmage*) Fix error message when local bin pkg path is not absolute
  @ *2015-07-22T17:06:27Z*

  * 40e9b07 Merge pull request `#25601`_ from terminalmage/fix-error-msg
  * dcccb0d Fix error message when local bin pkg path is not absolute

- **PR** `#25595`_: (*terminalmage*) Bring git_pillar up to feature parity with gitfs
  @ *2015-07-22T16:55:14Z*

  - **ISSUE** `#24876`_: (*terminalmage*) Bring git_pillar to feature parity with gitfs
    | refs: `#25595`_
  * bc2321a Merge pull request `#25595`_ from terminalmage/git_pillar-rewrite
  * a1ffa0c More test fixes

  * b9682cc Remove unused import

  * 7319239 Test fixes

  * 4d29582 Lint fixes

  * c05b22a Remove unused imports

  * 7584f5f Remove unnecessary whitespace

  * d109fce Add git_pillar rewrite info to release notes

  * a2fc11e Add new git_pillar configuration docs

  * da5d37b Add new git_pillar code to git_pillar initialization

  * f2bf7a7 Add git_pillar to master's preflight checks

  * f3f734a Use new GitFS class for gitfs

  * 2512453 Support calling git_pillar using new config schema

  * 86d4fe2 Use new GitPillar class for git_pillar

  * f61e7c1 Add new config options for git_pillar

  * f1aec94 Move gitfs code to classes, add git_pillar support

- **PR** `#25619`_: (*cachedout*) Lint stateconf changes
  @ *2015-07-22T16:52:31Z*

  * 2d697d6 Merge pull request `#25619`_ from cachedout/lint_25578_2015_8
  * 2a45097 Lint stateconf changes

- **PR** `#25578`_: (*davidjb*) Allow parent relative includes in state files
  @ *2015-07-22T16:51:13Z*

  - **ISSUE** `#25477`_: (*davidjb*) Ability to traverse within relative includes in state files
    | refs: `#25578`_
  * 3fe4a75 Merge pull request `#25578`_ from davidjb/relative-includes
  * 9ad0ddc Allow parent relative includes in state files

- **PR** `#25610`_: (*s0undt3ch*) [2015.8] Update the bootstrap script to latest release v2015.07.22
  @ *2015-07-22T15:04:57Z*

  - **ISSUE** `#630`_: (*syphernl*) Allow for an include statement in config files
    | refs: `#25609`_ `#25610`_
  - **PR** `#627`_: (*chjohnst*) add saltversion grain
    | refs: `#25609`_ `#25610`_
  * f4ad36b Merge pull request `#25610`_ from s0undt3ch/hotfix/bootstrap-script-2015.8
  * 165f9ae Update the bootstrap script to latest release v2015.07.22

- **PR** `#25599`_: (*jfindlay*) fix transport settings in `#25596`_
  @ *2015-07-21T23:43:45Z*

  - **PR** `#25596`_: (*jfindlay*) Tcp test
    | refs: `#25599`_
  * 5c94fe3 Merge pull request `#25599`_ from jfindlay/tcp_test
  * 146e6e5 fix transport settings in 3083c71

- **PR** `#25596`_: (*jfindlay*) Tcp test
  | refs: `#25599`_
  @ *2015-07-21T22:34:56Z*

  * 89e0f15 Merge pull request `#25596`_ from jfindlay/tcp_test
  * a95353b add tcp transport to shell.key tests

  * 5dadaec add tcp transport to jenkins and runtests

  * 3083c71 add tcp transport opt to test runner

- **PR** `#25591`_: (*garethgreenaway*) Return data for scheduled jobs in 2015.8 default to True.
  @ *2015-07-21T21:53:53Z*

  - **ISSUE** `#25560`_: (*dennisjac*) scheduled highstate runs don't return results to the job cache
    | refs: `#25590`_ `#25591`_
  * 50c331c Merge pull request `#25591`_ from garethgreenaway/25560_2015_8_schedule_return_data
  * c5b94e9 Switching default in 2015.8 for whether job data in returned to the mater job_cache.

- **PR** `#25588`_: (*basepi*) Fix some of the retcode work from `#23105`_
  @ *2015-07-21T19:22:33Z*

  - **ISSUE** `#25401`_: (*anlutro*) [2015.8] salt-ssh error when module function returns string
    | refs: `#25588`_ `#25588`_
  - **ISSUE** `#23102`_: (*ngrennan-inflection*) salt-ssh doesn't have a non-zero return code on a failure.
    | refs: `#23105`_
  - **PR** `#23105`_: (*ngrennan-inflection*) Fixing return code to be "1" instead of 0 when the return code of a run is something other than 0
    | refs: `#25588`_ `#25588`_
  * 12b8fd0 Merge pull request `#25588`_ from basepi/salt.ssh.retcode.25401
  * adbdfa9 Don't use the opts_pkg retcode for all wfuncs

  * 439a279 Remove retcode from code where it (probably) doesn't matter

  * ef936c7 Handle hosts which don't return a dict

- **PR** `#25583`_: (*jtand*) Fixed lint error where pprint wasn't imported.
  @ *2015-07-21T17:36:36Z*

  * bb6974a Merge pull request `#25583`_ from jtand/softlayer_lint
  * fb27f5d Removed pprint all together

  * 8254927 Fixed lint error where pprint wasn't imported.

- **PR** `#25572`_: (*rallytime*) Back-port `#25570`_ to 2015.8
  @ *2015-07-21T17:06:40Z*

  - **PR** `#25570`_: (*rallytime*) Fix create function in OpenNebula driver
    | refs: `#25572`_
  * ff2a817 Merge pull request `#25572`_ from rallytime/`bp-25570`_
  * b213049 Pylint

  * 8ed562f Fix create function in OpenNebula driver

- **PR** `#25575`_: (*rallytime*) Make Sure Scaleway driver works with deprecation paths
  @ *2015-07-21T17:06:19Z*

  - **PR** `#25549`_: (*techhat*) Switch Scaleway to salt.utils.cloud.bootstrap()
    | refs: `#25575`_
  - **PR** `#24796`_: (*rallytime*) Deprecate using "provider" in favor of "driver" in cloud provider files
    | refs: `#24866`_ `#24867`_ `#24946`_ `#25372`_ `#25575`_
  * 760955c Merge pull request `#25575`_ from rallytime/scaleway_fix
  * f9e5317 Don't require a profile size for scaleway driver

  * faabb30 Don't stacktrace when provisioning instances with scaleway

- **PR** `#25564`_: (*basepi*) [2015.8] Merge forward from 2015.5 to 2015.8
  @ *2015-07-21T15:43:54Z*

  - **ISSUE** `#25538`_: (*stanislavb*) S3 ext_pillar configuration requires verify_ssl
    | refs: `#25554`_
  - **ISSUE** `#25532`_: (*attiasr*) salt/modules/win_pkg.py list_pkgs is broken (encoding issues)
    | refs: `#25556`_ `#25580`_
  - **ISSUE** `#25511`_: (*rallytime*) Make provider --> driver change backward compatible
    | refs: `#25519`_ `#25519`_
  - **ISSUE** `#25493`_: (*blackduckx*) Issue with job_args on schedule.add command
    | refs: `#25513`_ `#25514`_
  - **ISSUE** `#25486`_: (*whiteinge*) Highstate outputter not used for state.apply
    | refs: `#25517`_
  - **ISSUE** `#25479`_: (*alexandrsushko*) multiple mount.mounted of one device
    | refs: `#25483`_
  - **ISSUE** `#25456`_: (*julienlavergne*) [2015.8.0rc1] salt-bootstrap fails to install salt master
    | refs: `#25506`_ `#25508`_
  - **ISSUE** `#25454`_: (*mschiff*) Regression: salt 2015.5 not working in secure chroot anymore.
    | refs: `#25498`_
  - **ISSUE** `#25432`_: (*gtmanfred*) [2015.5.3][raet] raet error with SaltRaetRoadStackJoiner
    | refs: `#25525`_
  - **ISSUE** `#25431`_: (*namcois*) Digital Ocean v2 reducing API calls by adding per_page
    | refs: `#25438`_ `#25439`_
  - **ISSUE** `#25384`_: (*rickh563*) pyopenssl 0.14 requirement in 2015.5.3 does not work in RHEL6 : ZD-364
    | refs: `#25468`_
  - **ISSUE** `#25270`_: (*iggy*) [2015.8.0rc1] salt-bootstrap fails to properly install a minion
    | refs: `#25506`_ `#25508`_
  - **ISSUE** `#25250`_: (*wipfs*) 'force' option in copy state deletes target file
    | refs: `#25461`_
  - **ISSUE** `#24647`_: (*nmadhok*) salt.states.file.copy does not copy the file if it already exists with force=True
    | refs: `#25461`_
  - **ISSUE** `#23574`_: (*CedNantes*) Failed to Deploy Salt-Minion on a Win 2012 R2 using wmware Cloud Driver from Develop branch
    | refs: `#24489`_ `#25462`_ `#25519`_
  - **ISSUE** `#21041`_: (*deuscapturus*) state module gem.installed not working on Windows.
    | refs: `#25430`_ `#25561`_ `#25428`_
  - **ISSUE** `#20441`_: (*deuscapturus*) State module file.managed returns an error on Windows and test=Test
    | refs: `#25418`_
  - **ISSUE** `#1846`_: (*seanchannel*) development dependencies
  - **ISSUE** `#625`_: (*whiteinge*) `cmd.run` state `user` flag is not working
    | refs: `#25506`_ `#25508`_
  - **ISSUE** `#611`_: (*fatbox*) Peer interface fails to return data occasionally
    | refs: `#25506`_ `#25508`_
  - **ISSUE** `#607`_: (*thatch45*) next level -X support
    | refs: `#25506`_ `#25508`_
  - **ISSUE** `#598`_: (*syphernl*) Explanation on how to execute interactive installs
    | refs: `#25506`_ `#25508`_
  - **ISSUE** `#455`_: (*whiteinge*) Document common troubleshooting tips
    | refs: `#25506`_ `#25508`_
  - **PR** `#25563`_: (*basepi*) [2015.5] Merge forward from 2014.7 to 2015.5
  - **PR** `#25559`_: (*cachedout*) Lint win_pkg
  - **PR** `#25556`_: (*attiasr*) fix for `#25532`_
  - **PR** `#25554`_: (*jfindlay*) verify_ssl=True for s3 ext pillar
  - **PR** `#25551`_: (*rallytime*) Backport `#25530`_ to 2015.5
  - **PR** `#25542`_: (*Oro*) Fix hipchat.send_message when using API v2
  - **PR** `#25533`_: (*attiasr*) port 445 for windows bootstraping
  - **PR** `#25531`_: (*rallytime*) Back-port `#25529`_ to 2015.5
  - **PR** `#25530`_: (*andre-luiz-dos-santos*) The variable name must be last
    | refs: `#25551`_
  - **PR** `#25529`_: (*davidjb*) Fix minor typo in best practice example
    | refs: `#25531`_
  - **PR** `#25528`_: (*davidjb*) Fix typo in extend declaration doco
  - **PR** `#25525`_: (*gtmanfred*) add make _prepare an alias for postinitio
  - **PR** `#25519`_: (*rallytime*) Backport vmware driver to 2015.5 branch
  - **PR** `#25517`_: (*rallytime*) Back-port `#25486`_ to 2015.5
  - **PR** `#25516`_: (*rallytime*) Back-port `#25483`_ to 2015.5
  - **PR** `#25513`_: (*garethgreenaway*) fixes to schedule.add documentation in 2015.5
  - **PR** `#25506`_: (*s0undt3ch*) [2015.5] Update bootstrap script to latest stable release, v2015.07.17
  - **PR** `#25498`_: (*jfindlay*) only read /proc/1/cmdline if it exists
  - **PR** `#25487`_: (*rallytime*) Back-port `#25464`_ to 2015.5
  - **PR** `#25485`_: (*attiasr*) fix file downloads on windows
  - **PR** `#25483`_: (*alexandrsushko*) Added 'none' to the set of specialFSes
    | refs: `#25516`_
  - **PR** `#25482`_: (*oeuftete*) Fix docker.running detection of running container
  - **PR** `#25468`_: (*joejulian*) Add support for pyOpenSSL > 0.10
  - **PR** `#25467`_: (*rallytime*) Add lxml dependency to opennebula docs
  - **PR** `#25465`_: (*EvaSDK*) 2015.5.3 LXC module fixes
    | refs: `#25573`_
  - **PR** `#25464`_: (*jquast*) docfix: "cache_jobs: False" => grains_cache: False"
    | refs: `#25487`_
  - **PR** `#25461`_: (*jahamn*) Update file, if force option and content not same
  - **PR** `#25459`_: (*jahamn*) Fixed 'defulats' typo in verify.py
  - **PR** `#25457`_: (*jacksontj*) Saltnado
  - **PR** `#25438`_: (*rallytime*) Reduce digital_ocean_v2 API call frequency
    | refs: `#25439`_
  - **PR** `#25433`_: (*jleroy*) Support for IPv6 addresses scopes in network.interfaces (ifconfig)
  - **PR** `#25430`_: (*twangboy*) Disabled rbenv execution module for Windows
  - **PR** `#25427`_: (*tony-cocco*) Saltnado runner client results in blocking call despite being set-up as Runner.async
    | refs: `#25457`_
  - **PR** `#25426`_: (*jquast*) bugfix: trailing "...done" in rabbitmq output (backport from 'develop' to 2015.5)
  - **PR** `#25420`_: (*techhat*) Move S3 to use AWS Signature Version 4
  - **PR** `#25418`_: (*twangboy*) Fixed problem with file.managed test=True
  - **PR** `#25417`_: (*ahus1*) extended documentation about dependencies for dig module
  - **PR** `#25416`_: (*cachedout*) Fix broken keyword
  - **PR** `#25151`_: (*jleroy*) Support for IPv6 addresses scopes in network.interfaces
    | refs: `#25274`_ `#25433`_
  - **PR** `#2015`_: (*thekuffs*) Esky / bbfreeze support
  - **PR** `#624`_: (*chjohnst*) Docs are not correct with network.ping as args are not supported
    | refs: `#25506`_ `#25508`_
  - **PR** `#621`_: (*akoumjian*) Adding ec2 cloud-init bootstrap docs
    | refs: `#25506`_ `#25508`_
  - **PR** `#606`_: (*terminalmage*) need empty line before code blocks. added ones that were missing.
    | refs: `#25506`_ `#25508`_
  - **PR** `#602`_: (*terminalmage*) State-related documentation changes
    | refs: `#25506`_ `#25508`_
  * cf317b4 Merge pull request `#25564`_ from basepi/merge-forward-2015.8
  * 0592c4a Remove _prepare assignments

  * 76e468b Merge remote-tracking branch 'upstream/2015.5' into merge-forward-2015.8

    * 2117ac8 Merge pull request `#25563`_ from basepi/merge-forward-2015.5

      * 3bf2f1a Merge remote-tracking branch 'upstream/2014.7' into merge-forward-2015.5

      * 09ebace Merge pull request `#25416`_ from cachedout/str_2014_7

        * cc51493 Fix broken keyword

    * 50c257b Merge pull request `#25559`_ from cachedout/lint_win_pkg

      * 53a00ad Lint win_pkg

    * 7c7015c Merge pull request `#25556`_ from attiasr/patch-1

      * 9b224e8 fix for `#25532`_

    * 3c73dab Merge pull request `#25554`_ from jfindlay/verify_ssl

      * ca3ab4e verify_ssl=True for s3 ext pillar

    * e3e2e67 Merge pull request `#25551`_ from rallytime/`bp-25530`_

      * df5003d The variable name must be last

    * 3e34419 Merge pull request `#25533`_ from attiasr/patch-2

      * c7fbf68 fix windows bootstrapping

    * 7fc051f Merge pull request `#25525`_ from gtmanfred/2015.5

      * 43950a5 add make _prepare an alias for postinitio

    * 725d1a4 Merge pull request `#25519`_ from rallytime/backport_vmware

      * 35e13ee Don't reference driver in older salt versions

      * f011890 Add vmware back-port change to release notes

      * 0f4f560 Backport vmware driver to 2015.5 branch

    * 2f0d695 Merge pull request `#25542`_ from Oro/fix-hipchat-v2-sendmessage

      * 3a9f5b0 Fix hipchat.send_message when using API v2

    * 390aa7d Merge pull request `#25531`_ from rallytime/`bp-25529`_

      * 3e24381 Fix minor typo in best practice example

    * 6e811bf Merge pull request `#25528`_ from davidjb/patch-7

      * bfc4f9f Fix typo in extend declaration doco

    * b9abd72 Merge pull request `#25517`_ from rallytime/`bp-25485`_

      * 6c2f318 fix file downloads on windows

    * 9cb436f Merge pull request `#25516`_ from rallytime/`bp-25483`_

      * e0af6e3 Added 'none' to the set of specialFSes

    * daf03ef Merge pull request `#25513`_ from garethgreenaway/25493_2015_5_schedule_add_documentation

      * bc2414b Fixing documentation for schedule.add when using the job_args parameter, value needs to be be in quotes for the value to be passed in as an array.

    * 48050cd Merge pull request `#25465`_ from EvaSDK/2015.5.3-lxc-fixes

      * 170eb52 Fix use of undefined cmd when install of boostrap script fails

      * 86118f4 Install bootstrap script like dns and systemd check scripts in container

      * 978e6d5 Error out if configdir could not be created when preparing LXC container

      * 41b6c3c Fix typo in redirecting shell output to /dev/null

      * 456393d Fix DNS script cleanup

    * f85f2b4 Merge pull request `#25506`_ from s0undt3ch/hotfix/bootstrap-script

      * ab6aaa6 Update bootstrap script to latest stable release, v2015.07.17

    * c8caf40 Merge pull request `#25498`_ from jfindlay/jail_init

      * c63a6c2 only read /proc/1/cmdline if it exists

    * 3f695a1 Merge pull request `#25487`_ from rallytime/`bp-25464`_

      * e947d8e docfix: "cache_jobs: False" => grains_cache: False"

    * 331808e Merge pull request `#25482`_ from oeuftete/docker-running-is-running-`fix-2015`_-5

      * b69379b Fix docker.running detection of running container

    * 7a20ecb Merge pull request `#25468`_ from joejulian/use_pyopenssl_0_10

      * 1b7a56a Add support for pyOpenSSL > 0.10

    * d169905 Merge pull request `#25467`_ from rallytime/lxml_dep

      * d326f4f Add lxml dependency to opennebula docs

    * 8964945 Merge pull request `#25461`_ from jahamn/fixed-file.copy-force-option-deleting-files-without-updating-them

      * 32cf1eb Update file, if force option and content not same

    * 146a81b Merge pull request `#25438`_ from rallytime/do_v2

      * faf49ea Add page number change release notes

      * da6ab82 Reduce digital_ocean_v2 API call frequency

    * cb98d79 Merge pull request `#25457`_ from jacksontj/saltnado

      * bc32f66 Add runner_async endpoint to salnado

      * b043fa9 Better name of method process manager is starting

    * 3f72eb5 Merge pull request `#25459`_ from jahamn/fix-defulats-typo-in-verify.py

      * 9bafd19 Fixed 'defulats' typo in verify.py

    * 7356618 Merge pull request `#25426`_ from jquast/2015.5

      * 005a7ca bugfix: trailing "...done" in rabbitmq output

    * cfec990 Merge pull request `#25433`_ from jleroy/ipv6-scope-support-ifconfig

      * bc36d05 Support for IPv6 addresses scopes in network.interfaces (ifconfig)

    * a425230 Merge pull request `#25430`_ from twangboy/fix_21041_2

      * 242fc21 Disabled rbenv execution module for Windows

    * c4b1584 Additional test case for question raised in `#1846`_

    * 9313804 Merge pull request `#25420`_ from techhat/s3sig4

      * 3edf3a1 Linting

      * c63c235 Move S3 to use AWS Signature Version 4

    * 30a41d3 Merge pull request `#25418`_ from twangboy/fix_20441

      * d895785 Fixed problem with file.managed test=True

    * 3805677 Merge pull request `#25417`_ from ahus1/patch-1

      * 3cd194e Update dig.py

      * 287f8f7 extended documentation about dependencies

- **PR** `#25566`_: (*techhat*) Fix download process for SPM repo updates
  @ *2015-07-21T02:44:55Z*

  - **ISSUE** `#25475`_: (*gravyboat*) SPM update_repo command doesn't seem to work properly
    | refs: `#25566`_
  * 4696626 Merge pull request `#25566`_ from techhat/issue25475
  * c19fdf1 Fix download process for SPM repo updates

- **PR** `#25553`_: (*techhat*) Switch SoftLayer to salt.utils.cloud.bootstrap()
  @ *2015-07-20T22:45:10Z*

  * a836796 Merge pull request `#25553`_ from techhat/softlayerbootstrap
  * dcdc4ef Linting

  * d9863ba Switch SoftLayer to salt.utils.cloud.bootstrap()

- **PR** `#25552`_: (*techhat*) Update pricing for SoftlayerHW
  @ *2015-07-20T22:44:11Z*

  * 4393342 Merge pull request `#25552`_ from techhat/softlayerprices
  * b23cfaa Set default to 1800 as per @underscorephil

  * cd7eb97 Update pricing for SoftlayerHW

- **PR** `#25547`_: (*techhat*) Switch Parallels to salt.utils.cloud.bootstrap()
  @ *2015-07-20T22:43:47Z*

  * 0b29481 Merge pull request `#25547`_ from techhat/parallelsbootstrap
  * ae1cf65 Linting

  * a8f44d6 Switch Parallels to salt.utils.cloud.bootstrap()

- **PR** `#25548`_: (*techhat*) Switch Proxmox to salt.utils.cloud.bootstrap()
  @ *2015-07-20T19:29:25Z*

  * c6f241d Merge pull request `#25548`_ from techhat/proxmoxbootstrap
  * b799a80 Linting

  * 9f819f4 Switch Proxmox to salt.utils.cloud.bootstrap()

- **PR** `#25543`_: (*techhat*) Switch GCE to salt.utils.cloud.bootstrap()
  @ *2015-07-20T19:27:29Z*

  * 2dc601c Merge pull request `#25543`_ from techhat/gcebootstrap
  * 1b325cf Linting

  * edffb82 Switch GCE to salt.utils.cloud.bootstrap()

- **PR** `#25546`_: (*techhat*) Switch CloudStack to salt.utils.cloud.bootstrap()
  @ *2015-07-20T17:51:36Z*

  * 2240d84 Merge pull request `#25546`_ from techhat/cloudstackbootstrap
  * d8cdf2c Linting

  * 5e41991 Switch CloudStack to salt.utils.cloud.bootstrap()

- **PR** `#25558`_: (*cachedout*) Lint config_test
  @ *2015-07-20T17:19:05Z*

  * 9a046e9 Merge pull request `#25558`_ from cachedout/lint_config_test
  * 89d595f Lint config_test

- **PR** `#25515`_: (*s0undt3ch*) salt.utils.schema fixes
  @ *2015-07-20T17:17:35Z*

  * 25f910e Merge pull request `#25515`_ from s0undt3ch/2015.8
  * 7c0ad43 Another fix for flattened properties and test cases

  * 85b191c Test case to make sure plain string requirements have the same outcome

  * 6b09ec0 Fix requirements items since they broke with the previous 2 commits.

  * 6e1ee65 Test case for missing required entries when flattening Schemas

  * b2a37a3 Fix missing required entries when flattening Schemas

- **PR** `#25514`_: (*garethgreenaway*) fixes to schedule.add documentation in 2015.8
  @ *2015-07-17T17:03:41Z*

  - **ISSUE** `#25493`_: (*blackduckx*) Issue with job_args on schedule.add command
    | refs: `#25513`_ `#25514`_
  * 56d6735 Merge pull request `#25514`_ from garethgreenaway/25493_2015_8_schedule_add_documentation
  * 188015c Fixing documentation for schedule.add when using the job_args parameter, value needs to be be in quotes for the value to be passed in as an array.

- **PR** `#25508`_: (*s0undt3ch*) [2015.8] Update bootstrap script to latest stable release, v2015.07.17
  @ *2015-07-17T15:40:54Z*

  - **ISSUE** `#25456`_: (*julienlavergne*) [2015.8.0rc1] salt-bootstrap fails to install salt master
    | refs: `#25506`_ `#25508`_
  - **ISSUE** `#25270`_: (*iggy*) [2015.8.0rc1] salt-bootstrap fails to properly install a minion
    | refs: `#25506`_ `#25508`_
  - **ISSUE** `#625`_: (*whiteinge*) `cmd.run` state `user` flag is not working
    | refs: `#25506`_ `#25508`_
  - **ISSUE** `#611`_: (*fatbox*) Peer interface fails to return data occasionally
    | refs: `#25506`_ `#25508`_
  - **ISSUE** `#607`_: (*thatch45*) next level -X support
    | refs: `#25506`_ `#25508`_
  - **ISSUE** `#598`_: (*syphernl*) Explanation on how to execute interactive installs
    | refs: `#25506`_ `#25508`_
  - **ISSUE** `#455`_: (*whiteinge*) Document common troubleshooting tips
    | refs: `#25506`_ `#25508`_
  - **PR** `#624`_: (*chjohnst*) Docs are not correct with network.ping as args are not supported
    | refs: `#25506`_ `#25508`_
  - **PR** `#621`_: (*akoumjian*) Adding ec2 cloud-init bootstrap docs
    | refs: `#25506`_ `#25508`_
  - **PR** `#606`_: (*terminalmage*) need empty line before code blocks. added ones that were missing.
    | refs: `#25506`_ `#25508`_
  - **PR** `#602`_: (*terminalmage*) State-related documentation changes
    | refs: `#25506`_ `#25508`_
  * 1200d9d Merge pull request `#25508`_ from s0undt3ch/hotfix/bootstrap-script-2015.8
  * e7a5235 Update bootstrap script to latest stable release, v2015.07.17

- **PR** `#25501`_: (*basepi*) Add optional job end time to the local_cache returner
  @ *2015-07-17T15:33:52Z*

  - **ISSUE** `#23563`_: (*ssgward*) Master Job Cache: add finish time for job runs
    | refs: `#25501`_
  * 77738f6 Merge pull request `#25501`_ from basepi/job.cache.finish.time.23563
  * b8c687d More stupid fixes

  * b3134d8 Add update_endtime functionality to salt.utils.job.store_job

  * 9ed805d More fixes

  * 6598b60 Something weird going on with __opts__

  * 747ccaa Fix copy pasta

  * 1c8f96f Add endtime functionality to job runner and more to local_cache

  * baec3f6 Add endtime functions to local cache, fix function call in masterapi.py

  * ce64266 Add new config values for job end time

  * 72bd62b Only store endtime if supported and configured as such

  * f1d49d8 Add starttime and endtime to job_cache returns

- **PR** `#25491`_: (*s0undt3ch*) Let's call it for what it is!
  @ *2015-07-16T18:57:32Z*

  * cef7461 Merge pull request `#25491`_ from s0undt3ch/2015.8
  * 393a211 Rename the module

  * 42bfec8 Let's call it for what it is!

- **PR** `#25462`_: (*rallytime*) Wrap is_profile_configrured calls in try/except block
  @ *2015-07-15T20:22:42Z*

  - **ISSUE** `#23574`_: (*CedNantes*) Failed to Deploy Salt-Minion on a Win 2012 R2 using wmware Cloud Driver from Develop branch
    | refs: `#24489`_ `#25462`_ `#25519`_
  * 721ece3 Merge pull request `#25462`_ from rallytime/protect_profile_config_check
  * 0df667b Add a few more drivers that don't require a profile size to non_size_drivers list

  * 2c01ef7 Wrap is_profile_configured calls in try/except blocks

- **PR** `#25439`_: (*rallytime*) Reduce digital_ocean API call frequency
  @ *2015-07-15T19:40:24Z*

  - **ISSUE** `#25431`_: (*namcois*) Digital Ocean v2 reducing API calls by adding per_page
    | refs: `#25438`_ `#25439`_
  - **PR** `#25438`_: (*rallytime*) Reduce digital_ocean_v2 API call frequency
    | refs: `#25439`_
  * 4f91f5b Merge pull request `#25439`_ from rallytime/`fix-25431`_
  * 7138f36 Add page number change to release notes

  * 8e27d06 Reduce digital_ocean API call frequency

- **PR** `#25451`_: (*s0undt3ch*) Salt-SSH Scan roster bugfixes (And Py3 support)
  @ *2015-07-15T15:00:29Z*

  * 7d4aee7 Merge pull request `#25451`_ from s0undt3ch/2015.8
  * 8e8c1af How did this ever worked!?

  * d147267 Add `ipaddress` to `salt._compat`

  * 6957005 Python 3 compatibility

- **PR** `#25449`_: (*ruzarowski*) Exclude dotfiles and directories from minion key lists (Fixes `#25448`_)
  @ *2015-07-15T14:37:10Z*

  - **ISSUE** `#25448`_: (*ruzarowski*) Dotfiles and directories in minion key directories are treated as authenticated minion ids (PR`#25449`_)
    | refs: `#25449`_
  * 279d0f1 Merge pull request `#25449`_ from ruzarowski/2015.8-minion_keys_exclude_dotfiles_and_dirs
  * b02f77a Exclude dot-files and directories from minion key listings and minion lists based on authenticated key names

  * 5420181 Merge remote-tracking branch 'upstream/2015.8' into 2015.8

- **PR** `#25421`_: (*basepi*) [2015.8] Merge forward from 2015.5 to 2015.8
  @ *2015-07-14T21:44:15Z*

  - **PR** `#25411`_: (*basepi*) [2015.5] Merge forward from 2014.7 to 2015.5
  - **PR** `#25375`_: (*cachedout*) Fix error in config.py for master_type
  - **PR** `#25324`_: (*jacobhammons*) Latest help theme updates
  * 0b4ca8d Merge pull request `#25421`_ from basepi/merge-forward-2015.8
  * b222d4b Merge remote-tracking branch 'upstream/2015.5' into merge-forward-2015.8

  * 4d92907 Merge pull request `#25411`_ from basepi/merge-forward-2015.5

    * 33d2451 Merge remote-tracking branch 'upstream/2014.7' into merge-forward-2015.5

    * 2a1dd11 Merge pull request `#25375`_ from cachedout/config_fix_2014_7

      * c041f29 Fix error in config.py for master_type

    * 2590e23 Merge pull request `#25324`_ from jacobhammons/doc-theme-updates

      * 88f5fcf Latest help theme updates

- **PR** `#25412`_: (*basepi*) [2015.8] Merge forward from 2015.5 to 2015.8
  @ *2015-07-14T18:01:05Z*

  - **ISSUE** `#25337`_: (*eliasp*) `salt-call` from non-existend cwd backtraces
    | refs: `#25379`_
  - **ISSUE** `#25320`_: (*podloucky-init*) zypper module list_upgrades broken (2015.5.2)
    | refs: `#25334`_
  - **ISSUE** `#25281`_: (*shinshenjs*) Unless usage in Official Doc syntax error?
  - **ISSUE** `#25277`_: (*jacobhammons*) CherryPy recommended versions
    | refs: `#25279`_
  - **ISSUE** `#25268`_: (*lichtamberg*) Salt not working anymore in 2015.8/develop: ValueError: 'scope' is not in list
    | refs: `#25274`_
  - **ISSUE** `#24827`_: (*yermulnik*) locale.present doesn't generate locales
    | refs: `#25309`_
  - **ISSUE** `#24520`_: (*nvx*) Tomcat module fails to extract version number from snapshot builds (2015.5 regression)
    | refs: `#24927`_
  - **ISSUE** `#24444`_: (*michaelkrupp*) file.managed does not handle dead symlinks
    | refs: `#25383`_
  - **ISSUE** `#24433`_: (*chrimi*) Salt locale state fails, if locale has not been generated
    | refs: `#25290`_
  - **ISSUE** `#22241`_: (*masterkorp*) Salt master not properly generating the map
    | refs: `#25358`_
  - **ISSUE** `#19288`_: (*oba11*) AssociatePublicIpAddress doesnt work with salt-cloud 2014.7.0
    | refs: `#20972`_ `#25326`_
  - **ISSUE** `#18808`_: (*amendlik*) Add command line argument to select pillar environment
    | refs: `#23926`_ `#25238`_
  - **ISSUE** `#13943`_: (*Supermathie*) Powershell commands that expect input hang forever
    | refs: `#25299`_
  - **PR** `#25408`_: (*rallytime*) Back-port `#25399`_ to 2015.5
  - **PR** `#25406`_: (*anlutro*) Force arguments to aptpkg.version_cmp into strings
  - **PR** `#25399`_: (*jarpy*) Demonstrate per-minion client_acl.
    | refs: `#25408`_
  - **PR** `#25398`_: (*twangboy*) Fix date
  - **PR** `#25397`_: (*GideonRed*) Introduce standard error output when cli exits with non-zero status
  - **PR** `#25395`_: (*rallytime*) Back-port `#25389`_ to 2015.5
  - **PR** `#25392`_: (*rallytime*) Back-port `#25256`_ to 2015.5
  - **PR** `#25389`_: (*l2ol33rt*) Adding entropy note for gpg renderer
    | refs: `#25395`_
  - **PR** `#25386`_: (*cachedout*) Lint `#25383`_
  - **PR** `#25383`_: (*jahamn*) Fix manage_file function in salt/modules/file.py to handle broken sym…
  - **PR** `#25379`_: (*jfindlay*) check for cwd before getting it
  - **PR** `#25369`_: (*anlutro*) Fix aptpkg.version_cmp
  - **PR** `#25358`_: (*dkiser*) Deep merge of pillar lists
  - **PR** `#25350`_: (*davidjb*) Fix documentation for file.blockreplace
  - **PR** `#25346`_: (*bechtoldt*) set correct indention in states/requisites.rst (docs), fixes `#25281`_
  - **PR** `#25339`_: (*jfindlay*) update orchestration docs
  - **PR** `#25336`_: (*terminalmage*) Don't try to read init binary if it wasn't found
  - **PR** `#25334`_: (*jfindlay*) return all cmd info back to zypper fcn
  - **PR** `#25328`_: (*rallytime*) Back-port `#25309`_ to 2015.5
  - **PR** `#25327`_: (*rallytime*) Back-port `#25290`_ to 2015.5
  - **PR** `#25326`_: (*rallytime*) Back-port `#20972`_ to 2015.5
  - **PR** `#25322`_: (*jacobhammons*) version change to 2015.5.3
  - **PR** `#25309`_: (*davidjb*) Format /etc/locale.gen correctly in salt.modules.localemod.gen_locale
    | refs: `#25328`_
  - **PR** `#25308`_: (*jacksontj*) Make clear commands trace level logging
  - **PR** `#25301`_: (*jacobhammons*) bug fix for module function display in help
  - **PR** `#25299`_: (*twangboy*) Added -NonInteractive so powershell doesn't hang waiting for input
  - **PR** `#25290`_: (*pcdummy*) Simple fix for locale.present on Ubuntu.
    | refs: `#25327`_
  - **PR** `#25279`_: (*jacobhammons*) Additional docs on external and master job cache, assorted doc fixes
  - **PR** `#25274`_: (*jleroy*) Fix for issue `#25268`_
  - **PR** `#25272`_: (*twangboy*) Fixed problem with service not starting
  - **PR** `#25269`_: (*jfindlay*) Extract tomcat war version
  - **PR** `#25256`_: (*yanatan16*) Dont assume source_hash exists
    | refs: `#25392`_
  - **PR** `#25240`_: (*tankywoo*) file make os.walk only be called one
  - **PR** `#25238`_: (*DmitryKuzmenko*) Pillarenv backport 2015.5
  - **PR** `#25151`_: (*jleroy*) Support for IPv6 addresses scopes in network.interfaces
    | refs: `#25274`_ `#25433`_
  - **PR** `#24927`_: (*egarbi*) Tomcat module fails to extract version number from snapshot builds `#2`_…
    | refs: `#25269`_
  - **PR** `#24737`_: (*jacksontj*) Move AES command logging to trace
    | refs: `#25308`_
  - **PR** `#23719`_: (*DmitryKuzmenko*) Support pillarenv cmdline in state.sls
  - **PR** `#20972`_: (*JohannesEbke*) Fix interface cleanup when using AssociatePublicIpAddress in `#19288`_
    | refs: `#25326`_
  * 8af30ce Merge pull request `#25412`_ from basepi/merge-forward-2015.8
  * 2a144b9 Merge remote-tracking branch 'upstream/2015.5' into merge-forward-2015.8

    * 81bed62 Merge pull request `#25406`_ from alprs/fix-apt_version_cmp_types

      * d56efd1 force arguments to apt_pkg.version_compare into strings

    * cd9ea63 Merge pull request `#25408`_ from rallytime/`bp-25399`_

      * da9c0eb Typo in client_acl ref doc.

      * 50e0baf Demonstrate per-minion client_acl.

    * ef9f6b0 Merge pull request `#25240`_ from tankywoo/fix-files-os-walk-multiple-times

      * 8044def file make os.walk only be called one

    * d02f388 Merge pull request `#25395`_ from rallytime/`bp-25389`_

      * a086e5a Adding entropy note

    * 008e329 Merge pull request `#25392`_ from rallytime/`bp-25256`_

      * 6b2da4d Dont assume source_hash exists

    * 3f27896 Merge pull request `#25398`_ from twangboy/fix_date

      * 52824f9 Added /V1 /Z to remove scheduled task after run

      * a055cca Changed date of scheduled task to work in other locales

    * 978d9f7 Merge pull request `#25397`_ from GideonRed/2015.5

      * ea7ab27 Introduce standard error output when cli exits with non-zero status

    * 09442ab Merge pull request `#25386`_ from cachedout/lint_25383

      * 7694299 Lint `#25383`_

    * 47bcc61 Merge pull request `#25383`_ from jahamn/Fix-file.managed_not_handling_dead_symlinks

      * ab17aa1 Fix manage_file function in salt/modules/file.py to handle broken symlinks

    * c9fe10e Merge pull request `#25369`_ from alprs/fix-apt_version_cmp

      * 6391b15 fix aptpkg.version_cmp

    * beb0238 Merge pull request `#25379`_ from jfindlay/check_wd

      * 6e4547f check for cwd before getting it

    * 274622a Merge pull request `#25334`_ from jfindlay/fix_zyp

      * c1e6339 return all cmd info back to zypper fcn

    * 71859c6 Merge pull request `#25339`_ from jfindlay/orch_doc

      * 0447808 clarify, motivate orchestration docs

    * 90a1ca0 Merge pull request `#25358`_ from dkiser/22241_pillar_merge_lists

      * d030e28 Deep merge of pillar lists

    * 66c619f Merge pull request `#25346`_ from bechtoldt/issue25281

      * 8eb2ac1 set correct indention in states/requisites.rst (docs), fixes `#25281`_

    * b122ed9 Merge pull request `#25336`_ from terminalmage/fix-init-grain

      * f473918 Don't try to read init binary if it wasn't found

    * 1805baf Merge pull request `#25350`_ from davidjb/patch-4

      * e13a9fd Fix documentation for file.blockreplace

    * b0196fc Merge pull request `#25326`_ from rallytime/`bp-20972`_

      * 51c941f Also fix cleanup of interfaces when using AssociatePublicIpAddress in `#19288`_

    * 28450d1 Merge pull request `#25327`_ from rallytime/`bp-25290`_

      * 20032c5 Simple fix for locale.present on Ubuntu.

    * 8f666a2 Merge pull request `#25328`_ from rallytime/`bp-25309`_

      * 44d44ec Format /etc/locale.gen correctly on gen_locale

    * 0a33a1d Merge pull request `#25322`_ from jacobhammons/release-2015.5.3

      * 19f8892 version change to 2015.5.3

    * 2f0f59b Merge pull request `#25308`_ from jacksontj/2015.5

      * 60fc770 Make clear commands trace level logging

    * 9b6646d Merge pull request `#25269`_ from jfindlay/tomcat

      * fd4fca1 consolidate tomcat exec and state version extract

      * 59dc833 update tomcat war_deployed state tests

      * edca458 Fixed 2 blank lines around import re

      * 7e528d1 Tomcat module fails to extract version number from snapshot builds `#24520`_

    * 0f82ac3 Merge pull request `#25238`_ from DSRCompany/pillarenv_backport_2015.5

      * 98792eb Pillarenv support in minion config, cp and cmdmod modules.

      * 88ff576 Support pillarenv cmdline in state.sls. Backport of PR `#23719`_

    * 219d4ca Merge pull request `#25299`_ from twangboy/fix_13943

      * c058890 Added -NonInteractive so powershell doesn't hang waiting for input

    * 1c43892 Merge pull request `#25301`_ from jacobhammons/doc-bugs

      * f656128 bug fix for module function display in help

    * 68149bc Merge pull request `#25279`_ from jacobhammons/job-cache-docs

      * 57dfa92 Fixed typos

      * 2f9e5b9 Additional docs on external and master job cache, assorted doc fixes Refs `#25277`_

    * 972fa2f Merge pull request `#25274`_ from jleroy/25268-fix

      * 2c698d2 Fix for issue `#25268`_

    * 8ebb73d Merge pull request `#25272`_ from twangboy/service

      * e61eeba Fixed problem with service not starting

- **PR** `#25415`_: (*bechtoldt*) [docs] declare YAML as code block
  @ *2015-07-14T17:11:59Z*

  * a3d84eb Merge pull request `#25415`_ from bechtoldt/elastic_docs
  * 79547c8 declare YAML as code block

- **PR** `#25407`_: (*rallytime*) Back-port `#23236`_ to 2015.8
  @ *2015-07-14T16:09:21Z*

  - **ISSUE** `#24612`_: (*cachedout*) Tornado IPC in master publisher
    | refs: `#23236`_
  - **PR** `#23236`_: (*cachedout*) Remove ZeroMQ dependency from master publisher
    | refs: `#25407`_
  * bd7c71e Merge pull request `#25407`_ from rallytime/`bp-23236`_
  * 8faa49a IPC transport skeleton

- **PR** `#25409`_: (*rallytime*) Back-port `#24422`_ to 2015.8
  @ *2015-07-14T16:08:49Z*

  - **ISSUE** `#23125`_: (*bemeyert*) Elasticsearch as master_job_cache throws critical
    | refs: `#24422`_
  - **ISSUE** `#22004`_: (*bechtoldt*) Provide elasticsearch state module
    | refs: `#24422`_
  - **ISSUE** `#21881`_: (*bechtoldt*) Improve elasticsearch returner
    | refs: `#24422`_
  - **ISSUE** `#20826`_: (*clinta*) Elasticsearch Returner "trying to serialize a value with no field associated with it"
    | refs: `#24422`_
  - **PR** `#24422`_: (*bechtoldt*) Refactor Elasticsearch integration
    | refs: `#25409`_
  * 334eafa Merge pull request `#25409`_ from rallytime/`bp-24422`_
  * a0130f5 Update Beryllium refs to 2015.8.0

  * 6fc8714 remove log entry that was used for debugging only

  * a12e287 improve profile mgmt

  * 8de1d23 raise exception in modules.elasticsearch when connection to ES cluster failed

  * 2676d84 refactor elasticsearch integration * salt.modules.elasticsearch * salt.states.elasticsearch* * salt.returners.elasticsearch

  * 7bb074c remove log entry that was used for debugging only

  * a4d1d24 improve profile mgmt

  * fd564b8 raise exception in modules.elasticsearch when connection to ES cluster failed

  * 3e2edd3 refactor elasticsearch integration * salt.modules.elasticsearch * salt.states.elasticsearch* * salt.returners.elasticsearch

- **PR** `#25394`_: (*rallytime*) Back-port `#25355`_ to 2015.8
  @ *2015-07-14T03:26:26Z*

  - **PR** `#25355`_: (*kaidokert*) EC2 cloud: Fix another availability zone mismatch
    | refs: `#25394`_
  * 17daf76 Merge pull request `#25394`_ from rallytime/`bp-25355`_
  * 9f1d4ab EC2 cloud: Fix another availability zone mismatch, preventing cloud.profile state from working correctly

- **PR** `#25393`_: (*rallytime*) Back-port `#25289`_ to 2015.8
  @ *2015-07-14T03:25:34Z*

  - **PR** `#25289`_: (*krak3n*) Fix: Boto SNS - Auth Basic Endpoint Compare
    | refs: `#25393`_
  * 2b5c2b3 Merge pull request `#25393`_ from rallytime/`bp-25289`_
  * 49becde Fixing lint error

  * 68fef7a Comment spelling corrections - thx @jackqu7

  * ffddb94 Allow auth basic subscriptions to be checked against existing subscriptions

- **PR** `#25387`_: (*cachedout*) Lint `#25319`_
  @ *2015-07-13T21:22:14Z*

  - **PR** `#25319`_: (*ruzarowski*) [cloud:EC2] Move SourceDest logic to _update_enis and add  alias for delete_interface_on_terminate
  * c02ab4d Merge pull request `#25387`_ from cachedout/lint_25319
  * 50ac0e2 Lint `#25319`_

- **PR** `#25319`_: (*ruzarowski*) [cloud:EC2] Move SourceDest logic to _update_enis and add  alias for delete_interface_on_terminate
  @ *2015-07-13T21:19:18Z*

  * 88f4e68 Merge pull request `#25319`_ from ruzarowski/2015.8-Move-SourceDestCheck-logic-to-_update_enis-to-make-it-work-with-prealloc-enis
  * d9389ba Merge remote-tracking branch 'upstream/2015.8' into 2015.8-Move-SourceDestCheck-logic-to-_update_enis-to-make-it-work-with-prealloc-enis

  * 4eba749 Merge branch '2015.8-Move-SourceDestCheck-logic-to-_update_enis-to-make-it-work-with-prealloc-enis' of github.com:ruzarowski/salt into 2015.8-Move-SourceDestCheck-logic-to-_update_enis-to-make-it-work-with-prealloc-enis

    * 50016f2 Merge branch '2015.8-Move-SourceDestCheck-logic-to-_update_enis-to-make-it-work-with-prealloc-enis' of github.com:ruzarowski/salt into 2015.8-Move-SourceDestCheck-logic-to-_update_enis-to-make-it-work-with-prealloc-enis

      * 5d6bcf6 Fix CopyPaste error

      * fb93dd1 Fix lint errors

      * 01dd2e0 [cloud:EC2] Move SourceDest logic to _update_enis and add DeleteOnTermination alias for delete_interface_on_terminate

    * 1ee4e48 Fix CopyPaste error

    * 0489062 Fix lint errors

    * 25272fe [cloud:EC2] Move SourceDest logic to _update_enis and add DeleteOnTermination alias for delete_interface_on_terminate

  * 66f2ab5 [cloud:EC2] Move SourceDest logic to _update_enis and add DeleteOnTermination alias for delete_interface_on_terminate

  * 95aca7a Fix CopyPaste error

  * d80fc02 Fix lint errors

  * 7389619 [cloud:EC2] Move SourceDest logic to _update_enis and add DeleteOnTermination alias for delete_interface_on_terminate

  * d319038 Fix AttributeError in fileserver update_opts, as some func objects passed into loop do not have the func_globals attribute

- **PR** `#25310`_: (*anlutro*) Add an "is list" test to the jinja environment
  @ *2015-07-13T18:41:16Z*

  * 601607f Merge pull request `#25310`_ from alprs/feature-jinja_is_list
  * e355b33 add an "is list" test to the jinja environment

              * 1ce48b1 Merge branch '2015.8' of https://github.com/saltstack/salt into 2015.8

- **PR** `#25264`_: (*ruzarowski*) Fix AttributeError in fileserver update_opts
  @ *2015-07-13T17:15:43Z*

  - **ISSUE** `#25259`_: (*ruzarowski*) AttributeError in fileserver update_opts()
    | refs: `#25264`_
  * f64b32b Merge pull request `#25264`_ from ruzarowski/2015.8-Fileserver-update_opts
  * 7873d9e Fix AttributeError in fileserver update_opts, as some func objects passed into loop do not have the func_globals attribute

- **PR** `#25372`_: (*rallytime*) Don't stacktrace when provisioning instances with softlayer* drivers
  @ *2015-07-13T16:15:09Z*

  - **ISSUE** `#25228`_: (*geraint-jones-nz*) Salt-cloud fails on Softlayer due to 'size' being mandatory
    | refs: `#25278`_ `#25372`_
  - **PR** `#24796`_: (*rallytime*) Deprecate using "provider" in favor of "driver" in cloud provider files
    | refs: `#24866`_ `#24867`_ `#24946`_ `#25372`_ `#25575`_
  * ae7138f Merge pull request `#25372`_ from rallytime/`fix-25228`_-provider
  * b9bf530 Don't stacktrace when provisioning instances on softlayer_hw

  * 60391c9 Don't stacktrace when provisioning instances on softlayer

- **PR** `#25315`_: (*ruzarowski*) [cloud:EC2] Move handling of AssociatePublicIpAddress to associate_eip/allocate_new_eip logic depending on value type
  @ *2015-07-13T14:38:47Z*

  * 0a0f8b0 Merge pull request `#25315`_ from ruzarowski/2015.8-EC2-ENI-Move-handling-of-AssociatePublicIpAddress-to-associate_eip-allocate_new_eip-logic
  * 2506585 Use already allocated variable instead of calling getter twice

  * 4d1fb45 [cloud:EC2] Move handling of AssociatePublicIpAddress to associate_eip/allocate_new_eip logic depending on value type

- **PR** `#25312`_: (*ruzarowski*) [cloud:EC2] Introduce eni Name property to set name tag value after its creation
  @ *2015-07-13T14:37:46Z*

  * e5d7ba0 Merge pull request `#25312`_ from ruzarowski/2015.8-Introduce-eni-Name-property-to-set-name-tag-value-after-its-creation
  * 47ba4f2 Do not raise if NAme Tag of eni cannot be set, log.error instead

  * ec6e017 Introduce eni Name property to set name tag value after its creation

- **PR** `#25311`_: (*ruzarowski*) [cloud:EC2] Add ability to attach an existing eni
  @ *2015-07-13T14:37:18Z*

  * b16d86a Merge pull request `#25311`_ from ruzarowski/2015.8-Add-ability-to-attach-existing-interface
  * 2c72bd8 Add ability to attach an existing eni

- **PR** `#25280`_: (*rallytime*) Remove deprecation warnings for Beryllium
  @ *2015-07-13T09:46:42Z*

  * 2fe94b7 Merge pull request `#25280`_ from rallytime/beryllium_deprecations
  * c581160 Put two boto_vpc functions on deprecation paths with warnings

  * 805041d Put data.getval and data.getvals on deprecation path with a warning

  * 7795670 Remove Beryllium Deprecation Warnings

  * 2b7d876 Put network.ip_in_subnet on deprecation path with a warning

- **PR** `#25329`_: (*twangboy*) Fixed some documentation errors
  @ *2015-07-10T18:24:13Z*

  * 49fe23f Merge pull request `#25329`_ from twangboy/wua_documentation
  * 821595e Fixed some documentation errors

- **PR** `#25300`_: (*s0undt3ch*) Fix ordering issue & Added requirements support
  @ *2015-07-10T10:15:38Z*

  * 3b3dc78 Merge pull request `#25300`_ from s0undt3ch/features/raas-17-salt-cloud-2015.8
  * 1388010 Remove hardcoded maxDiff

  * 3adb731 Fixed ordering issue

  * cf071ea Add test which asserts proper field ordering

  * 0fdfd5f Preserve item order if a configuration block is to be flatten

  * 665c201 Add `RequirementsItem` which will allow conditional requirements in the configuration class

- **PR** `#25283`_: (*jfindlay*) ensure ret is always defined
  @ *2015-07-10T01:29:25Z*

  * 4eb62e3 Merge pull request `#25283`_ from jfindlay/win_user
  * 9dbd6d8 ensure ret is always defined

- **PR** `#25252`_: (*jfindlay*) make args optional with default values in win_firewall.delete_rule
  @ *2015-07-10T01:27:50Z*

  * a2860cb Merge pull request `#25252`_ from jfindlay/win_fire
  * bba556c win_firewall exec mod optional args in delete_rule

  * 36f2af6 single quote win_firewall exec module

- **PR** `#25257`_: (*notpeter*) Document SourceDestCheck added in `#25242`_.
  @ *2015-07-09T23:29:48Z*

  - **ISSUE** `#25241`_: (*ruzarowski*) salt-cloud: SourceDestCheck flag not passed to AWS, provisioning NAT instances needs that
    | refs: `#25242`_
  - **PR** `#25242`_: (*ruzarowski*) Make SourceDestCheck flag available to network interface definition
  * cd405b4 Merge pull request `#25257`_ from notpeter/SourceDestCheck
  * 72323fc Document SourceDestCheck added in `#25242`_.

- **PR** `#25298`_: (*twangboy*) Continue if profile not found
  @ *2015-07-09T22:38:32Z*

  - **ISSUE** `#25275`_: (*twangboy*) user.absent fails in 2015.8 branch when purge=True
    | refs: `#25298`_
  * fb717d3 Merge pull request `#25298`_ from twangboy/fix_25275
  * 0e29607 More lint (removed import os)

  * dc00492 Fixed some lint

  * b71695a Continue if profile not found

- **PR** `#25296`_: (*twangboy*) Fixed file.comment for windows
  @ *2015-07-09T21:08:02Z*

  - **ISSUE** `#25294`_: (*twangboy*) file.comment fails in 2015.8 branch
    | refs: `#25296`_
  - **ISSUE** `#25054`_: (*twangboy*) Develop: Passed invalid arguments: string indices must be integers, not str
    | refs: `#25296`_
  * 0a7ec11 Merge pull request `#25296`_ from twangboy/fix_25294
  * b4380c0 Fixed some lint

  * d726bb4 Fixed file.comment for windows

- **PR** `#25254`_: (*rallytime*) Change versionadded/changed references from Beryllium to 2015.8.0
  @ *2015-07-09T21:01:15Z*

  * 58ca83c Merge pull request `#25254`_ from rallytime/change_beryllium_refs
  * 1b7efa9 Remove references to Beryllium in relevant docs

  * 588d4e1 More Beryllium references changed to 2015.8.0

  * b24911a More Beryllium --> 2015.8.0 version reference changes

  * abfae94 Started changing Beryllium references to 2015.8.0

- **PR** `#25285`_: (*thusoy*) Remove error logging of missing victorops keys
  @ *2015-07-09T15:10:48Z*

  * fa13f3e Merge pull request `#25285`_ from thusoy/patch-3
  * 3a8ad1e Remove error logging of missing victorops keys

- **PR** `#25266`_: (*ruzarowski*) cloud: EC2 eni property SourceDestCheck is a AttributeBooleanValue
  @ *2015-07-09T13:29:07Z*

  - **ISSUE** `#25265`_: (*ruzarowski*) cloud: Fix EC2 SourceDestCheck eni attribute Value
    | refs: `#25266`_
  * 06347f3 Merge pull request `#25266`_ from ruzarowski/2015.8-SourceDestCheck
  * 54f2bbe Fix pylint warnings in cloud/clouds/ec2.py

  * 2be0b54 cloud: EC2 Interface property SourceDestCheck is a AttributeBooleanValue (SourceDestCheck.Value=<bool>) at the API

- **PR** `#25216`_: (*jfindlay*) replace shell code with native python code
  @ *2015-07-09T09:58:44Z*

  - **PR** `#25201`_: (*ajacoutot*) OpenBSD: service.enable needs python_shell=true
    | refs: `#25216`_
  * 718c874 Merge pull request `#25216`_ from jfindlay/bsd_srv
  * ffe3a37 replace shell code with native python code

- **PR** `#25278`_: (*rallytime*) Don't require size for all cloud drivers when checking profile configs
  @ *2015-07-09T02:52:23Z*

  - **ISSUE** `#25228`_: (*geraint-jones-nz*) Salt-cloud fails on Softlayer due to 'size' being mandatory
    | refs: `#25278`_ `#25372`_
  * e078a6d Merge pull request `#25278`_ from rallytime/`fix-25228`_
  * 3579709 Use a better variable name

  * d60176b Don't require size for all cloud drivers when checking profile configs

- **PR** `#25271`_: (*basepi*) [2015.8] Merge forward from 2015.5 to 2015.8
  @ *2015-07-09T00:59:34Z*

  - **ISSUE** `#25223`_: (*nmadhok*) Runner occasionally fails with a RuntimeError when fired by a reactor
    | refs: `#25225`_ `#25226`_
  - **ISSUE** `#25016`_: (*martinhoefling*) salt-run doc.execution fails with AttributeError
  - **ISSUE** `#24301`_: (*iggy*) influxdb_user and influxdb_database states need virtual functions
    | refs: `#25059`_
  - **ISSUE** `#24272`_: (*rallytime*) Fix boto_vpc_test moto version check
    | refs: `#25194`_
  - **ISSUE** `#23822`_: (*sidcarter*) Zip file extracted permissions are incorrect
    | refs: `#25128`_
  - **ISSUE** `#21879`_: (*bechtoldt*) Reference pages in documentation are outdated again
    | refs: `#25019`_
  - **ISSUE** `#19262`_: (*bechtoldt*) salt.pillar.file_tree doesn't appear in the documentation
    | refs: `#25019`_
  - **ISSUE** `#18919`_: (*giner*) Windows: pkg.refresh_db returns false-positive success
    | refs: `#25196`_
  - **PR** `#25225`_: (*nmadhok*) Backporting fix for issue `#25223`_ on 2015.5 branch
  - **PR** `#25214`_: (*rallytime*) A couple of doc fixes for the http tutorial
  - **PR** `#25205`_: (*basepi*) Update releasecandidate docs
  - **PR** `#25196`_: (*twangboy*) Fixed `#18919`_ false-positive on pkg.refresh
  - **PR** `#25194`_: (*rallytime*) Update moto version check in boto_vpc_test and update min version
  - **PR** `#25191`_: (*basepi*) Add extrndest back to fileclient.is_cached in 2015.5
  - **PR** `#25187`_: (*UtahDave*) Doc fixes: Fix misspelling and remove extraneous double spaces
  - **PR** `#25185`_: (*rallytime*) Back-port `#25128`_ to 2015.5
  - **PR** `#25182`_: (*cachedout*) Try to re-pack long floats as strs
  - **PR** `#25181`_: (*rallytime*) Back-port `#25102`_ to 2015.5
  - **PR** `#25180`_: (*rallytime*) Back-port `#25088`_ to 2015.5
  - **PR** `#25179`_: (*rallytime*) Back-port `#25059`_ to 2015.5
  - **PR** `#25175`_: (*rallytime*) Back-port `#25020`_ to 2015.5
  - **PR** `#25173`_: (*rallytime*) Partial back-port of `#25019`_
  - **PR** `#25171`_: (*rallytime*) Back-port `#25001`_ to 2015.5
  - **PR** `#25128`_: (*stanislavb*) Use cmd_unzip to preserve permissions
    | refs: `#25185`_
  - **PR** `#25117`_: (*basepi*) Fix fileclient.is_cached
    | refs: `#25191`_
  - **PR** `#25102`_: (*derBroBro*) Update win_network.py
    | refs: `#25181`_
  - **PR** `#25088`_: (*supertom*) Update
    | refs: `#25180`_
  - **PR** `#25059`_: (*babilen*) Add virtual functions to influxdb state modules
    | refs: `#25179`_
  - **PR** `#25020`_: (*martinhoefling*) Fix for issue `#25016`_
    | refs: `#25175`_
  - **PR** `#25019`_: (*bechtoldt*) add missing module documentation to references
    | refs: `#25173`_
  - **PR** `#25001`_: (*jasonkeene*) Add docs for key arg in ssh_known_hosts.present
    | refs: `#25171`_
  - **PR** `#24421`_: (*bechtoldt*) add missing module documentation
    | refs: `#25019`_
  - **PR** `#21880`_: (*bechtoldt*) update references, fixes `#21879`_
    | refs: `#25019`_
  - **PR** `#20039`_: (*bechtoldt*) completing some doc references
    | refs: `#25019`_
  * 84ce602 Merge pull request `#25271`_ from basepi/merge-forward-2015.8
  * 3a7289a Merge remote-tracking branch 'upstream/2015.5' into merge-forward-2015.8

  * c6efd23 Merge pull request `#25225`_ from nmadhok/client-runtime-fix-backport-2015-2

    * 391b7d6 Backporting fix for issue `#25223`_ on 2015.2 branch

  * 207fbae Merge pull request `#25214`_ from rallytime/http_doc

    * d0b61f3 A couple of doc fixes for the http tutorial

  * 9dd5cd8 Merge pull request `#25194`_ from rallytime/`fix-24272`_

    * f959e16 Clean up imports

    * fbc9c0d Fix Pylint

    * fe2561f Update moto version check in boto_vpc_test and update min version

  * a3e9486 Merge pull request `#25205`_ from basepi/releasecandidatedocs

    * 452880d Update releasecandidate docs

  * fbafd39 Merge pull request `#25187`_ from UtahDave/fix_misspelling

    * 65abb63 remove some extraneous double spaces

    * c423b62 fix misspelling

  * ddee90c Merge pull request `#25182`_ from cachedout/pack_long_floats

    * a192ecf Try to re-pack long ints as strs

  * df9982b Merge pull request `#25185`_ from rallytime/`bp-25128`_

    * 1726057 Use cmd_unzip to preserve permissions

  * df0bb8c Merge pull request `#25181`_ from rallytime/`bp-25102`_

    * 64d8f14 Update win_network.py

    * 6789c5b Update win_network.py

  * 04fdd7b Merge pull request `#25179`_ from rallytime/`bp-25059`_

    * 1eeefbd Add virtual functions to influxdb state modules

  * 58b7d0e Merge pull request `#25196`_ from twangboy/pkg_refresh

    * 12ffcd1 Fixed `#18919`_ false-positive on pkg.refresh

  * 4a406ac Merge pull request `#25180`_ from rallytime/`bp-25088`_

    * 4078c8d added message recommending JSON file be used if the libcloud version is >= 0.17.0

  * 01ed062 Merge pull request `#25191`_ from basepi/fix.fileclient.is_cached

    * 5fa74f4 Add back in the extrndest stuff (which is now in develop)

  * a9404ae Merge pull request `#25175`_ from rallytime/`bp-25020`_

    * da2e170 Fix for issue `#25016`_

  * c70fec6 Merge pull request `#25173`_ from rallytime/partial-`bp-25019`_

    * c0c2463 Partial backport of `#25019`_

  * c5ba9a9 Merge pull request `#25171`_ from rallytime/`bp-25001`_

    * a891108 Add docs for key arg in ssh_known_hosts.present

- **PR** `#25263`_: (*techhat*) Allow non-standard HTTP requests on tornado
  @ *2015-07-08T21:27:08Z*

  * 9e90603 Merge pull request `#25263`_ from techhat/nonstandard
  * ee62c75 Allow non-standard HTTP requests on tornado

- **PR** `#25253`_: (*s0undt3ch*) Remove the deprecation warning. The driver has been renamed.
  @ *2015-07-08T20:48:31Z*

  * 4e7346a Merge pull request `#25253`_ from s0undt3ch/2015.8
  * ea7afb4 Remove the deprecation warning. The driver has been renamed.

- **PR** `#25248`_: (*techhat*) Do not resize while iterating
  @ *2015-07-08T19:38:36Z*

  - **ISSUE** `#22391`_: (*rallytime*) Joyent driver broken on develop when provisioning instances
    | refs: `#25248`_
  * 679cdba Merge pull request `#25248`_ from techhat/issue22391
  * 4f2abe5 Do not resize while iterating

- **PR** `#25244`_: (*rallytime*) Remove parted deprecations and fix failing tests
  @ *2015-07-08T16:42:00Z*

  * 631cee1 Merge pull request `#25244`_ from rallytime/parted_deprecations
  * 138c4f1 Remove parted deprecations and fix failing tests

- **PR** `#25242`_: (*ruzarowski*) Make SourceDestCheck flag available to network interface definition
  @ *2015-07-08T16:36:22Z*

  - **ISSUE** `#25241`_: (*ruzarowski*) salt-cloud: SourceDestCheck flag not passed to AWS, provisioning NAT instances needs that
    | refs: `#25242`_
  * 810b109 Merge pull request `#25242`_ from ruzarowski/2015.8
  * 62b6d4f Make SourceDestCheck flag available to network interface definition

- **PR** `#25226`_: (*nmadhok*) Backporting fix for issue `#25223`_ on 2015.8 branch
  @ *2015-07-08T15:11:03Z*

  - **ISSUE** `#25223`_: (*nmadhok*) Runner occasionally fails with a RuntimeError when fired by a reactor
    | refs: `#25225`_ `#25226`_
  * e6251e7 Merge pull request `#25226`_ from nmadhok/client-runtime-fix-backport-2015-8
  * 02c4ef6 Forgot to correct the spelling

  * 331b277 Backporting fix for issue `#25223`_ on 2015.8 branch

- **PR** `#25234`_: (*krak3n*) Fix: Bug in boto_asg state argument passing to boto_asg module
  @ *2015-07-08T14:59:26Z*

  * 98e4fde Merge pull request `#25234`_ from krak3n/fix/boto_asg_update_args
  * 3da8d7e Fixed bug with argument passing from boto_asg state to boto_asg module

- **PR** `#25222`_: (*rallytime*) Back-port `#25219`_ to 2015.8
  @ *2015-07-08T14:55:17Z*

  - **ISSUE** `#25213`_: (*aboe76*) Add spm man page to setup.py
    | refs: `#25219`_ `#25222`_
  - **PR** `#25219`_: (*jacobhammons*) Built man page for spm, added man page entry for spm to doc/conf.py
    | refs: `#25222`_
  * 5db000d Merge pull request `#25222`_ from rallytime/`bp-25219`_
  * 0a46dc4 Built man page for spm, added man page entry for spm to doc/conf.py Refs `#25213`_

- **PR** `#25188`_: (*rallytime*) Use linode status descriptions instead of ints when logging status to CLI
  @ *2015-07-07T17:08:02Z*

  * 6fe7ebd Merge pull request `#25188`_ from rallytime/linode_logs
  * 300a1f2 Use linode status descriptions instead of ints when logging status to CLI.

- **PR** `#25203`_: (*s0undt3ch*) Added DictConfig with tests & More tests
  @ *2015-07-07T16:32:52Z*

  * 1b2d438 Merge pull request `#25203`_ from s0undt3ch/features/raas-17-salt-cloud-2015.8
  * 08e454b Dedent and strip description if equal to docstring

  * f36123c ArrayConfig must have items passed. Added DictConfig with tests.

  * 8842125 Add test for subclassed Configuration classes

- **PR** `#25189`_: (*basepi*) [2015.8] Merge forward from 2015.5 to 2015.8
  @ *2015-07-07T00:59:17Z*

  - **ISSUE** `#24979`_: (*mavenAtHouzz*) [Discussion] Support for more than 1 netapi.rest_tornado server process
    | refs: `#25149`_
  - **ISSUE** `#18447`_: (*ryan-lane*) Can't install salt with raet using pip -e git
  - **PR** `#25170`_: (*rallytime*) Back-port `#24982`_ to 2015.5
  - **PR** `#25166`_: (*cachedout*) Lint `#25149`_
  - **PR** `#25161`_: (*aneeshusa*) Allow checking for non-normalized systemd units.
  - **PR** `#25151`_: (*jleroy*) Support for IPv6 addresses scopes in network.interfaces
    | refs: `#25274`_ `#25433`_
  - **PR** `#25149`_: (*jacksontj*) Saltnado multiprocess support
    | refs: `#25166`_
  - **PR** `#25129`_: (*basepi*) [2015.5] Merge forward from 2014.7 to 2015.5
  - **PR** `#25120`_: (*d--j*) add missing continue for exeption case
  - **PR** `#25117`_: (*basepi*) Fix fileclient.is_cached
    | refs: `#25191`_
  - **PR** `#25093`_: (*jaybocc2*) quick fix for issue `#18447`_
  - **PR** `#25087`_: (*0xf10e*) Fix execution module for glance - now based on 2015.5!
  - **PR** `#25069`_: (*puneetk*) Add a helper module function called list_enabled
  - **PR** `#24982`_: (*asyncsrc*) ec2 network_interfaces fix
    | refs: `#25170`_
  * f4758bd Merge pull request `#25189`_ from basepi/merge-forward-2015.8
  * 9fde9df Remove tests (glance rewrite requires test rewrite)

  * adcffc0 Move non-glance imports out of the try:except: block

  * 785f157 Merge remote-tracking branch 'upstream/2015.5' into merge-forward-2015.8

    * 3e06602 Merge pull request `#25170`_ from rallytime/`bp-24982`_

      * 3e6eab3 ec2 network_interfaces fix

    * 0960280 Merge pull request `#25161`_ from aneeshusa/allow-checking-non-normalized-systemd-service-availability

      * b4d544f Allow checking for non-normalized systemd units.

    * 3599b8a Merge pull request `#25151`_ from jleroy/ipv6-scope-support

      * edce034 Support for IPv6 addresses scopes in network.interfaces

    * 66d6365 Merge pull request `#25166`_ from cachedout/lint_saltnado

      * 2fe167e Lint `#25149`_

    * 2f1bad1 Merge pull request `#25149`_ from jacksontj/saltnado

      * 6aa5548 Enable multiprocess support in saltnado

      * 9a1351e Change print to logger, so we can set a level and log exc_info

    * a723af0 Merge pull request `#25120`_ from d--j/patch-2

      * 81d5d15 add missing continue for error case

    * 6e22222 Merge pull request `#25117`_ from basepi/fix.fileclient.is_cached

      * 38e243f Add fix from merge forward

      * 52f35f7 Add import

      * 23c32a7 Backport develop version of salt.fileclient.is_cached

    * c80990b Merge pull request `#25087`_ from 0xf10e/fix_glance_2015.5

      * 7749cc0 PEP8 W601...

      * bbda079 fix pylint E302, E502, E713, E1305

      * 3baacc7 use Glance API v1 for image_create

      * c3d6134 making pylint marginally happier

      * 19a20bf get valid properties for image_show() from the schema for "image"

      * 0c6a611 add some debugging, fix a few AttributeErrors

      * aceca0e fix return of glance.image_show()

      * a47509e fix return of image_list

      * 9f923ed Change confusing "nt_ks" to "g_client"

      * fa2bd1a bit of docs/comments in image_create()

      * 5c34d0c merge 439b1e42053239b into 2015.5

      * 7a3cf27 update attributes for image_show output

      * b1bec0f fix retry w/ user/pass if token fails

      * 2f4ef66 update attributes for image_list output

      * eef3bc7 use _auth() from neutron plus keystoneclient,

    * 549ee47 Merge pull request `#25129`_ from basepi/merge-forward-2015.5

      * 187268d Merge remote-tracking branch 'upstream/2014.7' into merge-forward-2015.5

      * 36d53ef Merge pull request `#25093`_ from jaybocc2/2014.7

        * c6a501e quick fix for issue `#18447`_

      * 38903a9 Merge pull request `#25069`_ from puneetk/patch-1

      * f0b4e60 Update Documentation to clarify version added

      * f8dc603 Pylint updates , removing whitespace

      * 532d315 [Code Review update] renamed function to is_enaled from list_enabled

      * 20b0462 Update schedule.py

      * 4f1471d Add a helper module function called list_enabled

- **PR** `#25184`_: (*rallytime*) Back-port `#25126`_ to 2015.8
  @ *2015-07-07T00:57:32Z*

  - **ISSUE** `#18508`_: (*arthurlogilab*) docker.running (and docker.build) actually do things with test=True
    | refs: `#25126`_
  - **PR** `#25126`_: (*stanislavb*) dockerio states respect the test flag
    | refs: `#25184`_
  * 3334cf6 Merge pull request `#25184`_ from rallytime/`bp-25126`_
  * 3ac35a5 Respect the test flag

- **PR** `#25172`_: (*s0undt3ch*) Comment out imports while the YAML and RST rendering is not in-place.
  @ *2015-07-06T17:25:57Z*

  * 8aac9c9 Merge pull request `#25172`_ from s0undt3ch/features/raas-17-salt-cloud-2015.8
  * b8f0eca Comment out imports while the YAML and RST rendering is not in-place.

- **PR** `#25158`_: (*s0undt3ch*) Comment out not implemented code
  @ *2015-07-06T10:45:11Z*

  * e5f77bc Merge pull request `#25158`_ from s0undt3ch/features/raas-17-salt-cloud-2015.8
  * 583a229 Comment out not implemented code

- **PR** `#25145`_: (*s0undt3ch*) Implement `oneOf`, `anyOf`, `allOf` and `not` with unit tests
  @ *2015-07-03T16:56:44Z*

  * 0cbf22d Merge pull request `#25145`_ from s0undt3ch/features/raas-17-salt-cloud-2015.8
  * 44738b2 Lint fixes

  * f84c3e4 Add support for `enumNames`

  * 0d9173c Remove repeated test

  * 625e0b6 Implement `oneOf`, `anyOf`, `allOf` and `not` with unit tests

- **PR** `#25140`_: (*s0undt3ch*) Make the detection code work under Python 3.4
  @ *2015-07-02T23:26:06Z*

  * 911862e Merge pull request `#25140`_ from s0undt3ch/features/raas-17-salt-cloud-2015.8
  * c59d433 Make the detection code work under Python 3.4

- **PR** `#25131`_: (*s0undt3ch*) Array support in salt.utils.config
  @ *2015-07-02T19:40:34Z*

  * 3922992 Merge pull request `#25131`_ from s0undt3ch/features/raas-17-salt-cloud-2015.8
  * babf0c7 Allow config item attributes to be set at the class level

  * 237023d Support `Configuration` as an array item

  * 51e76c3 Properly handle salt.utils.config.Null

  * e0f4706 Add array support to salt.utils.config (with unit tests)

- **PR** `#25130`_: (*basepi*) [2015.8] Merge forward from 2015.5 to 2015.8
  @ *2015-07-02T19:26:16Z*

  - **PR** `#25114`_: (*jfindlay*) Revert "Revert "adding states/postgres_database unit test case.""
  - **PR** `#24798`_: (*jtand*) Revert "adding states/postgres_database unit test case."
    | refs: `#25114`_
  - **PR** `#24362`_: (*jayeshka*) adding states/postgres_user unit test case.
  - **PR** `#24361`_: (*jayeshka*) adding states/postgres_schema unit test case.
  - **PR** `#24331`_: (*jayeshka*) adding states/postgres_extension unit test case.
  - **PR** `#24329`_: (*jayeshka*) adding states/postgres_database unit test case.
    | refs: `#24798`_
  * dfe3df0 Merge pull request `#25130`_ from basepi/merge-forward-2015.8
  * 24d51fb Merge remote-tracking branch 'upstream/2015.5' into merge-forward-2015.8

  * 86f2791 Merge pull request `#25114`_ from saltstack/revert-24798-revert-24329-postgres_database-states-unit-test

    * 071ee44 Revert "Revert "adding states/postgres_database unit test case.""

  * bf8c7e7 Merge pull request `#24362`_ from jayeshka/postgres_user-states-unit-test

    * fd1d834 adding states/postgres_user unit test case.

  * 4195cea Merge pull request `#24361`_ from jayeshka/postgres_schema-states-unit-test

    * 0558b0d adding states/postgres_schema unit test case.

  * ada8fe5 Merge pull request `#24331`_ from jayeshka/postgres_extension-states-unit-test

  * 3d465a5 adding states/postgres_extension unit test case.

* fac5c06 Add version number for Beryllium


- **PR** `#25106`_: (*s0undt3ch*) Minor refactor + Unit tests for salt.utils.config + minor changes to 2 cloud drivers
  @ *2015-07-02T10:58:34Z*

  * f65501f Merge pull request `#25106`_ from s0undt3ch/features/raas-17-salt-cloud-ng
  * 545d7e0 PyLint fixes

  * 0716742 Also test pattern

  * 4d4e94b Unit tests for `salt.utils.config`

  * d98d44d Create a thinner base class for configuration items

  * 0f83143 Add `__virtualname__` to the Cloudstack cloud driver.

  * a013b0f Add `__virtualname__` to the Alyiun cloud driver.

- **PR** `#25008`_: (*basepi*) Merge forward from 2015.5 to develop
  @ *2015-07-02T01:04:59Z*

  * 576f1b8 Merge pull request `#25008`_ from basepi/merge-forward-develop
  * 3c6f4a4 Strip leading / for local file paths

  * 99fc7ec Merge remote-tracking branch 'upstream/2015.5' into merge-forward-develop

- **PR** `#25103`_: (*UtahDave*) add missing namespaced function import
  @ *2015-07-01T20:02:42Z*

  * 9908412 Merge pull request `#25103`_ from UtahDave/develop
  * df87bcf add missing namespaced function import

- **PR** `#25081`_: (*gladiatr72*) replace bad value for master_type in example minion config
  @ *2015-07-01T16:45:12Z*

  * dd80bec Merge pull request `#25081`_ from gladiatr72/example-minion-config-master_type-adjustment
  * f6dbeaf replace bad value for master_type in example minion config

- **PR** `#25102`_: (*derBroBro*) Update win_network.py
  | refs: `#25181`_
  @ *2015-07-01T15:57:15Z*

  * 8e04944 Merge pull request `#25102`_ from derBroBro/patch-1
  * 0310400 Update win_network.py

  * b95c4ca Update win_network.py

- **PR** `#25092`_: (*cachedout*) Lint develop
  @ *2015-06-30T21:37:07Z*

  * 9a961cc Merge pull request `#25092`_ from cachedout/lint_develop
  * 35d92ec Lint develop

- **PR** `#24984`_: (*twangboy*) Win user
  @ *2015-06-30T20:54:50Z*

  * c940dbc Merge pull request `#24984`_ from twangboy/win_user
  * 96bc5ae Fixed more testing stuff, an egregious error

  * aafd079 Fixed where I broke user.absent

  * 9127d96 Merge branch 'develop' of https://github.com/saltstack/salt into win_user

  * b8d1169 Fixed some lint

  * a1c9e38 Added functionality for windows user mgmt

  * 1694a11 Added more descriptive error

- **PR** `#25086`_: (*cachedout*) Revert zmq test experiment
  @ *2015-06-30T20:38:57Z*

  * 8d68778 Merge pull request `#25086`_ from cachedout/revert_zmq_test
  * 69b9f17 Revert zmq test experiment

- **PR** `#25080`_: (*cachedout*) Handle GC in weakref iter
  @ *2015-06-30T19:39:11Z*

  * 639ca1b Merge pull request `#25080`_ from cachedout/weakref_gc
  * bbf90f0 Handle GC in weakref iter

- **PR** `#25082`_: (*cachedout*) Change pub test to return global ioloop instance
  @ *2015-06-30T19:38:59Z*

  * 52bad5f Merge pull request `#25082`_ from cachedout/zmq_test
  * 8a5caf0 Change pub test to return global ioloop instance

- **PR** `#25071`_: (*s0undt3ch*) First working version of our JSON Schema DLS implementation.
  @ *2015-06-30T18:27:56Z*

  - **ISSUE** `#17`_: (*thatch45*) Modules need to be autodocumenting
    | refs: `#25071`_
  * 35c20a7 Merge pull request `#25071`_ from s0undt3ch/features/raas-17-salt-cloud-ng
  * 0371296 Rename `IntConfig` to `IntegerConfig`

  * 3dccb96 Make PyLint happier

  * 3ac8131 Fixed a bug when defining the `exclusive_minimum` class attribute.

  * f314e1d Do some type checking for the passed `enum`

  * 9d63527 Add SecretConfig support

  * 6aef6c2 Add IPv6 and Hostname config items. Updated docstrings.

  * 82bfca8 Make PyLint a little happier

  * 30775c5 First working version of our JSON Schema DLS implementation.

- **PR** `#25059`_: (*babilen*) Add virtual functions to influxdb state modules
  | refs: `#25179`_
  @ *2015-06-30T17:56:50Z*

  - **ISSUE** `#24301`_: (*iggy*) influxdb_user and influxdb_database states need virtual functions
    | refs: `#25059`_
  * 328031f Merge pull request `#25059`_ from babilen/dev-influxdb-virtual
  * 7da9836 Add virtual functions to influxdb state modules

- **PR** `#25048`_: (*terminalmage*) Implement verson-aware binary package installation for APT
  @ *2015-06-30T17:09:51Z*

  * abc3c08 Merge pull request `#25048`_ from terminalmage/version-aware-deb
  * e2c09c8 Use python_shell=False to install .deb pkgs

  * dd79858 Implement version-aware binary package installation for APT

  * 52ef17f Add lowpkg.bin_pkg_info for dpkg

  * 050cf7b Fix binary package caching

  * 40d40ce Add missing quote

  * 531cc11 Update docstrings

- **PR** `#25074`_: (*techhat*) Update SPM-METADATA file format
  @ *2015-06-30T16:50:46Z*

  * 3e07802 Merge pull request `#25074`_ from techhat/spmmetadata
  * e376e60 Update SPM-METADATA file format

- **PR** `#25072`_: (*techhat*) Add man page for spm, change pillar to .orig
  @ *2015-06-30T16:50:23Z*

  * dc175ad Merge pull request `#25072`_ from techhat/spm
  * 1e4f7aa Add man page for spm, change pillar to .orig

- **PR** `#25066`_: (*techhat*) Handle pillars and loader modules
  @ *2015-06-30T13:55:23Z*

  * 9a68f85 Merge pull request `#25066`_ from techhat/spm
  * 393cbf2 Document pillars and loader modules

  * cdc2eea Handle pillars and loader modules

- **PR** `#25055`_: (*techhat*) Default uid and gid to current user/group
  @ *2015-06-30T12:22:02Z*

  - **ISSUE** `#25043`_: (*aboe76*) spm build should change the acl's to root:root
    | refs: `#25055`_
  * d77f8fb Merge pull request `#25055`_ from techhat/spm
  * c7efc95 Linting

  * d2d4d53 Default uid and gid to current user/group

- **PR** `#25056`_: (*cachedout*) Lint SPM
  @ *2015-06-30T05:31:26Z*

  * 2bae862 Merge pull request `#25056`_ from cachedout/spm_lint
  * 1991fb2 Lint SPM

- **PR** `#25035`_: (*techhat*) Add install confirmation to SPM
  @ *2015-06-29T23:36:41Z*

  * 1c4030b Merge pull request `#25035`_ from techhat/spm
  * 85be137 Fixing as per @s0undt3ch

  * ccc6b5d Order DB fields properly

  * e9314fe Move pylint disable to the right place

  * 750e206 Add help screen

  * 695d8f0 Linting

  * 91263d6 Importing print_function

  * 8df9833 Check for existing files

  * c7c8e1e Allow forcing package install

  * d089a83 Add install confirmation to SPM

- **PR** `#25050`_: (*cachedout*) Reset grains opts
  @ *2015-06-29T22:16:34Z*

  * ec194fe Merge pull request `#25050`_ from cachedout/reset_grains_opts
  * db9d612 Lint

  * afbe54e Reset grains opts on each test

- **PR** `#25046`_: (*cachedout*) Grains file lock
  @ *2015-06-29T20:45:16Z*

  * 1b9e3d4 Merge pull request `#25046`_ from cachedout/lock_grains
  * 7be248d Grains file lock

- **PR** `#25044`_: (*thatch45*) Rpmbuild fix
  @ *2015-06-29T20:05:21Z*

  * 824cc34 Merge pull request `#25044`_ from thatch45/rpmbuild_fix
  * 7564f46 on all network file calls

  * 1708d31 change to get_url

- **PR** `#25039`_: (*s0undt3ch*) Remove unused import
  @ *2015-06-29T18:54:33Z*

  * 7d440d4 Merge pull request `#25039`_ from s0undt3ch/features/spm-parser
  * b043688 Remove unused import

- **PR** `#24970`_: (*rallytime*) Update the Azure Cloud Provider tests to be more accurate and use newe…
  @ *2015-06-29T16:46:45Z*

  * 900c5e2 Merge pull request `#24970`_ from rallytime/azure-test-fix
  * b68e3c0 Update the Azure Cloud Provider tests to be more acurate and use newer azure SDK version

- **PR** `#24963`_: (*whytewolf*) Neutron.create_network more in line with neutron net-create, with test
  @ *2015-06-29T16:46:08Z*

  - **ISSUE** `#2`_: (*thatch45*) salt job queries
    | refs: `#22858`_
  - **ISSUE** `#1`_: (*thatch45*) Enable regex on the salt cli
    | refs: `#21356`_ `#21328`_
  * 51ac7ae Merge pull request `#24963`_ from whytewolf/neutron-update
  * 09ed674 forgot the unit test. or at least couldn't find it originally.

  * 314ebcc Revert "neutron doesn't like the input."

  * 126b122 neutron doesn't like the input.

  * 42134b3 Merge pull request `#2`_ from whytewolf/develop

    * b3c381a Merge pull request `#1`_ from saltstack/develop

  * 2b105ef update module.neutron to work with all options that create-network has in the neutron client.

- **PR** `#24980`_: (*UtahDave*) Templatize winrepo on the minion
  @ *2015-06-29T16:44:49Z*

  - **ISSUE** `#6859`_: (*UtahDave*) Rework Windows package manager to allow for rendering
    | refs: `#24980`_
  * 337a5fe Merge pull request `#24980`_ from UtahDave/templatize_winrepo
  * 99d2fd1 update docs to reflect new win rep changes

  * 5048ccf catch render exceptions

  * 9d6d3f4 split the log out

  * 796c6fc fix logging

  * b86b01f add missing import

  * 2fa2623 properly catch and log render errors

  * 3f1502c read winrepo.p from correct location

  * adee23b factor out loca repo cache locating code

  * b02b2ef run genrepo when calling refresh_db

  * ad7a36b update genrepo to work on the minion

  * c26826b use salt.syspaths to find cachedir

  * fd43abb fix misspelled argument

  * 6c56a15 copy genrepo from winrepo runner

  * 0841d6b new minions just need a source dir for the winrepo

- **PR** `#25037`_: (*cachedout*) Try another way to fix grains test
  @ *2015-06-29T16:43:49Z*

  * b17c15e Merge pull request `#25037`_ from cachedout/grains_reset
  * 96a6e44 Try another way to fix grains test

- **PR** `#25017`_: (*bechtoldt*) Adding salt-cloud linode driver enhancements
  @ *2015-06-29T16:43:16Z*

  - **ISSUE** `#11996`_: (*vishnevskiy*) salt-cloud Linode private ip
  - **PR** `#25015`_: (*bechtoldt*) add fixes and enhancements to salt.utils.http
    | refs: `#25017`_
  - **PR** `#24707`_: (*rallytime*) Move Linode driver to use REST API instead of libcloud/python-linode
    | refs: `#25015`_
  - **PR** `#12006`_: (*JustinHead*) Add ability to define root disk size and private ip address allocation on Linode
  * fc3c10f Merge pull request `#25017`_ from bechtoldt/cloud_linode_changes
  * a920216 update linode cloud driver examples

  * 1d93e3a enhance new linode driver implementation by @rallytime * bring back support for `#12006`_ / `#11996`_ (private_ip) * fix _wait_for_job (near-endless looping)

  * 6e61a3f improve linode http API query usage

- **PR** `#25021`_: (*GideonRed*) Introduce ip:port minion config
  @ *2015-06-29T16:42:25Z*

  * 4d3d7a3 Merge pull request `#25021`_ from GideonRed/develop
  * cb05120 Introduce ip:port minion config

- **PR** `#25034`_: (*s0undt3ch*) Move SPM's parser to `salt.utils.parsers` and add `-y` to it
  @ *2015-06-29T15:26:54Z*

  * 7a5497c Merge pull request `#25034`_ from s0undt3ch/features/spm-parser
  * a138a7b SPM also works on windows

  * ac086c9 Add the spm script to `setup.py`

  * b86ff4d Move SPM's parser to `salt.utils.parsers` and add `-y` to it

- **PR** `#25032`_: (*techhat*) Remove .yml from FORMULA and SPM-METADATA
  @ *2015-06-29T15:18:09Z*

  * 81ef4cc Merge pull request `#25032`_ from techhat/spm
  * 27eb174 Remove .yml from FORMULA and SPM-METADATA

- **PR** `#25020`_: (*martinhoefling*) Fix for issue `#25016`_
  | refs: `#25175`_
  @ *2015-06-29T14:01:02Z*

  - **ISSUE** `#25016`_: (*martinhoefling*) salt-run doc.execution fails with AttributeError
  * cfd904d Merge pull request `#25020`_ from martinhoefling/develop
  * 8b4aeff Fix for issue `#25016`_

- **PR** `#24989`_: (*htch*) Log traceback on 'Function in mine_functions failed to execute' exceptions in mine.update
  @ *2015-06-29T13:54:42Z*

  * 5965673 Merge pull request `#24989`_ from htch/develop
  * 788eb62 Salt mine: sending stack trace to the debug log on 'Function in mine_functions failed to execute'

  * 11dc96f stack trace

- **PR** `#25015`_: (*bechtoldt*) add fixes and enhancements to salt.utils.http
  | refs: `#25017`_
  @ *2015-06-29T13:53:33Z*

  - **PR** `#24707`_: (*rallytime*) Move Linode driver to use REST API instead of libcloud/python-linode
    | refs: `#25015`_
  * 47df472 Merge pull request `#25015`_ from bechtoldt/http_util
  * 9655b2b add fixes and enhancements to salt.utils.http * improve logging * fix unused GET params when using urllib2 backend

- **PR** `#25023`_: (*pengyao*) fixed a typo
  @ *2015-06-28T13:25:48Z*

  * 64cdd85 Merge pull request `#25023`_ from pengyao/schedule_typo
  * 083f879 a typo

- **PR** `#25019`_: (*bechtoldt*) add missing module documentation to references
  | refs: `#25173`_
  @ *2015-06-27T22:43:36Z*

  - **ISSUE** `#21879`_: (*bechtoldt*) Reference pages in documentation are outdated again
    | refs: `#25019`_
  - **ISSUE** `#19262`_: (*bechtoldt*) salt.pillar.file_tree doesn't appear in the documentation
    | refs: `#25019`_
  - **PR** `#24421`_: (*bechtoldt*) add missing module documentation
    | refs: `#25019`_
  - **PR** `#21880`_: (*bechtoldt*) update references, fixes `#21879`_
    | refs: `#25019`_
  - **PR** `#20039`_: (*bechtoldt*) completing some doc references
    | refs: `#25019`_
  * ae65c0f Merge pull request `#25019`_ from bechtoldt/update_docs_2
  * 689ba56 add missing module documentation to references

- **PR** `#25012`_: (*notpeter*) Add file as supported protocol for file source_hash
  @ *2015-06-27T22:39:03Z*

  - **ISSUE** `#23764`_: (*es1o*) source_hash from local file is not supported.
    | refs: `#25012`_
  * a5d2dca Merge pull request `#25012`_ from notpeter/source_hash_file
  * 1a6fb80 Add file as supported protocol for file source_hash. Fixes `#23764`_.

- **PR** `#25009`_: (*aboe76*) Fix documentation on mod_random.seed module
  @ *2015-06-27T22:34:19Z*

  * d41ee6d Merge pull request `#25009`_ from aboe76/fix_mod_random.seed
  * 1cda19a Fix documentation on mod_random.seed module

- **PR** `#25001`_: (*jasonkeene*) Add docs for key arg in ssh_known_hosts.present
  | refs: `#25171`_
  @ *2015-06-27T22:30:54Z*

  * b7654ae Merge pull request `#25001`_ from jasonkeene/clarify-ssh-know-hosts-docs
  * 4cef4ac Add docs for key arg in ssh_known_hosts.present

- **PR** `#24982`_: (*asyncsrc*) ec2 network_interfaces fix
  | refs: `#25170`_
  @ *2015-06-26T21:51:55Z*

  * a880fbc Merge pull request `#24982`_ from asyncsrc/develop
  * 7a393df ec2 network_interfaces fix

- **PR** `#24998`_: (*jacobhammons*) rebuilt man pages, versioned html theme css
  @ *2015-06-26T18:39:03Z*

  * 76251e5 Merge pull request `#24998`_ from jacobhammons/build-man-pages
  * 30a9075 rebuilt man pages, versioned html theme css

- **PR** `#24993`_: (*jacobhammons*) sphinx html theme updates - color changes for warning on development …
  @ *2015-06-26T16:28:51Z*

  * 9f8cef2 Merge pull request `#24993`_ from jacobhammons/doc-theme
  * 1587d56 Fixed doc/index.rst

  * 8be40d9 sphinx html theme updates - additional fix, updated index file

  * 01e96bc sphinx html theme updates - color changes for warning on development branch

- **PR** `#24946`_: (*rallytime*) Change provider --> driver for gce create function
  @ *2015-06-26T12:25:57Z*

  - **PR** `#24796`_: (*rallytime*) Deprecate using "provider" in favor of "driver" in cloud provider files
    | refs: `#24866`_ `#24867`_ `#24946`_ `#25372`_ `#25575`_
  * 99822b1 Merge pull request `#24946`_ from rallytime/driver-provider-gce
  * fc3677d Pylint

  * 4714d6e Change provider --> driver for gce create function

- **PR** `#24971`_: (*rallytime*) Add minimum Python Azure SDK version to azure docs.
  @ *2015-06-25T23:18:22Z*

  * a15f9f8 Merge pull request `#24971`_ from rallytime/azure_min_ver
  * 4ac8a94 Add minimum Python Azure SDK verion to azure docs.

- **PR** `#24937`_: (*basepi*) Merge forward from 2015.5 to develop
  @ *2015-06-25T22:03:48Z*

  * f65e663 Merge pull request `#24937`_ from basepi/merge-forward-develop
  * 63667e0 Add more side effects

  * 0d95be1 Fix bug in ssh_auth state

  * 880760f Fix ssh_auth test

  * 8b23cb0 Revert just config changes

  * 23d02be Revert "Revert wildly in an attempt to make tests pass"

  * 2d916c3 Revert wildly in an attempt to make tests pass

  * acb7c6f Merge remote-tracking branch 'upstream/2015.5' into merge-forward-develop

- **PR** `#24976`_: (*cachedout*) Catch typeerror on msgpack failure
  @ *2015-06-25T22:02:04Z*

  - **ISSUE** `#19130`_: (*Mrten*) grain typechecking
    | refs: `#24976`_
  * 8e60cc2 Merge pull request `#24976`_ from cachedout/issue_19130
  * 9680996 Catch typeerror on msgpack failure

- **PR** `#24973`_: (*ezheidtmann*) Fix typo: `Gcomment` should be `comment`
  @ *2015-06-25T21:49:45Z*

  * 2dbdffd Merge pull request `#24973`_ from ezheidtmann/patch-2
  * 160b3db Fix typo: `Gcomment` should be `comment`

- **PR** `#24974`_: (*cachedout*) Remove duplicate func doc
  @ *2015-06-25T21:49:19Z*

  - **ISSUE** `#23613`_: (*tkent-xetus*) DOCUMENTATION(minor): pillar_refresh vs refresh_pillar
    | refs: `#24974`_
  * 9861337 Merge pull request `#24974`_ from cachedout/issue_23613
  * fbea069 Remove duplicate func doc

- **PR** `#24972`_: (*cachedout*) Set grains test to local
  @ *2015-06-25T21:30:40Z*

  * e01291c Merge pull request `#24972`_ from cachedout/grains_fix
  * d48af16 Set grains test to local

- **PR** `#24957`_: (*batulin-s*) main fix behavior pkg.latest state and pkg.install module for working…
  @ *2015-06-25T20:03:24Z*

  - **ISSUE** `#22531`_: (*batulin-s*) pkg.latest behavior in gentoo
    | refs: `#24957`_
  * e915465 Merge pull request `#24957`_ from batulin-s/check_use_flags_ebuild
  * 768497c fix PEP8 mistakes

  * c7519f9 main fix behavior pkg.latest state and pkg.install module for working with gentoo flags in a proper way

- **PR** `#24729`_: (*gladiatr72*) boolean option `bare` for modules.gpg.(en|de)crypt()
  @ *2015-06-25T20:00:20Z*

  * 8f44506 Merge pull request `#24729`_ from gladiatr72/gpg_encrypt-decrypt__add_bare_kwarg
  * 70fc570 fix amateur-hour syntax errors

  * a36c316 Changes made to the return values of modules.gpg in support of gpg states resulted in dictionary-structured return values for gpg.encrypt and gpg.decrypt. For modules that use gpg.*() programmatically, a consistent gpg.(en|un)crypt()['comment'] is required to deal with the new structure.

- **PR** `#24877`_: (*mzupan*) Fix for rabbitmq policy changes on vhosts
  @ *2015-06-25T19:15:23Z*

  * 0dc2a21 Merge pull request `#24877`_ from mzupan/fix-rabbit-policy
  * c429741 fix the ordering to be standard

  * 27b068d need to run with a vhost to apply policies to other vhosts

  * 0ad0574 need to pass in a vhost to the module

- **PR** `#24952`_: (*pcn*) Don't split the string on a single line
  @ *2015-06-25T18:50:26Z*

  * 7c66611 Merge pull request `#24952`_ from pcn/patch-1
  * e44c047 Don't split the string on a single line

- **PR** `#24954`_: (*pengyao*) netapi client should create after daemonize
  @ *2015-06-25T18:50:15Z*

  * 925c32c Merge pull request `#24954`_ from pengyao/netapi_stop
  * f60c0b3 netapi client should create after daemonize

- **PR** `#24967`_: (*cachedout*) Cmdmod doc
  @ *2015-06-25T18:47:39Z*

  * a9f0491 Merge pull request `#24967`_ from cachedout/cmdmod_doc
  * 97c50ee Lint

  * f67993f Document additional functions

  * 72ca156 Document 'run' and 'script'

- **PR** `#24931`_: (*rallytime*) Don't stacktrace when provisioning instances for EC2
  @ *2015-06-24T17:49:10Z*

  - **ISSUE** `#24912`_: (*rallytime*) Salt-Cloud Provisioning Broken on Develop with EC2
    | refs: `#24931`_
  * 9bf1d52 Merge pull request `#24931`_ from rallytime/`fix-24912`_
  * 3f6e90e Fix salt-cloud stacktrace with provisioning instances for EC2

- **PR** `#24933`_: (*rallytime*) Change versionadded tag from 2015.5.3 to Beryllium for new mod_random func
  @ *2015-06-24T17:36:27Z*

  - **PR** `#24908`_: (*aboe76*) Added seed option to mod_random
    | refs: `#24933`_
  * 2e76629 Merge pull request `#24933`_ from rallytime/versionadded_mod_random
  * bb880f5 Change versionadded tag from 2015.5.3 to Beryllium for new mod_random func

- **PR** `#24890`_: (*krak3n*) Feature: New etcd salt state module to manage etcd keys
  @ *2015-06-24T17:07:56Z*

  * b225899 Merge pull request `#24890`_ from krak3n/feature/etcd-state-module
  * 6420db3 Implemented python3 lint error fix, thx @rallytime

  * 3500225 Added .. versionadded:: Beryllium

  * d7f2112 Fixing minor linting fixes

  * ec40139 New etcd salt state module to manage etcd keys

- **PR** `#24932`_: (*cachedout*) Fix grains test
  @ *2015-06-24T16:47:08Z*

  * 78eb91c Merge pull request `#24932`_ from cachedout/fix_grains_test
  * e106974 Fix grains test

- **PR** `#24709`_: (*garethgreenaway*) Convert Hipchat to salt.utils.http
  @ *2015-06-24T16:46:40Z*

  * 10e17da Merge pull request `#24709`_ from garethgreenaway/hipchat_salt_utils_http
  * b600edc a missing import of an unused module.

  * bbeb15a lint

  * 4bb42ca convert hipchat module and returner to use salt.utils.http.

- **PR** `#24734`_: (*garethgreenaway*) Alllow configuration items using either module.key or module:key
  @ *2015-06-24T16:46:09Z*

  * 2a91f6f Merge pull request `#24734`_ from garethgreenaway/config_changes
  * e4188e1 Updating slack_notify tests to reflect changes.

  * e8db087 lint

  * 779896f Changes to various modules to allow configuration items to be pulled via config.get using either module.key or module:key

- **PR** `#24801`_: (*garethgreenaway*) Updates to IFTTT module
  @ *2015-06-24T16:45:05Z*

  * 5a77f81 Merge pull request `#24801`_ from garethgreenaway/ifttt_module
  * 19c1759 lint.

  * 89e52f2 Reading the IFTTT docs closer there are only three parameters that can be sent via the IFTTT web call, value1, value2, value3.  Including the OccurredAt paramter.

- **PR** `#24810`_: (*garethgreenaway*) Adding a state module to trigger events in IFTTT.
  @ *2015-06-24T16:44:43Z*

  * 2dc4660 Merge pull request `#24810`_ from garethgreenaway/ifttt_state_module
  * b316c92 Adding a state module to trigger events in IFTTT.

- **PR** `#24815`_: (*twangboy*) Added additional settings to the wua module
  @ *2015-06-24T16:43:31Z*

  * 83da087 Merge pull request `#24815`_ from twangboy/wua_additional_functionality
  * 5133d8c Fixed some lint

  * 55ce571 Added additional settings to the wua module

- **PR** `#24881`_: (*garethgreenaway*) Switching nagios_returner to use salt.utils.http
  @ *2015-06-24T16:42:47Z*

  * d34c2ad Merge pull request `#24881`_ from garethgreenaway/nagios_return_salt_utils_http
  * cc63a1e removing unused import.

  * 143181f Switching nagios_returner to use salt.utils.http

- **PR** `#24887`_: (*opdude*) Fixed powercfg on windows 7
  @ *2015-06-24T16:42:18Z*

  * d82af08 Merge pull request `#24887`_ from Unity-Technologies/win-powercfg
  * 7fb0ba0 Fixed lint issues

  * 0a9294d Fixed unit tests for win_powercfg

  * c0bfa6a Fixed powercfg on windows 7

- **PR** `#24889`_: (*thusoy*) Add all iptables jump args from manpage
  @ *2015-06-24T16:41:45Z*

  * d3b26fd Merge pull request `#24889`_ from thusoy/patch-2
  * 449a387 Add all iptables jump args from manpage

- **PR** `#24894`_: (*batulin-s*) add functions for detecting changed USE flags
  @ *2015-06-24T16:41:20Z*

  * 04ca1de Merge pull request `#24894`_ from batulin-s/add-functions-to-portage_config
  * 46406f5 add versionadded

  * 2798fa0 change new functions fo increase usability

  * 8480608 add functions for detecting changed USE flags (with PEP8)last

  * 925a295 add functions for detecting changed USE flags (with PEP8)w

  * f956e02 add functions for detecting changed USE flags

- **PR** `#24908`_: (*aboe76*) Added seed option to mod_random
  | refs: `#24933`_
  @ *2015-06-24T16:40:16Z*

  * dac39b5 Merge pull request `#24908`_ from aboe76/mod_random_seed
  * 1a7e08f fix pylint warnings about indentation

  * 85a5c1e Added seed option to mod_random

- **PR** `#24913`_: (*rallytime*) Check for required parameters in salt-cloud provider and profile configs
  @ *2015-06-24T16:39:47Z*

  - **ISSUE** `#14231`_: (*whiteinge*) salt-cloud does not error when req'd params are missing
    | refs: `#24913`_
  * f6c6912 Merge pull request `#24913`_ from rallytime/required_params_helpers
  * 6e8b428 Put profile configure check in create function for gce

  * 5d88930 Check for image and size in provider configs

  * 9a891de Check for required profile configurations: image, size, and provider

  * 2d3993e Add password as a required param to linode driver.

  * 3f1d6a6 Don't hide error messages for required params for salt-cloud providers.

- **PR** `#24916`_: (*daodennis*) broken link, adding /en/latest
  @ *2015-06-24T16:39:18Z*

  * d630067 Merge pull request `#24916`_ from daodennis/patch-1
  * 8ada53c broken link, adding /en/latest

- **PR** `#24911`_: (*cachedout*) Display total time take by highstate run
  @ *2015-06-24T15:21:09Z*

  - **ISSUE** `#24904`_: (*nmadhok*) [feature Request] - Display Total time taken by highstate/state run
    | refs: `#24911`_
  * 6fdad74 Merge pull request `#24911`_ from cachedout/issue_24904
  * 5b7bba5 Remove fixme

  * 5d959fd Display total time take by highstate run

- **PR** `#24917`_: (*daodennis*) s/respctively/respectively
  @ *2015-06-24T15:15:41Z*

  * fc405bc Merge pull request `#24917`_ from daodennis/patch-2
  * 9081a7d s/respctively/respectively

- **PR** `#24928`_: (*klyr*) Fix typo in salt-cloud reactor section
  @ *2015-06-24T14:52:16Z*

  * 9375645 Merge pull request `#24928`_ from klyr/doc-fix-typo
  * 6d7e779 Fix typo in salt-cloud reactor section

- **PR** `#24922`_: (*s0undt3ch*) Call the right exception
  @ *2015-06-24T13:30:48Z*

  * 586b0b3 Merge pull request `#24922`_ from s0undt3ch/develop
  * 5125408 Call the right exception

- **PR** `#24864`_: (*mgwilliams*) boto_cfn: allow for optional keys in describe
  @ *2015-06-24T03:35:38Z*

  * bb65051 Merge pull request `#24864`_ from mgwilliams/boto_cfn
  * 91c07a6 boto_cfn: allow for optional keys in describe

- **PR** `#24896`_: (*techhat*) Initial commit of Salt Package Manager
  @ *2015-06-23T23:05:29Z*

  * 18b9a5d Merge pull request `#24896`_ from techhat/spm
  * 6384165 Better checking for required fields when building

  * 42983d9 Reject invalid packages

  * a7c865f Check to make sure arguments are passed where necessary

  * 32c1588 Adding docs for SPM

  * 0ea5f76 Linting

  * 798c98b Add remove functionality

  * 568886c Add package database

  * 8e1bebf Add versionadded

  * 4a95b11 Initial commit of Salt Package Manager

- **PR** `#24867`_: (*rallytime*) Clean up the Rackspace cloud tests and alias provider for driver in Openstack
  @ *2015-06-23T16:27:04Z*

  - **PR** `#24796`_: (*rallytime*) Deprecate using "provider" in favor of "driver" in cloud provider files
    | refs: `#24866`_ `#24867`_ `#24946`_ `#25372`_ `#25575`_
  * 3cadda6 Merge pull request `#24867`_ from rallytime/fix_cloud_tests
  * 164dfdd Alias provider for driver in openstack

  * e89564c Update Rackspace cloud test file to be more accurate

- **PR** `#24866`_: (*rallytime*) Alias provider for driver in GoGrid
  @ *2015-06-23T16:26:27Z*

  - **PR** `#24796`_: (*rallytime*) Deprecate using "provider" in favor of "driver" in cloud provider files
    | refs: `#24866`_ `#24867`_ `#24946`_ `#25372`_ `#25575`_
  * a0ffbfd Merge pull request `#24866`_ from rallytime/fix_gogrid_stacktrace
  * 2e78b20 Alias provider for driver in GoGrid

- **PR** `#24883`_: (*dmyerscough*) Remove unused function definition
  @ *2015-06-23T14:54:13Z*

  * 0458780 Merge pull request `#24883`_ from dmyerscough/remove-old-function-definition
  * e597fde Remove old commented out listen definition and make parser arguments PEP8 compliant

- **PR** `#24868`_: (*thusoy*) Don't error log missing IFTTT keys
  @ *2015-06-23T03:54:35Z*

  * 7db3d7e Merge pull request `#24868`_ from thusoy/patch-3
  * f0324d9 Don't error log missing IFTTT keys

- **PR** `#24825`_: (*dh-harald*) Fix password parsing in ssh sessions
  @ *2015-06-22T21:19:03Z*

  * 25d78d3 Merge pull request `#24825`_ from dh-harald/develop
  * 376f669 fix for 02683f544e647217dfb628bec7ac2958939b6b86

  * 02683f5 Fix password parsing in ssh sessions

- **PR** `#24857`_: (*gtmanfred*) add interfaces to subnets
  @ *2015-06-22T20:37:33Z*

  * bc08ee3 Merge pull request `#24857`_ from gtmanfred/develop
  * 13a6f7b python 2.6 compatibility

  * 0d04173 add docs for subnets with interfaces

  * c7f6819 add interfaces to subnets

- **PR** `#24845`_: (*porterjamesj*) fix bug in docker.loaded
  @ *2015-06-22T20:36:36Z*

  * e488578 Merge pull request `#24845`_ from porterjamesj/patch-1
  * 35d2cff fix bug in docker.loaded

- **PR** `#24838`_: (*rhealitycheck*) Feature mongo return update pymongo
  @ *2015-06-22T20:36:14Z*

  * 4f2b897 Merge pull request `#24838`_ from rhealitycheck/feature-mongo-return-update-pymongo
  * 7f89f87 adding support for pymongo versions < 2.4

  * da82d88 updating from using deprecated Connection class to MongoClient class as per latest pymongo version 3.0.2, MongoClient is supported starting in pymongo 2.4

- **PR** `#24837`_: (*gashev*) Added --trusted-host option to pip.installed.
  @ *2015-06-22T20:35:49Z*

  * 1779b68 Merge pull request `#24837`_ from gashev/add_trusted_host_option_to_pip
  * 6dcafea Added --trusted-host option to pip.installed.

- **PR** `#24848`_: (*nmadhok*) Correcting bash code blocks
  @ *2015-06-22T16:18:03Z*

  * b72b392 Merge pull request `#24848`_ from nmadhok/patch-1
  * cb54c7b Correcting bash code blocks

- **PR** `#24847`_: (*borutmrak*) unset size parameter for lxc.create when backing=zfs
  @ *2015-06-22T16:17:05Z*

  * 7d1d195 Merge pull request `#24847`_ from borutmrak/develop
  * 9fab34f unset size parameter for lxc.create when backing=zfs

- **PR** `#24839`_: (*infestdead*) fix for issue `#24799`_
  @ *2015-06-22T16:14:24Z*

  - **ISSUE** `#24799`_: (*infestdead*) Forced remount because options changed when no options changed (glusterfs)
  * f502402 Merge pull request `#24839`_ from infestdead/develop
  * ec491df fix for issue `#24799`_

- **PR** `#24831`_: (*DmitryKuzmenko*) Cherrypy timeout
  @ *2015-06-22T15:27:13Z*

  - **ISSUE** `#23408`_: (*MartinEmrich*) salt-api returns 500 Internal Server Error for large job result
    | refs: `#24831`_
  * 650891c Merge pull request `#24831`_ from DSRCompany/cherrypy_timeout
  * a9b33c6 add rest_timeout master config option and jobs?timeout=... rest param

  * 954ba6e Fixed GET /jobs/<id> requests

- **PR** `#24742`_: (*The-Loeki*) Contribution: Module for creating temporary files & dirs
  @ *2015-06-22T15:23:30Z*

  * df3a069 Merge pull request `#24742`_ from The-Loeki/tempmodule
  * 152b4fb nail in pylint newline coffin for temp

  * 2a73f16 undo pylint fix to fix pylint

  * 4397545 DocFixes for temp module

  * 8bd3b21 pylint fix for tempmodule

  * dfa8540 Module for creating temporary files & dirs

- **PR** `#24833`_: (*rallytime*) Fix linode cloud tests
  @ *2015-06-20T20:15:09Z*

  * 6fa7e5c Merge pull request `#24833`_ from rallytime/fix_linode_tests
  * c56d315 Fix linode cloud tests

- **PR** `#24844`_: (*rallytime*) Merge forward from 2015.5 to develop
  @ *2015-06-20T20:14:51Z*

  * f07308e Merge pull request `#24844`_ from rallytime/merge_forward_develop
  * a306216 Merge branch '2015.5' into merge_forward_develop

- **PR** `#24843`_: (*rallytime*) Update Linode docs to reflect rest API change
  @ *2015-06-19T22:55:18Z*

  * 04ce5f2 Merge pull request `#24843`_ from rallytime/update_linode_docs
  * 9b4b6bc Add rest api change to release notes

  * b3ef394 Clean up

  * ddab875 Update linode rest driver docs

- **PR** `#24840`_: (*rallytime*) Add missing reboot function to linode driver
  @ *2015-06-19T22:27:03Z*

  * d716fa5 Merge pull request `#24840`_ from rallytime/linode_reboot
  * 3694312 Add missing reboot function to linode driver

- **PR** `#24835`_: (*ticosax*) [doc] Fix anchors
  @ *2015-06-19T21:51:00Z*

  * 1a0044d Merge pull request `#24835`_ from ticosax/fix-doc-links
  * 7b15d54 Fix anchors

- **PR** `#24817`_: (*rallytime*) Make the GoGrid Cloud Provider Tests work
  @ *2015-06-19T17:14:51Z*

  * c69650a Merge pull request `#24817`_ from rallytime/enable_gogrid_tests
  * 4a0626b Python 3 compat fix

  * 5c137c8 Make the GoGrid Cloud Provider Tests work

- **PR** `#24796`_: (*rallytime*) Deprecate using "provider" in favor of "driver" in cloud provider files
  | refs: `#24866`_ `#24867`_ `#24946`_ `#25372`_ `#25575`_
  @ *2015-06-19T15:43:26Z*

  * d299475 Merge pull request `#24796`_ from rallytime/deprecate_provider_for_driver
  * 5c5dfc5 More aws --> ec2 references

  * 4de5afb Replace references to aws with ec2

  * 61de27a Bah! Fix more whitespace.

  * 1e85bb9 Fix bugs caught by tests, and clean up some of the tests

  * 6d57ceb Whitespace fix

  * 4042682 Add provider --> driver change to release notes

  * 0dba3fe Change provider config refernces to driver in docs

  * 391516e Remove unreachable code from cloud/__init__.py

  * 2b8a955 Also alias provider for driver when creating VMs without a profile

  * 841e86a Alias vm_['provider'] references to vm_['driver'] in vmware driver

  * ea31f53 Alias vm_['provider'] references to vm_['driver'] in cloud drivers

  * 10d58d7 Deprecate using "provider" in favor of "driver" in cloud provider files

- **PR** `#24794`_: (*anlutro*) Add module function "pillar.keys"
  @ *2015-06-19T15:24:02Z*

  - **ISSUE** `#24787`_: (*anlutro*) Add a pillar.keys module function
    | refs: `#24794`_
  * 6fcff4d Merge pull request `#24794`_ from alprs/feature-pillar_keys
  * db229d1 Add module function "pillar.keys"

- **PR** `#24360`_: (*dr4Ke*) more complete unit tests for state grains
  @ *2015-06-19T15:10:08Z*

  * df74df3 Merge pull request `#24360`_ from dr4Ke/unit_tests_state_grains_develop
  * ed4d064 unit tests for state grains: use a subdirectory for config file

  * 4d1810b fix weird error in test test_absent_delete

  * ff5267b trying to fix jenkins error

  * 650fa90 more complete unit tests for state grains

- **PR** `#24811`_: (*rallytime*) Add notes to map and gogrid docs -- don't use -P with map files
  @ *2015-06-18T20:58:50Z*

  - **ISSUE** `#14666`_: (*luciddr34m3r*) salt-cloud GoGrid exception when using map file
    | refs: `#24811`_
  * 0245ea1 Merge pull request `#24811`_ from rallytime/gogrid_map_warning
  * d045fb5 Add notes to map and gogrid docs -- don't use -P with map files

- **PR** `#24812`_: (*cachedout*) Lint win_status
  @ *2015-06-18T20:29:41Z*

  * d2fff57 Merge pull request `#24812`_ from cachedout/win_status_lint
  * f3b0608 Lint win_status

- **PR** `#24804`_: (*basepi*) Merge forward from 2015.5 to develop
  @ *2015-06-18T20:12:01Z*

  * da8b637 Merge pull request `#24804`_ from basepi/merge-forward-develop
  * e707193 Lint

  * a5c9681 Merge remote-tracking branch 'upstream/2015.5' into merge-forward-develop

- **PR** `#24808`_: (*cachedout*) Fix lint in state.py
  @ *2015-06-18T18:13:06Z*

  * b93fa83 Merge pull request `#24808`_ from cachedout/lint_state
  * 92a61ff Fix lint in state.py

- **PR** `#24807`_: (*cachedout*) Skip encoding tests if unsupported
  @ *2015-06-18T18:09:28Z*

  * bf0fe4e Merge pull request `#24807`_ from cachedout/skip_enc
  * 558ce63 Skip encoding tests if unsupported

- **PR** `#24806`_: (*cachedout*) Improved debugging for missing or corrupt payloads
  @ *2015-06-18T17:53:15Z*

  * 0da049b Merge pull request `#24806`_ from cachedout/better_payload_logging
  * e7d8e23 Improved debugging for missing or corrupt payloads

- **PR** `#24805`_: (*cachedout*) Fix failing zmq tests
  @ *2015-06-18T17:46:39Z*

  * 07b6a2b Merge pull request `#24805`_ from cachedout/test_zmq_wait
  * 72752f5 Fix failing zmq tests

- **PR** `#24785`_: (*The-Loeki*) Small utility function for deriving IPv6 SLAAC EUI-64 identifiers
  @ *2015-06-18T14:53:46Z*

  * 6693993 Merge pull request `#24785`_ from The-Loeki/patch-1
  * 036e654 leading zero fix for mac2eui64

  * e1f08f1 PyLint fix

  * c944661 Update network.py

  * 26ce922 Small utility function for deriving IPv6 SLAAC EUI-64 identifiers

- **PR** `#24777`_: (*nmadhok*) Fixing issue where --static option fails with ValueError Fixes `#24776`_
  | refs: `#24778`_
  @ *2015-06-18T14:51:19Z*

  - **ISSUE** `#24776`_: (*nmadhok*) --static option in salt raises ValueError and has been broken for a very long time
    | refs: `#24777`_
  - **PR** `#24779`_: (*nmadhok*) Backporting Changes to 2014.7 branch
    | refs: `#24777`_
  - **PR** `#24778`_: (*nmadhok*) Backporting PR `#24777`_ to 2015.2 branch
    | refs: `#24777`_
  * b290b9b Merge pull request `#24777`_ from nmadhok/develop
  * a34b74a Fixing issue where --static option fails with ValueError Fixes `#24776`_

- **PR** `#24786`_: (*chrismcmacken*) Adding a couple tests for the mysql.grant_exists
  @ *2015-06-18T14:41:48Z*

  * 4e7abeb Merge pull request `#24786`_ from chrismcmacken/develop
  * 3025ba1 Adding a couple of tests for grant_exists

- **PR** `#24767`_: (*dmyerscough*) Fixing spacing typo
  @ *2015-06-18T14:39:38Z*

  * afc58bb Merge pull request `#24767`_ from dmyerscough/Fixing-doc-typo
  * 916519c Fixing spacing typo

- **PR** `#24788`_: (*cachedout*) Lint and remove unused import
  @ *2015-06-18T14:39:02Z*

  - **PR** `#24772`_: (*garethgreenaway*) Initially adding a module to trigger events in IFTTT from Salt.
    | refs: `#24788`_
  * f3120b3 Merge pull request `#24788`_ from cachedout/lint_24772
  * bf0a849 Lint and remove unused import

- **PR** `#24772`_: (*garethgreenaway*) Initially adding a module to trigger events in IFTTT from Salt.
  | refs: `#24788`_
  @ *2015-06-18T14:35:21Z*

  * 5c4bc17 Merge pull request `#24772`_ from garethgreenaway/ifttt_module
  * 5b0218b Initially adding a module to trigger events in IFTTT from Salt.

- **PR** `#24765`_: (*cachedout*) Fix extreme edge case where system encoding can not be detected
  @ *2015-06-17T22:01:28Z*

  * 99af769 Merge pull request `#24765`_ from cachedout/encoding_fallback
  * 4cbf86a Fix extreme edge case where system encoding can not be detected

- **PR** `#24764`_: (*cachedout*) Fix syntax error
  @ *2015-06-17T19:59:46Z*

  * fc4d491 Merge pull request `#24764`_ from cachedout/ssh_syntax_error
  * b83d386 Fix syntax error

- **PR** `#24763`_: (*cachedout*) Lint riak
  @ *2015-06-17T19:04:40Z*

  * 3401f9d Merge pull request `#24763`_ from cachedout/fix_lint_24590
  * 511e24d Lint riak

- **PR** `#24590`_: (*dmyerscough*) Additional riak functions
  @ *2015-06-17T19:03:19Z*

  * c3fcef0 Merge pull request `#24590`_ from dmyerscough/riak-features
  * 7ceffd4 Additional riak functions

- **PR** `#24741`_: (*CameronNemo*) Improve Upstart enable/disable handling
  @ *2015-06-17T18:59:22Z*

  * 6e78a55 Merge pull request `#24741`_ from CameronNemo/upstart-enable-fix
  * f3078174 Add missing import

  * 26e406a salt.modules.upstart: fix lint errors

  * 03278bd Improve Upstart enable/disable handling

- **PR** `#23105`_: (*ngrennan-inflection*) Fixing return code to be "1" instead of 0 when the return code of a run is something other than 0
  | refs: `#25588`_ `#25588`_
  @ *2015-06-17T18:37:23Z*

  - **ISSUE** `#23102`_: (*ngrennan-inflection*) salt-ssh doesn't have a non-zero return code on a failure.
    | refs: `#23105`_
  * e99863c Merge pull request `#23105`_ from ngrennan-inflection/salt-ssh-return-code
  * d02d365 Fixing retcode for normal run with no errors

  * 041bdbf Adding EX_AGGREGATE exit code and using it

  * 16ac1d8 Cleaning up extra spaces

  * ce41e41 Merge branch 'salt-ssh-return-code' of github.com:ngrennan-inflection/salt into salt-ssh-return-code

    * 593491f Adding zero to avoid error

    * 43a6511 Adding extra line to make pylint happy

    * b2a888e Moving final_exit out of the loop

  * 305d743 Adding retcode for salt-ssh in some cases

  * 7592ef9 Fixing return code to be "1" instead of 0 when the return code of a run is something other than 0

- **PR** `#24762`_: (*cachedout*) Add Boron release notes
  @ *2015-06-17T18:30:11Z*

  * f5e0ee1 Merge pull request `#24762`_ from cachedout/boron_notes
  * ae65d78 Add Boron release notes

- **PR** `#24703`_: (*mattmb*) Multiple onchanges requisite behaviour
  @ *2015-06-17T18:26:40Z*

  - **ISSUE** `#19592`_: (*lorengordon*) Execute a state when any of several other states change
    | refs: `#24703`_
  * e6dcf3a Merge pull request `#24703`_ from mattmb/fix/onchanges-and-or
  * a5607d5 Multiple onchanges requisite behaviour

- **PR** `#24757`_: (*cachedout*) Fix loader call in pyobjects
  @ *2015-06-17T17:59:29Z*

  - **PR** `#24668`_: (*grischa*) enable virtual package names in pyobjects renderer
    | refs: `#24757`_
  * 9b3ec4b Merge pull request `#24757`_ from cachedout/fix_pyobjects
  * 1aab1bd Fix loader call in pyobjects

- **PR** `#24756`_: (*rallytime*) Remove SALT_CLOUD_REQS from setup.py --> develop
  @ *2015-06-17T17:42:51Z*

  - **PR** `#24715`_: (*rallytime*) Remove requirements/cloud.txt
    | refs: `#24756`_
  * 7f01eda Merge pull request `#24756`_ from rallytime/fix_setup_develop
  * 9a6b159 Remove SALT_CLOUD_REQS from setup.py --> develop

- **PR** `#24760`_: (*cachedout*) Fix GPG in `#24084`_
  @ *2015-06-17T17:33:17Z*

  * 7b8609b Merge pull request `#24760`_ from cachedout/issue_24084
  * a2f5b64 Switch to get to fix failing test

- **PR** `#24084`_: (*quantonganh*) gpg module: fix result checking of import_key()
  @ *2015-06-17T17:32:51Z*

  - **ISSUE** `#24082`_: (*quantonganh*) gpg module: AttributeError: 'ImportResult' object has no attribute 'imported'
    | refs: `#24084`_
  * d6227bd Merge pull request `#24084`_ from quantonganh/gpg-module-import-key
  * bf57c0b gpg module: fix result checking of import_key()

- **PR** `#24743`_: (*The-Loeki*) Contribution: Addition of udev information module
  @ *2015-06-17T17:18:01Z*

  * 999e6f7 Merge pull request `#24743`_ from The-Loeki/udevmodule
  * 07da991 CopyPasteFix is a difficult workflow

  * 74250d5 Doc fixes for udev

  * e8c7ebd Addition of udev information module

- **PR** `#23383`_: (*cachedout*) Overstate is dead. Long live orchestrate!
  @ *2015-06-17T17:14:52Z*

  * d877f4f Merge pull request `#23383`_ from cachedout/remove_overstate
  * dab4ecc Remove overstate tests

  * c9277c5 Pylint

  * d23a669 Remove overstate tests

  * 7dae045 Remove overstate documentation

  * c4a7961 Remove overstate system

- **PR** `#24706`_: (*jacksontj*) Fix `#23289`_ Workaround for pyzmq's inability to unregister sockets sometimes
  @ *2015-06-17T17:01:10Z*

  - **ISSUE** `#23289`_: (*UtahDave*) `cp.push` stacktraces on an empty file
  * 6ff1468 Merge pull request `#24706`_ from jacksontj/develop
  * baca9bf Fix `#23289`_ Workaround for pyzmq's inability to unregister sockets sometimes

- **PR** `#24679`_: (*cachedout*) Include data in highstate outputter
  @ *2015-06-17T16:59:35Z*

  - **ISSUE** `#24665`_: (*techhat*) Highstate outputter does not show data from monitoring states
    | refs: `#24679`_
  * 091725d Merge pull request `#24679`_ from cachedout/issue_24665
  * 909c1a2 Lint

  * b743555 Include data in highstate outputter

- **PR** `#24720`_: (*TheScriptSage*) Issue 24621 - AD/LDAP Group Auth Issue
  @ *2015-06-17T16:43:08Z*

  * f51bb58 Merge pull request `#24720`_ from TheScriptSage/develop
  * f763395 Updating master.py to properly check against groups when user is only authed against group.  Tested against unit.auth_test.

- **PR** `#24707`_: (*rallytime*) Move Linode driver to use REST API instead of libcloud/python-linode
  | refs: `#25015`_
  @ *2015-06-17T16:42:57Z*

  * 4e63e57 Merge pull request `#24707`_ from rallytime/linode_rest
  * 11b0ea9 Add note to docs about needing a default root password

  * 64447fa Pylint

  * f7c7c09 Move Linode driver to use REST API instead of libcloud/python-linode

- **PR** `#24749`_: (*obestwalter*) add windows specfic default for multiprocessing
  @ *2015-06-17T15:42:21Z*

  * 2cfaae7 Merge pull request `#24749`_ from obestwalter/patch-1
  * 027bb2d add windows specfic default for multiprocessing

- **PR** `#24735`_: (*notpeter*) Add 2015.5 codename to version numbers docs
  @ *2015-06-17T03:31:08Z*

  * 4cbef0f Merge pull request `#24735`_ from notpeter/develop
  * 05114de Add codenames for 2015.5 and future versions. Trailing newline.

- **PR** `#24717`_: (*gthb*) virtualenv.managed: document user and no_chown
  @ *2015-06-17T03:19:11Z*

  * 023b171 Merge pull request `#24717`_ from gthb/issue-24716
  * 2ed86d1 virtualenv.managed: document user and no_chown

- **PR** `#24715`_: (*rallytime*) Remove requirements/cloud.txt
  | refs: `#24756`_
  @ *2015-06-17T03:17:25Z*

  * b67742d Merge pull request `#24715`_ from rallytime/remove_cloud_reqs_develop
  * 9a3caa2 Remove requirements/cloud.txt

- **PR** `#24726`_: (*techhat*) Allow manually assigning IP address
  @ *2015-06-16T23:03:48Z*

  - **ISSUE** `#14791`_: (*mvdwalle*) [salt-cloud][Gogrid] Define IP-adresses in advance when creating a VM
    | refs: `#24726`_
  * 00916ac Merge pull request `#24726`_ from techhat/gogridip
  * d09c1a0 Linting

  * b4dd2c4 Add versionadded

  * fb7957b Update docs for GoGrid

  * de0756b Allow manually assigning IP address

- **PR** `#24725`_: (*basepi*) Merge forward from 2015.5 to develop
  @ *2015-06-16T22:46:35Z*

  * 67142fd Merge pull request `#24725`_ from basepi/merge-forward-develop
  * 2ae0d7d Merge remote-tracking branch 'upstream/2015.5' into merge-forward-develop

- **PR** `#24728`_: (*rallytime*) Remove development warning from nova driver
  @ *2015-06-16T21:49:14Z*

  - **PR** `#24686`_: (*techhat*) Deprecate openstack driver
    | refs: `#24728`_
  * b32e6cb Merge pull request `#24728`_ from rallytime/remove_nova_warning
  * 000668b Remove development warning from nova driver

- **PR** `#24710`_: (*rallytime*) Fix pylint failure on develop
  @ *2015-06-16T19:15:03Z*

  * 65dd8b6 Merge pull request `#24710`_ from rallytime/pylint-fix
  * 81a0c2b Fix pylint failure on develop

- **PR** `#24705`_: (*cachedout*) Lint PR
  @ *2015-06-16T16:49:43Z*

  - **PR** `#24629`_: (*frostyslav*) Add username/password support to artifactory module
    | refs: `#24705`_
  * 4a34922 Merge pull request `#24705`_ from cachedout/lint_24629
  * 5aff5c4 Lint PR

- **PR** `#24678`_: (*batulin-s*) change ebuild.py latest_version function
  @ *2015-06-16T15:32:28Z*

  * 84d9fca Merge pull request `#24678`_ from batulin-s/improve-support-portage
  * d1fe490 change ebuild.py latest_version function - now it returns latest version of package independent of installed package

- **PR** `#24615`_: (*msteed*) py3 unittest compat
  @ *2015-06-16T15:25:19Z*

  * 1753234 Merge pull request `#24615`_ from msteed/py3-unittests-5
  * 0a5725a no-op

  * 77f4e59 Revert "py3: fix salt/payload.py"

  * 5eb097e py3: fix tests/unit/states/cron_test.py

  * 846e1a2 py3: fix tests/unit/stateconf_test.py

  * 0b20abd py3: fixes to salt/utils/event.py and schedule.py

  * 9e27682 py3: fix version.py

  * ca34897 py3: fix salt/modules/win_status.py and tests

  * e7620a2 py3: fix tests/unit/states/modjk_test.py

  * 56941f9 rm pdb invocation :/

  * 6f0da2a py3: (mostly) fix tests/unit/pydsl_test.py

  * f688700 py3: fix salt/modules/file.py

  * 90929f9 py3: fix salt/fileserver/roots.py

  * b4bc60d py3: fix salt/modules/dockerng.py

  * 4b6b4d1 py3: fix tests/unit/pillar_test.py

  * 11b99ba py3: fix salt/serializers/yamlex.py

  * 229f7c9 py3: fix salt/serializers/yaml.py

  * 11ba14c py3: decode msgpack strings as utf-8

  * dcf4f0e py3: fix salt/payload.py

- **PR** `#24668`_: (*grischa*) enable virtual package names in pyobjects renderer
  | refs: `#24757`_
  @ *2015-06-16T15:05:58Z*

  * eef9317 Merge pull request `#24668`_ from grischa/pyobjects_honour_virtual
  * c0c25e8 fixing other test

  * 2739be2 fixing text for virtual support in pyobjects

  * be4d2b6 enable virtual package names in pyobjects renderer

- **PR** `#24629`_: (*frostyslav*) Add username/password support to artifactory module
  | refs: `#24705`_
  @ *2015-06-16T15:02:39Z*

  * 678ce0c Merge pull request `#24629`_ from frostyslav/develop
  * 18f08c5 Fix tests for artifactory module

  * f2db700 Add username/password support to artifactory module

- **PR** `#24700`_: (*t0fik*) Return type consistency
  @ *2015-06-16T14:56:38Z*

  * d43a06a Merge pull request `#24700`_ from jdsieci/develop
  * c758fa3 Merge remote-tracking branch 'upstream/develop' into develop

  * 90d21bc Merge remote-tracking branch 'upstream/develop' into develop

  * 449a67c Changed return value if Exception occurs to empty list

- **PR** `#24692`_: (*garethgreenaway*) fix to returners configuration
  @ *2015-06-16T14:56:11Z*

  * 00d4f9d Merge pull request `#24692`_ from garethgreenaway/returner_configuration_fixes
  * f97089e Fixing an issue when configuring returners and specifing the configuration as a dictionary.

- **PR** `#24684`_: (*techhat*) Move get_salt_interface() to salt.utils.cloud
  @ *2015-06-16T02:59:36Z*

  * 211bf36 Merge pull request `#24684`_ from techhat/getsaltinterface
  * 2974473 Linting

  * 5096813 Move get_salt_interface() to salt.utils.cloud

- **PR** `#24691`_: (*techhat*) Fix pricing examples
  @ *2015-06-16T02:58:12Z*

  * 9dff54a Merge pull request `#24691`_ from techhat/pricingexample
  * 257f412 Fix pricing examples

- **PR** `#24339`_: (*devopsbrett*) Use consul as an external pillar source. Requires python-consul
  @ *2015-06-15T21:16:27Z*

  * 5ee8e50 Merge pull request `#24339`_ from devopsbrett/add-consul-support
  * c86a3d3 Merge branch 'add-consul-support' of github.com:devopsbrett/salt into add-consul-support

    * e92a7ca Fixed change to README

    * 8405802 Don't split multiline values into a list if wrapped inside " Use salt.utils.dictupdate to merge dictionaries

    * 9963bef ping

    * 50c8048 More style guideline fixes

    * e4d4e9b Style changes to bring code in line with coding standards

    * df7530d Fixed a typo

    * c90db5b Use consul as an external pillar source. Requires python-consul

  * 410f942 Fixed change to README

  * 6ca1dbd Don't split multiline values into a list if wrapped inside " Use salt.utils.dictupdate to merge dictionaries

  * ec95fe1 ping

  * 1bbaf0e More style guideline fixes

  * 2ce52ee Style changes to bring code in line with coding standards

  * ec932f2 Fixed a typo

  * fed5ce8 Use consul as an external pillar source. Requires python-consul

- **PR** `#24681`_: (*techhat*) Move Azure driver to salt.utils.cloud.bootstrap()
  @ *2015-06-15T21:10:19Z*

  * 3b57bbb Merge pull request `#24681`_ from techhat/azurebootstrap
  * 5a43791 Linting

  * e5a7d69 Move Azure driver to salt.utils.cloud.bootstrap()

- **PR** `#24686`_: (*techhat*) Deprecate openstack driver
  | refs: `#24728`_
  @ *2015-06-15T20:46:43Z*

  * 70d4574 Merge pull request `#24686`_ from techhat/depreopenstack
  * 7b960bc Use correct deprecation function

  * e236044 Deprecate openstack driver

- **PR** `#24685`_: (*techhat*) Remove unused ssh_pub() function from libcloudfuncs
  @ *2015-06-15T18:17:15Z*

  * 5f417d5 Merge pull request `#24685`_ from techhat/delsshpub
  * aa5bb87 Remove unused ssh_pub() function from libcloudfuncs

- **PR** `#24682`_: (*techhat*) Fix kwarg checking in Azure driver
  @ *2015-06-15T16:25:14Z*

  * d02a718 Merge pull request `#24682`_ from techhat/azurekwargs
  * f23107e Fix kwarg checking in Azure driver

- **PR** `#24641`_: (*garethgreenaway*) Changes to various schedule related functions to ensure persistence.
  @ *2015-06-15T16:05:08Z*

  * 8997d95 Merge pull request `#24641`_ from garethgreenaway/more_schedule_persistence
  * d68cd6f fixing unit tests related to schedule jobs in pillar.

  * bbd1bfe only persist non-pillar schedule items

  * 56ee5b7 updating unit tests to reflect changes.

  * ce6ebde Fixing lint and unit test issues.

  * 0eb9420 Adding the default option to persist the configured schedule into /etc/salt/minion.d/_schedule.conf to all schedule related functions in the execution module.  Adding documention to the state module showing how to control persistence.  Reworked the save function in the schedule execution module to follow suit and save to /etc/salt/minion.d/_schedule.conf as well.

- **PR** `#24625`_: (*tankywoo*) remove unneeded os.walk require directory
  @ *2015-06-15T16:04:36Z*

  - **ISSUE** `#15862`_: (*tankywoo*) Performance problem in states.file.directory function
    | refs: `#24625`_
  - **PR** `#15912`_: (*tankywoo*) Fix `#15862`_ remove dirs in keep list when walk path
    | refs: `#24625`_
  * 35d3748 Merge pull request `#24625`_ from tankywoo/file-directory-clean-performance
  * f2d9705 remove unneeded os.walk require directory

- **PR** `#24672`_: (*s0undt3ch*) Pass options to dump function
  @ *2015-06-15T16:04:11Z*

  * 9bc4843 Merge pull request `#24672`_ from s0undt3ch/develop
  * 36c0806 Pass options to dump function

- **PR** `#24656`_: (*garethgreenaway*) Converting nagios_rpc to salt.utils.http
  @ *2015-06-15T15:59:40Z*

  * 8f90f68 Merge pull request `#24656`_ from garethgreenaway/nagios_rpc_salt_utils_http
  * 41f9033 lint

  * 19dd977 Converting nagios_rpc to salt.utils.http

- **PR** `#24640`_: (*techhat*) Move digital_ocean to salt.utils.cloud.bootstrap()
  @ *2015-06-15T15:35:46Z*

  * 9c12d30 Merge pull request `#24640`_ from techhat/digitalocean
  * 7860241 Linting

  * 01f3355 Move digital_ocean to salt.utils.cloud.bootstrap()

- **PR** `#24636`_: (*techhat*) Cleanup old libcloud references
  @ *2015-06-15T15:35:07Z*

  * 9aa70ad Merge pull request `#24636`_ from techhat/libcloudcleanup
  * 4e814a1 Namespaced

  * 74a7004 More lint

  * eb327c0 Linting

  * 5558b32 Cleanup old libcloud references

- **PR** `#24675`_: (*geraint-jones-nz*) Rabbitmq 3.2.4 on Ubuntu has `...done.` not `...done`
  @ *2015-06-15T15:26:54Z*

  * 7e00fc0 Merge pull request `#24675`_ from geraint-jones-nz/develop
  * 3c3d99f Rabbitmq 3.2.4 on Ubuntu has ...done. not ...done, change the if to be more portable

- **PR** `#24657`_: (*gashev*) Fixed warning salt.loaded.int.module.rpmbuild.__virtual__() is wrongly returning `None`.
  @ *2015-06-15T15:17:50Z*

  * a7f146f Merge pull request `#24657`_ from gashev/rpmbuild_virtual_fix
  * cb741b3 Fixed warning: salt/modules/rpmbuild.py:34: [E8302(expected-2-blank-lines-found-0), ] PEP8 E302: expected 2 blank lines, found 0.

  * 2290f43 Fixed warning salt.loaded.int.module.rpmbuild.__virtual__() is wrongly returning `None`.

- **PR** `#24634`_: (*techhat*) Move GoGrid to a direct REST driver
  @ *2015-06-13T15:55:15Z*

  * 388e1be Merge pull request `#24634`_ from techhat/gogrid
  * f01b853 Fix docstrings

  * bbb76bf Linting

  * a00b7b4 Fix virtualname

  * aab9e0e Move GoGrid to a direct REST driver

- **PR** `#24662`_: (*rallytime*) Add versionadded to show_pricing function for digital ocean and GCE
  @ *2015-06-13T15:54:44Z*

  * 6107f00 Merge pull request `#24662`_ from rallytime/develop
  * 4c29af7 Version added for show_pricing for GCE too

  * 6da5e1a Add versionadded to show_pricing function for digital ocean

- **PR** `#24645`_: (*techhat*) Add pricing data to digital_ocean
  @ *2015-06-13T14:45:52Z*

  * 047018c Merge pull request `#24645`_ from techhat/dopricing
  * fd1fded Add pricing data to digital_ocean

- **PR** `#24652`_: (*techhat*) Adding pricing information for GCE
  @ *2015-06-13T04:22:27Z*

  * d733a82 Merge pull request `#24652`_ from techhat/gceprice
  * 06c8852 Linting

  * 699e279 Adding pricing information for GCE

- **PR** `#24633`_: (*basepi*) Merge forward from 2015.5 to develop
  @ *2015-06-12T21:54:45Z*

  * 806dbe5 Merge pull request `#24633`_ from basepi/merge-forward-develop
  * 0de6acc Merge remote-tracking branch 'upstream/2015.5' into merge-forward-develop

  * 5b49e89 Merge remote-tracking branch 'upstream/2015.5' into merge-forward-develop

- **PR** `#24635`_: (*techhat*) Deprecate the aws driver for Salt Cloud, in favor of ec2
  @ *2015-06-12T19:57:49Z*

  * 478d790 Merge pull request `#24635`_ from techhat/deprecateaws
  * 41a212e Deprecate the aws driver for Salt Cloud, in favor of ec2

- **PR** `#24614`_: (*skizunov*) Add support for presence change of a locally connected minion
  @ *2015-06-12T16:25:19Z*

  * 95dc331 Merge pull request `#24614`_ from skizunov/develop2
  * aca0894 Add support for presence change of a locally connected minion

- **PR** `#24610`_: (*adelcast*) Allow '-' on lsb grains
  @ *2015-06-12T16:24:59Z*

  * 73b1f38 Merge pull request `#24610`_ from adelcast/dev/adelcast/fix_lsb_grains
  * 32522c6 Allow '-' on lsb grains

- **PR** `#24618`_: (*madprog*) Add 'm_state' to 'm_'-prefixed arguments of 'module.run'
  @ *2015-06-12T02:01:01Z*

  * 9f24ec2 Merge pull request `#24618`_ from madprog/develop
  * 8c85a04 Add prefixable argument `state' for module.run

  * f3bb50c Add names of prefixable module arguments in doc

- **PR** `#24606`_: (*basepi*) Merge forward from 2015.5 to develop
  @ *2015-06-11T22:57:11Z*

  * 21d9df2 Merge pull request `#24606`_ from basepi/merge-forward-develop
  * 725e5c6 Merge remote-tracking branch 'upstream/2015.5' into merge-forward-develop

- **PR** `#24602`_: (*msteed*) Undo the memoization of contrived locale
  @ *2015-06-11T19:55:37Z*

  * 22c4449 Merge pull request `#24602`_ from msteed/py3-fix-ascii-arch
  * 91aeaab undo the memoization of contrived locale

- **PR** `#24599`_: (*jacobhammons*) changed 'reload_modules' argument to 'refresh' in sync_modules function
  @ *2015-06-11T18:48:50Z*

  - **ISSUE** `#24056`_: (*BlaineAtAffirm*) Minor doc string bug with modules.saltutil.sync_all
    | refs: `#24599`_
  * 8e2599d Merge pull request `#24599`_ from jacobhammons/24056
  * e62a3f1 changed 'reload_modules' argument to 'refresh' in sync_all function

  * 0f840e0 changed 'reload_modules' argument to 'refresh' in sync_modules function Refs `#24056`_

- **PR** `#24597`_: (*rallytime*) Fix doc example test that is failing on develop
  @ *2015-06-11T17:06:48Z*

  * bef32b8 Merge pull request `#24597`_ from rallytime/slack_doc_example
  * 3283a5d Fix doc example test that is failing on develop

- **PR** `#24549`_: (*jfindlay*) Shutdown time
  @ *2015-06-11T16:20:55Z*

  - **ISSUE** `#24411`_: (*vernondcole*) module system.shutdown timeout value not documented and inconsistant
    | refs: `#24549`_
  * 78a6814 Merge pull request `#24549`_ from jfindlay/shutdown_time
  * 79de6cd prefer shutdown timeout value in minutes on windows

  * b845775 document system.shutdown arg

- **PR** `#24591`_: (*tbaker57*) Add some documentation surrounding Jinja vs yaml comments -
  @ *2015-06-11T15:54:17Z*

  - **ISSUE** `#24494`_: (*arnoutpierre*) Computed comments in jinja states
    | refs: `#24591`_
  - **ISSUE** `#24073`_: (*primechuck*) State.highstate uses stale grain data.
    | refs: `#24492`_
  - **ISSUE** `#23359`_: (*BalintSzigeti*) init.sls parsing issue
    | refs: `#24591`_
  - **ISSUE** `#21217`_: (*Colstuwjx*) Maybe a bug for jinja render?
    | refs: `#24591`_
  - **PR** `#24492`_: (*DmitryKuzmenko*) Don't remove grains from opts
  * 2059548 Merge pull request `#24591`_ from tbaker57/issue_24494
  * a39ecc3 Add extra clarification why jinja comments are needed.

  * e57cdf5 Fix typo

  * bbdcc5a Add some documentation surrounding Jinja comments - refs `#24492`_, `#21217`_, `#23359`_

- **PR** `#24584`_: (*cachedout*) Fix unit test warnings
  @ *2015-06-11T15:17:59Z*

  * 39ef4f3 Merge pull request `#24584`_ from cachedout/unit_warnings
  * b3b1536 Derp

  * 7e153bc Fix unit test warnings

- **PR** `#24582`_: (*kaithar*) Fixing mysql list jobs
  @ *2015-06-11T02:17:03Z*

  - **ISSUE** `#22713`_: (*ckochenower*) Should get_jids required for Master/External Job Cache should return a dictionary!
    | refs: `#24582`_
  * ea57845 Merge pull request `#24582`_ from kaithar/issue/Fixing-mysql-list_jobs
  * f4386b7 MIssed a blank newline

  * 8ae51d2 Have get_jids() return a dict instead of a list

  * 27dfc60 Move format_jid_instance from local_cache.py to jid.py to allow reuse

  * bdfaffe Change the documentation for get_jids() to not claim it returns a list

- **PR** `#24124`_: (*ticosax*) [dockerng] Migrate salt.mine to dockerng
  @ *2015-06-11T02:15:17Z*

  * 5ec9d33 Merge pull request `#24124`_ from ticosax/mine-dockerng
  * 9a435c4 Make sure legacy docker execution module is still refreshing mine data

  * 1e8e082 Migrate salt.mine to dockerng

- **PR** `#24557`_: (*msteed*) More py3 unittest fixes
  @ *2015-06-11T02:14:14Z*

  * d3feedd Merge pull request `#24557`_ from msteed/py3-unittests-4
  * 63531c2 fix failing unit test

  * 2434364 py3: fix salt/utils/locales

  * f43d563 py3: fix tests/unit/modules/win_status_test.py

  * afbd52b py3: fix tests/unit/modules/win_network_test.py

  * 6abd6d2 py3: fix tests/unit/modules/win_dns_client_test.py

  * 8897e5f lint

  * 0b20f54 py3: fix salt/modules/win_disk.py

  * 989062a Merge branch 'py3-unittests-4' of github.com:msteed/salt into py3-unittests-4

    * da1bb74 py3: fix salt/crypt.py

  * de7fe49 py3: fix tests/unit/modules/virt_test.py

  * aec070d py3: fix salt/modules/slack_notify.py

  * cb29857 py3: fix salt/crypt.py

- **PR** `#24552`_: (*joejulian*) Don't pollute the TZ environment variable
  @ *2015-06-11T02:13:21Z*

  - **ISSUE** `#24480`_: (*kiorky*) [CRITICAL] [2015.5] tls breaks tzinfo
    | refs: `#24552`_
  * 14c22e6 Merge pull request `#24552`_ from joejulian/develop_dont_pollute_environment
  * 9199893 Don't pollute the TZ environment variable

- **PR** `#24545`_: (*jfindlay*) add purge option to aptpkg.autoremove
  @ *2015-06-11T02:12:23Z*

  - **ISSUE** `#24370`_: (*Talkless*) Feature request: aptpkg: --purge option for autoremove
    | refs: `#24545`_
  * 6df201a Merge pull request `#24545`_ from jfindlay/apt_purge
  * 5638e43 add purge option to aptpkg.autoremove

- **PR** `#24544`_: (*garethgreenaway*) Converting pushover to use salt.utils.http
  @ *2015-06-11T02:12:12Z*

  * e637c84 Merge pull request `#24544`_ from garethgreenaway/pushover_refactor_salt_utils_http
  * ffab488 fixing lint.

  * 9c75066 Converting pushover to use salt.utils.http

- **PR** `#24534`_: (*skizunov*) On Windows, don't use IsUserAnAdmin() because it is deprecated
  @ *2015-06-11T02:11:25Z*

  * d87949c Merge pull request `#24534`_ from skizunov/develop2
  * 59c605b On Windows, don't use IsUserAnAdmin() because it is deprecated

- **PR** `#24531`_: (*DmitryKuzmenko*) salt.utils.which() don't lookup outside sys.path
  @ *2015-06-11T02:10:56Z*

  - **ISSUE** `#24085`_: (*thenewwazoo*) Salt caller raises CommandExecutionError when grains loader can't find a command
    | refs: `#24531`_
  - **ISSUE** `#7990`_: (*shantanub*) /usr/bin/salt-call network.interfaces not working in v.17 like it did in v.16.4 in a cronjob
    | refs: `#24531`_
  * 46a8719 Merge pull request `#24531`_ from DSRCompany/which_fix
  * 31aef18 salt.utils.which() don't lookup outside $PATH

- **PR** `#24519`_: (*dmyerscough*) Additional Riak features with error messages printed
  @ *2015-06-11T02:10:29Z*

  * 5df5fb0 Merge pull request `#24519`_ from dmyerscough/riak-module
  * a8254f1 Fixing pylint errors

  * 59e04d1 Fixing unittests for new functionality

  * d6c4102 Fixing version added and changed

  * 00946ac Additional Riak features with error messages printed

- **PR** `#24511`_: (*jquast*) bugfix: trailing "...done" in rabbitmq output
  @ *2015-06-11T02:09:23Z*

  * 94067fd Merge pull request `#24511`_ from jquast/rabbitmq-trailing-outp-fix
  * a154280 bugfix: trailing "...done" in rabbitmq output

- **PR** `#24316`_: (*kev009*) New disks grain
  @ *2015-06-11T02:09:06Z*

  * 16ffe20 Merge pull request `#24316`_ from kev009/freebsd-disks-grain
  * 18ba0d8 Remove unneeded print

  * 3aafa64 Add an index to the string format to make lint happy

  * 7962612 Lint

  * b009763 Simplify attribs list with list comprehension

  * 1036764 New disks grain

- **PR** `#24576`_: (*basepi*) Merge forward from 2015.5 to develop
  @ *2015-06-10T19:40:02Z*

  * b869823 Merge pull request `#24576`_ from basepi/merge-forward-develop
  * d9db80c Merge remote-tracking branch 'upstream/2015.5' into merge-forward-develop

- **PR** `#24570`_: (*msteed*) network module: import ipaddress the same way as in other modules
  @ *2015-06-10T16:57:58Z*

  * 24c90c7 Merge pull request `#24570`_ from msteed/py3-fix-arch-again
  * c390fc5 import ipaddress the same way as in other modules

- **PR** `#24516`_: (*nmadhok*) Make sure to catch TypeErrors
  @ *2015-06-10T16:37:32Z*

  * 03c1df3 Merge pull request `#24516`_ from nmadhok/patch-1
  * dfa1cf2 Python3 compat

  * 9471cd6 Update vmware.py

- **PR** `#24569`_: (*iacopo-papalini*) Fix Issue `#24559`_ - salt-cloud - Azure - should be possible to specify…
  @ *2015-06-10T15:56:31Z*

  - **ISSUE** `#24559`_: (*iacopo-papalini*) salt-cloud - Azure - should be possible to specify virtual network & subnet in profile
  * 9988310 Merge pull request `#24569`_ from iacopo-papalini/feature-`#24559`_
  * 11e97fe Fix Issue `#24559`_ - salt-cloud - Azure - should be possible to specify virtual network & subnet in profile

- **PR** `#24542`_: (*msteed*) py3: fix arch failures
  @ *2015-06-09T23:49:52Z*

  * eced487 Merge pull request `#24542`_ from msteed/py3-fix-arch
  * ddde2e1 use a realistic service sid in test_getsid()

  * 454e86a py3: fix salt/modules/win_service.py

  * f9cf15a fix new failures on ubuntu 14.04

  * f725b8e lint

  * 0543f9a fix tests/unit/modules/network_test.py

  * 8669dac likewise in test_render_with_utf8_syntax_error()

  * 4b34b60 set encoding in test_render_with_unicode_syntax_error()

  * ce5f14b set encoding in test__unicode_match()

  * f85a3e3 specify encoding in test_to_str()

- **PR** `#24550`_: (*basepi*) Update six to 1.9.0
  @ *2015-06-09T23:29:02Z*

  * b5c5fe3 Merge pull request `#24550`_ from basepi/six1.9upgrade
  * c9fc247 Update six to 1.9.0

- **PR** `#24539`_: (*basepi*) Merge forward from 2015.5 to develop
  @ *2015-06-09T21:15:13Z*

  * 359efdf Merge pull request `#24539`_ from basepi/merge-forward-develop
  * 6e87ad3 lint

  * 52a694b Python 3 compat

  * 94d6ef1 Merge remote-tracking branch 'upstream/2015.5' into merge-forward-develop

- **PR** `#24476`_: (*thatch45*) Rpmbuild
  @ *2015-06-09T20:27:02Z*

  * 1023f9b Merge pull request `#24476`_ from thatch45/rpmbuild
  * bd64e4d Add pylint disable

  * c6fec0d lint

  * c8fe849 Add docs to pkgbuiild state

  * 766cf0a Add docs to rpmbuild

  * 259a568 fix stagnat file issues

  * 058b9f9 Add initial pkgbuild.repo state

  * fbc5c85 apply a bunch of fixes

  * 7c24a3d some little fixes

  * d40654b initial pkgbuild state

  * d4db402 change to name pkgbuild

  * 48b83f8 initial mapping of the rpmbuild execution module

  * c57f012 initial work on the rpmbuild module

- **PR** `#24543`_: (*rallytime*) The first arg in a state should always be name, and unfreeze name from salt/state.py
  @ *2015-06-09T20:07:14Z*

  - **PR** `#24332`_: (*jacksontj*) Add party controls to zk_concurrency
    | refs: `#24543`_
  * dfef03f Merge pull request `#24543`_ from rallytime/fix_centos_prkrepo_test
  * eb02eee The first arg in a state should always be name, and unfreeze name from salt/state.py

- **PR** `#24536`_: (*ryan-lane*) Support all route53 record types
  @ *2015-06-09T19:41:58Z*

  * a10ccc5 Merge pull request `#24536`_ from lyft/route53-more-record-support
  * d8bf25c Support all route53 record types

- **PR** `#24532`_: (*kiorky*) [CRITICAL] Fix syntax error
  @ *2015-06-09T16:59:54Z*

  * a652bef Merge pull request `#24532`_ from makinacorpus/syntax_error2
  * bff68cf Fix syntax error

- **PR** `#24492`_: (*DmitryKuzmenko*) Don't remove grains from opts
  @ *2015-06-09T15:11:25Z*

  - **ISSUE** `#24073`_: (*primechuck*) State.highstate uses stale grain data.
    | refs: `#24492`_
  * 2418b1e Merge pull request `#24492`_ from DSRCompany/keep_grains_in_opts
  * 1d42ae5 Don't remove grains from opts

- **PR** `#24514`_: (*msteed*) More py3 unittest fixes
  @ *2015-06-09T15:10:35Z*

  * 06279dd Merge pull request `#24514`_ from msteed/py3-unittests-3
  * f99fa67 Update docstring on mac_str_to_bytes()

  * cb83dbf py3: fix tests/unit/modules/pkg_resource_test.py

  * 03ba3c4 py3: fix tests/unit/modules/network_test.py

  * cc1a6ac py3: fix salt/utils/http.py

  * cded6bf py3: fix salt/modules/rh_ip.py and tests

  * 73bae6d py3: fix salt/modules/random_org.py

  * 980e799 py3: fix salt/modules/postgres.py and tests

  * b2b3511 py3: fix salt/modules/pecl.py

  * f163e50 py3: fix salt/modules/network.py and friends

  * 24626b7 py3: fix salt/modules/linux_sysctl.py

- **PR** `#24518`_: (*rallytime*) Merge `#24448`_ with Pylint Fixes
  @ *2015-06-09T05:48:14Z*

  - **PR** `#24448`_: (*codertux*) Update modules path for operating systems using systemd
    | refs: `#24518`_
  * 88d2eec Merge pull request `#24518`_ from rallytime/merge-24448
  * 28af2bf Pylint fix

  * 3a155e6 Update modules path for operating systems using systemd

- **PR** `#24356`_: (*kev009*) ignore_timeout on cmd.run/watch
  @ *2015-06-09T04:40:09Z*

  * de8a08b Merge pull request `#24356`_ from kev009/cmdmod-notimeout
  * 8ed6966 Add versionadded meta to cmd.run ignore_timeout

  * 47ba15b ignore_timeout on cmd.run/watch

- **PR** `#24459`_: (*basepi*) Merge forward from 2015.5 to develop
  @ *2015-06-09T04:27:08Z*

  - **ISSUE** `#18`_: (*thatch45*) Minon needs to be able to reload modules
  * 87e1c60 Merge pull request `#24459`_ from basepi/merge-forward-develop
  * 49819f3 Merge pull request `#18`_ from joejulian/fix_tls_tests_for_forward_merge

    * 4a840f3 Fix tls test to work against develop branch

    * 81c242d Fix incorrect path printing

    * 0487137 Revert "Disable tls tests (for now)"

  * 5833a0e Disable tls tests (for now)

  * 9cf402e Python3 compat

  * 6d503c1 Merge remote-tracking branch 'upstream/2015.5' into merge-forward-develop

- **PR** `#24509`_: (*t0fik*) BugFix in new RH route template
  @ *2015-06-09T04:02:36Z*

  * cadba53 Merge pull request `#24509`_ from jdsieci/develop
  * fbb6f88 Merge remote-tracking branch 'upstream/develop' into develop

  * 3fac7cd Bugfix in template. Missing endif block

- **PR** `#24505`_: (*UtahDave*) Add missing string formatting
  @ *2015-06-09T03:57:49Z*

  * 274815b Merge pull request `#24505`_ from UtahDave/develop
  * 79b6888 Add missing string formatting

- **PR** `#24503`_: (*garethgreenaway*) Fixes to random_org.py
  @ *2015-06-09T03:56:53Z*

  * 18a09f4 Merge pull request `#24503`_ from garethgreenaway/refactor_random_salt_utils_http
  * 571e26e missing import for salt.utils.http

- **PR** `#24489`_: (*nmadhok*) If deploying salt on windows VM, 'win_password' may be specified instead of 'password'
  @ *2015-06-09T03:39:46Z*

  - **ISSUE** `#23574`_: (*CedNantes*) Failed to Deploy Salt-Minion on a Win 2012 R2 using wmware Cloud Driver from Develop branch
    | refs: `#24489`_ `#25462`_ `#25519`_
  * ad02a04 Merge pull request `#24489`_ from nmadhok/patch-cloud
  * e011219 If deploying salt on windows VM, win_password may be specified instead of password Fixes `#23574`_

- **PR** `#24500`_: (*msteed*) Continued unit test py3 compat
  @ *2015-06-08T21:52:21Z*

  * 4c8e8a4 Merge pull request `#24500`_ from msteed/py3-unittests-2
  * c56631b Added "CLI Example" to make failing test happy on develop

  * 911b39f fix deprecation warnings shown during unit tests

  * 97be5d7 py3: fix tests/unit/modules/ini_manage_test.py

  * bd8538d py3: fix salt/modules/file.py and unit tests

  * 12be97a py3: fix salt/modules/debian_ip.py

  * 3c5e82e py3: fix tests/unit/modules/deb_apache_test.py

  * a4c8e31 py3: fix salt/utils/rsax931.py and tests

  * 4bad02e py3: use salt.ext.six.moves.urllib instead of urllib2

  * a1b693a fix failure in btrfs_test.py

- **PR** `#24508`_: (*skizunov*) On Windows, use win32api.GetUserName instead of getpass.getuser
  @ *2015-06-08T21:11:36Z*

  * c7bf4e1 Merge pull request `#24508`_ from skizunov/develop2
  * 2c5d302 On Windows, use win32api.GetUserName instead of getpass.getuser

- **PR** `#24507`_: (*kiorky*) fix dockerng reference -ng -> ng
  @ *2015-06-08T20:09:40Z*

  * 8b2a0e1 Merge pull request `#24507`_ from makinacorpus/dcktypo
  * 8fdc9ac fix dockerng reference -ng -> ng

- **PR** `#24499`_: (*rallytime*) Added "CLI Example" to make failing test happy on develop
  @ *2015-06-08T16:24:21Z*

  * a10c11e Merge pull request `#24499`_ from rallytime/fix_doc_failure_develop
  * 49b6ea9 Added "CLI Example" to make failing test happy on develop

- **PR** `#24478`_: (*nmadhok*) Vmware cloud driver additions and refactors
  @ *2015-06-08T15:27:37Z*

  * 6c4cef2 Merge pull request `#24478`_ from nmadhok/vmware-cloud-driver
  * e8dab8a Update vmware.py

  * 83babc2 Adding CLI Example for random.rand_int so tests don't fail

  * 6246702 Correct warning message if timeout reached and vmware tools not running

  * 763466c Do not log global exceptions on KeyboardInterrupt

  * a9a38a2 Waiting for vmware tools to be running

  * 94ebd4b Show same examples for memory

  * e7b855f adding docs for ability to specify memory in mb and gb

  * 53e508d Ability to specify memory in mb and gb along with other minor fixes

  * a61516c The default for power_on should be True instead of False as per the docs

- **PR** `#24470`_: (*garethgreenaway*) Updating consul module to use salt.utils.http instead of requests.
  @ *2015-06-08T15:26:29Z*

  * 49584e7 Merge pull request `#24470`_ from garethgreenaway/refactor_consul_salt_utils_http
  * 66e09b1 Missing import for salt.utils.http

  * 6f487b6 lint.  wrong variable check in a check.

  * 056eb9a Updating consul module to use salt.utils.http instead of requests.

- **PR** `#24450`_: (*ruzarowski*) Fix salt cli runs with batch-size set
  @ *2015-06-08T15:24:28Z*

  - **ISSUE** `#1`_: (*thatch45*) Enable regex on the salt cli
    | refs: `#21356`_ `#21328`_
  * b351af0 Merge pull request `#24450`_ from ruzarowski/develop
  * e565077 Merge pull request `#1`_ from ruzarowski/ruzarowski-fix-batch-cli

    * 4419be0 Fix salt runs with batch-size set

- **PR** `#24487`_: (*nmadhok*) Deprecating vsphere cloud driver in favor of vmware cloud driver
  @ *2015-06-08T01:51:56Z*

  * 7edb687 Merge pull request `#24487`_ from nmadhok/deprecate-vsphere
  * 308681f Change removed to deprecated

  * 676bf48 Add deprecation to beryllium release

  * ceac83d Deprecating vsphere cloud driver in favor of vmware cloud driver

- **PR** `#24454`_: (*rhertzog*) Strip extraneous newline character added in last environment variable
  @ *2015-06-06T23:15:26Z*

  * dce1f34 Merge pull request `#24454`_ from rhertzog/rhertzog-patch-1
  * b9c950b Avoid extraneous newline character added in last environment variable

- **PR** `#24420`_: (*aboe76*) added random integer module to mod_random.py
  @ *2015-06-06T14:25:00Z*

  - **ISSUE** `#24407`_: (*aboe76*) Please expand salt module random
    | refs: `#24420`_
  * d6a4bd9 Merge pull request `#24420`_ from aboe76/add_mod_random_integer/develop
  * ef66533 Fix lint error and update versionadded to 2015.5.3

  * 157768c added random integer module to mod_random.py

* 83a9636 Manual merge of `#24414`_ per thatch45

  - **PR** `#24414`_: (*msteed*) Initial work toward making unit tests pass under python 3

- **PR** `#24424`_: (*skizunov*) On Windows running salt with admin privileges now authenticates
  @ *2015-06-06T00:18:28Z*

  * dccb83e Merge pull request `#24424`_ from skizunov/develop2
  * 270267e On Windows running salt with admin privileges now authenticates

- **PR** `#24423`_: (*garethgreenaway*) Refactoring random.org module to use salt.utils.http instead of requests
  @ *2015-06-05T17:09:18Z*

  * 98608c8 Merge pull request `#24423`_ from garethgreenaway/refactor_random_salt_utils_http
  * c95f8be Updating unit tests based on changes to module.

  * 8d7906b removing unnecessary imports.

  * e896c4a Refactoring random.org module to use salt.utils.http instead of requests

- **PR** `#24453`_: (*bechtoldt*) set versionadded Beryllium for salt.runners.pkg
  @ *2015-06-05T15:33:53Z*

  * ec32648 Merge pull request `#24453`_ from bechtoldt/pkg_runner_docs
  * 9b66f09 set versionadded Beryllium for salt.runners.pkg

- **PR** `#24442`_: (*ajacoutot*) openbsd: add _openbsd_remotes_on
  @ *2015-06-05T15:19:29Z*

  * cfe1e2c Merge pull request `#24442`_ from ajacoutot/openbsd-network
  * aacf1eb openbsd: add _openbsd_remotes_on

- **PR** `#24441`_: (*arthurlogilab*) [doc] Alignement fix on external_auth documentation
  @ *2015-06-05T15:15:11Z*

  * 69965de Merge pull request `#24441`_ from arthurlogilab/patch-6
  * 24502e2 [doc] Alignement fix on external_auth documentation

- **PR** `#24432`_: (*rallytime*) Whitespace fix
  @ *2015-06-05T01:31:03Z*

  * 0ca6e26 Merge pull request `#24432`_ from rallytime/whitespace
  * 87fd535 Whitespace fix

- **PR** `#24431`_: (*rallytime*) Merge `#24417`_ with pylint fixes
  @ *2015-06-05T00:57:46Z*

  - **PR** `#24417`_: (*jtand*) Fixed a small pylint error
    | refs: `#24431`_
  * 80d6e65 Merge pull request `#24431`_ from rallytime/merge-24417
  * e739a99 Merge `#24417`_ with pylint fixes

  * db83996 Moved it back up above exceptions import

  * ffb5018 Fixed a small pylint error

- **PR** `#24421`_: (*bechtoldt*) add missing module documentation
  | refs: `#25019`_
  @ *2015-06-05T00:30:39Z*

  * 6b0044a Merge pull request `#24421`_ from bechtoldt/update_docs
  * fc7f072 add missing module documentation to references

- **PR** `#24415`_: (*garethgreenaway*) Switching slack module and slack returner to using salt.utils.http
  @ *2015-06-05T00:25:39Z*

  * 97104ee Merge pull request `#24415`_ from garethgreenaway/refactor_slack_salt_utils_http
  * 921827c removing unneeded imports to fix lint issues.

  * 64dedc0 Removing unneeded logging statements.  Adding log statement that was mistakenly removed.

  * b480e89 Switching slack module and slack returner to using salt.utils.http

- **PR** `#24425`_: (*jtand*) Added example docstring to fix test failures
  @ *2015-06-05T00:21:49Z*

  * b770939 Merge pull request `#24425`_ from jtand/docstring_rpm
  * 356bfa7 Added example docstring to fix test failures

- **PR** `#24410`_: (*jtand*) Changed mock path to be absolute in test_parse_targets
  @ *2015-06-05T00:21:07Z*

  * 75890b2 Merge pull request `#24410`_ from jtand/pkg_resource
  * 1df4020 Changed mock path to be absolute in test_parse_targets

- **PR** `#24418`_: (*garethgreenaway*) Victorops support
  @ *2015-06-04T20:50:48Z*

  * 7cd2950 Merge pull request `#24418`_ from garethgreenaway/victorops_support
  * 55f1477 Adding documentation for some parameters previously missed.  If adding the event failed, return False with the failure message.

  * 3fb6ef6 Initial addition for execution and state modules to send events to VictorOps.

- **PR** `#24364`_: (*DmitryKuzmenko*) Salt ssh identities only
  @ *2015-06-04T20:06:58Z*

  - **ISSUE** `#24096`_: (*ryanfields*) salt-ssh: Too many authentication failures
    | refs: `#24364`_
  * ebd63a7 Merge pull request `#24364`_ from DSRCompany/salt_ssh_identities_only
  * 77770ed Add --identities-only cmdline to salt-ssh.

  * bfe7093 Support IdentitiesOnly ssh option in salt-ssh

- **PR** `#24341`_: (*nKaloussian*) Provide option to set a display name. Defaults to instance's name.
  @ *2015-06-04T20:03:17Z*

  * fcb1ae1 Merge pull request `#24341`_ from nKaloussian/add-cloudstack-displayname
  * 26e6533 Fix PyLint error.

  * 514aafd Merge branch 'develop' of https://github.com/saltstack/salt into add-cloudstack-displayname

- **PR** `#24404`_: (*edouardb*) Add Getting Started for Scaleway provider
  @ *2015-06-04T15:33:39Z*

  * ca2b732 Merge pull request `#24404`_ from edouardb/scaleway-provider-doc
  * 908b278 Add Getting Started for Scaleway provider

- **PR** `#24393`_: (*dr4Ke*) Fix grains.set preserve list order
  @ *2015-06-04T15:10:19Z*

  - **ISSUE** `#24391`_: (*dr4Ke*) grains.set should preserve list order
    | refs: `#24393`_
  * 76b54fc Merge pull request `#24393`_ from dr4Ke/fix_grains.set_preserve_list_order
  * c902cb7 module function grains.set: fix preserve list order

  * 7b94514 module grains tests: test list order preservation

- **PR** `#24392`_: (*quixoten*) Fix "No such file or directory" in grains/core.py
  @ *2015-06-04T15:08:06Z*

  * a5d14ec Merge pull request `#24392`_ from quixoten/use_found_cmd_path
  * b69e0cf Use path found by salt.utils.which

- **PR** `#24335`_: (*nmadhok*) Only pop the key if the key exists otherwise do nothing
  @ *2015-06-04T14:47:58Z*

  * ddc1679 Merge pull request `#24335`_ from nmadhok/patch-cloud
  * fcbe08c Removing unneeded check

  * b5a61a4 Only pop the key if the key exists otherwise do nothing

- **PR** `#24377`_: (*ryan-lane*) Add boto_kms docs
  @ *2015-06-03T23:03:34Z*

  * c40e5d8 Merge pull request `#24377`_ from lyft/boto-kms-docs
  * a3924bb Add boto_kms docs

- **PR** `#23620`_: (*ryan-lane*) Make boto util get_error function compatible with newer boto modules
  @ *2015-06-03T22:34:35Z*

  * f9f16de Merge pull request `#23620`_ from lyft/boto-util-get-error-fix
  * 4699756 Lint fix

  * 055fa8b Greater compatibility for modules in get_error in boto utils

  * c810ad0 Make boto util get_error function compatible with newer boto modules

- **PR** `#24373`_: (*basepi*) Merge forward from 2015.5 to develop
  @ *2015-06-03T21:19:45Z*

  * 6c84fa0 Merge pull request `#24373`_ from basepi/merge-forward-develop
  * c41d9f4 Reformat lxc.py and fix a bad merge conflict resolution

  * baf4337 Merge remote-tracking branch 'upstream/2015.5' into merge-forward-develop

- **PR** `#24357`_: (*zhujinhe*) fix invoke issues of Jinja Macros example
  @ *2015-06-03T21:06:30Z*

  * 1e0f247 Merge pull request `#24357`_ from zhujinhe/develop
  * 15cdd58 fix invoke issues of Jinja Macros example

- **PR** `#24353`_: (*cetra3*) Set changed = true if the file has changed when using file.copy state
  @ *2015-06-03T20:38:54Z*

  - **ISSUE** `#24295`_: (*cetra3*) file.copy deletes the destination file if it already exists and force=True
    | refs: `#24353`_
  * 5cbebf6 Merge pull request `#24353`_ from cetra3/file-copy-force-fix
  * 0ff4366 Set changed = true if the file has changed when using file.copy state and force

- **PR** `#24347`_: (*basepi*) Merge forward from 2015.5 to develop
  @ *2015-06-03T15:38:49Z*

  * d710489 Merge pull request `#24347`_ from basepi/merge-forward-develop
  * 288d49e Merge remote-tracking branch 'upstream/2015.5' into merge-forward-develop

- **PR** `#23915`_: (*terminalmage*) pkg.installed: Check binary pkg metadata to determine action
  @ *2015-06-03T14:50:40Z*

  - **ISSUE** `#7772`_: (*Cidan*) Version support for "sources" arg in pkg.installed states
    | refs: `#23915`_
  * 6ad4013 Merge pull request `#23915`_ from terminalmage/issue7772
  * 359ef9e pkg.installed: Check metadata for "sources"

  * be11930 Support using lowpkg.bin_pkg_info to parse RPM metadata

  * 59f56bc Add normalize support to pkg_resource.py

  * 14d47e4 Add lowpkg.bin_pkg_info for RPM

  * 67bcdce Add new utils module for RPM-specific functions

- **PR** `#24315`_: (*twangboy*) Fixed stacktrace when looking for M2Crypto
  @ *2015-06-03T14:49:30Z*

  - **ISSUE** `#24311`_: (*twangboy*) https file.managed on develop stacktraces but downloads the file
    | refs: `#24315`_
  * 12f3b16 Merge pull request `#24315`_ from twangboy/fix_x509
  * 1c79405 Fix lint (except ImportError)

  * 820d934 Fixed stacktrace when looking for M2Crypto

- **PR** `#24332`_: (*jacksontj*) Add party controls to zk_concurrency
  | refs: `#24543`_
  @ *2015-06-03T03:29:28Z*

  * 636288c Merge pull request `#24332`_ from jacksontj/develop
  * 2c6a5c7 Add comment attempting to explain the security shortcomings of salt-cp

  * e7e01fa Add `name` kwarg to STATE_RUNTIME_KEYWORDS

  * 651f215 Add party controls to zk_concurrency

- **PR** `#24321`_: (*dr4Ke*) Feature grains.set
  @ *2015-06-03T03:27:25Z*

  - **ISSUE** `#23446`_: (*dr4Ke*) New module function grains.set to modify part of a nested grain
    | refs: `#24321`_
  * 38714ac Merge pull request `#24321`_ from dr4Ke/feature_grains.set
  * f2d7460 grains module: use DEFAULT_TARGET_DELIM

  * 756f5d8 new set function for module grains, and unit tests

- **PR** `#24026`_: (*jpic*) Document DHCP usage on LXC < 1.0.7
  @ *2015-06-02T20:41:19Z*

  * 31f4994 Merge pull request `#24026`_ from jpic/fix/lxc_network_profile
  * d733cfb Document DHCP usage on LXC < 1.0.7

          * 041de41 Provide option to set a display name. Defaults to instance's name.

- **PR** `#24333`_: (*corywright*) Fix formatting of example curl command in netapi.rest_cherrypy docs
  @ *2015-06-02T15:00:21Z*

  * f995509 Merge pull request `#24333`_ from corywright/fix-netapi-cherrypi-docs
  * 084c636 Fix formatting of example curl command in netapi.rest_cherrypy docs

- **PR** `#24324`_: (*nmadhok*) Sometimes VMware tools status is unavailable so make sure not to fail with KeyError
  @ *2015-06-02T14:15:58Z*

  - **ISSUE** `#24323`_: (*nmadhok*) salt-cloud select query with VMware cloud driver fails with KeyError
    | refs: `#24324`_
  * a273a9a Merge pull request `#24324`_ from nmadhok/vmware-cloud-driver
  * fcb6d22 Sometimes VMware tools status is unavailable so make sure not to throw a KeyError

- **PR** `#24325`_: (*nmadhok*) Making sure there is a new line after the Deprecation Warnings under salt-cloud
  @ *2015-06-02T14:15:15Z*

  * c71c01f Merge pull request `#24325`_ from nmadhok/patch-warning
  * 9a9268f Making sure there is a new line after the Deprecation Warnings

- **PR** `#24307`_: (*techhat*) Standardize return values in EC2 pricing
  @ *2015-06-01T21:30:33Z*

  * c07af62 Merge pull request `#24307`_ from techhat/ec2pricestd
  * 90efbbf Make sure profile name is in return

  * 5fd7b32 Standardize return values in EC2 pricing

- **PR** `#24300`_: (*basepi*) Merge forward from 2015.5 to develop
  @ *2015-06-01T21:21:40Z*

  * 6d38528 Merge pull request `#24300`_ from basepi/merge-forward-develop
  * f5c19fa Remove unused import

  * a6a868b Merge remote-tracking branch 'upstream/2015.5' into merge-forward-develop

- **PR** `#24306`_: (*techhat*) Allow Softlayer HW driver to display pricing information
  @ *2015-06-01T20:40:42Z*

  * dee3589 Merge pull request `#24306`_ from techhat/softlayerprice
  * d728320 Fix EC2 refs

  * 62b982b Allow Softlayer HW driver to display pricing information

- **PR** `#23982`_: (*kiorky*) lxc: path support
  | refs: `#24080`_
  @ *2015-06-01T19:38:52Z*

  - **ISSUE** `#23657`_: (*arthurlogilab*) [salt-cloud lxc] NameError: global name '__salt__' is not defined
    | refs: `#23897`_ `#23982`_ `#23898`_ `#24080`_
  - **PR** `#24080`_: (*kiorky*) Lxc consistency2
    | refs: `#23982`_ `#24066`_
  - **PR** `#24066`_: (*kiorky*) Merge forward 2015.5 -> develop
    | refs: `#23982`_
  - **PR** `#24065`_: (*kiorky*) continue to fix `#23883`_
    | refs: `#24066`_ `#24080`_
  * e9b3bbb Merge pull request `#23982`_ from makinacorpus/lxc_path
  * f50e6da lxc: path support

- **PR** `#24293`_: (*edouardb*) Added Scaleway cloud provider
  @ *2015-06-01T17:47:24Z*

  * 438a024 Merge pull request `#24293`_ from edouardb/scaleway-provider
  * b85deb3 Fix Python 3 compatibility

  * 84d95ae Rework array building in list_nodes_full for python2.6 compatibility

  * f312606 Remove unused import

  * dcebb38 /"/'

  * 884c9bc Rework comments

  * 79a638d Add comments

  * 1ce8b4c Rework array building with oneliner

  * 920f12e Use Python best practices

  * 4edd7df s/while <var>/for var in range()/

  * 40c68c0 Remove use of HAS_REQUESTS

  * d401ad2 Change api.cloud.online.net to api.scaleway.com

  * ed4bed5 PEP8 fixes

  * c1e6383 Added scaleway provider

- **PR** `#24282`_: (*The-Loeki*) Final part of `#22080`_
  @ *2015-06-01T17:46:15Z*

  - **ISSUE** `#22080`_: (*The-Loeki*) CIDR matching for IPv6 / improve IPv6 support in utils.network
    | refs: `#22691`_ `#23253`_ `#23896`_ `#24282`_ `#24282`_
  * 5eae6de Merge pull request `#24282`_ from The-Loeki/better-ipv6
  * 2a2210b Fix subnets

  * d1e9e54 Revert addition of oddly behaving tests

  * 9682388 Pylint fixes

  * 35a5919 * PyLint fixes * Make _subnets() IP agnostic * Add subnets6 * Fix CkMinions with the same <ugh> ipcidr matcher code

  * 15e8518 Move loading of ipaddress module where it belongs

  * 65096c4 Stoopid typos

  * 07af81e Try adding a few extra unit tests First drop of final fix for `#22080`_

  * f36a3d9 Improve calculate_subnet further, rename to calc_net

  * d69659e Deprecate utils.ip_in_subnet

  * 91b7258 get_net_start IP agnostic

  * f14b462 Refactor ip_addr functions to utilize ipaddress library & become properly loopback aware

- **PR** `#24188`_: (*aneeshusa*) Add sqlite3 pillar
  @ *2015-06-01T17:45:15Z*

  * ac1134a Merge pull request `#24188`_ from aneeshusa/add-sqlite-pillar
  * 37442ea Fix lint issues.

  * ac4792f Add a SQLite3 ext_pillar built on the sql_base pillar.

  * decb6ce Extract PEP 249 compliant sql_base ext_pillar from MySQL.

- **PR** `#24278`_: (*rallytime*) Add arg documentation for delete_policies
  @ *2015-06-01T04:28:49Z*

  - **PR** `#24218`_: (*jimjh*) Add a `delete_policies` argument to `boto_iam_role.present`
    | refs: `#24278`_
  * 9514964 Merge pull request `#24278`_ from rallytime/boto_delete_policies_doc
  * 3ed3dd6 Add arg documentation for delete_policies

- **PR** `#24270`_: (*jodv*) Add log_handlers syncing to saltutil module
  @ *2015-06-01T04:27:30Z*

  * 40da36b Merge pull request `#24270`_ from jodv/sync_log_handlers
  * 486e140 add "versionadded" to sync_log_handlers docstring

  * b15dafb Add log_handlers syncing to saltutil module

- **PR** `#24285`_: (*davidjb*) Document availability of arguments to file states
  @ *2015-06-01T04:26:32Z*

  * 4e48d3e Merge pull request `#24285`_ from davidjb/patch-2
  * c2bc1f8 Document availability of arguments to file states

- **PR** `#24271`_: (*randybias*) Fixed the setup instructions
  @ *2015-05-31T15:46:54Z*

  * 7ee303a Merge pull request `#24271`_ from randybias/patch-1
  * 037f7e2 Fixed the setup instructions

- **PR** `#24264`_: (*techhat*) Allow EC2 driver to display pricing information
  @ *2015-05-31T15:29:00Z*

  * aa01493 Merge pull request `#24264`_ from techhat/ec2prices
  * 59b99ce Adding versionadded

  * f6af440 Allow EC2 driver to display pricing information

- **PR** `#24266`_: (*techhat*) Add execution module for RallyDev
  @ *2015-05-31T15:28:50Z*

  * d8ab565 Merge pull request `#24266`_ from techhat/rallydev
  * d1df6e1 Adding versionadded

  * c79b4c6 Linting

  * c54a097 Add execution module for RallyDev

- **PR** `#24265`_: (*techhat*) Add execution module for BambooHR
  @ *2015-05-31T15:28:38Z*

  * 900470e Merge pull request `#24265`_ from techhat/bamboohr
  * 6562a7a Adding versionadded

  * fa7e46e Add execution module for BambooHR

- **PR** `#24236`_: (*t0fik*) RedHat IPv6 static routes
  @ *2015-05-31T03:34:24Z*

  * e7542e7 Merge pull request `#24236`_ from jdsieci/develop
  * 2f3d029 pylint volation fixes

  * ded5002 Return values fixes

  * 9eb9892 Changed return values and assertions to lists

  * e564a0b Added setting of __grains__['osrelease'] in test

  * 15ef095 FIX: pylint errors

  * 8775906 Merge remote-tracking branch 'upstream/develop' into develop

  * 6a167d9 IPv6 routes support for RedHat Linux

  * 03c32e4 .gitignore update

  * 1d30f32 Added new RH route template for RHEL6 and newer

- **PR** `#24267`_: (*aneeshusa*) Have a nice error message if running as the wrong user.
  @ *2015-05-30T17:38:31Z*

  * 4e19be2 Merge pull request `#24267`_ from aneeshusa/add-nice-error-msg-for-permission-denied
  * 6b07aa6 Have a nice error message if running as the wrong user.

- **PR** `#24263`_: (*cdarwin*) Correct usage of import_yaml in formula documentation
  @ *2015-05-30T17:36:42Z*

  * a71d3f9 Merge pull request `#24263`_ from luciddg/docs-import-yaml
  * 37775a5 Correct usage of import_yaml in formula documentation

- **PR** `#24261`_: (*basepi*) Merge forward from 2015.5 to develop
  @ *2015-05-30T17:35:00Z*

  * 01694b7 Merge pull request `#24261`_ from basepi/merge-forward-develop
  * 5fcbcfe Merge remote-tracking branch 'upstream/2015.5' into merge-forward-develop

- **PR** `#24256`_: (*rallytime*) Deprecate digital_ocean.py in favor of digital_ocean_v2.py
  @ *2015-05-29T23:09:12Z*

  * 742cf7e Merge pull request `#24256`_ from rallytime/remove_digital_ocean_v1
  * 095979d Add digitalocean deprecation notice to Beryllium release notes

  * c10453e Deprecate digital_ocean.py in favor of digital_ocean_v2.py

- **PR** `#23060`_: (*kiorky*) ubuntu systemd/legacy init support
  @ *2015-05-29T23:02:08Z*

  * a28515a Merge pull request `#23060`_ from makinacorpus/service
  * 46f7033 fix centos tests

  * 3df3d67 consistent mock usage

  * 8f9ddbb add some tests for ubuntu/systemd

  * 0e8ce88 ubuntu systemd support

- **PR** `#24007`_: (*garethgreenaway*) Adding a state module to manage beacons
  @ *2015-05-29T23:00:22Z*

  * b07e606 Merge pull request `#24007`_ from garethgreenaway/beacon_state_module
  * 8aa5861 lint

  * 142c486 Adding some additional documentation to state and execution modules.

  * 4f0e50a Adding a state module to manage beacons.  adding a new method to the beacon execution module to modify existing beacons.

- **PR** `#24103`_: (*kiorky*) Profiling
  @ *2015-05-29T22:59:50Z*

  * 41ada36 Merge pull request `#24103`_ from makinacorpus/profiling
  * b093d32 lint

  * 2931df0 lint

  * 3dae4ca parsers: fix --enable-profiling option

  * d07949d Gate cProfile

  * 12734be Support for profiling in salt-run

  * 96b7593 Salt call profiling support

  * 6b01973 test.rand_str: better kwargs handling

  * 1b8e0d0 Refactor test.rand_str to reuse later

- **PR** `#24223`_: (*twangboy*) Added module win_wua.py for managing windows updates
  @ *2015-05-29T22:58:37Z*

  * 48ba667 Merge pull request `#24223`_ from twangboy/win_wua_module
  * d0aa681 Pylint V: PyCharm's Revenge

  * ab940a4 Even more pylint fixes... will there be a sequel?

  * 5d10934 More pylint errors

  * cbdb932 Fix pylint errors

  * b381931 Added module win_wua.py for managing windows updates

- **PR** `#24249`_: (*cedwards*) patch pillar.item to support nested pillar
  @ *2015-05-29T22:58:12Z*

  * fd91e22 Merge pull request `#24249`_ from cedwards/pillar_item_patch
  * aa34848 patch pillar.item to support nested pillar

- **PR** `#23837`_: (*cedwards*) Initial Traffic Server state module
  @ *2015-05-29T22:57:27Z*

  * 195167e Merge pull request `#23837`_ from cedwards/ats_state
  * e57f29b addressing more lint issues

  * 730a829 added versionadded tag

  * 0cb793e fixing virtual function to properly load module

  * 3eeae2e Initial Traffic Server state module

- **PR** `#24224`_: (*basepi*) Merge forward from 2015.5 to develop
  @ *2015-05-29T22:26:53Z*

  * bf2eddc Merge pull request `#24224`_ from basepi/merge-forward-develop
  * 90cb448 Fix rest of rabbitmq tests

  * 7736509 Fix rabbitmq test

  * 22837e4 Add six back in and use it for new code

  * 6b1c1c6 Remove unused import

  * c4f5e23 Merge remote-tracking branch 'upstream/2015.5' into merge-forward-develop2

- **PR** `#24248`_: (*msteed*) Reinit pycrypto RNG in Cloud multiprocess paths
  @ *2015-05-29T18:27:09Z*

  - **ISSUE** `#24176`_: (*nmadhok*) [salt-cloud] VM creation fails with NameError on develop branch
    | refs: `#24248`_
  * 28dc62c Merge pull request `#24248`_ from msteed/issue-24176
  * 3112013 Reinit pycrypto RNG in Cloud multiprocess paths

- **PR** `#24230`_: (*aneeshusa*) Add serializers as a new module type
  @ *2015-05-29T17:14:12Z*

  - **ISSUE** `#22257`_: (*whiteinge*) Make new 'serializer' module type
    | refs: `#24230`_
  * f1f90a2 Merge pull request `#24230`_ from aneeshusa/add-serializers
  * 82a4794 Do not reference serializers from aggregation docs.

  * 4b93115 Add new module type for serializers from issue `#22257`_.

- **PR** `#24182`_: (*rfairburn*) Support split_dns on route53
  @ *2015-05-29T15:53:55Z*

  * ad1c5a2 Merge pull request `#24182`_ from rfairburn/boto_route53_splitdns
  * db99610 Support split_dns on route53

- **PR** `#24168`_: (*The-Loeki*) Improvements to data module; behave much more like a dict
  @ *2015-05-29T15:53:09Z*

  * 5562b6f Merge pull request `#24168`_ from The-Loeki/patch-2
  * 66fdb39 Merge fix

  * 024f276 doc fixes

  * f1a2fa3 Improvements to data module; behave much more like a dict

- **PR** `#24228`_: (*aneeshusa*) Print the host name with the highstate summary.
  @ *2015-05-29T15:05:08Z*

  * 8ff8bb2 Merge pull request `#24228`_ from aneeshusa/print-host-name-with-summary
  * 77af646 Print the host name with the highstate summary.

- **PR** `#24244`_: (*vladislav-jomedia*) m_names variable added to module.run
  @ *2015-05-29T14:23:43Z*

  * d957134 Merge pull request `#24244`_ from vladislav-jomedia/develop
  * eb34c39 m_names variable added to module.run func so now it is possible to run cloud.create module and others who use the names var instead of name, example is in header

  * 0532fd5 m_names variable added to module.run func so now it is possible to run cloud.create module and others who use the names var instead of name

- **PR** `#24242`_: (*travishegner*) Adding hostname to highstate summary output
  @ *2015-05-29T14:21:33Z*

  * b104235 Merge pull request `#24242`_ from travishegner/develop
  * 6620e20 adding the hostname to the summary in the proper way now

  * 1310b6b adding hostname to summary of highstate output

- **PR** `#24221`_: (*rallytime*) Add SyntaxError to get_error exception
  @ *2015-05-29T03:10:00Z*

  * 1b306c5 Merge pull request `#24221`_ from rallytime/fix_python26_boto_util_error
  * 1f8190b Add SyntaxError to get_error exception

- **PR** `#24220`_: (*djcrabhat*) adding key_filename param to vsphere provider
  @ *2015-05-29T03:06:58Z*

  - **ISSUE** `#24210`_: (*damonnk*) salt-cloud vsphere.py should allow key_filename param
    | refs: `#24220`_
  * decb286 Merge pull request `#24220`_ from djcrabhat/develop
  * bed2af7 adding key_filename param to vsphere provider

- **PR** `#24218`_: (*jimjh*) Add a `delete_policies` argument to `boto_iam_role.present`
  | refs: `#24278`_
  @ *2015-05-28T20:15:13Z*

  * 4e61c43 Merge pull request `#24218`_ from jimjh/add-delete-policies
  * da93f85 add delete_policies arg

- **PR** `#24205`_: (*hazelesque*) Docstring fix in salt.modules.yumpkg.hold
  @ *2015-05-28T14:37:08Z*

  * ea413bc Merge pull request `#24205`_ from hazelesque/20150528-yumpkg-hold-docstring-fix
  * 72a5399 Docstring fix in salt.modules.yumpkg.hold

- **PR** `#24187`_: (*DmitryKuzmenko*) Changed the now deprecated .postinitio to ._prepare
  @ *2015-05-27T22:12:46Z*

  - **ISSUE** `#21640`_: (*plastikos*) [raet] run-time exception: 'SaltSchedule' object has no attribute 'schedule'
    | refs: `#24187`_
  * 561d7b7 Merge pull request `#24187`_ from DSRCompany/postinitio_rename
  * b8c0d17 Changed the now deprecated .postinitio to ._prepare

- **PR** `#24157`_: (*basepi*) Merge forward from 2015.5 to develop
  @ *2015-05-27T22:09:00Z*

  * fd41993 Merge pull request `#24157`_ from basepi/merge-forward-develop
  * 116b88d Fix mocking in file state unit tests

  * 90e557c join_locale is now in salt.utils.locales

  * 9dab9a1 Fix python3 lint

  * 60f2e9e Merge remote-tracking branch 'upstream/2015.5' into merge-forward-develop

- **PR** `#24186`_: (*thcipriani*) Update salt vagrant provisioner info
  @ *2015-05-27T19:31:30Z*

  * 42d4244 Merge pull request `#24186`_ from thcipriani/develop
  * 8ec82b6 Update salt vagrant provisioner info

- **PR** `#24152`_: (*dougluce*) Allow URL specification of NPM packages
  @ *2015-05-27T16:22:06Z*

  - **ISSUE** `#24151`_: (*dougluce*) npm: IndexError when installing a module via a URL
    | refs: `#24152`_
  * a21dbe4 Merge pull request `#24152`_ from dougluce/npm-allow-url-specification
  * 2e36b8a Fix indentation.

  * 6fe47ea Allow URL specification of NPM packages

- **PR** `#24155`_: (*techhat*) Let lookup_jid show only missing minions
  @ *2015-05-27T16:21:39Z*

  * 5437898 Merge pull request `#24155`_ from techhat/returnedjobs
  * 6655831 Let lookup_jid show only missing minions

- **PR** `#24173`_: (*techhat*) Better error and cookie handling
  @ *2015-05-27T15:57:24Z*

  * 987aeb1 Merge pull request `#24173`_ from techhat/cookieerr
  * 3e22888 Linting

  * 4c66a9b Better error and cookie handling

- **PR** `#24170`_: (*merll*) Signing policy lookup in pillar.
  @ *2015-05-27T15:16:54Z*

  * 417f4e7 Merge pull request `#24170`_ from Precis/fix-pillar-signing-policy
  * 45f93c6 Added signing policy lookup in pillar.

- **PR** `#24143`_: (*terminalmage*) Drop default use of docker-exec in dockerng
  @ *2015-05-26T23:18:58Z*

  * 555cdc9 Merge pull request `#24143`_ from terminalmage/docker-exec
  * cce85d0 Lint fixes

  * 13fa7e6 Drop default use of docker-exec in dockerng

- **PR** `#24129`_: (*pengyao*) Wheel client doc
  @ *2015-05-26T15:48:40Z*

  * 75a2239 Merge pull request `#24129`_ from pengyao/wheel_client_doc
  * 6b88772 fixed a typo

  * dff2731 Add cmd doc for WheelClient

- **PR** `#23937`_: (*jfindlay*) replace file.contains_regex_multiline with file.search
  @ *2015-05-25T19:47:05Z*

  * be701f9 Merge pull request `#23937`_ from jfindlay/depr_file_func
  * 2b8175e contains_regex_multiline -> search in kmod module

  * 422b5f0 contains_regex_multiline -> search in file state

  * c6004f8 deprecate file.contains_regex_multiline with file.search

  * 92a054d enable multiline searching with file.replace

  * 7a5612a update and expand re flags handling in file mod

  * cf26ab7 fix typo in salt.utils.filebuffer

- **PR** `#24075`_: (*DmitryKuzmenko*) Add config options for raet network buffers count
  @ *2015-05-25T19:46:05Z*

  * 554f327 Merge pull request `#24075`_ from DSRCompany/raet_bufcnt_conf
  * 698211b Add config options for raet network buffers count

- **PR** `#24076`_: (*garethgreenaway*) Refactoring schedule module
  @ *2015-05-25T19:45:51Z*

  * f76622a Merge pull request `#24076`_ from garethgreenaway/refactoring_schedule_module
  * a09f0b2 Updating schedule unit tests to align with refactoring changes.

  * a9c475a removing logging statements.

  * 69ce8e8 refactoring the schedule execution module, also fixing issues that resulted in a disconnect when using salt vs salt-call to call the module function.

- **PR** `#24118`_: (*trevor-h*) removed deprecated pymongo usage
  @ *2015-05-25T19:37:17Z*

  * b7e68a5 Merge pull request `#24118`_ from trevor-h/fix-extpillar-mongo
  * d8b8f6c removed deprecated pymongo usage as no longer functional with pymongo > 3.x

- **PR** `#24116`_: (*awdrius*) Fixed typo in chown username (ending dot) that fails the command.
  @ *2015-05-25T18:20:26Z*

  * bb57880 Merge pull request `#24116`_ from awdrius/develop
  * e33337c Fixed typo in chown username (ending dot) that fails the command.

- **PR** `#24014`_: (*ticosax*) [dockerng] Enforce environment values to be strings.
  @ *2015-05-25T15:43:58Z*

  * 4f080e3 Merge pull request `#24014`_ from ticosax/dockerng-enforce-env-string
  * 82ee2da Enforce environment values to be strings.

- **PR** `#24105`_: (*cedwards*) Updated some beacon-specific documentation formatting
  @ *2015-05-25T12:29:30Z*

  * 81e03e9 Merge pull request `#24105`_ from cedwards/beacon_docs
  * 4552e6e Updated some beacon-specific documentation formatting

- **PR** `#24104`_: (*pruiz*) Only try to stop a VM if it's not already stopped. (fixes `#23364`_)
  @ *2015-05-25T11:49:49Z*

  - **ISSUE** `#23364`_: (*pruiz*) Unable to destroy host using proxmox cloud: There was an error destroying machines: 501 Server Error: Method 'DELETE /nodes/pmx1/openvz/openvz/100' not implemented
  * d75dca4 Merge pull request `#24104`_ from pruiz/`fix-23364`_
  * cd48a95 Only try to stop a VM if it's not already stopped. (fixes `#23364`_)

- **PR** `#24091`_: (*rallytime*) Revert "Remove key management test from digital ocean cloud tests"
  @ *2015-05-22T23:10:37Z*

  * 7646cb1 Merge pull request `#24091`_ from rallytime/revert_test_removal
  * 7146871 Revert "Remove key management test from digital ocean cloud tests"

- **PR** `#24079`_: (*jfindlay*) Revert "Fix for https://github.com/saltstack/salt/issues/23221"
  @ *2015-05-22T23:08:53Z*

  - **PR** `#24061`_: (*diego-XA*) Fix for https://github.com/saltstack/salt/issues/23221
    | refs: `#24079`_
  * 522ae92 Merge pull request `#24079`_ from saltstack/revert-24061-develop
  * e85f80a Revert "Fix for https://github.com/saltstack/salt/issues/23221"

- **PR** `#24069`_: (*ticosax*) [dockerng] Introduce "start" argument to dockerng.running
  @ *2015-05-22T23:04:38Z*

  * 810297c Merge pull request `#24069`_ from ticosax/check_is_running
  * 34e52a0 remove the assert to be more user friendly

  * 1f68d2d Update test to follow new argument name

  * 7f42cde Change check_is_running to start

  * 8b7ddcb Introduce check_is_running

- **PR** `#24081`_: (*jacobhammons*) added custom search for each branch, fixed style issues
  @ *2015-05-22T23:04:17Z*

  - **ISSUE** `#23856`_: (*CedNantes*) VMWare Salt-Cloud documentation is missing since Website has been updated
    | refs: `#24081`_
  - **ISSUE** `#23818`_: (*aneeshusa*) Thoughts and suggestions on new documentation site
    | refs: `#24081`_
  * 0fcdb32 Merge pull request `#24081`_ from jacobhammons/develop
  * 1e1eb2b added custom search for each branch, fixed style issues

- **PR** `#24087`_: (*basepi*) Merge forward from 2015.5 to develop
  @ *2015-05-22T21:13:00Z*

  * 8d940af Merge pull request `#24087`_ from basepi/merge-forward-develop
  * 4b7ef52 Use six.string_types

  * d7362bb Merge remote-tracking branch 'upstream/2015.5' into merge-forward-develop

- **PR** `#24083`_: (*swdream*) fix code block syntax
  @ *2015-05-22T19:56:17Z*

  * c3744ef Merge pull request `#24083`_ from swdream/swedream_Fix_code_block_syntax
  * 01b546e fix code block syntax

- **PR** `#24061`_: (*diego-XA*) Fix for https://github.com/saltstack/salt/issues/23221
  | refs: `#24079`_
  @ *2015-05-22T16:57:55Z*

  * 55732ab Merge pull request `#24061`_ from diego-XA/develop
  * d2aec15 Fix for https://github.com/saltstack/salt/issues/23221

- **PR** `#24072`_: (*rallytime*) Merge `#24055`_ with version added tags
  @ *2015-05-22T16:57:29Z*

  - **PR** `#24055`_: (*mgwilliams*) add zone management funcs to boto_route53
    | refs: `#24072`_
  * d5b5fc1 Merge pull request `#24072`_ from rallytime/merge-24055
  * 3609c10 Merge `#24055`_ with versionadded tags for new functions

- **PR** `#24055`_: (*mgwilliams*) add zone management funcs to boto_route53
  | refs: `#24072`_
  @ *2015-05-22T16:57:21Z*

  * 273b0b1 Merge pull request `#24055`_ from mgwilliams/boto
  * 8677ad3 Merge remote-tracking branch 'origin/develop' into boto

  * 8996b19 modules.boto_route53: add zone management funcs

- **PR** `#24053`_: (*gladiatr72*) Sqlite que  adjust quoting take2
  @ *2015-05-22T16:57:07Z*

  - **PR** `#23991`_: (*gladiatr72*) adjustments to facilitate insertion and deletion of items containing
    | refs: `#24053`_
  * 4d51b57 Merge pull request `#24053`_ from gladiatr72/sqlite_que__adjust_quoting_take2
  * e240c9e tone down the "'s

  * d2629c1 similar fixes for pop()

  * ee8be75 adjustments to facilitate insertion and deletion of items containing quotation marks

- **PR** `#23870`_: (*kaithar*) MySQL can go away, this seems the most reliable way of checking it's …
  @ *2015-05-22T16:55:13Z*

  * 64fc294 Merge pull request `#23870`_ from kaithar/issue/attempt-reconnect
  * ee468a7 pylint fix

  * 624993c MySQL can go away, this seems the most reliable way of checking it's still alive.

- **PR** `#23981`_: (*DmitryKuzmenko*) Add ZMQ socket monitor for master queue channel
  @ *2015-05-22T16:28:55Z*

  * dd50688 Merge pull request `#23981`_ from DSRCompany/zmq_monitor_master
  * 702ad84 Add 'zmq_monitor' default config value

  * 2779c94 Add ZMQ socket monitor for master queue channel

- **PR** `#23978`_: (*kaithar*) Instead of raising the exception() instance, raise from exc_info()
  @ *2015-05-22T16:28:30Z*

  * 033cc83 Merge pull request `#23978`_ from kaithar/issue/re-raise_preserving_context
  * 563cca7 Add a comment directing helpful future readers  to the PR.

  * 54dbfd1 Tweak to be compatible with both python 2 and python 3

  * 5580eab Instead of raising the exception() instance, raise from exc_info()

- **PR** `#23949`_: (*gladiatr72*) Fix salt.cloud.Cloud salt.client.get_local_client call
  @ *2015-05-22T16:27:24Z*

  * c4a0ae5 Merge pull request `#23949`_ from gladiatr72/fix_salt.cloud.Cloud_salt.client_get_local_client_call
  * b5a5493 adjust local client instantiation to not use hard-coded paths and to load the minon configuration rather than master.

  * 95d829f Same problem only in salt.cloud.libcloudfuncs

  * be7aa14 Nothing really minion-specific about the loader.  But it is, after all, the loader.

  * ede4bd4 not minion opts

  * 10633bf salt.cloud.Cloud() instantiates a localClient to facilitate options such as sync_after_install

- **PR** `#23920`_: (*ticosax*) [dockerng] Fix pulled image comparison
  @ *2015-05-22T16:26:37Z*

  - **PR** `#23912`_: (*ticosax*) [dockerng] More flexible validation for mount points and ports.
    | refs: `#23920`_ `#23975`_ `#24011`_
  - **PR** `#23851`_: (*ticosax*) [dockerng] fix mounting
    | refs: `#23912`_
  * 94b951d Merge pull request `#23920`_ from ticosax/fix-pulled-image-comparison
  * 09d934b Fix pull images

- **PR** `#24067`_: (*ticosax*) [dockerng] compare images by ID not by name
  @ *2015-05-22T13:46:15Z*

  * 01fb405 Merge pull request `#24067`_ from ticosax/compare-images-by-id
  * b681f71 compare images by ID not by name

- **PR** `#24054`_: (*mgwilliams*) s3.head: return useful data
  | refs: `#25584`_
  @ *2015-05-22T05:35:00Z*

  * 475032c Merge pull request `#24054`_ from mgwilliams/s3
  * 80c7a69 s3.head: return useful data

- **PR** `#24051`_: (*rallytime*) Update minimum version for pycrypto
  @ *2015-05-21T23:44:17Z*

  - **ISSUE** `#23695`_: (*terminalmage*) develop branch relies on newer pycrypto than is available in some distros
    | refs: `#24051`_
  * f851ec7 Merge pull request `#24051`_ from rallytime/update_pycrypto_requirement
  * fba0de8 Update minimum version for pycrypto

- **PR** `#24041`_: (*basepi*) Merge forward from 2015.5 to develop
  @ *2015-05-21T19:32:38Z*

  * d13e2a3 Merge pull request `#24041`_ from basepi/merge-forward-develop
  * 58aed60 Merge remote-tracking branch 'upstream/2015.5' into merge-forward-develop

- **PR** `#24015`_: (*YanChii*) minor improvement of solarisips docs & fix typos
  @ *2015-05-21T16:43:43Z*

  * dbbd05b Merge pull request `#24015`_ from YanChii/solarisips-docs2
  * f14381d minor improovement of solarisips docs & fix typos

- **PR** `#24013`_: (*jbq*) Fix enabling a service on Ubuntu `#24012`_
  @ *2015-05-21T16:40:49Z*

  - **ISSUE** `#24012`_: (*jbq*) Enabling a service does not create the appropriate rc.d symlinks on Ubuntu
    | refs: `#24013`_
  * b74c70b Merge pull request `#24013`_ from jbq/issue_24012
  * 868db3a Fix enabling a service on Ubuntu `#24012`_

- **PR** `#24027`_: (*wfhg*) Add baseurl to salt.modules.zypper.mod_repo
  @ *2015-05-21T15:20:57Z*

  - **ISSUE** `#23088`_: (*wfhg*) Segfault when adding a Zypper repo on SLES 11.3
    | refs: `#24027`_
  * c938d00 Merge pull request `#24027`_ from wfhg/develop
  * 9d22aff Added baseurl as alias for url and mirrorlist in salt.modules.zypper.mod_repo.

- **PR** `#24011`_: (*ticosax*) [dockerng] Tests for `#23975`_ and apply same logic for `ports` and `port_bindings`
  @ *2015-05-21T15:00:23Z*

  - **PR** `#23975`_: (*terminalmage*) Check for VOLUME lines in image
    | refs: `#24011`_
  - **PR** `#23912`_: (*ticosax*) [dockerng] More flexible validation for mount points and ports.
    | refs: `#23920`_ `#23975`_ `#24011`_
  - **PR** `#23851`_: (*ticosax*) [dockerng] fix mounting
    | refs: `#23912`_
  * 2b74e81 Merge pull request `#24011`_ from ticosax/dockerng-ports-not-expose
  * 5f8f24b Related to `#23975`_ and apply same logic for `ports` and `port_bindings`

- **PR** `#23999`_: (*neogenix*) Develop branch fix for `#23950`_
  @ *2015-05-21T04:19:50Z*

  - **ISSUE** `#23950`_: (*neogenix*) iptables state generates a 0 position which is invalid in iptables cli
    | refs: `#23999`_
  * 229594d Merge pull request `#23999`_ from neogenix/develop-23950
  * dd13b99 Develop branch fix for `#23950`_

- **PR** `#24000`_: (*wt*) Remove yaml terminator in yaml formatter.
  @ *2015-05-21T02:52:59Z*

  * 17615dd Merge pull request `#24000`_ from wt/remove_yaml_terminator
  * a7dd113 Remove yaml terminator in yaml formatter.

- **PR** `#23975`_: (*terminalmage*) Check for VOLUME lines in image
  | refs: `#24011`_
  @ *2015-05-20T19:59:04Z*

  - **PR** `#23912`_: (*ticosax*) [dockerng] More flexible validation for mount points and ports.
    | refs: `#23920`_ `#23975`_ `#24011`_
  - **PR** `#23851`_: (*ticosax*) [dockerng] fix mounting
    | refs: `#23912`_
  * b39e2d9 Merge pull request `#23975`_ from terminalmage/fix-docker-volumes
  * 8ad8b52 Update test to mock dockerng.history

  * 9624eec Simplify for loop

  * 868a140 Check for VOLUME lines in image

- **PR** `#23990`_: (*basepi*) Merge forward from 2015.5 to develop
  @ *2015-05-20T19:58:23Z*

  * 301da56 Merge pull request `#23990`_ from basepi/merge-forward-develop
  * 9dbafcc Merge remote-tracking branch 'upstream/2015.5' into merge-forward-develop

- **PR** `#23984`_: (*rallytime*) Added a CLI Example to the tls.get_extensions function
  @ *2015-05-20T18:32:08Z*

  * e5783d6 Merge pull request `#23984`_ from rallytime/cli_example_tls_get_extensions
  * d86afbb Added a CLI Example to the tls.get_extensions function

- **PR** `#23980`_: (*iggy*) template: jinja2 -> jinja
  @ *2015-05-20T17:31:05Z*

  * 23211d2 Merge pull request `#23980`_ from iggy/patch-1
  * 8ec6d89 template: jinja2 -> jinja

- **PR** `#23977`_: (*ionutbalutoiu*) Fixed glance image_create
  @ *2015-05-20T17:25:15Z*

  * c04c8cc Merge pull request `#23977`_ from ionutbalutoiu/develop
  * 7ed6ab9 Fixed glance image_create

- **PR** `#23964`_: (*quantonganh*) Tls get extensions
  @ *2015-05-20T15:40:20Z*

  * 9fc0b22 Merge pull request `#23964`_ from quantonganh/tls-get-extensions
  * cdc3980 tls module: PEP 8

  * 060e59f tls module: default CA filename should be only used when it is not None

  * adb4e5e tls module: handle the case when the pillar for extensions is not defined

  * 7785e0b tls module: missing `cacert_path` when calling `maybe_fix_ssl_version`

- **PR** `#23972`_: (*alkivi-sas*) Improved matching on dict keys
  @ *2015-05-20T15:38:55Z*

  * afa1971 Merge pull request `#23972`_ from alkivi-sas/targeting-dict-keys
  * cdf0999 Improved matching on dict keys

- **PR** `#23968`_: (*s0undt3ch*) `salt.utils.http` fixes
  @ *2015-05-20T15:36:00Z*

  * 03c9936 Merge pull request `#23968`_ from s0undt3ch/develop
  * 3d6a410 Fix wrong variable assignment

  * 9f821e9 Don't try to set cookies if we don't have a instantiated cookie jar

  * d4eb9fc Default missing items as an empty string.

  * 4d37601 Have cookie JAR's respect the configured `cachedir`

- **PR** `#23974`_: (*drawsmcgraw*) Quick note on usability of 'include' statement.
  @ *2015-05-20T15:25:39Z*

  * ede34f2 Merge pull request `#23974`_ from drawsmcgraw/update-include-docs
  * fb0f108 Quick note on usability of 'include' statement.

- **PR** `#23962`_: (*jarpy*) Fixed-pitch messages from Slack returner.
  @ *2015-05-20T15:21:23Z*

  * 479e24b Merge pull request `#23962`_ from jarpy/fixed-pitch-slack
  * c2cb013 Fixed-pitch messages from Slack returner.

- **PR** `#23897`_: (*kiorky*) Lxc seed and prof ports
  | refs: `#23898`_
  @ *2015-05-20T13:12:27Z*

  - **ISSUE** `#23847`_: (*kiorky*) lxc: systemd containers cant be seeded
    | refs: `#23897`_ `#23808`_ `#23898`_ `#23806`_
  - **ISSUE** `#23833`_: (*kiorky*) lxc.set_dns fails intermittently
    | refs: `#23897`_ `#23808`_ `#23898`_ `#23807`_
  - **ISSUE** `#23772`_: (*cheuschober*) lxc.init fails to bootstrap container
    | refs: `#23897`_ `#23808`_ `#23898`_ `#23807`_ `#23806`_
  - **ISSUE** `#23658`_: (*arthurlogilab*) [salt-cloud lxc] too verbose, shows host: True multiple times when starting
    | refs: `#23897`_ `#23898`_
  - **ISSUE** `#23657`_: (*arthurlogilab*) [salt-cloud lxc] NameError: global name '__salt__' is not defined
    | refs: `#23897`_ `#23982`_ `#23898`_ `#24080`_
  - **PR** `#23898`_: (*kiorky*) Lxc profiles
    | refs: `#23897`_
  - **PR** `#23808`_: (*kiorky*) Lxc seed and prof ports
    | refs: `#23897`_ `#23807`_
  - **PR** `#23807`_: (*kiorky*) Lxc profiles
    | refs: `#23898`_
  - **PR** `#23806`_: (*kiorky*) Lxc seeding
    | refs: `#23807`_
  * c641c0c Merge pull request `#23897`_ from makinacorpus/lxc_seed_and_prof_ports
  * d1d6cef lxc: reconcile with forward merge

- **PR** `#23959`_: (*gladiatr72*) Oops. Neglected to replace the string, 'server', with cert_type when
  @ *2015-05-20T04:37:45Z*

  * 97b3f0b Merge pull request `#23959`_ from gladiatr72/tls_exec_module__create_csr__cert_type_propigation_fix
  * 8f00d72 Oops. Neglected to replace the string, 'server', with cert_type when those bits were added in.  Eagle eye award to @quantonganh

- **PR** `#23954`_: (*nmadhok*) Fixing ImportError in salt 2014.7.0 version causing VMware salt-cloud driver to fail
  @ *2015-05-20T03:27:23Z*

  - **ISSUE** `#23953`_: (*nmadhok*) salt-cloud VMware driver fails when used with 2014.7.0
    | refs: `#23954`_
  * 9f196e1 Merge pull request `#23954`_ from nmadhok/vmware-patch-1
  * d458cfd Fixing ImportError in salt 2014.7.0 version

- **PR** `#23938`_: (*basepi*) Merge forward from 2015.5 to develop
  @ *2015-05-20T03:12:16Z*

  * 237542b Merge pull request `#23938`_ from basepi/merge-forward-develop
  * 8f53adb Merge remote-tracking branch 'upstream/2015.5' into merge-forward-develop

- **PR** `#23944`_: (*ryan-lane*) Add missing loginclass argument to _changes call
  @ *2015-05-20T03:11:30Z*

  * e23a4b2 Merge pull request `#23944`_ from lyft/fix-user-present
  * da8d384 Add missing loginclass argument to _changes call

- **PR** `#23951`_: (*ryan-lane*) Do not check perms in file.copy if preserve
  @ *2015-05-20T01:47:40Z*

  * 92cdfec Merge pull request `#23951`_ from lyft/file-copy-preserve-fix
  * e225333 Update file.py

  * 6347b3c Do not check perms in file.copy if preserve

- **PR** `#23934`_: (*techhat*) Set cookie domain to string if None
  @ *2015-05-20T01:41:41Z*

  * 8927b91 Merge pull request `#23934`_ from techhat/sessioncookie
  * 7c4b8cd Set cookie domain to string if None

- **PR** `#23926`_: (*DmitryKuzmenko*) Pillarenv support in minion config, cp and cmdmod modules.
  @ *2015-05-20T00:47:37Z*

  - **ISSUE** `#18808`_: (*amendlik*) Add command line argument to select pillar environment
    | refs: `#23926`_ `#25238`_
  * 3713834 Merge pull request `#23926`_ from DSRCompany/pillarenv
  * 584c54a Added pillarenv support to cp module

  * 75291e0 Add pillarenv and pillar args to cmdmod module

  * 0eedf7c Add 'pillarenv' into minion config.

- **PR** `#23906`_: (*gladiatr72*) Added exception handler to trap the RuntimeError raised when
  @ *2015-05-20T00:46:48Z*

  - **ISSUE** `#23839`_: (*gladiatr72*) wonky loader syndrome
    | refs: `#23906`_
  - **ISSUE** `#23373`_: (*tnypex*) reactor/orchestrate race condition on salt['pillar.get']
    | refs: `#23906`_
  * 529e171 Merge pull request `#23906`_ from gladiatr72/exception_handler_for_Depends_decorator
  * 878eb09 add proper marker for format argument

  * 2ddbad8 Added exception handler to trap the RuntimeError raised when Depends.enforce_dependency() class method fires unsuccessfully. There appears to be no synchronization within the Depends decorator class wrt the class global dependency_dict which results in incomplete population of any loader instantiation occuring at the time of one of these exceptions.

- **PR** `#23930`_: (*garethgreenaway*) updates to beacons module
  @ *2015-05-19T22:22:41Z*

  * 3124408 Merge pull request `#23930`_ from garethgreenaway/beacon_module_updates_to_list_function
  * 5d60c0f switching the list function in the beacon execution module to use an event to retrieve the list of beacons to ensure consistency when using salt vs salt-call

- **PR** `#23893`_: (*basepi*) Merge forward from 2015.5 to develop
  @ *2015-05-19T17:23:16Z*

  * 622bda8 Merge pull request `#23893`_ from basepi/merge-forward-develop
  * a87b057 Merge remote-tracking branch 'upstream/2015.5' into merge-forward-develop

  * ed3a71d Fix scheduleadd test

  * d8a60d6 Merge remote-tracking branch 'upstream/2015.5' into merge-forward-develop

- **PR** `#23923`_: (*terminalmage*) Add warning about case-sensitivity in pkg states
  @ *2015-05-19T16:59:52Z*

  - **ISSUE** `#23746`_: (*amontalban*) pkg.install is failing in FreeBSD 10.1
    | refs: `#23923`_
  * 7b0a5ea Merge pull request `#23923`_ from terminalmage/issue23746
  * 5e67f0e Add warning about case-sensitivity in pkg states

- **PR** `#23919`_: (*gcamus*) Manage user own cron with minion launch with unprivileged user
  @ *2015-05-19T16:58:25Z*

  - **ISSUE** `#23918`_: (*gcamus*) Feature request : Support cron management with unprivileged user
    | refs: `#23919`_
  * 7550db2 Merge pull request `#23919`_ from gcamus/cron-unprivileged-user
  * f4195d8 Fix Pylint violations

  * 78ccf97 Manage user own cron with minion launch with unprivileged user

- **PR** `#23913`_: (*kiorky*) tls: Open appropriatly tls serial file
  @ *2015-05-19T15:57:19Z*

  - **ISSUE** `#23911`_: (*kiorky*) tls module: selfsigned certs support is broken
    | refs: `#23913`_
  * 3a91f7c Merge pull request `#23913`_ from makinacorpus/fixtls3
  * c145a57 tls: Open appropriatly tls serial file

- **PR** `#23902`_: (*ryan-lane*) Kms support
  @ *2015-05-19T15:56:25Z*

  * 9d0d5d5 Merge pull request `#23902`_ from lyft/kms-support
  * 7fae782 Followups for module docs, consistency and reliability

  * ae5288b Initial commit of boto_kms state and execution modules

- **PR** `#23896`_: (*The-Loeki*) `#22080`_ part 4: Make the related functions fully IP-agnostic
  @ *2015-05-19T15:54:08Z*

  - **ISSUE** `#22080`_: (*The-Loeki*) CIDR matching for IPv6 / improve IPv6 support in utils.network
    | refs: `#22691`_ `#23253`_ `#23896`_ `#24282`_ `#24282`_
  - **ISSUE** `#21721`_: (*deuscapturus*) datetime as value in pillar causes error
    | refs: `#22118`_
  - **ISSUE** `#21113`_: (*The-Loeki*) SaltStack can't serialize Decimals
  - **ISSUE** `#11630`_: (*basepi*) Check for non-standard data structures in YAML-rendered data (specifically opts)
  - **PR** `#22118`_: (*surajssd*) Datetime support for msgpack for issue-21721
  * 22f5415 Merge pull request `#23896`_ from The-Loeki/better-ipv6
  * 0749b4c Fix for failed unit test; Related to `#21113`_, `#11630`_, `#22118`_ Serialization of ipaddress objects would be nice!

  * 46c2816 PyLint fix

  * 6e9b11a small fix

  * 45dab9f * utils.network.in_subnet IP-agnostic * utils.network.ip_in_subnet IP-agnostic * utils.network.calculate_subnet IP-agnostic * add cidr to modules.network.ip_addrs6

- **PR** `#23867`_: (*gladiatr72*) Tls add cert type option
  @ *2015-05-19T15:51:02Z*

  * 7845512 Merge pull request `#23867`_ from gladiatr72/tls_add-cert_type-option
  * 934a224 lint fixes

  * 3ecdd6a create_ca_signed_cert(): new args; module docs + enhanced function docs

  * d22e9f7 Add cert_type argument to create_csr() and create_ca_signed_cert()

- **PR** `#23865`_: (*alkivi-sas*) Added feature to handle dict in file.accumulated
  @ *2015-05-19T15:50:33Z*

  * 6a309c8 Merge pull request `#23865`_ from alkivi-sas/dict-in-file-accumulated
  * bb8d94f Added feature to handle dict in file.accumulated

- **PR** `#23164`_: (*vladimir-didenko*) Switch resolver to threaded variant
  @ *2015-05-19T15:50:20Z*

  * cffa82f Merge pull request `#23164`_ from vladimir-didenko/nonblocking-resolver
  * fce3da3 Add blank line to satisfy pylint

  * ed8e068 Switch resolver to threaded variant since ExecutorResolver by default uses blocking implementation

- **PR** `#23851`_: (*ticosax*) [dockerng] fix mounting
  | refs: `#23912`_
  @ *2015-05-19T15:47:55Z*

  * e97a9c4 Merge pull request `#23851`_ from ticosax/fix-volumes
  * f45c7bd Add boilerplate unit test pieces to new dockerng_test file

  * df48ac2 volumes path, on create, should be the one inside the container

  * a8af238 typo

- **PR** `#23846`_: (*alkivi-sas*) Add feature to match for key in dict pillar
  @ *2015-05-19T15:47:23Z*

  * b50ed6c Merge pull request `#23846`_ from alkivi-sas/targeting-dict-keys
  * c2a1eeb fix return

  * e4f5b61 Add feature to match for key in dict pillar

- **PR** `#23827`_: (*kiorky*) fix tls virtual
  @ *2015-05-19T15:46:35Z*

  - **ISSUE** `#23826`_: (*kiorky*) tls module is broken
    | refs: `#23827`_
  * bed9630 Merge pull request `#23827`_ from makinacorpus/fixtls
  * d9a6464 more tls virtual fixes

  * c13ece6 fix tls virtual

- **PR** `#23908`_: (*nleib*) fix connection function to mongo
  @ *2015-05-19T15:41:21Z*

  * 97cf705 Merge pull request `#23908`_ from nleib/patch-1
  * 12f6fa5 fix connection function to mongo

- **PR** `#23880`_: (*bastiaanb*) if setting client_config_dir to '~', expand path
  @ *2015-05-18T22:19:23Z*

  * 77175a7 Merge pull request `#23880`_ from bastiaanb/fix/should-expand-homedir-for-saltrc
  * d9fa8b8 if setting client_config_dir to '~', expand path

- **PR** `#23877`_: (*rallytime*) Cloud tests should use an image that is LTS
  @ *2015-05-18T22:16:43Z*

  * 03317ec Merge pull request `#23877`_ from rallytime/change_do_test_image
  * 7ed776c Cloud tests should use an image that is LTS

- **PR** `#23878`_: (*nmadhok*) Fixing Sphinx errors and warnings
  @ *2015-05-18T22:14:40Z*

  * dfbefa8 Merge pull request `#23878`_ from nmadhok/sphinx-patch
  * 8def200 Fixing more sphinx errors and warnings

  * dca6fb8 Fixing more sphinx errors and warnings

  * 2c13cf3 Fixing more sphinx errors and warnings

  * 9dc1e0b Fixing sphinx errors and warnings

- **PR** `#23869`_: (*basepi*) Merge forward from 2015.5 to develop
  @ *2015-05-18T20:22:05Z*

  * 31680c7 Merge pull request `#23869`_ from basepi/merge-forward-develop
  * 46a882e Absolute import on new win_inet_pton.py

  * 6530a20 Merge remote-tracking branch 'upstream/2015.5' into merge-forward-develop

- **PR** `#23803`_: (*skizunov*) Make extensionless scripts runable in Windows
  @ *2015-05-18T17:04:31Z*

  * 46a52a6 Merge pull request `#23803`_ from skizunov/develop2
  * 57fba60 Make extensionless scripts runable in Windows

- **PR** `#23804`_: (*skizunov*) Adding missing .bat scripts for salt-master and friends
  @ *2015-05-18T16:53:55Z*

  * 57c8f7c Merge pull request `#23804`_ from skizunov/develop3
  * 714dc95 Adding missing .bat scripts for salt-master and friends

- **PR** `#23857`_: (*rallytime*) Merge `#23773`_ with pylint fix
  @ *2015-05-18T16:42:19Z*

  - **PR** `#23773`_: (*mgwilliams*) boto_cfn.describe
    | refs: `#23857`_
  * 804c3c2 Merge pull request `#23857`_ from rallytime/merge-23773
  * 5307d65 Merge `#23773`_ with pylint fix

  * 47e729f modules.boto_cfn: fix typo

  * f534287 modules.boto_cfn: only apply funcs if HAS_BOTO

  * 219a661 modules.boto_cfn: tweak pylint

  * 7fd787a add boto_cfn.describe; clean up imports

- **PR** `#23825`_: (*kiorky*) Fix crypto
  @ *2015-05-18T16:11:35Z*

  - **ISSUE** `#23824`_: (*kiorky*) salt.crypt broken in develop
    | refs: `#23825`_
  * 424bcc6 Merge pull request `#23825`_ from makinacorpus/fixcrypto
  * 3fc4071 lint

  * 59a124a use reinit_crypto everywhere

  * f103da4 Fix PyCrypto routines at fork

- **PR** `#23849`_: (*pille*) beacon docs: fix YAML markup and typo
  @ *2015-05-18T15:27:38Z*

  * bc82999 Merge pull request `#23849`_ from pille/beacon-doc-fix
  * 5d30d49 beacon docs: fix YAML markup and typo

- **PR** `#23848`_: (*dumol*) Updated installation docs for SLES 12.
  @ *2015-05-18T15:27:04Z*

  * bf62d43 Merge pull request `#23848`_ from dumol/patch-1
  * 06bed05 Updated for SLES 12.

- **PR** `#23841`_: (*favadi*) fix wrong package name for rng-tools
  @ *2015-05-18T15:23:03Z*

  * d12f881 Merge pull request `#23841`_ from favadi/gpg-rng-tools
  * 70a77db fix wrong package name for rng-tools

- **PR** `#23838`_: (*gtmanfred*) add refresh_beacons and sync_beacons
  @ *2015-05-18T15:22:20Z*

  * a81f352 Merge pull request `#23838`_ from gtmanfred/develop
  * 4405685 add refresh_beacons and sync_beacons

- **PR** `#23836`_: (*cedwards*) improving function output and return code status in trafficserver
  @ *2015-05-18T15:17:48Z*

  * 6c2cdbf Merge pull request `#23836`_ from cedwards/ats_module
  * 7c620a2 improving function output and return code status in trafficserver

- **PR** `#23834`_: (*Arabus*) Avoid deprecation warning from  portage.dep.strip_empty()
  @ *2015-05-18T15:11:59Z*

  * 41f315b Merge pull request `#23834`_ from Arabus/develop
  * 8656721 Proper replacement for portage.dep.strip_empty() with list comprehension, pep8fix

  * 427e3fe Switch portage.dep.strip_empty(...) to filter(None,...) to avoid deprecation warning and do essentially the same

- **PR** `#23813`_: (*nmadhok*) Fixing Sphinx errors and warnings
  @ *2015-05-18T15:06:32Z*

  * 573791a Merge pull request `#23813`_ from nmadhok/sphinx-patch
  * 63d8325 Fixing more sphinx/docs errors and warnings

  * 12ea8f5 Fixing more sphinx/docs errors and warnings

  * 391a267 Fixing more sphinx/docs errors and warnings

  * 0189e06 Fixing more sphinx/docs errors and warnings

  * ac254a4 Fixing more sphinx/docs errors and warnings

  * 09b6450 Fixing sphinx/docs errors and warnings

- **PR** `#23716`_: (*kiorky*) Correct detect service toggling
  @ *2015-05-16T17:00:44Z*

  - **ISSUE** `#23715`_: (*kiorky*) service.* / init_delay is broken
    | refs: `#23716`_
  - **ISSUE** `#23713`_: (*kiorky*) service.dead is no more stateful
    | refs: `#23716`_
  - **PR** `#23717`_: (*kiorky*) Fix init delay throwing in the changes dict...
    | refs: `#23716`_
  * a2e23fd Merge pull request `#23716`_ from makinacorpus/i23713
  * e26885d lint

  * bde7867 service/{dead/running} optimizations & test fixes

  * 585d898 lint

  * 77aa940 Correct detect service toggling

- **PR** `#23790`_: (*aboe76*) updated suse spec file to version 2015.5.0
  @ *2015-05-15T21:37:24Z*

  * 72a8a77 Merge pull request `#23790`_ from aboe76/opensuse_spec
  * 15139c3 updated suse spec file to version 2015.5.0

- **PR** `#23786`_: (*kaithar*) Log the error generated that causes returns.mysql.returner to except.
  @ *2015-05-15T20:47:58Z*

  * 2d687d0 Merge pull request `#23786`_ from kaithar/issue/log-errors-in-returner
  * 29ffe32 Log the error generated that causes returns.mysql.returner to except.

- **PR** `#23784`_: (*basepi*) Merge forward from 2015.5 to develop
  @ *2015-05-15T20:30:01Z*

  * dcae51b Merge pull request `#23784`_ from basepi/merge-forward-develop
  * 4ea3f8f Merge remote-tracking branch 'upstream/2015.5' into merge-forward-develop

- **PR** `#23750`_: (*basepi*) Gate the new zmq.eventloop.ioloop imports for salt-ssh
  @ *2015-05-15T19:30:59Z*

  - **ISSUE** `#23340`_: (*philipsd6*) salt-ssh 2015.2.0-1187-gb224d82 requires zmq, why?
    | refs: `#23750`_
  * da42af7 Merge pull request `#23750`_ from basepi/salt-ssh.zmq.develop.23340
  * bd61889 Lint

  * 3f6fed0 Gate the new zmq.eventloop.ioloop imports for salt-ssh

- **PR** `#23777`_: (*jfindlay*) Merge `#23665`_
  @ *2015-05-15T18:16:21Z*

  - **PR** `#23665`_: (*txomon*) ssh: AuthorizedKeysFile expands defined tokens
    | refs: `#23777`_
  * aab9c43 Merge pull request `#23777`_ from jfindlay/merge_23665
  * 87e000d fix ssh module unit tests

  * 8766209 fix ssh AuthorizedKeysFile path processing

  * 6362072 Remove trailing whitespace

  * 5cab0ec ssh: AuthorizedKeysFile expands defined tokens

- **PR** `#23756`_: (*jfindlay*) Merge 23747
  @ *2015-05-15T18:14:03Z*

  - **PR** `#23747`_: (*gladiatr72*) x509 extension handling fix `#23696`_
    | refs: `#23756`_
  * 41d8b84 Merge pull request `#23756`_ from jfindlay/merge_23747
  * 50df023 LooseVersion takes strings

  * 0afa827 A good point made by @garthk wrt multi-dotted version strings not being very float() compatible.

  * f1ed515 If I'm going to use floats for version comparison, it behoves me to provide something for float() to work with.

  * 244d923 Fix lint violations

  * f9905c6 version tag

  * f85c373 Re-add the original __virtual__ check for ca.cert_base_path

  * 3c6decf . __virtual__()     - now with a version-specific check and log message

- **PR** `#23749`_: (*rallytime*) Move digital_ocean_v2 tests to be the default/only cloud tests for digital ocean
  @ *2015-05-15T18:13:53Z*

  * 8f53dd1 Merge pull request `#23749`_ from rallytime/remove_do_apiv1_tests
  * 7e15ff9 Move digital_ocean_v2 tests to be the defauly/only tests for digital ocean cloud tests

- **PR** `#23747`_: (*gladiatr72*) x509 extension handling fix `#23696`_
  | refs: `#23756`_
  @ *2015-05-15T18:12:59Z*

  * 51609f2 Merge pull request `#23747`_ from gladiatr72/tls_extension_work
  * ddc759e LooseVersion takes strings

  * ac8e5d9 A good point made by @garthk wrt multi-dotted version strings not being very float() compatible.

  * 392363f If I'm going to use floats for version comparison, it behoves me to provide something for float() to work with.

  * fefa890 Fix lint violations

  * 594cbc3 version tag

  * 299fbbd Merge branch 'tls_extension_work' of github.com:gladiatr72/salt into tls_extension_work

    * c4a46fd . __virtual__()     - now with a version-specific check and log message

  * d622a7c Re-add the original __virtual__ check for ca.cert_base_path

  * c8218d4 . __virtual__()     - now with a version-specific check and log message

- **PR** `#23719`_: (*DmitryKuzmenko*) Support pillarenv cmdline in state.sls
  @ *2015-05-15T18:10:08Z*

  * 98c1613 Merge pull request `#23719`_ from DSRCompany/pillarenv
  * 1153fcb Minor KeyError bugfix

  * 39bf836 Support pillarenv in all state.*sls* commands

  * 095f700 Bugfixes and state module update

  * 045aa50 Support pillarenv cmdline in state.sls

- **PR** `#22548`_: (*terminalmage*) Add docker-ng state module
  @ *2015-05-15T18:09:58Z*

  * d951bc8 Merge pull request `#22548`_ from terminalmage/docker-ng
  * 150d4e2 Update unit.utils.utils_test.UtilsTestCase.test_clean_kwargs

  * e285388 Rename references to docker-ng with dockerng

  * 422da16 Lint fixes

  * e723aff Refactor/add to dockerng states

  * bee42eb Fixes/additions to dockerng module to work better with states

  * b151bcf Make salt.utils.clean_kwargs() clean all kwargs starting with dunder

  * 3289736 Fix typo

  * 23a8275 Add docker-ng state docs to toctree

  * 510f697 Add docker-ng state module

  * 2b3308d Docstring tweaks

  * 7fe4cea More bugfixes discovered while writing docker-ng states

- **PR** `#23757`_: (*clan*) use abspath, do not eliminating symlinks
  @ *2015-05-15T17:36:02Z*

  * d7ce64f Merge pull request `#23757`_ from clan/file_directory_require
  * c02e4ef use abspath, do not eliminating symlinks

- **PR** `#23755`_: (*iamfil*) instance_id being set to location instead of None. Causes rename to fail when using name.
  @ *2015-05-15T17:31:09Z*

  * 1ac41f1 Merge pull request `#23755`_ from iamfil/fix-ec2-rename
  * 780bc87 instance_id being set to location instead of None. Causes rename to fail when using name.

- **PR** `#23754`_: (*rfairburn*) yumpkg.py multiple enable/disablerepos + repoquery without stderr
  @ *2015-05-15T17:25:10Z*

  * d4d84d9 Merge pull request `#23754`_ from rfairburn/yumpkg-fixes
  * a0e8197 yumpkg.py multiple enable/disablerepos + repoquery without stderr

- **PR** `#23739`_: (*rallytime*) Add version added tag to win_service.create
  @ *2015-05-14T21:59:05Z*

  - **ISSUE** `#23738`_: (*KevinOrtman*) win_service.create needs version annotations
    | refs: `#23739`_
  * 0d0eaa9 Merge pull request `#23739`_ from rallytime/`fix-23738`_
  * 609ac8e Add version added tag to win_service.create

- **PR** `#23732`_: (*rallytime*) Add docstring and CLI Example to tls.revoke_cert
  @ *2015-05-14T21:58:48Z*

  - **PR** `#23701`_: (*quantonganh*) Tls module revoke
    | refs: `#23732`_
  * ca107e8 Merge pull request `#23732`_ from rallytime/tls_docstring_fix
  * f953d55 Add versionadded directives to tls.revoke_cert and tls.create_empty_crl

  * e6f6208 Add docstring and CLI Example to tls.revoke_cert

- **PR** `#23729`_: (*rallytime*) Partially merge `#23437`_ (grains fix)
  @ *2015-05-14T21:58:24Z*

  - **PR** `#23437`_: (*cedwards*) Grains item patch
    | refs: `#23729`_
  * cdce414 Merge pull request `#23729`_ from rallytime/merge-23437-partially
  * 1a8b945 adding support for nested grains to grains.item

- **PR** `#23697`_: (*rmcleay*) Added templates and sources to file.blockreplace
  @ *2015-05-14T21:57:40Z*

  - **ISSUE** `#21490`_: (*kuyote*) Feature request: addition of source for the blockreplace
    | refs: `#23697`_
  - **ISSUE** `#14363`_: (*xenophonf*) file.blockreplace and file.accumulated should support source/sources arguments similar to file.append
    | refs: `#23697`_
  * d9d5d1e Merge pull request `#23697`_ from rmcleay/templated_file.blockreplace
  * 6811e81 Added templates and sources to file.blockreplace

- **PR** `#23737`_: (*bradthurber*) fix for 2015.5.0 modules/archive.py ZipFile instance has no attribute…
  @ *2015-05-14T21:17:01Z*

  - **ISSUE** `#23734`_: (*bradthurber*) 2015.5.0 modules/archive.py ZipFile instance has no attribute '__exit__' - only python 2.6?
    | refs: `#23737`_
  * 675a374 Merge pull request `#23737`_ from bradthurber/fix_23734
  * b11a188 fix for 2015.5.0 modules/archive.py ZipFile instance has no attribute '__exit__' - only python 2.6? `#23734`_

- **PR** `#23721`_: (*basepi*) Merge forward from 2015.5 to develop
  @ *2015-05-14T20:27:55Z*

  - **ISSUE** `#17`_: (*thatch45*) Modules need to be autodocumenting
    | refs: `#25071`_
  * 98c2cb4 Merge pull request `#23721`_ from basepi/merge-forward-develop
  * cf55aeb Merge pull request `#17`_ from jfindlay/dev_tests

    * e90bb25 update debian_ip unit tests

  * 31740e9 Remove unused import

  * 7d8038f Merge remote-tracking branch 'upstream/2015.5' into merge-forward-develop

- **PR** `#23726`_: (*msteed*) fix `#23695`_
  @ *2015-05-14T19:35:41Z*

  - **ISSUE** `#23695`_: (*terminalmage*) develop branch relies on newer pycrypto than is available in some distros
    | refs: `#24051`_
  * 6dc4c4a Merge pull request `#23726`_ from msteed/issue-23695
  * 9506f7b lint

  * 6d91b88 handle pycrypto < 2.1 for non-zmq case

  * 05a10f8 fix `#23695`_

- **PR** `#23717`_: (*kiorky*) Fix init delay throwing in the changes dict...
  | refs: `#23716`_
  @ *2015-05-14T16:46:08Z*

  * 9a54f3e Merge pull request `#23717`_ from makinacorpus/i23715
  * 62bc21d Fix init delay throwing in the changes dict...

- **PR** `#23701`_: (*quantonganh*) Tls module revoke
  | refs: `#23732`_
  @ *2015-05-14T16:15:02Z*

  * fd2d596 Merge pull request `#23701`_ from quantonganh/tls-module-revoke
  * bcb35cc tls module: prevent CA cert is created everytime

  * 8a4d263 tls module: add function to revoke a certificate

  * 42e937e tls module: create a function to get cert's basic info

  * 09081fd tls module: allow to specify `cert_path`

  * 23dd2e3 tls module: allow to specify csr_path

  * 2f74e51 tls module: allow to specify CA filename

  * 2943154 tls module: add a function to create an empty CRL

- **PR** `#23693`_: (*anastrophe*) Removed link to github page that no longer exists.
  @ *2015-05-14T05:04:34Z*

  * 4c844a4 Merge pull request `#23693`_ from anastrophe/rm-deadlink-docs
  * f7f002d Removed link to github page that no longer exists.

- **PR** `#23692`_: (*obestwalter*) fix typos in architecture.rst
  @ *2015-05-14T00:53:03Z*

  * 521ba14 Merge pull request `#23692`_ from obestwalter/fix-typos-in-architecture
  * 4ba0f20 fix typos

- **PR** `#23691`_: (*dennisjac*) add initial configuration documentation for varstack pillar
  @ *2015-05-14T00:51:15Z*

  * d6954fd Merge pull request `#23691`_ from conversis/develop
  * 445fa19 add initial configuration documentation for varstack pillar

- **PR** `#23684`_: (*garethgreenaway*) Additions to aptpkg module
  @ *2015-05-13T20:35:12Z*

  - **ISSUE** `#23501`_: (*anitakrueger*) aptpkg does not support passing --force-confnew
    | refs: `#23684`_
  * 9d0bb55 Merge pull request `#23684`_ from garethgreenaway/23501_aptpkg_allow_force_new_configuration_files
  * 6cef2ac Additions to the aptpkg module to allow installing new configuration files by default

- **PR** `#23676`_: (*basepi*) Merge forward from 2015.5 to develop
  @ *2015-05-13T19:45:22Z*

  * 2be887d Merge pull request `#23676`_ from basepi/merge-forward-develop
  * 434f7bc Catch StopIteration

  * 5ee7f25 Merge remote-tracking branch 'upstream/2015.5' into merge-forward-develop

- **PR** `#23671`_: (*rallytime*) Added versionadded directive to new influxdb returner
  @ *2015-05-13T17:56:27Z*

  - **PR** `#23614`_: (*dgeorgievski*) Added influxdb (www.influxdb.com) returner. The returner supports Mas…
    | refs: `#23671`_
  * e490383 Merge pull request `#23671`_ from rallytime/version_influxdb_return
  * f1c7248 Added versionadded directive to new influxdb returner

- **PR** `#23668`_: (*rallytime*) Merge `#23633`_ into develop
  @ *2015-05-13T17:11:51Z*

  - **PR** `#23633`_: (*jayeshka*) made changes to test_interfaces function.
    | refs: `#23668`_
  * 670625c Merge pull request `#23668`_ from rallytime/fix_windows_test_upstream
  * 17987d9 made changes to test_interfaces function.

- **PR** `#23614`_: (*dgeorgievski*) Added influxdb (www.influxdb.com) returner. The returner supports Mas…
  | refs: `#23671`_
  @ *2015-05-13T17:05:48Z*

  * 21009fd Merge pull request `#23614`_ from dgeorgievski/add-influxdb-returner
  * fb7fc76 Last editing introduced two empty lines which would probably be reported as errors. Re-commiting without them

  * b833904 Removed last reported pylint inconsistencies. Still using broad Exceptions. influxdb client is not exporting its exceptions

  * e7e499c Code made compliant with pylint

  * 9fb5c10 Added influxdb (www.influxdb.com) returner. The returner supports Master Job Cache, External Job Cache and Event Returners.

- **PR** `#23607`_: (*Azidburn*) Fix for `#23604`_. No error reporting. Exitcode !=0 are ok
  @ *2015-05-13T17:05:17Z*

  - **ISSUE** `#23604`_: (*Azidburn*) service.dead on systemd Minion create an Error Message
    | refs: `#23607`_
  * 1323bf8 Merge pull request `#23607`_ from Azidburn/2014.7
  * 0ce2811 Fix for `#23604`_. No error reporting. Exitcode !=0 are ok

- **PR** `#23634`_: (*cachedout*) CLI error codes on salt-key conditions
  @ *2015-05-13T15:47:58Z*

  - **ISSUE** `#23629`_: (*unixorn*) salt-key exits zero even when it can't find the key specified
    | refs: `#23634`_
  * 6e1c132 Merge pull request `#23634`_ from cachedout/issue_23629
  * 58a4a44 Also catch case where attempt to delete non-existent key fails

  * 90cb6d6 Raise exit with err code if no key found

- **PR** `#23656`_: (*arthurlogilab*) typo fix in modules/lxc.py
  @ *2015-05-13T15:26:56Z*

  * 2c54fb5 Merge pull request `#23656`_ from arthurlogilab/patch-5
  * 0a9a85d typo fix in modules/lxc.py

- **PR** `#23645`_: (*cachedout*) Read response buffer instad of httpresponse
  @ *2015-05-13T15:23:13Z*

  - **ISSUE** `#23323`_: (*thusoy*) file.managed with HTTP source fails with tornado backend
    | refs: `#23645`_
  * 8da26c5 Merge pull request `#23645`_ from cachedout/issue_23323
  * 4718fb4 Read response buffer instad of httpsresponse

- **PR** `#23660`_: (*rallytime*) Merge `#23635`_ with some grammar fixes
  @ *2015-05-13T15:06:02Z*

  - **PR** `#23635`_: (*cachedout*) Loader doc
    | refs: `#23660`_
  * c1e8d27 Merge pull request `#23660`_ from rallytime/merge-23635
  * 580ed73 Add a couple of grammar fixes to opts docs

  * 7bbae94 Lint whitespace

  * 439ed03 minion_mod doc

  * c003d49 Deprecated flag

  * 9f7750a Continuing with loader documentation

  * 125625b Start to build out additional per-func docs in loader

  * 1432077 Add documentation about opts generation

- **PR** `#23632`_: (*cachedout*) Sort keys on output with salt-key
  @ *2015-05-13T14:54:43Z*

  - **ISSUE** `#23529`_: (*cachedout*) salt-key -F ungrouped output for local keys
    | refs: `#23632`_
  * 2acf0c5 Merge pull request `#23632`_ from cachedout/issue_23529
  * fc75f70 Sort keys on output with salt-key

- **PR** `#23625`_: (*basepi*) Merge forward from 2015.5 to develop
  @ *2015-05-12T23:02:31Z*

  * c061bde Merge pull request `#23625`_ from basepi/merge-forward-develop
  * eca368a Merge remote-tracking branch 'upstream/2015.5' into merge-forward-develop

- **PR** `#23609`_: (*kaidokert*) file_map: chown created directories if not root `#23608`_
  @ *2015-05-12T21:19:04Z*

  * ec54da2 Merge pull request `#23609`_ from kaidokert/develop
  * f246642 Merge branch 'develop' of https://github.com/saltstack/salt into develop

- **PR** `#23596`_: (*rallytime*) Merge `#23584`_ with pylint fixes and versionadded tags
  @ *2015-05-12T18:36:11Z*

  - **PR** `#23584`_: (*opdude*) Added power cfg module and state for windows minions
    | refs: `#23596`_
  * 33b0b4a Merge pull request `#23596`_ from rallytime/merge-23584
  * e6faec5 Add versionadded tags and absolute imports

  * 30d8be8 Lint fixes

  * 899ba78 Added power cfg module and state for windows minions

- **PR** `#23591`_: (*garethgreenaway*) Additions to beacons module
  @ *2015-05-12T16:42:26Z*

  - **ISSUE** `#23400`_: (*samart*) Beacon Control - Pause beacons during state/highstate
    | refs: `#23515`_ `#23591`_
  * 2ee134d Merge pull request `#23591`_ from garethgreenaway/enable_disable_individual_beacons
  * 66b86a0 adding code to allow enabling and disabling specific beacons.

- **PR** `#23577`_: (*msciciel*) Fix find and remove functions to pass database param
  @ *2015-05-12T16:29:04Z*

  - **ISSUE** `#1`_: (*thatch45*) Enable regex on the salt cli
    | refs: `#21356`_ `#21328`_
  * d6badd3 Merge pull request `#23577`_ from msciciel/develop
  * efff2c3 Merge pull request `#1`_ from msciciel/msciciel-patch-mongodb-find-remove-database

    * 62d4c1c Fix find and remove functions to pass database param

- **PR** `#23283`_: (*iggy*) Add support for tablespaces to postgres module & postgres_tablespace states
  @ *2015-05-12T15:32:13Z*

  * a46aa40 Merge pull request `#23283`_ from iggy/add-postgres-tablespace-support
  * 8570ae1 Add versionadded annotations to new functions

  * d9e0ab9 pylint fixes

  * a0aa114 Add support for tablespaces to postgres module & postgres_tablespace states

- **PR** `#23586`_: (*Lothiraldan*) Fix salt.state.file._unify_sources_and_hashes when sources is used without sources_hashes
  @ *2015-05-12T15:25:00Z*

  * b6a690e Merge pull request `#23586`_ from tinyclues/salt-state-file-_unify_sources_and_hashes-fix
  * ae22179 Remove unused import

  * d538c84 Use the zip_longest from six module for python 3 compatiblity

  * 7907ff6 Fix salt.state.file._unify_sources_and_hashes when sources is used without sources_hashes

- **PR** `#23578`_: (*YanChii*) updated docs - solarisips
  @ *2015-05-12T15:22:43Z*

  * b0620b2 Merge pull request `#23578`_ from YanChii/solarisips-docs
  * 68f1786 updated documentation because solarisips is now the default module for S11+

- **PR** `#23571`_: (*bemeyert*) How to still use existing $PATH in "cmd" modules
  @ *2015-05-12T15:20:31Z*

  - **ISSUE** `#21840`_: (*bemeyert*) Docs for cmd.run env should say that no evaluation is done
    | refs: `#22736`_ `#23571`_
  * 8d8e2df Merge pull request `#23571`_ from bemeyert/21840-use_existing_PATH_in_cmd_env
  * 61eab1e How to still use existing $PATH in "cmd" modules

- **PR** `#23568`_: (*techhat*) Allow Salt Cloud to use either SCP or SFTP, as configured
  @ *2015-05-12T15:20:02Z*

  * d30e88c Merge pull request `#23568`_ from techhat/ssh_file
  * d4b3518 Allow Salt Cloud to use either SCP or SFTP, as configured

- **PR** `#23557`_: (*jfindlay*) use @world pkg set, add backtrack option to ebuild module
  @ *2015-05-12T15:17:31Z*

  * 33eeda2 Merge pull request `#23557`_ from jfindlay/update_ebuild
  * 5a796e7 use @world pkg set, add backtrack option

- **PR** `#23549`_: (*vr-jack*) Update __init__.py
  @ *2015-05-12T15:17:02Z*

  * e91e229 Merge pull request `#23549`_ from vr-jack/develop
  * 3c0a087 Update __init__.py

- **PR** `#23527`_: (*cedwards*) updated trafficserver execution module to better align with upstream
  @ *2015-05-12T15:12:48Z*

  * d198891 Merge pull request `#23527`_ from cedwards/ats_module
  * f159b00 fixed lint issue in previous commit

  * 9bf294d Merge branch 'ats_module' of https://github.com/cedwards/salt into develop

    * ed17bd8 updated trafficserver execution module to better align with upstream docs & command options

- **PR** `#23482`_: (*rmcleay*) Boto secgroup improvements
  @ *2015-05-12T15:12:26Z*

  * d30a849 Merge pull request `#23482`_ from rmcleay/boto_secgroup_improvements
  * 7d0ecb5 Fixing change detection for protocols without from_port and to_port.

  * 798348a Removed requirement to specify egress rules list.

- **PR** `#23561`_: (*kaidokert*) Fix wrongly passed around 'location' in EC2 cloud, resulting in us-ea…
  @ *2015-05-12T04:08:06Z*

  * 3b0b55b Merge pull request `#23561`_ from kaidokert/develop
- **PR** `#23562`_: (*basepi*) Remove the rc sidebar entry
  @ *2015-05-11T22:33:50Z*

  * efd2a8e Merge pull request `#23562`_ from basepi/2015.5.0release
  * 115a26a Remove the rc sidebar entry

- **PR** `#23560`_: (*basepi*) Update latest release to 2015.5.0
  @ *2015-05-11T22:05:46Z*

  * 1cd0157 Merge pull request `#23560`_ from basepi/2015.5.0release
  * 1bb8a73 Update latest release to 2015.5.0

- **PR** `#23559`_: (*sh3llsh0ck*) add to authors
  @ *2015-05-11T21:59:02Z*

  * 0813139 Merge pull request `#23559`_ from Code-Vortex/develop
  * cec9c72 add mostafa hussein to authors

- **PR** `#23555`_: (*gravyboat*) Add details to first line of top docs
  @ *2015-05-11T21:57:45Z*

  * 24b512d Merge pull request `#23555`_ from gravyboat/patch-1
  * 552eb52 Add details to first line.

- **PR** `#23545`_: (*basepi*) Merge forward from 2015.5 to develop
  @ *2015-05-11T21:52:42Z*

  * 47ab126 Merge pull request `#23545`_ from basepi/merge-forward-develop
  * 9b2f27b Remove unused mock_open

  * 3c51d36 Remove tests.unit.modules.seed_test.test_mkconfig

  * 4982d7f pillar/neutron.py absolute_import

  * 1d77ae9 Merge remote-tracking branch 'upstream/2015.5' into merge-forward-develop

              * 1718963 file_map: chmod created directories if not root

      * d0c38f9 Remove accidental ec2.py.orig file

- **PR** `#23542`_: (*thatch45*) update dev reqs for python 3
  @ *2015-05-11T17:51:24Z*

  * 811564a Merge pull request `#23542`_ from thatch45/devdeps3
  * 13e5463 update dev reqs for python 3

- **PR** `#23541`_: (*jtand*) fixed python3 compatibility error
  @ *2015-05-11T17:51:06Z*

  * 98b137e Merge pull request `#23541`_ from jtand/neutron_pylint
  * dd2b31a fixed python3 compatibility error

- **PR** `#23455`_: (*techhat*) Allow SMTP return to use a template
  @ *2015-05-11T17:08:57Z*

  - **ISSUE** `#23453`_: (*sh3llsh0ck*) modifying the returner output when using smtp_returner
    | refs: `#23455`_
  - **ISSUE** `#1`_: (*thatch45*) Enable regex on the salt cli
    | refs: `#21356`_ `#21328`_
  * 2bc7f9c Merge pull request `#23455`_ from techhat/smtptemplate
  * d8cb145 Merge pull request `#1`_ from jfindlay/smtp

    * 0d8f865 update smtp returner unit tests

  * 7e4198e Linting

  * 8b068e1 Allow SMTP return to use a template

- **PR** `#23521`_: (*sh3llsh0ck*) fix for wrong params in slack returner
  @ *2015-05-11T06:09:19Z*

  * aca62d4 Merge pull request `#23521`_ from Code-Vortex/develop
  * f2dd1a6 remove whitespace

  * 2326c5e remove trailing whitespace

  * 575a1ba fix indentation

  * f25164e fixing wrong params in _post_message _post_changing from_user to username, adding as_user param

- **PR** `#23515`_: (*garethgreenaway*) additons to beacons module
  @ *2015-05-11T06:09:04Z*

  - **ISSUE** `#23400`_: (*samart*) Beacon Control - Pause beacons during state/highstate
    | refs: `#23515`_ `#23591`_
  * de782f5 Merge pull request `#23515`_ from garethgreenaway/enable_disable_save_beacons
  * d9ca60a lint fixes.

  * 2cffd75 Additions to beacons execution module to allow enabling, disabling and saving beacons.

- **PR** `#23519`_: (*s0undt3ch*) Several Py3 fixes
  @ *2015-05-10T15:01:29Z*

  * ccb186b Merge pull request `#23519`_ from s0undt3ch/hotfix/py3
  * bd452de Allow the extra checks to be skipped

  * 72b4bb6 Only encode under Python 2.x

  * c2a1677 Py3 does not provide the `func.__func__` attribute.

  * 015cdce `os.getgrouplist` returns a list of group IDs; We're after the group names

- **PR** `#23511`_: (*nmadhok*) Python3 compatibility fixes
  @ *2015-05-09T13:25:03Z*

  * 58c7ba2 Merge pull request `#23511`_ from nmadhok/python3-compatibility
  * bf91c29 Making salt.master Python3 compatible

  * 268ed61 Making salt.minion Python3 compatible

  * a4f15ab Making salt.cloud.clouds.linode Python3 compatible

  * a3b339b Making salt.cli.salt Python3 compatible

  * 2cd8a04 Making salt.cli.batch Python3 compatible

  * c9b3797 Making salt.states.x509 Python3 compatible

  * e60be04 Making salt.states.bigip Python3 compatible

  * 7c44e29 Making salt.modules.yumpkg Python3 compatible

  * 916b259 Making salt.modules.x509 Python3 compatible

  * f243564 Making salt.modules.splay Python3 compatible

  * 816bf17 Making salt.modules.boto_rds Python3 compatible

  * a0a5e6f Making salt.modules.bigip Python3 compatible

- **PR** `#23499`_: (*mgwilliams*) boto_vpc fixes
  @ *2015-05-09T13:24:49Z*

  * a52bbf3 Merge pull request `#23499`_ from mgwilliams/boto_vpc
  * 2059432 states.boto_vpc: remove log statement

  * 5bd8bd2 states.boto_vpc: fix bugs in route_table_present

  * 2735d6f modules.boto_vpc: add support for internet_gateway_name in create_route

- **PR** `#23484`_: (*garethgreenaway*) Consul module
  @ *2015-05-09T13:23:46Z*

  * f417540 Merge pull request `#23484`_ from garethgreenaway/consul_module
  * 0654a06 Lint fixes.

  * 3d46b4d Initial commit of a execution module to interact with and manage Consul

- **PR** `#23510`_: (*nmadhok*) Vmware cloud driver additions
  @ *2015-05-09T06:11:13Z*

  * 8dfe043 Merge pull request `#23510`_ from nmadhok/vmware-cloud-driver
  * 46dd881 Merge branch 'develop' of https://github.com/saltstack/salt into vmware-cloud-driver

- **PR** `#23430`_: (*basepi*) Merge forward from 2015.5 to develop
  @ *2015-05-08T22:46:21Z*

  * 1bf2ff9 Merge pull request `#23430`_ from basepi/merge-forward-develop
  * e6905b4 Delete the win_useradd tests

  * ce9064d No arguments to list_users

  * ece63c3 Merge remote-tracking branch 'upstream/2015.5' into merge-forward-develop

- **PR** `#23498`_: (*bogdanr*) Made some claridications in the AWS provider for salt-cloud
  @ *2015-05-08T17:35:25Z*

  * 58dcd13 Merge pull request `#23498`_ from bogdanr/develop
  * 4f19852 Made some claridications in the AWS provider for salt-cloud

- **PR** `#23497`_: (*skizunov*) Tweak network address comparisons
  @ *2015-05-08T17:35:16Z*

  - **PR** `#23481`_: (*ckochenower*) Python 3 compatability refactor
    | refs: `#23497`_
  * 3b53650 Merge pull request `#23497`_ from skizunov/develop2
  * 408fac3 Tweak network address comparisons

- **PR** `#23496`_: (*martinhoefling*) Fix for issue `#23110`_
  @ *2015-05-08T17:33:08Z*

  - **ISSUE** `#23110`_: (*martinhoefling*) Copying files from gitfs in file.recurse state fails
  * 0d37ace Merge pull request `#23496`_ from martinhoefling/develop
  * e49326f Fix for issue `#23110`_ This resolves issues when the freshly created directory is removed by fileserver.update.

- **PR** `#23487`_: (*nmadhok*) Vmware cloud driver additions/refactors
  @ *2015-05-08T14:39:16Z*

  - **ISSUE** `#23486`_: (*nmadhok*) VMware salt-cloud driver: If a datastore cluster is specified, DRS storage recommendations are not applied as suggested by docs
    | refs: `#23487`_
  * d88cdc1 Merge pull request `#23487`_ from nmadhok/vmware-cloud-driver
- **PR** `#23353`_: (*Anthonyhawkins*) Addition of f5 bigip state module
  @ *2015-05-08T14:38:35Z*

  * ef668dc Merge pull request `#23353`_ from Anthonyhawkins/add-f5-state-module
  * 931ebfa added final new line chars

  * b290457 fixed spacing

  * 23065b6 indentation fixes

  * b772c12 Addressing line endings and various fixes

  * fffc4e6 Fixed logger and added metadata to state

  * 432f7ba Transaction support and fixes

  * 30693f0 adding changes for bigip exec module

  * 598e946 Addition of bigip state module and rework of bigip exec module

- **PR** `#23399`_: (*mattrobenolt*) Add salt.loader.grain_funcs
  @ *2015-05-08T14:37:30Z*

  * bfcee39 Merge pull request `#23399`_ from mattrobenolt/expose-grains
  * 2e55f55 Add salt.loader.grain_funcs

- **PR** `#23442`_: (*clan*) add directory itself to keep list
  @ *2015-05-08T14:36:59Z*

  * 57f6c72 Merge pull request `#23442`_ from clan/file_directory_require
  * 65143de check w/ low['name'] only

  * fe43c66 another fix for file defined w/ id, but require name

  * 58d359e add directory itself to keep list

- **PR** `#23462`_: (*whiteinge*) State test pillar check
  @ *2015-05-08T14:36:28Z*

  - **PR** `#23456`_: (*0xf10e*) Add state-function to check for presence/type of pillar-keys
    | refs: `#23462`_
  * 31eb2bc Merge pull request `#23462`_ from whiteinge/state-test-pillar-check
  * 669d9a0 Replace mutable defaults with None in test.check_pillar

  * 632f12a added "verbose" kwarg for check_pillar

  * ae687d4 Add function check_pillar().

- **PR** `#23472`_: (*techhat*) Allow neutron network list to be used as pillar data
  @ *2015-05-08T14:36:06Z*

  * ab884e7 Merge pull request `#23472`_ from techhat/neutronpillar
  * 7665158 Allow neutron network list to be used as pillar data

- **PR** `#23481`_: (*ckochenower*) Python 3 compatability refactor
  | refs: `#23497`_
  @ *2015-05-08T02:55:25Z*

  * d56ebe4 Merge pull request `#23481`_ from ckochenower/develop
  * 3ece10a Python 3 compatability refactor

- **PR** `#23252`_: (*skizunov*) Fix Issue `#11727`_: Got a bad pillar from master
  @ *2015-05-07T20:00:54Z*

  - **ISSUE** `#11727`_: (*evilNullPointer*) Error "Got a bad pillar from master, type bool, expecting dict: False"
  * 2107c41 Merge pull request `#23252`_ from skizunov/develop
  * c8dc89b Fix Issue `#11727`_: Got a bad pillar from master

- **PR** `#23475`_: (*cachedout*) Trafficserver lint
  @ *2015-05-07T19:50:54Z*

  * 28dfed5 Merge pull request `#23475`_ from cachedout/trafficserver_lint
  * 8eb36ed Trafficserver lint

- **PR** `#23436`_: (*cedwards*) Initial Apache Traffic Server module
  @ *2015-05-07T19:49:01Z*

  * 09975b3 Merge pull request `#23436`_ from cedwards/ats_module
  * a578cf4 fixing pylint issues in trafficserver.py

  * d21bccd Initial Apache Traffic Server module

- **PR** `#23471`_: (*msteed*) fix loading of libcrypto on various platforms
  @ *2015-05-07T19:46:40Z*

  * 2f3163d Merge pull request `#23471`_ from msteed/fix-load-libcrypto
  * 64d6d41 fix loading of libcrypto on various platforms

- **PR** `#23465`_: (*s0undt3ch*) Only encode under Python 2.x
  @ *2015-05-07T19:18:40Z*

  * e0014fb Merge pull request `#23465`_ from s0undt3ch/hotfix/py3
  * aa8f136 Only encode under Python 2.x

- **PR** `#23459`_: (*jtand*) Python3 compatibility fix
  @ *2015-05-07T19:11:22Z*

  * 94f4c57 Merge pull request `#23459`_ from jtand/sys_profiler_pylint
  * e64b59a Python3 compatibility fix

- **PR** `#23445`_: (*ajacoutot*) OpenBSD: add default CA certificates path.
  @ *2015-05-07T18:58:00Z*

  * c995d52 Merge pull request `#23445`_ from ajacoutot/openbsd-ssl
  * 9d0dade OpenBSD: add default CA certificates path.

- **PR** `#23443`_: (*ajacoutot*) Add installation doc for OpenBSD.
  @ *2015-05-07T18:57:22Z*

  * 682ef36 Merge pull request `#23443`_ from ajacoutot/openbsd-doc
  * 6608437 Typo.

  * 47abe73 Add installation doc for OpenBSD.

- **PR** `#23428`_: (*nmadhok*) Vmware cloud driver additions
  @ *2015-05-07T09:16:46Z*

  - **ISSUE** `#23360`_: (*radiumx3*) VMware new driver : config file credential parsing seems incorrect
    | refs: `#23428`_
  - **ISSUE** `#23231`_: (*angystardust*) Adding functionality to create() in vmware cloud driver to be able to add/reconfigure cdrom device
    | refs: `#23428`_
  * b22060b Merge pull request `#23428`_ from nmadhok/vmware-cloud-driver
- **PR** `#23441`_: (*cewood*) Update boto_elb.create docstring with correct syntax
  @ *2015-05-07T07:47:23Z*

  * ff1ef02 Merge pull request `#23441`_ from cewood/boto_elb_create_docs
  * 8b46860 Update boto_elb.create docstring with correct syntax

- **PR** `#23421`_: (*thatch45*) Add __context__ to ext pillar
  @ *2015-05-06T22:10:18Z*

  * 3048861 Merge pull request `#23421`_ from thatch45/pillar_context
  * 6346eb5 Add __context__ to ext pillar

- **PR** `#23398`_: (*basepi*) Merge forward from 2015.2 to develop
  @ *2015-05-06T21:42:44Z*

  - **ISSUE** `#16`_: (*thatch45*) Add introspection functions to the salt functions dict
  * ccf6690 Merge pull request `#23398`_ from basepi/merge-forward-develop
  * 56d382a Fix xmpp test

  * cdfa4e1 Merge pull request `#16`_ from s0undt3ch/hotfix/basepi-conflict-resolve

    * b618dc4 Resolve conflicts

  * 2981aed Merge remote-tracking branch 'upstream/2015.2' into merge-forward-develop

- **PR** `#23424`_: (*jtand*) Added python_shell=True for refresh_db in pacman.py
  @ *2015-05-06T21:37:42Z*

  * 49bec0b Merge pull request `#23424`_ from jtand/pacman_2015_2
  * 9996913 Added python_shell=True for refresh_db in pacman.py

- **PR** `#23346`_: (*ericfode*) Allow file_map in salt-cloud to handle folders.
  @ *2015-05-06T06:15:21Z*

  * 1f1785b Merge pull request `#23346`_ from ericfode/file_map_to_handle_folders
  * 630d17f more linting fixes

  * b4f4a0b cleaned up some pylint errors

  * 8352308 added logic to sftp_file and file_map to allow folder uploads using file_map

- **PR** `#23388`_: (*jfindlay*) salt:// URL escaping
  @ *2015-05-06T03:44:00Z*

  - **PR** `#23351`_: (*jfindlay*) salt url handling utils
    | refs: `#23388`_
  * 6f1e03f Merge pull request `#23388`_ from jfindlay/salt_url
  * 0d514ed add salt:// url (un)escaping methods

  * 84a0064 use salt url utils to work with salt://

- **PR** `#23386`_: (*UtahDave*) Add fire event state compiler feature
  @ *2015-05-06T03:42:26Z*

  * 32d3c5a Merge pull request `#23386`_ from UtahDave/add_fire_event
  * f42f935 add 'fire_event' to runtime keywords

  * 921d6c1 change `fire_event_flag` to `fire_event`

  * 10e0a2a clean up doc a bit

  * 750bae1 add docs for the `fire_event` state feature

  * 4a7b686 add `fire_event` option to salt state compiler

- **PR** `#23392`_: (*llua*) mutually exclusive completion for the target options
  @ *2015-05-05T23:08:12Z*

  * c5b46d0 Merge pull request `#23392`_ from llua/zsh-completion
  * 7b39678 mutually exclusive completion for the target options

- **PR** `#23394`_: (*whiteinge*) Deprecated Halite from the Salt docs
  @ *2015-05-05T23:03:55Z*

  * 747c061 Merge pull request `#23394`_ from whiteinge/doc-deprecate-halite
  * dc6eac4 Deprecate Halite from the Salt docs

- **PR** `#23348`_: (*msteed*) Remove m2crypto
  @ *2015-05-05T22:15:22Z*

  * a7e417c Merge pull request `#23348`_ from msteed/remove-m2crypto
  * c7ad84c egad, lint

  * 2947e45 lint

  * eb0bb52 lint

  * 493388a add calls to Crypto.Random.atfork() to reinit RNG

  * 20e7719 make it actually run end-to-end

  * 82c67f7 add unit tests and fix a bug

  * 21b52fa Initial pass at removing M2Crypto

- **PR** `#23387`_: (*rallytime*) Add some "What are all these labels for?" documentation
  @ *2015-05-05T21:40:28Z*

  - **ISSUE** `#23101`_: (*gravyboat*) Create a docs page for labels
    | refs: `#23387`_
  * 1aa27ed Merge pull request `#23387`_ from rallytime/labels_docs
  * 0fe9d05a Make sure the parameters are in the correct order

  * e9491e8 Add "* Change" label parameters

  * 8024acc Remove "workaround" wording

  * ed788a2 Some small fixes

  * 475a32d Link the new labels doc in contributing and hacking docs

  * 644201a Add pull request label definitions

  * 3c95bd9 Add Feature Request label definition

  * 1780e2e Add issue definition and augment functional areas section

  * 85e9284 Start a "what are all of these labels for?" doc

- **PR** `#23367`_: (*kaithar*) Put the sed insert statement back in to the output.
  @ *2015-05-05T21:34:08Z*

  - **PR** `#18368`_: (*basepi*) Merge forward from 2014.7 to develop
    | refs: `#23367`_
  * 3412d55 Merge pull request `#23367`_ from kaithar/issue/fix-_add_var
  * 60826b4 Pylint fix

  * 11466bd Put the sed insert statement back in to the output.

- **PR** `#23389`_: (*cachedout*) Correct fail_hard typo
  @ *2015-05-05T21:24:29Z*

  - **ISSUE** `#22908`_: (*karanjad*) Add failhard option to salt orchestration
    | refs: `#23389`_
  * 0a4f7be Merge pull request `#23389`_ from cachedout/issue_22908
  * 36e7eca Correct fail_hard typo

- **PR** `#23382`_: (*jtand*) Python3 compatibility fix in salt/utils/url.py
  @ *2015-05-05T18:19:55Z*

  * 7bb7f31 Merge pull request `#23382`_ from jtand/url_pylint
  * 7bbedbf Python3 compatibility fix in salt/utils/url.py

- **PR** `#23375`_: (*DmitryKuzmenko*) Fixed zmq monitor for pyzmq < 14.0.0
  @ *2015-05-05T17:52:20Z*

  - **ISSUE** `#23240`_: (*terminalmage*) 0b7a13aa breaks salt for older pyzmq versions
    | refs: `#23375`_
  * a4d2cd4 Merge pull request `#23375`_ from DSRCompany/zmq_monitor_fix_old
  * e88d2de Fixed zmq monitor for pyzmq < 14.0.0

- **PR** `#23374`_: (*claudiupopescu*) GlusterFS force volume creation
  @ *2015-05-05T17:51:04Z*

  * dabfa85 Merge pull request `#23374`_ from claudiupopescu/glusterfs-force-flag
  * 1abff37 Allow volumes to be forced even if on root FS

- **PR** `#23381`_: (*gtirloni*) Configuration file for Code Climate static code analysis.
  @ *2015-05-05T17:47:58Z*

  * f9fd5c2 Merge pull request `#23381`_ from gtirloni/develop
  * 644b455 Configuration file for Code Climate static code analysis.

- **PR** `#23378`_: (*rallytime*) Add versionadded tags to new functions in boto_iam module
  @ *2015-05-05T16:34:44Z*

  - **PR** `#23249`_: (*ryan-lane*) Support for assumed role policies and roles without instance profiles
    | refs: `#23378`_
  * f01d288 Merge pull request `#23378`_ from rallytime/versionadded_boto
  * 662b57d Add versionadded tags to new functions in boto_iam module

- **PR** `#23372`_: (*s0undt3ch*) Py3 fix
  @ *2015-05-05T15:48:49Z*

  * c698786 Merge pull request `#23372`_ from s0undt3ch/develop
  * 8218cd6 Py3 fix

- **PR** `#23249`_: (*ryan-lane*) Support for assumed role policies and roles without instance profiles
  | refs: `#23378`_
  @ *2015-05-05T15:20:15Z*

  - **ISSUE** `#23486`_: (*nmadhok*) VMware salt-cloud driver: If a datastore cluster is specified, DRS storage recommendations are not applied as suggested by docs
    | refs: `#23487`_
  - **ISSUE** `#23360`_: (*radiumx3*) VMware new driver : config file credential parsing seems incorrect
    | refs: `#23428`_
  - **ISSUE** `#23231`_: (*angystardust*) Adding functionality to create() in vmware cloud driver to be able to add/reconfigure cdrom device
    | refs: `#23428`_
  - **ISSUE** `#14`_: (*thatch45*) make salt-minion still run if a module does not load
  * dcfdbf1 Merge pull request `#23249`_ from lyft/boto-iam-assume-role-support
  * 538f8f0 Fix lint error

  * a0ee7cb Fix unit tests and add coverage for new functions.

  * ca44c8c Add missing docstrings

  * e801287 Fix lint

  * 6073a89 Ensure values are lists before checking their length

  * 2f5b34e Add support for assumed role policies and roles without instance profiles

                    * cf359ae Making vmware cloud driver python3 compatible

                    * 36289e9 Renaming inv to si

                    * 3b9a41d Adding port and protocol to the Getting started docs

                    * 574ad5b Adding test_vcenter_connection() and ability to specify ports and protocol

                  * 496cd4c Lint Fix

                  * b6cae9b If datastore cluster specified, make sure storage DRS recommendations are applied Fixes `#23486`_

                  * 8185f47 Additional refactors, grammar, spelling etc

                  * 69c8aa5 Refactors

                  * 98c80c3 Show the traceback if debug logging level is enabled

                  * b52474c Rename add_datastore_cluster() to create_datastore_cluster() and other refactors

                  * 6629568 Merge pull request `#14`_ from mpmoers/add-datastore-cluster

                  * a2335ab grammer fix

                  * 9a7701a added function add_datastore_cluster() This function takes an input of a name for a new datastore cluster and an existing datacenter and creates a datastore cluster attached to the datacenter

            * 4a3f3bd Make sure the provider config field values are quoted Fixes `#23360`_

            * 93b664d Fixes

            * 6184fcd Doc fix

            * bd57a99 Adding docs to be able to create/reconfigure new CD/DVD drives Fixes `#23231`_

            * 35bd08e Polling every minute and speeding up IP lookup after creation

            * e774569 Adding functionality to create() to be able to add/reconfigure cdrom device Fixes `#23231`_

- **PR** `#23351`_: (*jfindlay*) salt url handling utils
  | refs: `#23388`_
  @ *2015-05-05T14:11:22Z*

  * 6291d5a Merge pull request `#23351`_ from jfindlay/salt_url
  * 9ea2f47 more than ZMQ supported for transport, other typos

  * b4629d4 remove unused function in the file state

  * 11d893d explicitly quote requirements filename

  * 29a023a better path query parsing in fileserver

  * 2c3f82b also handle salt://| escaping in fileclient

  * e0ab1e9 always override global saltenv with url saltenv

  * db0f85a quote source file name in file mod error messages

  * f58f3da integration test for char escaping in file paths

  * 336a48e add salt.utils.url unit tests

  * 3a9c5af collect additional url utils

  * b237917 create and parse salt:// URLs with url util

  * 1b786d0 replace env_splitter construct with urllib utils

  * cc8ecee add salt:// URL utils

- **PR** `#23357`_: (*ryan-lane*) Add missing pagerduty and boto docs
  @ *2015-05-05T14:10:25Z*

  * f78fa26 Merge pull request `#23357`_ from lyft/add-missing-docs
  * f03c686 Add missing pagerduty and boto docs

- **PR** `#23366`_: (*skizunov*) Remove unused code
  @ *2015-05-05T14:09:51Z*

  * 5f29e4b Merge pull request `#23366`_ from skizunov/develop2
  * 938bb4f Remove unused code

- **PR** `#23354`_: (*plastikos*) Add a short argument (-P) for --grain-pcre
  @ *2015-05-05T04:02:29Z*

  * 221f6e5 Merge pull request `#23354`_ from plastikos/improvement-grain_pcre
  * 51f3252 Add a short argument (-P) for --grain-pcre

- **PR** `#23345`_: (*nmadhok*) Adding ability to change type of existing network adapter if specified during create()
  @ *2015-05-04T23:15:26Z*

  * 69333f4 Merge pull request `#23345`_ from nmadhok/vmware-cloud-driver
  * edcad4b Adding ability to change type of existing network adapter if specified

- **PR** `#23333`_: (*skizunov*) Fix salt-call using RAET on Windows
  @ *2015-05-04T20:58:50Z*

  * 006b522 Merge pull request `#23333`_ from skizunov/develop2
  * b0e7f59 Fix salt-call using RAET on Windows

- **PR** `#23314`_: (*nmadhok*) Better error handling in vmware cloud driver create()
  @ *2015-05-04T20:57:36Z*

  - **ISSUE** `#23312`_: (*syphernl*) Vmware cloud driver: exceptions must be old-style classes or derived from BaseException
    | refs: `#23314`_
  * 988e73f Merge pull request `#23314`_ from nmadhok/vmware-cloud-driver
  * daf5ab2 Error checking and better debug messages

  * cd3ba1e Syntax fix

  * 8a9e9ee Better error checking

  * ace1d58 Make sure exception raises is of type Exception() Fixes `#23312`_

- **PR** `#23309`_: (*rmcleay*) Egress rule support for boto_secgroup
  @ *2015-05-04T20:57:02Z*

  * e23e4f6 Merge pull request `#23309`_ from rmcleay/secgroup_egress
  * 57067a3 Fixing linting in boto_secgroup module and unit test.

  * 78e22e6 Fixed 'all' protocol case for boto_secgroup state.

  * 0361d39 Added rules_egress docs for boto_secgroup state.

  * c269598 Added rules_egress to boto_secgroup unit test.

  * ce3fb4b Added initial states.boto_secgroup support for egress rules.

  * 59fc64f Added initial module.boto_secgroup support for egress rules.

- **PR** `#23308`_: (*thusoy*) Don't merge: Add missing jump arguments to iptables module
  @ *2015-05-04T15:09:15Z*

  * b224d82 Merge pull request `#23308`_ from thusoy/patch-2
  * 64f661d Add missing jump arguments to iptables module

- **PR** `#23328`_: (*s0undt3ch*) Py3 fix & unrelated .pylint fix
  @ *2015-05-04T15:08:46Z*

  * 55e2185 Merge pull request `#23328`_ from s0undt3ch/develop
  * c4bba0c Python 3 fix

  * 171e022 Start checking code to enforce a minimum python version support

- **PR** `#23322`_: (*thusoy*) Silence iptables checks
  @ *2015-05-04T15:00:12Z*

  * 83b62b4 Merge pull request `#23322`_ from thusoy/patch-3
  * 275147d Silence iptables checks

- **PR** `#23305`_: (*farcaller*) Fixed a Runenr typo in the docs
  @ *2015-05-03T20:43:27Z*

  * c85094d Merge pull request `#23305`_ from farcaller/typo
  * 921aaea Fixed a Runenr typo in the docs

- **PR** `#23306`_: (*nmadhok*) VMware cloud driver doc fixes
  @ *2015-05-03T20:42:18Z*

  * a624abd Merge pull request `#23306`_ from nmadhok/vmware-cloud-driver
  * 49f5789 VMware cloud driver doc fixes

- **PR** `#23300`_: (*nmadhok*) Fixing bugs causing errors when creating VM using VMware cloud driver
  @ *2015-05-03T15:51:12Z*

  - **ISSUE** `#23301`_: (*nmadhok*) VMware cloud driver create function fails with error if network not specified under devices or if network adapter is changed from distributed portgroup to standard network switch
    | refs: `#23300`_
  - **ISSUE** `#23213`_: (*syphernl*) Cloud: Unable to create VM using VMware driver due to hostname error
    | refs: `#23300`_
  * be7d11d Merge pull request `#23300`_ from nmadhok/vmware-cloud-driver
  * a5edd45 Fixing bug that caused error during creating VM if network was not specified under devices Fixes `#23301`_

  * c860cc4 Fixing bug that caused hostname error when using FQDN as the vm name Fixes `#23213`_

- **PR** `#23299`_: (*jodv*) Fix st_ctime in local_cache returner update
  @ *2015-05-03T02:32:12Z*

  * 7246e7d Merge pull request `#23299`_ from jodv/localcache_fast_cleanup
  * cf94a2b st_ctime is an attribute, not a method

- **PR** `#23243`_: (*cachedout*) [EXPERT REVIEW REQUIRED] Remove grains workaround from pillar generation
  @ *2015-05-03T00:43:58Z*

  - **ISSUE** `#11453`_: (*erenfro*) Pillar states no longer properly execute salt functions in 2014.1.1
    | refs: `#23243`_ `#23243`_
  * 755f048 Merge pull request `#23243`_ from cachedout/fix_pillar_stacktraces
  * df7b5f6 Remove grains workaround from pillar generation

- **PR** `#23296`_: (*chris-prince*) Fixed issue `#18880`_ in develop branch
  @ *2015-05-03T00:43:25Z*

  - **ISSUE** `#18880`_: (*johtso*) npm installed breaks when a module is missing
  * c607145 Merge pull request `#23296`_ from chris-prince/develop
  * 023fab7 Fixed issue `#18880`_ in develop branch

- **PR** `#23287`_: (*UtahDave*) Allow for modifying the path of uploaded file inside of master cache dir.
  @ *2015-05-03T00:43:06Z*

  * e0af0ed Merge pull request `#23287`_ from UtahDave/add_upload_path
  * c4cf0a6 Add `upload_path` to cp.push_dir

  * 72ed91a Add 'upload_path' option

- **PR** `#23282`_: (*lisa2lisa*) Iss23201-fix the revoke *.* bug for mysql module
  @ *2015-05-03T00:42:34Z*

  * bf867c6 Merge pull request `#23282`_ from lisa2lisa/iss23201
  * 69d3819 modified the mysql.py file to fixed the problem for revoke *.* for more detail please see: https://github.com/saltstack/salt/issues/23201

  * 802ebe2 fix the mysql module cannot revoke *.* problem, for more detail, https://github.com/saltstack/salt/issues/23201

- **PR** `#23275`_: (*terminalmage*) Add pkg.group_installed state
  @ *2015-05-03T00:41:39Z*

  - **ISSUE** `#5504`_: (*racooper*) Add state support for pkg.group_install
    | refs: `#23275`_
  * 1a93dea Merge pull request `#23275`_ from terminalmage/issue5504
  * 3c55aba lint fixes

  * 37a84e2 Add pkg.group_installed state

  * 282ec1b Exclude groupinstall alias from docs

  * 3f03314 Move group_install with the other group funcs

- **PR** `#23273`_: (*jodv*) use ctime for old jobs cleanup in local cache returner
  @ *2015-05-03T00:41:09Z*

  * b5c75d1 Merge pull request `#23273`_ from jodv/localcache_fast_cleanup
  * d42a83c use ctime for old job cleanup

- **PR** `#23265`_: (*basepi*) Merge forward from 2015.2 to develop
  @ *2015-05-03T00:40:32Z*

  * 8f8214e Merge pull request `#23265`_ from basepi/merge-forward-develop
  * c7d2155 Merge remote-tracking branch 'upstream/2015.2' into merge-forward-develop

- **PR** `#23255`_: (*froztbyte*) [docs/pkg] add some clarity around custom repo usage in pkg/pkgs
  @ *2015-05-03T00:39:55Z*

  * 944074e Merge pull request `#23255`_ from froztbyte/develop
  * f4abf7f [docs/pkg] add some clarity around custom repo usage in pkg/pkgs

- **PR** `#23253`_: (*The-Loeki*) `#22080`_ Parts 2 & 3: Deprecation & Removal of ipaddr and IPv4Address
  @ *2015-05-03T00:38:57Z*

  - **ISSUE** `#22080`_: (*The-Loeki*) CIDR matching for IPv6 / improve IPv6 support in utils.network
    | refs: `#22691`_ `#23253`_ `#23896`_ `#24282`_ `#24282`_
  * 3071c6d Merge pull request `#23253`_ from The-Loeki/better-ipv6
  * d814b7f Better unit test fix, add 2 unit tests for IPv6

  * d81fbc4 Unit test fix

  * 5346a07 Removal of embedded IPv4Address class

  * 8839a72 Replace dependendy on embedded IPv4Address class from utils/network

  * bb91de0 Change is_loopback, is_private and reverse_ip to utilize the ipaddress lib (removes dependency on embedded IPv4Address in utils.network)

  * 394a044 Removal of ipaddr

  * 2c111fa Deprecation of ipaddr Modified roster/scan to be IP-agnostic

  * 34ccbda Merge branch 'develop' of https://github.com/saltstack/salt into better-ipv6

  * 73876ae Fix for hosts() in IPv6Network

  * 6cdc21f * minor fixes from cPython * backport of reverse_pointer functions from cPython

- **PR** `#23285`_: (*kiorky*) Boto check
  @ *2015-05-02T03:53:43Z*

  - **ISSUE** `#23277`_: (*kiorky*) boto modules are something messing up
    | refs: `#23285`_
  * 0b36c33 Merge pull request `#23285`_ from makinacorpus/boto
  * 14daaa9 Boto check

- **PR** `#23267`_: (*jtand*) Fixed pylint error for python3 compatibility in salt/utils/http.py
  @ *2015-05-02T02:45:47Z*

  * 7287138 Merge pull request `#23267`_ from jtand/http_pylint
  * 9c1f84e Fixed pylint error for python3 compatibility in salt/utils/http.py

- **PR** `#23268`_: (*basepi*) Add tornado to salt-thin
  @ *2015-05-02T02:30:28Z*

  * f95dcac Merge pull request `#23268`_ from basepi/salt-ssh.thin.tornado
  * 9fcc3a7 Add tornado to the thin

- **PR** `#23291`_: (*cachedout*) Document 0MQ transport
  @ *2015-05-02T01:47:37Z*

  * d2a477e Merge pull request `#23291`_ from cachedout/transport_docs
  * 5a9f819 Document 0MQ transport

- **PR** `#23276`_: (*whiteinge*) Fix the build process for a few empty docs
  @ *2015-05-01T20:28:44Z*

  - **ISSUE** `#22820`_: (*VynceMontgomery*) some docs missing again (cf `#22720`_)
    | refs: `#23276`_
  * bdfb589 Merge pull request `#23276`_ from whiteinge/missing-docs-pt-deux
  * d844ca5 Removed docs for ext_pillar module that is a wip

  * 6be273d Removed stormpath_mod and linodepy docs; these were renamed

  * cda915b Remove fsutils module documentation

  * 901fa33 Mocked tornado.httputil

- **PR** `#23266`_: (*nmadhok*) Fixing issues with VMware cloud driver create function
  @ *2015-05-01T20:16:26Z*

  - **ISSUE** `#23264`_: (*nmadhok*) VMware salt-cloud driver fails to create a VM when trying to add a new network adapter
    | refs: `#23266`_
  - **ISSUE** `#23262`_: (*nmadhok*) VMware salt-cloud driver does not change the number of cpus when creating a VM
    | refs: `#23266`_
  * 0c53340 Merge pull request `#23266`_ from nmadhok/bug-fix-vmware
  * 846519c Fixing issues with VMware cloud driver create function Fixes `#23262`_ `#23264`_

- **PR** `#23260`_: (*jtand*) Locales pylint
  @ *2015-05-01T17:36:42Z*

  * b76807a Merge pull request `#23260`_ from jtand/locales_pylint
  * 2defe02 Fixed pylint error in /salt/utils/locales.py

  * 922f1f3 Fixed pylint error in /salt/utils/locales.py

- **PR** `#23251`_: (*nmadhok*) Adding support to be able to specify distributed virtual port group or standard switch network upon VM creation
  @ *2015-05-01T15:02:25Z*

  * 4b836e0 Merge pull request `#23251`_ from nmadhok/vmware-portgroup
  * dc7903b Adding support to be able to add distributed virtual portgroup to vm upon creation

- **PR** `#23235`_: (*techhat*) Add tornado to http.query, and make it the default
  @ *2015-05-01T01:42:30Z*

  * 5188d6c Merge pull request `#23235`_ from techhat/tornadoclient
  * 49baddb Linting

  * 3dea1e9 Add tornado to http.query, and make it the default

- **PR** `#23234`_: (*nmadhok*) Adding reboot_host() to be able to reboot a host system
  @ *2015-05-01T01:41:14Z*

  * 3e6823c Merge pull request `#23234`_ from nmadhok/vmware-cloud-driver
  * edfce00 Adding reboot_host() to be able to reboot a host system

- **PR** `#23225`_: (*skizunov*) Fix engines on Windows
  @ *2015-05-01T01:40:53Z*

  * cad5d77 Merge pull request `#23225`_ from skizunov/develop
  * 19320ca Fix engines on Windows

- **PR** `#23238`_: (*basepi*) Merge forward from 2015.2 to develop
  @ *2015-05-01T01:31:40Z*

  * 17f32d1 Merge pull request `#23238`_ from basepi/merge-forward-develop
  * 94ea3b7 Merge remote-tracking branch 'upstream/2015.2' into merge-forward-develop

- **PR** `#23248`_: (*nmadhok*) Making sure that the key exists in dict and doesn't fail if devices have not been specified
  @ *2015-05-01T01:22:20Z*

  - **ISSUE** `#23247`_: (*nmadhok*) creating a VM fails using VMware cloud driver if devices have not been specified
    | refs: `#23248`_
  * 7e58b06 Merge pull request `#23248`_ from nmadhok/patch-vmware-driver
  * ee84650 Making sure that the key exists in dict Fixes `#23247`_

- **PR** `#23229`_: (*jtand*) Boto pylint
  @ *2015-05-01T00:03:39Z*

  * e1f150f Merge pull request `#23229`_ from jtand/boto_pylint
  * 1a49ecf Last pylint fix...

  * 941f611 Fixed pylint errors

  * 1b5f357 Pylint Error fix

  * f464402 Fixed pylint error in boto.py

- **PR** `#23230`_: (*cachedout*) Fix bug preventing minionswarm from working with tcp transport
  @ *2015-04-30T18:49:45Z*

  * 92d7fcf Merge pull request `#23230`_ from cachedout/swarm_tcp
  * d0eda05 Fix bug preventing minionswarm from working with tcp transport

- **PR** `#22948`_: (*jacksontj*) Req channel singletons
  @ *2015-04-30T15:24:22Z*

  * 1ae9dcb Merge pull request `#22948`_ from jacksontj/develop
  * 0b69776 Work when the master_uri is passed in as a kwarg

  * 3ddcb10 pylint

  * 2a0ca63 Make tcp and zeromq req channels singletons per IOLoop

  * c96d4f7 Cache the IOLoop used for sync wrappers per parent ioloop

- **PR** `#23202`_: (*tsaridas*) Test modes for boto states rds/elb
  @ *2015-04-30T15:23:31Z*

  - **ISSUE** `#23068`_: (*ryan-lane*) boto_rds state's replica_present module doesn't support test mode
    | refs: `#23202`_
  - **ISSUE** `#22274`_: (*ryan-lane*) boto_elb state's register_instances function doesn't support test mode
    | refs: `#23202`_
  * de635ce Merge pull request `#23202`_ from tsaridas/boto_rds_replica
  * 4ab9af0 RDS exists comment when creating a new instance

- **PR** `#23199`_: (*ykomatsu*) Fix wrong number of arguments
  @ *2015-04-30T15:23:12Z*

  * 55285c8 Merge pull request `#23199`_ from ykomatsu/aptpkg
  * b27a953 Fix wrong number of arguments

- **PR** `#23197`_: (*nmadhok*) VMware cloud driver additions
  @ *2015-04-30T15:22:51Z*

  * f044678 Merge pull request `#23197`_ from nmadhok/vmware-cloud-driver
  * edcef7d Auto retrieve the host system's SSL thumbprint

  * 0a08e4e Lint

  * 3a1186b Adding connect_host() and disconnect_host() to be able to connect and disconnect the host system

  * 48d58c5 Lint

  * 6519923 Adding remove_host() to be able to remove a host from the vcenter

  * f14a52c Adding add_host() to be able to add a host to a cluster or a datacenter

- **PR** `#23178`_: (*jfindlay*) fix incorrect boto_vpc state versionaddeds
  @ *2015-04-30T15:22:25Z*

  - **ISSUE** `#23162`_: (*rmcleay*) Available in version is incorrect for states.boto_vpc
    | refs: `#23178`_
  * 46b7938 Merge pull request `#23178`_ from jfindlay/boto_version
  * 8064483 fix incorrect boto_vpc state versionaddeds

- **PR** `#23203`_: (*tsaridas*) Boto iam fix
  @ *2015-04-30T15:22:11Z*

  * d5a326b Merge pull request `#23203`_ from tsaridas/boto_iam_fix
  * b931da8 Fix for case that group is not present and we want to add users.

  * 8f19b76 Test mode for : - rds replica_present - elb register_instances

- **PR** `#23174`_: (*jfindlay*) move locale utils to separate module
  @ *2015-04-30T15:22:00Z*

  * 4fabf46 Merge pull request `#23174`_ from jfindlay/locale_utils
  * f46db2c move locale specifier utilities to utils/locales

  * e8792c7 move locale utils to utils.locales

  * 2be92b9 remove extemporaneous file `tmp`

- **PR** `#23171`_: (*skizunov*) Bugfix: 'clean_proc_dir' is broken
  @ *2015-04-30T15:21:32Z*

  * fd6448a Merge pull request `#23171`_ from skizunov/develop
  * 5b2a80e Bugfix: 'clean_proc_dir' is broken

- **PR** `#23219`_: (*joehealy*) Removed debian dir as only likely to cause confusion.
  @ *2015-04-30T15:20:41Z*

  * 6c511be Merge pull request `#23219`_ from joehealy/debian_remove_debian_dir
  * d4a41a7 Removed debian dir as only likely to cause confusion.

- **PR** `#23217`_: (*ykomatsu*) Fix wrong namespaces
  @ *2015-04-30T15:20:08Z*

  * 5f75b87 Merge pull request `#23217`_ from ykomatsu/http
  * 48cc60b Fix wrong namespaces

- **PR** `#23216`_: (*joehealy*) Clean up of docs following jessie
  @ *2015-04-30T15:15:30Z*

  * 31de5b5 Merge pull request `#23216`_ from joehealy/debian_doc_update
  * f791a2c Clean up of docs following jessie

- **PR** `#23212`_: (*alexandrsushko*) Fix for grain virtual in lxc-libvirt
  @ *2015-04-30T15:15:19Z*

  - **ISSUE** `#23210`_: (*alexandrsushko*) grain 'virtual' shows 'physical' in lxc-libvirt container
    | refs: `#23212`_
  - **ISSUE** `#15846`_: (*Artanicus*) Handle dmidecode brokenness gracefully on limited LXC containers
    | refs: `#23212`_
  * 48bdbed Merge pull request `#23212`_ from alexandrsushko/`fix-23210`_
  * 55b0663 Fix for grain virtual in lxc-libvirt

- **PR** `#23189`_: (*mattrobenolt*) softlayer shouldn't try and use libcloud's script function
  @ *2015-04-30T01:54:44Z*

  - **PR** `#23187`_: (*mattrobenolt*) softlayer provider also requires libcloud
    | refs: `#23189`_
  * c369bc1 Merge pull request `#23189`_ from mattrobenolt/softlayer
  * 22bfb30 softlayer shouldn't try and use libcloud's script function

- **PR** `#23175`_: (*basepi*) Merge forward from 2015.2 to develop
  @ *2015-04-29T21:54:32Z*

  - **ISSUE** `#15`_: (*thatch45*) Add list to the acceptable "glob" type
  * 0a11908 Merge pull request `#23175`_ from basepi/merge-forward-develop
  * 10b7574 Merge pull request `#15`_ from jfindlay/dev_test

    * d935b99 fix cmd_test for develop branch

    * f6eb08b fix develop py-2.6 lint

  * cca8ddc Merge remote-tracking branch 'upstream/2015.2' into merge-forward-develop

- **PR** `#23182`_: (*jtand*) Fixed a pylint error in qingcloud.py
  @ *2015-04-29T20:47:06Z*

  * e385085 Merge pull request `#23182`_ from jtand/qingcloud_pylint
  * 0ebe284 Fixed a pylint error in qingcloud.py

- **PR** `#23170`_: (*DmitryKuzmenko*) `#22595`_ Re-add ZMQ Monitor socket
  @ *2015-04-29T16:19:26Z*

  - **ISSUE** `#22595`_: (*cachedout*) New transport does not include monitor sockets
    | refs: `#23170`_
  * ee91670 Merge pull request `#23170`_ from DSRCompany/readd_zmq_monitor
  * 0b7a13a Re-add ZMQ Monitor socket

- **PR** `#23163`_: (*ckochenower*) Do not convert Cassandra collections (set, list, map) to strings.
  @ *2015-04-29T16:18:32Z*

  * bdd5f8f Merge pull request `#23163`_ from ckochenower/develop
  * 9dd71f4 Do not convert Cassandra set, list, maps to strings

  * b2d9189 Merge branch 'develop' of http://github.com/ckochenower/salt into develop

    * 1803027 Choose better partition ids and PRIMARY KEYs

- **PR** `#23152`_: (*mgwilliams*) Separate subnet_ids and subnet_names in boto_vpc.route_table_present
  @ *2015-04-29T15:32:08Z*

  * 68391e3 Merge pull request `#23152`_ from mgwilliams/boto_vpc
  * e32976b Merge remote-tracking branch 'origin/develop' into boto_dicts

  * 7e1fd56 states.boto_vpc: lint

  * 6d5d17b modules.boto_vpc: fix log message

  * 63cc88e states.boto_vpc: use separate subnet_ids and subnet_names kwargs in route_table_present

- **PR** `#23160`_: (*ykomatsu*) Do not use runas when user is correct
  @ *2015-04-29T15:20:48Z*

  * 114c29f Merge pull request `#23160`_ from ykomatsu/brew
  * 42ef698 Fix typos

  * 1bda536 Fix tests

  * 44b06f4 Use _call_brew

  * 821fd9e Do not use runas when user is correct

- **PR** `#23155`_: (*skizunov*) Bugfix: When writing MsgPack content to file, binary mode is required
  @ *2015-04-28T23:22:41Z*

  * a8235b3 Merge pull request `#23155`_ from skizunov/develop
  * 97c7e76 Bugfix: When writing MsgPack content to file, binary mode is required

- **PR** `#23156`_: (*cachedout*) syndic_wait var not referred to anywhere
  @ *2015-04-28T23:20:51Z*

  * ba0f503 Merge pull request `#23156`_ from cachedout/remove_unused_var
  * 47d7509 syndic_wait var not referred to anywhere

- **PR** `#23150`_: (*cachedout*) Better timeout error
  @ *2015-04-28T20:58:41Z*

  - **ISSUE** `#19087`_: (*akavel*) in 'salt/crypt.py' function sign_in(), please add note about timeout to message
    | refs: `#23150`_
  * 7380198 Merge pull request `#23150`_ from cachedout/issue_19087
  * 3293fad Better timeout error

- **PR** `#23062`_: (*mgwilliams*) return dicts from all boto_vpc functions
  @ *2015-04-28T20:25:59Z*

  * 3735865 Merge pull request `#23062`_ from mgwilliams/boto_dicts
  * 796fd60 use Mixin for Subnets test case in boto_vpc state module tests

  * 68c7ba7 fix lint in boto_vpc execution module tests

  * d976c83 states.boto_vpc: fix bug

  * 76f739d boto_vpc: lint

  * 682b494 loader: remove extraneous pass stmt

  * 22f1ff3 modules.boto_vpc: always catch exceptions when calling _get_conn (more)

  * 1c61cce modules.boto_vpc: always catch exceptions when calling _get_conn

  * 91e155a add TODO to boto_vpc execution module tests

  * 6752c81 add additional tests for boto_vpc state

  * 4d8b243 states.boto_vpc: fix bugs

  * 4018b04 modules.boto_vpc: fix bug

  * 2993b97 states.boto_vpc: remove erroneous docs for route_table_present

  * 57aa746 states.boto_vpc: sync route states with execution module

  * bd40be4 Merge branch 'develop' into boto_dicts

  * 899427a boto_vpc: lint

  * e6a02a6 WIP: states.boto_vpc: sync with execution module changes

  * bd409d5 use "exactly_one" from utils.boto for now

  * 0628dcc utils.boto: delete keys by value too

  * f3d994a modules.boto_vpc: return dicts from all functions

  * 97bd79d Merge remote-tracking branch 'origin/develop' into boto_dicts

  * 5dbba08 states.boto_vpc: sync vpc.present/absent and subnet.present/absent with execution module; add tests

  * afd1824 modules.boto_vpc: fix a couple bugs

  * d2af264 loader: add context kwarg to utils

  * 9ddfc6c boto_vpc: [WIP] always return dicts

  * 7347f63 utils.boto: add additional docs

  * 5f2715b add utils.compat

  * 04f7acd loader: add missing import

  * 759b522 Revert "utils.boto: add temporary ability to use without loader"

  * 8d3556e utils.boto: add temporary ability to use without loader

  * 81540c7 add exactly_n and exactly_one funcs to utils

  * 9ecf4f3 utils.boto: convert BotoExecutionError back to func

  * 7fa429c boto_vpc: fix lint

  * 3501a28 boto_vpc_test: fix indentation

  * 4d05730 boto_vpc: correct a docstring

  * 24511ae boto_vpc: fix hanging indentation

  * ab7c934 boto_vpc: remove superflous blank line

  * 9c39634 Merge remote-tracking branch 'origin/develop' into boto_vpc2

  * 935b7e8 modules.boto_vpc: remove trailing line

  * db8a9af boto_vpc: remove duplicate func decl; fix string format

  * bef7467 Merge branch 'boto_utils' into boto_vpc2

  * 98f06e0 boto_vpc: fix another module<->state discrepency

  * 92ad530 boto_vpc: fix module<->state discrepencies

  * 08c104a Merge branch 'boto_utils' into boto_vpc2

  * a5d111e Merge branch 'boto_utils' into mergetest

  * 393f42c boto_vpc: test fixes

  * 7b879f5 Merge branch 'boto_utils' into mergetest

  * 6f9434c [WIP] refactor boto_vpc execution module

- **PR** `#23109`_: (*skizunov*) Add option to read additional arguments from stdin
  @ *2015-04-28T20:00:01Z*

  * b133b0e Merge pull request `#23109`_ from skizunov/develop
  * 6a5624d Add option to read additional arguments from stdin

- **PR** `#23077`_: (*vinta*) Add QingCloud provider for salt-cloud
  @ *2015-04-28T18:53:11Z*

  * 94d9571 Merge pull request `#23077`_ from vinta/salt-cloud-qingcloud
  * f834dbe versionadded: Beryllium

  * 16abca5 use string formatting instead of string substitution

  * c57c5b3 remove ASCII art comments

  * 8f65f53 improve naming

  * d84ca16 filtering list_nodes_full()

  * facc2ee new salt-cloud provider: QingCloud

- **PR** `#23138`_: (*nmadhok*) VMware cloud driver additions
  @ *2015-04-28T18:48:44Z*

  - **ISSUE** `#10`_: (*thatch45*) list jobs option
  * 5578619 Merge pull request `#23138`_ from nmadhok/vmware-cloud-driver
  * 00c69cf Lint fix

  * 7e5c2e7 Making consolidate in remove_all_snapshots more clear

  * 2568e85 Changing memdump default from False to True in create_snapshot()

  * 30def2b Adding ability to get current snapshot information for vm

  * a9c7a03 Doc fixes

  * 9be470e Refactoring create_snapshot(), revert_to_snapshot() and remove_all_snapshots()

  * 85f75bf Merge pull request `#10`_ from rmgoodberlet/vmware-cloud-driver

    * 666206c Fixed some copy errors and error messages.

    * 603dc84 Added create_snapshot(), revert_to_snapshot(), and consolidate_snapshots() actions to perform these operations on a given VM.

- **PR** `#23136`_: (*basepi*) Merge forward from 2015.2 to develop
  @ *2015-04-28T18:00:24Z*

  * baca0bd Merge pull request `#23136`_ from basepi/merge-forward-develop
  * d9cede5 Merge remote-tracking branch 'upstream/2015.2' into merge-forward-develop

- **PR** `#23124`_: (*ether42*) fix parsing the output of parted in parted.list_()
  @ *2015-04-28T16:00:12Z*

  - **ISSUE** `#16188`_: (*drawks*) salt.modules.parted has various functions with bogus input validation.
    | refs: `#23124`_
  * a1ec423 Merge pull request `#23124`_ from ether42/develop
  * e6c9cc9 fix tests for the parted module

  * 6560839 fix parsing the output of parted

- **PR** `#23121`_: (*nmadhok*) Adding task polling of start, stop, suspend and reset actions in VMware cloud driver
  @ *2015-04-28T14:21:09Z*

  * 33ed60f Merge pull request `#23121`_ from nmadhok/vmware-action-polling
  * 3a9ceba Adding task polling of start, stop, suspend and reset actions in VMware cloud driver

- **PR** `#23089`_: (*cachedout*) Stringify version number before lstrip
  @ *2015-04-28T14:20:28Z*

  * 4a2d3be Merge pull request `#23089`_ from cachedout/apt_str
  * 142be49 Stringify version number before lstrip

- **PR** `#23127`_: (*rallytime*) Remove os.popen call in colletor.py
  @ *2015-04-28T14:19:47Z*

  * b5023c2 Merge pull request `#23127`_ from rallytime/remove_popen
  * feb10e0 Remove os.popen call in colletor.py

- **PR** `#23096`_: (*basepi*) Merge forward from 2015.2 to develop
  @ *2015-04-28T05:23:08Z*

  - **ISSUE** `#14`_: (*thatch45*) make salt-minion still run if a module does not load
  * 7a805b5 Merge pull request `#23096`_ from basepi/merge-forward-develop
  * d4a257e Merge pull request `#14`_ from jfindlay/dev_lint

    * cd472ea merge 2015.2 -> develop lint

  * befb666 Merge remote-tracking branch 'upstream/2015.2' into merge-forward-develop

- **PR** `#23099`_: (*garethgreenaway*) Additions to scheduler
  @ *2015-04-27T18:55:30Z*

  * 11087e2 Merge pull request `#23099`_ from garethgreenaway/schedule_adding_after_option
  * b6b1b8a Adding the ability to add an option to have jobs begin running "after" a specified time or date.

- **PR** `#23097`_: (*rallytime*) Change s3 to s3fs in fileserver_roots docs example
  @ *2015-04-27T18:12:10Z*

  - **ISSUE** `#23085`_: (*xenophonf*) Use "s3fs" (not "s3") in fileserver_roots
    | refs: `#23097`_
  * 308e4b5 Merge pull request `#23097`_ from rallytime/`fix-23085`_
  * 0b73397 Change s3 to s3fs in fileserver_roots docs example

- **PR** `#23069`_: (*nmadhok*) Adding list_hbas(), list_dvs(), list_vapps(), create_folder(), enter_maintenance_mode() and exit_maintenance_mode function in vmware cloud driver
  @ *2015-04-27T17:38:56Z*

  - **ISSUE** `#9`_: (*thatch45*) Enable authentication modes
  * 556215e Merge pull request `#23069`_ from nmadhok/vmware-cloud-driver
  * 83522d3 Adding create_folder() to be able to create the specified folder structure

  * 5c0ed19 Adding list_vapps() to be able to list all vApps in the environment

  * dd524cd Adding list_dvs() to be able to list all distributed virtual switches in the environment

  * 3d54bac Adding enter_maintenance_mode() and exit_maintenance_mode() for host systems

  * 973d169 Doc fix

  * 6dcf996 Lint fix

  * a23a384 Refactoring list_hbas()

  * 3ebeb68 Merge pull request `#9`_ from rmgoodberlet/vmware-cloud-driver

    * 2445d20 Added list_hba() function to list all HBAs on provider, HBAs by host, HBAs on provider by type, or HBAs on host by type.

- **PR** `#23092`_: (*rallytime*) Pylint dev
  @ *2015-04-27T17:05:59Z*

  * e5751f4 Merge pull request `#23092`_ from rallytime/pylint-dev
  * 39207ea Use salt.utils.fopen instead of open

  * d1f75be Python 3 compat for query.py

  * c544af5 Python 3 compat for collector.py

  * d258fa0 Python 3 compat for dbhandle.py

- **PR** `#23075`_: (*hvnsweeting*) py3 octal literal
  @ *2015-04-27T06:16:02Z*

  * 0a2adcd Merge pull request `#23075`_ from hvnsweeting/py3-chmod
  * 9894fc5 py3 octal literal

- **PR** `#23071`_: (*jfindlay*) py3 octal literal
  @ *2015-04-27T05:22:52Z*

  * b94346b Merge pull request `#23071`_ from jfindlay/dev_lint
  * 33e6968 py3 octal literal

- **PR** `#23074`_: (*dmyerscough*) Fixing small typo
  @ *2015-04-27T05:22:40Z*

  * 2936a03 Merge pull request `#23074`_ from dmyerscough/fix-typo
  * 9de7396 Fixing small typo

- **PR** `#23064`_: (*nmadhok*) Suppress InsecureRequestWarning and InsecurePlatformWarning messages in vmware cloud driver
  @ *2015-04-26T05:08:03Z*

  * 83a4f13 Merge pull request `#23064`_ from nmadhok/vmware-connection-warning
  * 83d1c2d Lint fix

  * 9f22475 Import disable_warnings() from requests.packages.urllib3 in try-except block

- **PR** `#23065`_: (*tsaridas*) Update boto_ec2.py comments
  @ *2015-04-25T23:16:39Z*

  * 2f41797 Merge pull request `#23065`_ from tsaridas/patch-1
  * c2f7c1e Update boto_ec2.py comments

- **PR** `#22826`_: (*tsaridas*) Fixes for group present
  @ *2015-04-25T17:00:13Z*

  - **ISSUE** `#22630`_: (*ryan-lane*) boto_iam state's group_present function adds users to group, but doesn't remove
    | refs: `#22826`_
  - **ISSUE** `#22273`_: (*ryan-lane*) boto_iam state's delete_keys function doesn't support test mode
    | refs: `#22283`_ `#22826`_
  * ec64dea Merge pull request `#22826`_ from tsaridas/fix_group_present
  * 53b76f2 - fix comments

  * 3ac4133 - option to add policies for user_present state

  * b77310d - remove option to add user to group from user_present

  * ca86289 - pylint

  * e0a0d23 test mode for keys_absent

  * 3afb677 - get_user_policy - get_all_user_policies - put_user_policy - delete_user_policy

  * aff3cd0 pylint + comments

  * 58018aa draft proposal

- **PR** `#23058`_: (*plastikos*) [improvement] compound match as list
  @ *2015-04-25T16:57:49Z*

  * 9ca2d58 Merge pull request `#23058`_ from plastikos/improvement-compound_as_list
  * 6f4cfd0 Specify compound matches as lists

  * 4adcf1c Correct referencing delimiter

  * 5abd3a7 Correct undefined variable.

  * 9933736 Allow grain and pillar delimiter to be specified in compound matcher syntax.

- **PR** `#22996`_: (*skizunov*) Fix Windows salt-master support for RAET
  @ *2015-04-25T16:55:59Z*

  * 0d7eb07 Merge pull request `#22996`_ from skizunov/develop
  * f21881a Fix Windows salt-master support for RAET

- **PR** `#22923`_: (*bruce-lyft*) Pagerduty orchestration
  @ *2015-04-25T16:54:21Z*

  * 02ec038 Merge pull request `#22923`_ from lyft/pagerduty_orchestration
  * ce8993f Fix a couple docstrings

  * 16e41c7 lint

  * 286e6f7 pylint

  * d8e5b07 add test mode, pager_service, cleanup

  * ac2fadb Merge branch 'develop' into pagerduty_orchestration

  * 29190c5 add pagerduty resources

- **PR** `#22886`_: (*terminalmage*) Better solution for PR 22838
  @ *2015-04-25T16:54:08Z*

  - **PR** `#22838`_: (*favadi*) add pkgrepo.absent keyid and keyid_ppa arguments
    | refs: `#22886`_ `#22886`_
  * 671d7a5 Merge pull request `#22886`_ from terminalmage/pr-22838
  * eb696f4 Lint fix

  * 8560929 Call pkg.del_repo_key to remove key

  * 53f520e Add del_repo_key to aptpkg.py

  * dd0db05 add pkgrepo.absent keyid and keyid_ppa arguments

- **PR** `#22858`_: (*isbm*) Node inspector module(s)
  @ *2015-04-25T16:53:56Z*

  - **ISSUE** `#2`_: (*thatch45*) salt job queries
    | refs: `#22858`_
  * 80034e9 Merge pull request `#22858`_ from isbm/isbm-salt-inspector
  * 59e6989 Lintfix

  * 11036bb Lintfix

  * e086a55 Licence year

  * a029d21 Implement allowed-only filtering for payload scanner.

  * a32cdb1 Allow pass keywords to the inspector

  * bb4a965 Added docstring for inspector

  * 385584a Add filtering of allowed payload scan

  * 18521c3 Query doc string

  * 8b04b5a Implemenation of payload information return

  * 24f890a Local UID/GID resolver

  * b10e178 Configuration data might me not available

  * 899fdcc Payload could be not available.

  * 2847aff Ignore home directories

  * 771de49 Remove unnecessary exception handling

  * 8b6d13d Bugfix: skip ignorables at entry level too

  * 32af607 Bugfix: path may not really exist

  * 5b4a865 Bugfix: typo

  * 6a27a2f Use 8-bit strings in SQLite db

  * 4cae0ba Save scanned payload

  * 2d9ec62 Payload saver to the database

  * ac1d861 Payload scanner

  * 699024d Call full scan preparation

  * dd6516e Add remark

  * 4c4d763 Do not purge database at snapshot moment

  * 5234069 Implementation of full scan perparation

  * b243ffd Implementation of intersection between managed and all files for payload

  * 1201014 Custom implementation of os.walk

  * 71b9e86 Add constants ignorable items

  * f7d862e Extend cache with the payload table.

  * 397c780 Add docstring

  * b6939b2 Stub

  * 78ad7d3 Get managed files from RPM database. Dpkg is to come.

  * 1e511c4 Bugfix: purge should actually just reset the db. Fixed wrong SQL binding.

  * 3dcdb8e Implement filtering for changed only config files

  * 2759171 Purge database before snapshot

  * 9102e1c Save only changed configuration files

  * f4f4ce2 Use external InspectorSnapshotException

  * f3f264a Implement inspector-specific DBHandle on top of DBHandleBase

  * 84aacf3 Implement purge the database without thrashing the database file itself.

  * ffd0f3f Create generic DBHandleBase class so it can be setup properly for precise use

  * e816177 Log exception as an error

  * babc1fb Use external SIException

  * 58d27f2 Use external SIException

  * 232e804 Use external SIException

  * d8ad6e6 Move InspectorQueryException outside

  * 9911e9f Use external InspectorQueryException

  * 66bc7d0 Moved SIException externally

  * 27b725b Use external exceptions

  * 27dac06 Use external InspectorQueryException

  * 76b1346 Do not raise "No data" exception when querying for all information

  * 005b99a Added logging

  * 212b050 Added logging

  * 0d0b6e6 Use external InspectorQueryException

  * c4b3b32 Use external InspectorSnapshotException

  * 8071061 Use external exceptions

  * ffc004f Moved InspectorSnapshotException externally

  * 62a3bbb Created exceptions classes outside

  * b4eb0c2 Implementation of system inspection call

  * 7b24cb5 Unnecessary imports

  * a80cf42 Exception fix

  * 4d58cf4 Configuration query implementation

  * 2768e64 Collector module, which is also a standalone utility

  * ed1180a SQLite dbhandler

  * a810a6a Basic "all data" implementation

  * 747fe43 Include mounts data

  * cb98bda Better stub for payload

  * b2d0265 Implementation of identity inspection

  * 1df929d Add external accounts inspection

  * 9229dbb Add local groups inspection

  * 6bfc0aa Add local users inspection

  * 84b95d7 Add mounts inspection

  * a13e996 Add services inspection

  * 665eb37 Software scope query implementation

  * 6d4605f Get OS data

  * 2535183 Get network data

  * 95c0e60 Runtime exception handling

  * a2dc741 Use lscpu instead of grains

  * f87e2f1 Get OS data

  * dea1281 Get network devices data and configuration

  * dd2f4a2 Runtime exception handling

  * f01e1f3 Get disk devices

  * 31a9722 Use lscpu for CPU data, instead of grains

  * fb14ac3 Get disk size info

  * 208bef1 Add grains helper alias

  * 59a9489 Handle exceptions in query

  * 654e321 Add possibility to parametrize query

  * a4c0d36 Cleanup imports

  * bbed7c0 Initial commit for Inspector module

- **PR** `#23056`_: (*jakubek*) print option mode presented in human friendly way
  @ *2015-04-25T16:07:24Z*

  * edb528d Merge pull request `#23056`_ from jakubek/develop
  * 7e82e32 fixed comparison

  * 4fb5ab3 print option mode presented in human readable value

- **PR** `#23033`_: (*nmadhok*) Additions to VMware salt-cloud driver
  @ *2015-04-25T03:01:05Z*

  - **ISSUE** `#7`_: (*thatch45*) stats module
  - **ISSUE** `#5`_: (*thatch45*) cmd module
  * 480bd2c Merge pull request `#23033`_ from nmadhok/vmware-cloud-driver
  * 440378a Doc fix

  * 4886703 Fixing code-blocks

  * ced82c2 Fixing lint and adding more checks to _upg_tools_helper

  * 73a6bb3 Removing redundant dictionary key

  * b4777e0 refactors to match the standards

  * d89c609 Adding list_clusters_by_datacenter()

  * ed2a2a5 Refactoring list_hosts_by_cluster() and list_hosts_by_datacenter()

  * c4734f6 Merge pull request `#7`_ from mpmoers/vmware-cloud-driver

    * e16908d Added function list_hosts_by_datacenter(): 	Takes an optional parameter "datacenter" to only list hosts in that datacenter

    * 8efe6b3 Merge remote-tracking branch 'origin/vmware-cloud-driver' into vmware-cloud-driver

      * 572150e Added function list_hosts_by_cluster()

    * 3852b8b Added function list_hosts_by_cluster()

  * 79a0cba Merge branch 'develop' of https://github.com/saltstack/salt into vmware-cloud-driver

  * e72c801 Merge pull request `#5`_ from rmgoodberlet/vmware-cloud-driver

    * a81b0e5 Added _upg_tools_helper() function to upgrade vmware tools on a VM object.  Reworked upgrade_tools() to use _upg_tools_helper() function and added upgrade_tools_all() to upgrade vmware tools on all VMs for a specified provider.

- **PR** `#23036`_: (*jfindlay*) adding states/boto_elasticache unit test
  @ *2015-04-24T19:47:27Z*

  * 6efef05 Merge pull request `#23036`_ from jfindlay/merge_23017
  * eda40c4 adding states/boto_elasticache unit test

- **PR** `#23037`_: (*jfindlay*) adding states/boto_elb unit test
  @ *2015-04-24T19:47:18Z*

  * cbfcc07 Merge pull request `#23037`_ from jfindlay/merge_23018
  * 06979ca adding states/boto_elb unit test

- **PR** `#23030`_: (*basepi*) Merge forward from 2015.2 to develop
  @ *2015-04-24T17:23:27Z*

  * a74ae78 Merge pull request `#23030`_ from basepi/merge-forward-develop
  * 313c465 Merge remote-tracking branch 'upstream/2015.2' into merge-forward-develop

- **PR** `#23024`_: (*The-Loeki*) minion nodes should parse minion configs
  @ *2015-04-24T15:34:17Z*

  * d5a4173 Merge pull request `#23024`_ from The-Loeki/patch-1
  * 96af032 minion nodes should parse minion configs

- **PR** `#23011`_: (*plastikos*) Add a versionadded note for the leading "not"
  @ *2015-04-24T14:11:34Z*

  * 24d2c6f Merge pull request `#23011`_ from plastikos/improvement-leading_not
  * bbd063f Add a versionadded note for the leading "not"

- **PR** `#22962`_: (*cachedout*) Remove update() in git pillar
  @ *2015-04-24T03:45:54Z*

  - **ISSUE** `#19994`_: (*msciciel*) Ext pillar refresh interval
    | refs: `#22962`_
  - **ISSUE** `#18593`_: (*msciciel*) salt-master - a lot of gettimeofday
    | refs: `#22962`_
  * 4d57a2d Merge pull request `#22962`_ from cachedout/remove_gitpillar_update
  * bb49244 Fix test

  * 339bbbb Remove update() in git pillar

- **PR** `#22963`_: (*garethgreenaway*) Additions to schedule module
  @ *2015-04-24T03:45:25Z*

  * 9a1a558 Merge pull request `#22963`_ from garethgreenaway/verify_schedule_functions_with_events
  * 503bd89 lint

  * 58bce28 fixing various things that caused unit tests to fail.  updating unit tests based on code changes

  * 664a249 add() when test=True result should be True.

  * 8cea3ac Verify that various schedule management functions were successfull using events

- **PR** `#22966`_: (*techhat*) Updates to Stormpath as per @rdegges
  @ *2015-04-24T03:44:58Z*

  * de24ecf Merge pull request `#22966`_ from techhat/stormpathup
  * 2a4ef7c Updates to Stormpath as per Randall Degges

- **PR** `#22969`_: (*plastikos*) Allow compound expressions to begin with "not"
  @ *2015-04-24T03:44:45Z*

  * 5799911 Merge pull request `#22969`_ from plastikos/improvement-leading_not
  * 6aab11f Appease the pylint gods.

  * d6fe499 Allow compound expressions to begin with "not"

- **PR** `#22998`_: (*techhat*) Add REST driver for SDB
  @ *2015-04-24T03:43:16Z*

  * e33e3c1 Merge pull request `#22998`_ from techhat/restsdb
  * a6d2b3d Lint

  * e5a186e Fixing etcd reference

  * 60378b4 Add REST driver for SDB

- **PR** `#23005`_: (*clinta*) X509
  @ *2015-04-24T03:41:12Z*

  * d130586 Merge pull request `#23005`_ from clinta/x509
  * 802fe53 Merge branch 'develop' into x509

  * b54f15a Merge branch 'develop' of https://github.com/saltstack/salt into x509

  * 57c37cc only remove authoritykeyid serial if self-signed

  * cd9174d only remove authoritykeyid serial if self-signed

  * 4b1efb1 Merge branch 'develop' of https://github.com/saltstack/salt into x509

  * 7ef694d don't send state args to publish

  * 049cbdf Merge branch 'develop' of https://github.com/saltstack/salt into x509

  * 3658318 deepcopy

  * 7e2c10b Merge branch 'x509' of github.com:clinta/salt into x509

    * eac59f5 Merge branch 'develop' of https://github.com/saltstack/salt into x509

  * 231c964 forgot import

  * 74a3dff Merge branch 'develop' of https://github.com/saltstack/salt into x509

  * 0e53fde fix authorityid bug

- **PR** `#23003`_: (*notpeter*) Typo in ssh.check_key_file doc example
  @ *2015-04-24T03:16:34Z*

  * 336373c Merge pull request `#23003`_ from notpeter/develop
  * 3a36824 Typo in ssh.check_key_file example.

- **PR** `#22995`_: (*basepi*) Merge forward from 2015.2 to develop
  @ *2015-04-23T20:10:19Z*

  * ed6eadc Merge pull request `#22995`_ from basepi/merge-forward-develop
  * 035ad54 Merge remote-tracking branch 'upstream/2015.2' into merge-forward-develop

- **PR** `#22992`_: (*plastikos*) [bug] Update time so that minion startup can timeout.
  @ *2015-04-23T18:16:52Z*

  * 1445f58 Merge pull request `#22992`_ from plastikos/bug-test_startup_timeout
  * f155daf Update time so that minion startup can timeout.

- **PR** `#22986`_: (*hnsk*) Added option keyalgorithm for DDNS updates
  @ *2015-04-23T16:12:49Z*

  * fc7ec24 Merge pull request `#22986`_ from hnsk/develop
  * 74405f1 Added option keyalgorithm for DDNS updates (defaults to: HMAC-MD5.SIG-ALG.REG.INT).

- **PR** `#22971`_: (*scottp-dpaw*) Allow PPAs on Linux Mint
  @ *2015-04-23T05:12:19Z*

  * 3695641 Merge pull request `#22971`_ from scottp-dpaw/develop
  * a98c4bf Allow PPAs on Linux Mint

- **PR** `#22967`_: (*jfindlay*) adding states/boto_ec2 unit test case
  @ *2015-04-23T05:02:49Z*

  * b0e59b2 Merge pull request `#22967`_ from jfindlay/merge_22937
  * ed5f483 adding states/boto_ec2 unit test case

- **PR** `#22965`_: (*basepi*) Release 2014.7.5
  @ *2015-04-22T21:56:24Z*

  * 2d5abc8 Merge pull request `#22965`_ from basepi/2014.7.5release
  * 8247756 Release 2014.7.5

- **PR** `#22953`_: (*basepi*) Merge forward from 2015.2 to develop
  @ *2015-04-22T18:42:53Z*

  * 9defb04 Merge pull request `#22953`_ from basepi/merge-forward-develop
  * 1a38b4b Merge remote-tracking branch 'upstream/2015.2' into merge-forward-develop

- **PR** `#22916`_: (*cachedout*) Raise exception on render error
  @ *2015-04-22T18:34:39Z*

  - **ISSUE** `#22512`_: (*kostko*) gpg renderer should abort when decryption fails
    | refs: `#22916`_
  * 23d80d8 Merge pull request `#22916`_ from cachedout/issue_22512
  * e542fa1 Change default to False and handle different gnupg version

  * 5d48bc3 Raise exception on render error

- **PR** `#22949`_: (*s0undt3ch*) Disable some PyLint false positives
  @ *2015-04-22T17:01:34Z*

  * a5df4ad Merge pull request `#22949`_ from s0undt3ch/develop
  * d3284ba Disable some PyLint false positives

- **PR** `#22659`_: (*jacksontj*) Transport: misc cleanup
  @ *2015-04-22T15:48:01Z*

  * 3867950 Merge pull request `#22659`_ from jacksontj/transport
  * 9c68051 Switch to a non-blocking resolver

  * 2acce3f Add AsyncPillar interfaces

  * 719c416 Fix event publishes from beacon system

  * 0a65b69 Avoid double closing the tcp session

  * 7bcc5da Correct log msg

  * a1016d5 Style cleanup

  * 0aa5100 Raise exception when unable to connect to any master in SMinion

- **PR** `#22913`_: (*skizunov*) Fix Windows salt-master support for ZeroMQ
  @ *2015-04-22T15:40:36Z*

  * b03a614 Merge pull request `#22913`_ from skizunov/develop
  * af65bba Fix Windows salt-master support for ZeroMQ

- **PR** `#22928`_: (*DmitryKuzmenko*) Issue `#22814`_: Flush returners queue before salt master shutdown
  @ *2015-04-22T15:32:19Z*

  * e3fb101 Merge pull request `#22928`_ from DSRCompany/flush_returners_queue
  * 8b6c7ee Flush returners queue before salt master shutdown

- **PR** `#22909`_: (*mguegan*) Fix compatibility with pkgin > 0.7
  @ *2015-04-22T04:48:43Z*

  * 775bee9 Merge pull request `#22909`_ from virtua-network/fix_pkgin_parser
  * c37d70a Fix compatibility with pkgin > 0.7

- **PR** `#22927`_: (*jfindlay*)  [develop] lint fixes
  @ *2015-04-22T04:19:36Z*

  - **PR** `#22922`_: (*s0undt3ch*) [develop] lint fixes
    | refs: `#22927`_
  * a0e253d Merge pull request `#22927`_ from jfindlay/merge_22922
  * f7e6f71 Make PEP-8 checker happier

  * b831d14 Properly indent comments

  * 5f7ab3d Another PEP-8 preciosity disabled

  * 4617f03 Make PEP-8 happier

  * 23ad161 Additionally ignore import-error

  * 492c651 Fix W1504(unidiomatic-typecheck)

- **PR** `#22926`_: (*rallytime*) Python 3 compat for salt/auth/pam.py
  @ *2015-04-22T02:30:45Z*

  * d34e7c0 Merge pull request `#22926`_ from rallytime/pylint-dev
  * f61abb0 Python 3 compat for salt/auth/pam.py

- **PR** `#22920`_: (*cachedout*) Better err handling for unresoveable master addr
  @ *2015-04-22T01:00:00Z*

  * f870f75 Merge pull request `#22920`_ from cachedout/dns_check_err
  * bac22b1 Better err handling for unresoveable master addr

- **PR** `#22915`_: (*basepi*) Update versionadded for boto_rds modules
  @ *2015-04-21T22:06:14Z*

  * d23ee2f Merge pull request `#22915`_ from basepi/boto_rds.version_added
  * 073f79a Update versionadded for boto_rds modules

- **PR** `#22895`_: (*aletourneau*) pam_tally counter was not reset to 0 after a succesfull login
  @ *2015-04-21T18:50:27Z*

  * ac58203 Merge pull request `#22895`_ from aletourneau/pam_tally2.fix
  * 0f4fbe9 Fixed pylint issues

  * 508f704 Cleaned up pull request

  * d8fe360 pam_tally counter was not reset to 0 after a succesfull login

- **PR** `#22900`_: (*basepi*) Merge forward from 2015.2 to develop
  @ *2015-04-21T18:01:39Z*

  * 3565816 Merge pull request `#22900`_ from basepi/merge-forward-develop
  * bd6ecdf Merge remote-tracking branch 'upstream/2015.2' into merge-forward-develop

- **PR** `#22875`_: (*nmadhok*) Revert `#22562`_
  @ *2015-04-21T15:57:27Z*

  - **ISSUE** `#22874`_: (*nmadhok*) incorrect grain information populated on the minions created using salt-cloud
    | refs: `#22875`_
  - **ISSUE** `#22561`_: (*kiorky*) since recently, grains or pillar can be empty in certain sls executions
    | refs: `#22562`_ `#22875`_
  - **PR** `#22562`_: (*kiorky*) Workaround for grains loading
  * 7ad8d79 Merge pull request `#22875`_ from nmadhok/grains-patch
  * 7853277 Revert `#22562`_

- **PR** `#22829`_: (*F30*) Always return a boolean in gen_locale()
  @ *2015-04-21T03:58:43Z*

  - **ISSUE** `#21140`_: (*holms*) locale.present state executed successfully, although originally fails
    | refs: `#22829`_
  - **ISSUE** `#2417`_: (*ffa*) Module standards
    | refs: `#22829`_
  * bf52ba7 Merge pull request `#22829`_ from F30/gen_locale-return-value
  * 9e47d8c Adjust tests to the new return value of modules.localemod.gen_locale()

  * 46f1f4f Always return a boolean in modules.localemod.gen_locale()

- **PR** `#22860`_: (*nmadhok*) Fixing issue that causes RuntimeError maximum recursion Fixes `#22839`_
  @ *2015-04-20T22:09:25Z*

  - **ISSUE** `#22839`_: (*nmadhok*) Getting RuntimeError on latest develop branch
    | refs: `#22860`_
  * 6454804 Merge pull request `#22860`_ from nmadhok/patch-runtime-error
  * 1f703ef Rename key

  * 5b6f299 Makes changes as suggested by Thomas so the loader does not break

  * 1688d19 Fixing issue that causes RuntimeError maximum recursion Fixes `#22839`_

- **PR** `#22864`_: (*rallytime*) Python 3 compat fix for modules/splay.py
  @ *2015-04-20T20:16:40Z*

  * 799875f Merge pull request `#22864`_ from rallytime/pylint
  * 2dd761c Python 3 compat fix for modules/splay.py

- **PR** `#22862`_: (*basepi*) Merge forward from 2015.2 to develop
  @ *2015-04-20T18:22:13Z*

  * 371ed19 Merge pull request `#22862`_ from basepi/merge-forward-develop
  * ef58329 Merge remote-tracking branch 'upstream/2015.2' into merge-forward-develop

- **PR** `#22832`_: (*F30*) Improve docs for modules.localemod & states.locale
  @ *2015-04-20T16:29:34Z*

  * b90306f Merge pull request `#22832`_ from F30/locale-docs
  * 169ea9e Document charmap for locale generation

  * 3925299 Add example for locale.present to the states.locale docs

- **PR** `#22830`_: (*F30*) Remove Tox config
  @ *2015-04-20T15:38:36Z*

  * 1339ee5 Merge pull request `#22830`_ from F30/remove-tox
  * 6828c4b Remove Tox config

- **PR** `#22562`_: (*kiorky*) Workaround for grains loading
  @ *2015-04-20T15:22:19Z*

  - **ISSUE** `#22561`_: (*kiorky*) since recently, grains or pillar can be empty in certain sls executions
    | refs: `#22562`_ `#22875`_
  * 962755c Merge pull request `#22562`_ from makinacorpus/g
  * d7a9aea lint

  * d753e2d Workaround for grains loading

- **PR** `#22841`_: (*felskrone*) Connected - CacheWorker addition
  @ *2015-04-20T15:21:31Z*

  * 3c24694 Merge pull request `#22841`_ from felskrone/upstream_concache_worker
  * 8f38512 pylint fix

  * 8fa09bc doc fix

  * 9e5cbe2 change loglevel to debug

  * c2f5829 enhance cache update to distinguish between CacheWorker and Mworker updates

  * 7e39d40 dont do elifs, both might match during a single iteration

  * c66df2d query the cache before updating it

  * f0b43ef no need to call parent

  * 0cd0b2d start a CacheWorker in 30 second intervals to keep cached minions up to date

  * e0ff8ad Mworker send 1-item-lists, CacheWorkers send larger lists and replace the cache

  * e64c4d2 remove deprecated/unneeded old code

  * e675dc7 add CacheWorker for ConnectedCache as multiprocessing.process

- **PR** `#22836`_: (*jodv*) fix conditional logic for missing function messages
  @ *2015-04-20T15:19:47Z*

  * d7413b9 Merge pull request `#22836`_ from jodv/fix_missing_module_error_msg
  * 15bb35e fix trailing whitespace

  * 1d246fb fix conditional logic for missing function messages

- **PR** `#22835`_: (*jodv*) add splay module
  @ *2015-04-20T15:17:10Z*

  * 80526b7 Merge pull request `#22835`_ from jodv/splay_mod
  * e876c5f PEP 263 UTF-8 encoding

  * b74b2dd pylint fixes

  * 656a8d1 add splay module

- **PR** `#22817`_: (*garethgreenaway*) Beacon management module
  @ *2015-04-20T15:14:32Z*

  * 5f6393d Merge pull request `#22817`_ from garethgreenaway/beacon_management_module
  * 3f19ebb Lint fixes

  * 6ce0af0 Moving code in the add method into the else section of the if...else clause.  Adding check in the delete method that the beacon was really deleted.

  * 371643f Fixing versionadded tag.

  * 9815549 Adding beacons module.

  * 7ea207d Adding a validate function to each beacon that will be used by the beacons.add function to ensure configuration is correct.

  * d2eac55 Adding validation bits to ensure beacon data is correct before adding.

- **PR** `#22837`_: (*nmadhok*) Making vmware cloud driver Python3 compatible and other additions
  @ *2015-04-19T21:57:43Z*

  - **ISSUE** `#22364`_: (*angystardust*) Adding functionality to create() in vmware cloud driver to be able to add/reconfigure scsi adapters
    | refs: `#22837`_
  * 3b17858 Merge pull request `#22837`_ from nmadhok/vmware-cloud-driver
  * cbe860d Making vmware-cloud driver python3 compatible

  * 2c2705f Rename _set_network_adapter_mapping to _set_network_adapter_mapping_helper

  * 1b0f248 Combining duplicate code for network adapter mapping in a single helper function

  * 64e527c Adding ability to modify/create SCSI adapters `#22364`_

- **PR** `#22812`_: (*nmadhok*) Added functions rescan_all_hbas() & rescan_hba() in vmware salt cloud driver
  @ *2015-04-19T13:28:57Z*

  - **ISSUE** `#4`_: (*thatch45*) pacman module
  * 46c391b Merge pull request `#22812`_ from nmadhok/vmware-cloud-driver
  * 5da9ee1 Better error hangling

  * 67d7873 syntax fix

  * 364bc25 Combine rescan_hba() and rescan_all_hbas()

  * 37b4d09 Merge pull request `#4`_ from mpmoers/vmware-cloud-driver

    * 27a6869 Updated function names and spaceing

    * d01b0d6 updated spacing issues and example usage

    * 0fdd5f8 changed references to vim.HostSystem in rescan functions

    * 47fc49a Merge branch 'vmware-cloud-driver' of https://github.com/nmadhok/salt into vmware-cloud-driver

    * 3d7f26d added function rescanHba

    * e0b7239 fixed syntax errors

    * b8ce68e added function rescanAllHba

- **PR** `#22824`_: (*favadi*) Add xmpp.send_msg_multi state/module
  @ *2015-04-18T16:54:55Z*

  * 3e21e43 Merge pull request `#22824`_ from favadi/xmpp-multi
  * 83c21f9 add xmpp.send_msg_multi state

  * b576080 add xmpp.send_msg_multi module

- **PR** `#22806`_: (*jfindlay*) use cmd.run_all instead of cmd.run_stdout
  @ *2015-04-18T00:19:22Z*

  - **ISSUE** `#22574`_: (*unicolet*) error when which is not available
    | refs: `#22806`_
  * 1cd2996 Merge pull request `#22806`_ from jfindlay/fix_grain_whereis
  * b4a86ad use cmd.run_all instead of cmd.run_stdout

- **PR** `#22784`_: (*techhat*) Adding and updating Stormpath modules
  @ *2015-04-17T22:50:25Z*

  * dcd9e16 Merge pull request `#22784`_ from techhat/stormpath
  * 514dd38 Python 3 compat

  * 54dbf9b Specify which version Stormpath was added to

  * 9c73abe Removing unused import

  * f9a38ce Linting

  * 7ee6103 Adding and updating Stormpath modules

- **PR** `#22805`_: (*rallytime*) Another pylint fix for develop
  @ *2015-04-17T21:21:49Z*

  * 6a554d5 Merge pull request `#22805`_ from rallytime/all-the-pylint
  * 9e83d85 Another pylint fix for develop

- **PR** `#22788`_: (*nmadhok*) Speeding up list_nodes_select() and few other tweaks in VMware cloud driver
  @ *2015-04-17T20:05:56Z*

  * dbbd6bf Merge pull request `#22788`_ from nmadhok/vmware-cloud-driver
  * faa2fd7 Lint

  * 59d8faa Merge branch 'develop' of https://github.com/saltstack/salt into vmware-cloud-driver

  * 950fbce Adding terminate() action to be able to immediately power off the VM

  * a0dde74 Speeding up list_nodes_select() and few other tweaks

- **PR** `#22798`_: (*rallytime*) Python 3 compat fixes for develop
  @ *2015-04-17T19:14:46Z*

  * 1097d25 Merge pull request `#22798`_ from rallytime/pylint-develop
  * 1e4b93d Python 3 compat fixes for develop

- **PR** `#22799`_: (*nmadhok*) Fixes `#22792`_
  @ *2015-04-17T19:13:04Z*

  - **ISSUE** `#22792`_: (*nmadhok*) Sphinx make failing because of a syntax error present in file
    | refs: `#22799`_
  * 81d4d90 Merge pull request `#22799`_ from nmadhok/develop
  * 964df53 Fixes `#22792`_

- **PR** `#22801`_: (*rallytime*) Add 2014.7.5 release notes to develop
  @ *2015-04-17T18:54:59Z*

  * fc62a37 Merge pull request `#22801`_ from rallytime/release_notes_develop
  * 36b54ee Remove extra line

  * 93a858c Added release note for 2014.7.5 release

- **PR** `#22793`_: (*basepi*) Merge forward from 2015.2 to develop
  @ *2015-04-17T18:49:42Z*

  * b88f7b0 Merge pull request `#22793`_ from basepi/merge-forward-develop
  * 279e98a Merge remote-tracking branch 'upstream/2015.2' into merge-forward-develop

- **PR** `#22789`_: (*julienlavergne*) added recursive for ignored vagrant project files
  @ *2015-04-17T18:49:17Z*

  * cfb7e97 Merge pull request `#22789`_ from julienlavergne/gitignore
  * 1c91622 added recursive ignored vagrant project files

- **PR** `#22785`_: (*junckritter*) Allow additional parameters for GCE cloud profile
  @ *2015-04-17T18:43:46Z*

  - **ISSUE** `#22346`_: (*RobertAtomic*) Specify additional disks with GCE provider
    | refs: `#22785`_
  * 890c89c Merge pull request `#22785`_ from junckritter/cloud-gce-disks
  * 42d26cc Shorter disk resource definition

  * cbc37d7 Merge branch 'cloud-gce-disks' of github.com:junckritter/salt into cloud-gce-disks

    * b1f6bd1 Working test for extended profile

    * f7efbf5 Allow setting multiple disks and scopes on create of instance for GCE

  * 5d93b76 Working test for extended profile

  * 6f34f0d Allow setting multiple disks and scopes on create of instance for GCE

- **PR** `#22783`_: (*eliasp*) Fixed typo/grammar.
  @ *2015-04-17T18:05:10Z*

  * d6ab56b Merge pull request `#22783`_ from eliasp/develop-states.group.present-typo
  * f31a75d Fixed typo/grammar.

- **PR** `#22781`_: (*eliasp*) develop.pillar ldap doc fixes
  @ *2015-04-17T15:06:47Z*

  * 871cdd7 Merge pull request `#22781`_ from eliasp/develop.pillar_ldap-doc-fixes
  * 7b85666 Fix alignment of code example.

  * d685e49 Added missing newline before code-block.

- **PR** `#22773`_: (*analogbyte*) smtp module: make multiple recipients work as expected
  @ *2015-04-17T14:43:40Z*

  * e4f7da9 Merge pull request `#22773`_ from analogbyte/develop
  * f4fe028 smtp module: make multiple recipients work as expected

- **PR** `#22776`_: (*The-Loeki*) Minor fix on clean
  @ *2015-04-17T14:42:58Z*

  * 6226d60 Merge pull request `#22776`_ from The-Loeki/patch-1
  * e07c480 Minor fix on clean

- **PR** `#22668`_: (*basepi*) Merge forward from 2015.2 to develop
  @ *2015-04-17T05:22:36Z*

  - **ISSUE** `#13`_: (*thatch45*) Expand the stats module
  - **ISSUE** `#12`_: (*thatch45*) Expand the pacman module
  - **ISSUE** `#11`_: (*thatch45*) Add disable_modules to the config
  * 2210bd1 Merge pull request `#22668`_ from basepi/merge-forward-develop
  * 84c8ae5 Merge pull request `#13`_ from rallytime/basepi-merge-forward-develop

    * 872974a Fully mock GPG mock class to allow gpg_tests to pass

  * 7bb5e0f Merge pull request `#12`_ from rallytime/basepi-merge-forward-develop

    * ad99c80 Mock __salt__ and call to salt.loader.render to fix win_repo test

    * c82339b fix saltmod.function unit test

  * 728e74c Better return data for mocked saltutil.cmd for saltmod.function

  * a8a5ee5 Allow proto or protocol in iptables

  * e3be4bf Mock pillar_pcre for the mine tests

  * 40a6ed4 Fix puppet test to mock cmd.run_all with return value including retcode

  * fd03627 Fix iptables test_flush

  * 7ab3c44 Merge pull request `#11`_ from rallytime/basepi-merge-forward

    * 1f59e13 Chang variable to empty string if it's None

  * 5deff64 Remove unused import

  * b943eb5 How did this sneak in there?

  * e235c97 Mock config.option for pagerduty tests

  * 66378be Merge remote-tracking branch 'upstream/2015.2' into merge-forward-develop

  * 11356cb Use print_function

  * 000de95 Merge remote-tracking branch 'upstream/2015.2' into merge-forward-develop

- **PR** `#22764`_: (*rallytime*) Pylint fixes for develop
  @ *2015-04-17T04:31:51Z*

  * 601e0ce Merge pull request `#22764`_ from rallytime/pylint
  * d6bc395 Pylint fixes for develop

- **PR** `#22763`_: (*terminalmage*) Add clarification regarding saltutil.sync_modules behavior in state runs
  @ *2015-04-17T04:29:10Z*

  * 50611a3 Merge pull request `#22763`_ from terminalmage/issue22744
  * 8768e51 Add note about using module_refresh to refresh modules in state run

  * e51a8e0 Add external anchor for "reloading modules" section of state docs

- **PR** `#22765`_: (*dmuntean*) Requests to AWS instance metadata should never be proxied
  @ *2015-04-17T04:28:35Z*

  * 6c65b05 Merge pull request `#22765`_ from dmuntean/requests-to-instance-metadata-should-not-be-proxied
  * 293fef2 Requests to AWS instance metadata should never be proxied

- **PR** `#22757`_: (*nmadhok*) Adding vm_tools_upgrade() action to vmware salt cloud driver
  @ *2015-04-17T03:48:45Z*

  - **ISSUE** `#2`_: (*thatch45*) salt job queries
    | refs: `#22858`_
  * 1ce6d7a Merge pull request `#22757`_ from nmadhok/vmware-cloud-driver
  * 745692d Lint

  * 2e0e6a0 Renaming vm_tools_upgrade() to upgrade_tools()

  * 55e63b9 Lint fix

  * 72c5152 Refactor vm_tools_upgrade()

  * d024374 Merge branch 'vmware-cloud-driver' of github.com:nmadhok/salt into vmware-cloud-driver

    * a59417d Merge pull request `#2`_ from rmgoodberlet/vmware-cloud-driver

      * ebf7add Removing unwanted newlines and justified comments to code blocks.

      * 9ec95c2 Adding vm_tools_upgrade() to be able to upgrade vmware tools on a specified vm.

- **PR** `#22758`_: (*rallytime*) Change latest release version in doc sidebar
  @ *2015-04-16T22:20:31Z*

  - **ISSUE** `#22755`_: (*Whissi*) docs.saltstack.com still lists outdated 2014.7.2 release as latest version
    | refs: `#22758`_
  * 5b83dc7 Merge pull request `#22758`_ from rallytime/doc_sidebar
  * 662593c Change latest release version in doc sidebar

- **PR** `#22729`_: (*nmadhok*) Adding list_nodes_select(), create_datacenter() and create_cluster() in vmware salt cloud driver
  @ *2015-04-16T17:54:56Z*

  * 58617f9 Merge pull request `#22729`_ from nmadhok/vmware-cloud-driver
  * b90471b Lint fix

  * 60d2404 Adding create_cluster() to be able to create new host clusters

  * 6a05f52 Change log.error for checking action or function to raising SaltCloudSystemExit

  * f3405eb Adding create_datacenter() to be able to create a datacenter

  * e754c16 Making wait messages contain the vmname (Helpful in parallel mode)

  * dd18c16 Fixing the issue where Pickling error arises again and again

  * a2be1dd Merge branch 'develop' of https://github.com/saltstack/salt into vmware-cloud-driver

  * bb33b05 Adding list_nodes_select()

  * f74c66f Merge branch 'develop' of https://github.com/saltstack/salt into vmware-cloud-driver

  * 1b02d72 Syntax error fix

  * e28427a Adding _wait_for_task()

- **PR** `#22750`_: (*jfindlay*) revise contributing documentation
  @ *2015-04-16T17:45:50Z*

  * d4e8e4d Merge pull request `#22750`_ from jfindlay/update_contributing
  * e586c66 revise contributing documentation

- **PR** `#22687`_: (*ryan-lane*) Make boto_iam more consistent with boto_iam_role for groups
  @ *2015-04-16T16:52:41Z*

  * 3362c13 Merge pull request `#22687`_ from lyft/boto-iam-consistency
  * 1a9e307 Fix TODO

  * 0aac2a9 Make boto_iam more consistent with boto_iam_role for groups

- **PR** `#22737`_: (*ticosax*) [salt.mine.get_docker] Discard containers that doesn't expose their internal ports.
  @ *2015-04-16T16:47:11Z*

  * 073e019 Merge pull request `#22737`_ from ticosax/ports-not-exposed-has-no-ip
  * fd352dd 'IP' is present in response only if the port is exposed to the host.

- **PR** `#22736`_: (*bemeyert*) improve cmd.run env documentation
  @ *2015-04-16T13:17:16Z*

  - **ISSUE** `#21840`_: (*bemeyert*) Docs for cmd.run env should say that no evaluation is done
    | refs: `#22736`_ `#23571`_
  * f29e7a5 Merge pull request `#22736`_ from bemeyert/21840-improve_cmd.run_env_docs
  * 1341784 improve cmd.run env documentation

- **PR** `#22675`_: (*twangboy*) Winrepo sls files now run through the templating system
  @ *2015-04-16T04:52:19Z*

  * c031192 Merge pull request `#22675`_ from twangboy/winrepo_parsing
  * 2b5b934 Update winrepo.py

  * e6b9c5b Update win_repo.py

  * 6e00171 Winrepo sls files now run through the templating system

- **PR** `#22728`_: (*whiteinge*) Add several modules to the mocked modules list for the docs build
  @ *2015-04-16T01:58:57Z*

  - **ISSUE** `#22720`_: (*VynceMontgomery*) Documentation for salt.states.file is blank
    | refs: `#22728`_
  * 6452590 Merge pull request `#22728`_ from whiteinge/fix-docmageddon
  * fe8f3e0 Added generated doc for clustershell roster module

  * f15e3ce Add missing blank line after code-block directive

  * aaf1917 Add mocked references for new module additions

  * 767c328 Remove docs for old nagios_json module

- **PR** `#22726`_: (*VynceMontgomery*) fix link to bug reporting in FAQ
  @ *2015-04-16T01:57:59Z*

  * f5b6223 Merge pull request `#22726`_ from VynceMontgomery/patch-2
  * 80d6e9e fix link to bug reporting in FAQ

- **PR** `#22730`_: (*basepi*) Add minor CVEs to 2014.7.4 release notes
  @ *2015-04-16T01:02:06Z*

  * bb37e4f Merge pull request `#22730`_ from basepi/2014.7.4releasenotes
  * ff8561d Add minor CVEs to 2014.7.4 release notes

- **PR** `#22722`_: (*VynceMontgomery*) fix alphabetization
  @ *2015-04-16T00:17:54Z*

  * 5a32eeb Merge pull request `#22722`_ from VynceMontgomery/patch-1
  * 0d2a0a3 fix alphabetization

- **PR** `#22556`_: (*Anthonyhawkins*) Addition of F5 BigIP iControl REST Execution Module
  @ *2015-04-15T22:54:59Z*

  * 843c7d0 Merge pull request `#22556`_ from Anthonyhawkins/develop
  * 421d541 Indent and formatting issues

  * 533cd67 Addressed formatting and other failures from tests

  * 6ba06c3 Merge branch 'develop' of https://github.com/Anthonyhawkins/salt into add-f5-bigip-execution-module

    * 1415ae5 bug fixes and profiles rework

    * 51de006 Merge branch 'develop' of https://github.com/Anthonyhawkins/salt into add-f5-bigip-execution-module

      * bf6f44f Delete v3qymexn.q1w.txt

      * 851baa2 Delete sjpzsiva.bnh.txt

      * 49234ef Delete h3ogajn2.544.txt

      * 7192638 Added list and dictionary logic for option builders

      * 0edb15c Added virtual function.

      * fdf5e38 Initial Commit

    * e32d58a Delete v3qymexn.q1w.txt

    * b0e66e2 Delete sjpzsiva.bnh.txt

    * 3fbd35f Delete h3ogajn2.544.txt

    * a58ec48 Added list and dictionary logic for option builders

    * dd598d1 Added virtual function.

    * 1cc0a2c Initial Commit

  * b6a7663 bug fixes and profiles rework

  * a844365 Delete sjpzsiva.bnh.txt

  * 300aade Delete h3ogajn2.544.txt

  * 4f9a7f0 Added list and dictionary logic for option builders

  * 9db96ed Added virtual function.

  * 3cb5ee5 Delete v3qymexn.q1w.txt

  * caf5ef7 Delete sjpzsiva.bnh.txt

  * 0144171 Delete h3ogajn2.544.txt

  * d202ca2 Added list and dictionary logic for option builders

  * 63b2a7e Added virtual function.

  * 215ea74 Initial Commit

- **PR** `#22715`_: (*obestwalter*) Add mention of Windows release candidates
  @ *2015-04-15T19:49:27Z*

  * ee9e618 Merge pull request `#22715`_ from obestwalter/patch-1
  * 20ce197 Add mention of Windows release candidates

- **PR** `#22691`_: (*The-Loeki*) `#22080`_ part 1: Addition of Python 3 compatible ipaddress module
  @ *2015-04-15T19:49:02Z*

  - **ISSUE** `#22080`_: (*The-Loeki*) CIDR matching for IPv6 / improve IPv6 support in utils.network
    | refs: `#22691`_ `#23253`_ `#23896`_ `#24282`_ `#24282`_
  * a64df92 Merge pull request `#22691`_ from The-Loeki/better-ipv6
  * d04c66d Ignore PyLint for external ipaddress module

  * 64bda95 Addition of Python 3 compatible ipaddress module https://bitbucket.org/kwi/py2-ipaddress/

- **PR** `#22710`_: (*thatch45*) Salt cp out
  @ *2015-04-15T19:40:36Z*

  * 66c47be Merge pull request `#22710`_ from thatch45/salt_cp_out
  * b626149 fix tests

  * 0bf800e remove unused import

  * 6201929 Add ouput options mixing to salt-cp

  * 78d5c87 use outputters for salt-cp

- **PR** `#22671`_: (*rallytime*) Merge `#22613`_ with pylint fix
  @ *2015-04-15T18:12:06Z*

  - **PR** `#22613`_: (*garethgreenaway*) Replacing numeric HTTP codes.
    | refs: `#22671`_
  * 1af66ef Merge pull request `#22671`_ from rallytime/merge-22613
  * 2217d41 Pylint fix again!

  * a0e2d98 Fix pylint error

  * d8d4366 Replacing 404 and 409 codes with salt.ext.six.moves.http_client.NOT_FOUND and salt.ext.six.moves.http_client.CONFLICT

- **PR** `#22672`_: (*garethgreenaway*) Beacon management module
  @ *2015-04-15T15:56:53Z*

  * ea04f6d Merge pull request `#22672`_ from garethgreenaway/beacon_management_module
  * e3e9954 Adding a function to delete beacon items.

  * 1c24d60 Need to "handle" the beacons after changing them

  * 03f8472 adding module to manage beacons

- **PR** `#22616`_: (*alxbse*) add initial support for WinRM in Windows cloud deployment
  @ *2015-04-15T15:55:30Z*

  - **ISSUE** `#15984`_: (*bkeroack*) salt-cloud windows minion installation fails
    | refs: `#22616`_
  * b8e0638 Merge pull request `#22616`_ from alxbse/winrm-support
  * 3145241 fix pylint errors

  * b7db208 add initial support for WinRM in Windows cloud deployment

- **PR** `#22406`_: (*babilen*) Fix handling of disabled apt repositories in pkgrepo.managed
  @ *2015-04-15T15:23:08Z*

  * 1c2a2fa Merge pull request `#22406`_ from babilen/dev-pkgrepo
  * 28bb352 Remove broken disabled comps handling in aptpkg

  * c52e9a9 Remove enabled option from pkgrepo.managed

* accb3e1 Merge branch 'marianuspotratz-add-profiling-to-terse-output' into develop


  * 0b864a8 fix spacing issue

  * 2da2b7a Merge branch 'add-profiling-to-terse-output' of https://github.com/marianuspotratz/salt into marianuspotratz-add-profiling-to-terse-output

  * ad5ebde Adds profiling to highstate terse output.

- **PR** `#22695`_: (*claudiupopescu*) Fixes yaml block indentation for GlusterFS state
  @ *2015-04-15T14:15:16Z*

  * 9cc388c Merge pull request `#22695`_ from claudiupopescu/glusterfs_doc_fix
  * 2a5098d Fixes yaml block indentation

- **PR** `#22689`_: (*mgwilliams*) make salt-key work with tcp transport
  @ *2015-04-15T01:45:27Z*

  * c5f814b Merge pull request `#22689`_ from mgwilliams/tcp-key
  * 87362fd fix salt-key display for tcp transport

  * b258875 make salt-key work with tcp transport

- **PR** `#22680`_: (*rallytime*) Pylint fix for develop
  @ *2015-04-15T01:39:09Z*

  * 79e0961 Merge pull request `#22680`_ from rallytime/moar_pylint
  * 3cc8788 Pylint fix for develop

- **PR** `#22611`_: (*mgwilliams*) use cached connection in boto_* modules
  @ *2015-04-15T01:27:46Z*

  * 0408bfe Merge pull request `#22611`_ from mgwilliams/boto_utils
  * 88d3d30 boto_vpc: one last lint fix

  * 220c933 boto_*: fix incorrect pylint exceptions

  * 8fa76d7 lint on boto_vpc_test

  * 9228f13 lint on boto_rds

  * 7df4bd1 lint on boto_sns

  * 77f60fb lint on boto_route53

  * 6b56407 lint on boto_dynamodb

  * f8a6082 lint on boto_vpc

  * 46bde83 Merge remote-tracking branch 'origin/develop' into boto_utils

- **PR** `#22673`_: (*cachedout*) Fix broken salt-tcpdump
  @ *2015-04-14T19:36:04Z*

  * e20e2ae Merge pull request `#22673`_ from cachedout/fix_tcpdump
  * c324e56 Fix broken salt-tcpdump

- **PR** `#22665`_: (*rallytime*) Python 3 compat changes to salt/states/boto_vpc.py
  @ *2015-04-14T18:55:57Z*

  * c2f4b64 Merge pull request `#22665`_ from rallytime/pylinting
  * 32e20f3 Python 3 compat changes to salt/states/boto_vpc.py

- **PR** `#22646`_: (*claudiupopescu*) Boto EC2 instance attributes
  @ *2015-04-14T16:44:49Z*

  * 7d418be Merge pull request `#22646`_ from claudiupopescu/boto_ec2_attributes
  * 4efcf82 Fixes pylint

  * b80b263 Changed return

  * df917fa Adds support for getting and setting ec2 instace attributes

- **PR** `#22657`_: (*rallytime*) Python 3 Compat for new transport files
  @ *2015-04-14T16:10:49Z*

  * 3fa1392 Merge pull request `#22657`_ from rallytime/pylint_develop
  * 63c3ada Python 3 Compat for new transport files

- **PR** `#22628`_: (*thatch45*) Merge `#22527`_
  @ *2015-04-14T16:06:11Z*

  * 26420c3 Merge pull request `#22628`_ from thatch45/claudiupopescu-boto_vpc_route_table_subnets
  * 8259770 disable silly lint

  * c742cec Merge branch 'boto_vpc_route_table_subnets' of https://github.com/claudiupopescu/salt into claudiupopescu-boto_vpc_route_table_subnets

    * b6f4b9f Documentation updates and fixes changes dictionary update

    * 1990b84 Fixes some pylint

    * fe11e59 Adds support for boto vpc subnet associations

- **PR** `#22620`_: (*kwadrat*) Fix Messaging, indicate incomprehensible word
  @ *2015-04-14T15:32:22Z*

  * bb528b6 Merge pull request `#22620`_ from kwadrat/develop
  * 148ec13 Fix word activating

  * 709df55 Fix Messaging, indicate incomprehensible word

- **PR** `#22648`_: (*isbm*) Bugfix: Report all FS types, if filter was not specified.
  @ *2015-04-14T15:09:45Z*

  * 1e74730 Merge pull request `#22648`_ from isbm/isbm-fsutils-fixes
  * 5d77dce Report all FS types, if filter was not specified.

- **PR** `#22635`_: (*BretFisher*) give SmartOS/sunos5 the correct CONFIG_DIR
  @ *2015-04-14T14:39:58Z*

  - **ISSUE** `#22634`_: (*BretFisher*) Default CONFIG_DIR on SmartOS is wrong in salt/syspaths.py
    | refs: `#22635`_
  * 2fc5a0f Merge pull request `#22635`_ from BretFisher/sunos5_config_dir
  * cb36f1a give SmartOS/sunos5 the correct CONFIG_DIR

- **PR** `#22629`_: (*ngrennan-inflection*) Adding ssh_priv option in master configuration file to allow use of agent-forwarding
  @ *2015-04-14T14:35:33Z*

  - **ISSUE** `#22618`_: (*ngrennan-inflection*) salt-ssh doesn't allow use of agent forwarding
    | refs: `#22629`_
  * cdb65bc Merge pull request `#22629`_ from ngrennan-inflection/develop
  * 428b24b Adding ssh_priv option in master configuration file to allow use of agent-forwarding

- **PR** `#22632`_: (*jacksontj*) Add some support pyzmq 13.0.x
  @ *2015-04-14T02:54:42Z*

  - **PR** `#22453`_: (*jacksontj*) Abstracted Transport
    | refs: `#22632`_
  * e8f521e Merge pull request `#22632`_ from jacksontj/transport
  * 435fc7b Add some support pyzmq 13.0.x

- **PR** `#22627`_: (*jfindlay*) fix develop lint
  @ *2015-04-14T00:24:38Z*

  * a0f0303 Merge pull request `#22627`_ from jfindlay/dev_lint
  * 3226c6c further saltnado lint

  * 3f1558b No reason to implement get_app in the mixin

  * 1372489 Remove unused method

  * 16bc3d0 Pylint fixup

- **PR** `#22619`_: (*vladionescu*) Fixed issue `#22609`_ - yumpkg.group_list is now RHEL 7 (yum 3.4.3) compatible
  @ *2015-04-13T22:50:04Z*

  - **ISSUE** `#22609`_: (*vladionescu*) pkg.group_list does not correctly interpret yum output
    | refs: `#22619`_
  * 4e0c7e7 Merge pull request `#22619`_ from vladionescu/22609
  * d3c379c Fixed issue `#22609`_ - yumpkg.group_list is now RHEL 7 (yum 3.4.3) compatible

          * afb52ec boto_*: a third attempt at making lint happy

          * 709ae7e boto_*: another attempt at making lint happy

          * d42325d utils.boto: tweak BotoExecutionError

          * 9f7294d Merge remote-tracking branch 'origin/develop' into boto_utils

* a78a501 Merge branch '0xf10e-develop' into develop


  * 0049a05 lint

  * e5320f6 Merge branch 'develop' of https://github.com/0xf10e/salt into 0xf10e-develop

  * c36fb72 Replace '%s' in parameter command with minion_id

  * 3632365 merge with current salt develop

  * fb4d96d Added get_net_size() and prefixlen_to_netmask to module network.

  * 87f9b20 use ValueError instead of unspecific Exception

  * 295a8b7 make pylint 0.09 points happier

  * 424d087 Workaround b/c salt.utils.network isn't a refreshable module.

  * 10079bf add netmask_to_prefixlen to salt.utils.network and make it available through network.netmask_to_prefixlen

  * ac53869 and now network.get_routes(dest=default) works

  * 1e27f20 now actually including the gateway in the routes returned

  * c66d443 Linux-specific network.get_route(iface=None)

          * b8ead7a utils.boto get_exception -> class

          * b01ef9e Merge remote-tracking branch 'origin/develop' into boto_utils

- **PR** `#22094`_: (*gladiatr72*) fine tuning systemd support (or, how not to destroy open-file limits when upgrading your salt-master)
  @ *2015-04-13T21:47:34Z*

  * 2364dfd Merge pull request `#22094`_ from gladiatr72/RPM_systemd_NOFILE
  * 307ded4 salt-api.service:LimitNOFILE=8192 salt-master.service:LimitNOFILE=16384 salt-minion.service:LimitNOFILE=8192 salt-syndic.service:LimitNOFILE=8192

  * 9980a25 At the very least there should be a comment of some sort indicating what directive needs to be set.

  * 8483fd3 Old crufty patches

  * 88be7b3 This is the (RPM) spec file used by Erik Johnson for building EPEL packages.

  * ab4bd93 The spec file for salt-api is anachronistic at this point

- **PR** `#22622`_: (*rallytime*) Apply release note fix to develop branch
  @ *2015-04-13T21:35:11Z*

  * 7f00493 Merge pull request `#22622`_ from rallytime/apply-22621-develop
  * becc997 Apply release note fix to develop branch

- **PR** `#22614`_: (*rallytime*) Apply release note change to develop
  @ *2015-04-13T21:26:25Z*

  * 8712a8b Merge pull request `#22614`_ from rallytime/apply-22610
  * 1f243d6 Apply release note change to develop

- **PR** `#22588`_: (*claudiupopescu*) Boto ElastiCache support for subnet_groups
  @ *2015-04-13T20:38:45Z*

  * efb53cb Merge pull request `#22588`_ from claudiupopescu/elasticache_subnet_group_support
  * 08c4941 Fixes pylint

  * 7a5a371 Adds support for subnet_groups and syntax changes

- **PR** `#22587`_: (*isbm*) Bugfix: fsutils
  @ *2015-04-13T20:35:40Z*

  * 205d84f Merge pull request `#22587`_ from isbm/isbm-fsutils-bugfix
  * 0beaf12 Preserve type if not specified

  * 0341f4e Dead code removal

- **PR** `#22600`_: (*nmadhok*) additions to doc
  @ *2015-04-13T20:26:07Z*

  * 211120f Merge pull request `#22600`_ from nmadhok/develop
  * 2fe7669 Merge branch 'develop' of https://github.com/saltstack/salt into develop

  * 031bb2b Merge branch 'develop' of https://github.com/saltstack/salt into develop

  * 39f31b1 Adding salt.engines.sqs_events.rst to doc

  * 87e70a7 Adding salt.engines.logstash.rst to doc

- **PR** `#22581`_: (*claudiupopescu*) Boto RDS bug fixes and adds support for subnet_group
  @ *2015-04-13T20:25:56Z*

  * f8ca4a3 Merge pull request `#22581`_ from claudiupopescu/boto_rds_subnet_support
  * a2d5281 Fixes lint error

  * 9660b82 Fixes parameters passed to subnet_group_absent

  * 7d2e340 Added subnet_group_absent and fixes minor dict returns

  * 9bac8a4 Minor naming fixes

  * 6deeb38 Fixes some bugs and adds subnet_group_present

- **PR** `#22575`_: (*unicolet*) fix infinite loop introduced by `#20124`_ when init (/proc/1/cmdline) is not in the supported_inits list
  @ *2015-04-13T20:25:06Z*

  - **PR** `#20124`_: (*cgtx*) add init system to default grains
  * 1725ee3 Merge pull request `#22575`_ from unicolet/pullrequests/saltgrains/initloop
  * e6dd369 fix infinite loop introduced by `#20124`_ when the init system is not in the supported_inits list

- **PR** `#22573`_: (*Chronojam*) Fileclient get dir improv
  @ *2015-04-13T20:22:55Z*

  * a558448 Merge pull request `#22573`_ from Chronojam/fileclient_get_dir_improv
  * d717850 removed warning log

  * 1d3fc5a added prefix to cp.get_dir when fetching file list

- **PR** `#22565`_: (*kaszuba*) Increase frequency of ssh terminal output checking
  @ *2015-04-13T20:15:56Z*

  * 0a1bc64 Merge pull request `#22565`_ from kaszuba/speedup-salt-ssh-execution
  * 935f0b2 Increase frequency of ssh terminal output checking

- **PR** `#22563`_: (*kaszuba*) Fix for high cpu usage by salt-ssh
  @ *2015-04-13T20:14:54Z*

  * 0d63b8f Merge pull request `#22563`_ from kaszuba/fix-salt-ssh-high-cpu-load
  * 6612048 Remove blank line

  * b220d0e Fix for high cpu usage by salt-ssh

                * 5d9a1f7 boto_elb: let connection errors bubble up

                * 66f3c41 fix boto_ tests for use with utils.boto

                * 36a01c4 use utils.boto in boto_sqs

                * 66d22ce use utils.boto in boto_sns

                * f0b89ea use utils.boto in boto_route53 and boto_secgroup

                * bf7bee7 use utils.boto in boto_iam and boto_rds

                * 5f03b0d use utils.boto in boto_elb

                * 89d6bbc use utils.boto in boto_elasticache

                * 751081b modules.boto_dynamodb: remove unused import

                * 5f7bd48 use utils.boto in dynamodb; return false instead of none for dynamodb.exists

                * 4e69635 use utils.boto in boto_cloudwatch

                * 5e5204c use utils.boto in boto_cfn

                * 0249e84 use utils.boto in asg, and ec2

                * 00f170b make pylint happy

                * 2a392d5 utils.boto: pass module arg in get_connection_func

                * 7d78a8c modules.boto_vpc: add profile back to _get_conn

                * 6d4947d utils.boto add "assign_funcs" convenience function

                * 1c9a01b Merge remote-tracking branch 'origin/develop' into boto_utils

- **PR** `#22591`_: (*mgwilliams*) utils.boto: convenience partials
  @ *2015-04-13T17:59:24Z*

  * dcfe4cc Merge pull request `#22591`_ from mgwilliams/boto_utils
- **PR** `#22545`_: (*dmyerscough*) Digital Ocean APIv2 Integration Testing
  @ *2015-04-13T17:17:20Z*

  * 2d9b6eb Merge pull request `#22545`_ from dmyerscough/digital-ocean-v2-tests
  * f51fd03 Fix pylint error

  * c6e618b Digital Ocean APIv2 Integration Testing

                * 8259417 modules.boto_vpc: remove unneeded code

                * 4959bf4 modules.boto_vpc use utils get_conn and cache_id

    * 45b118f Merge remote-tracking branch 'origin/develop' into boto_utils

- **PR** `#22453`_: (*jacksontj*) Abstracted Transport
  | refs: `#22632`_
  @ *2015-04-13T15:38:52Z*

  * 6a11ead Merge pull request `#22453`_ from jacksontj/transport
  * 4c5ac66 pylint cleanup

  * df0c170 Set a linger of 0 on the stream's socket, and dont try to close twice

  * 66016ed pylint

  * 6cd6055 Add workaround to a bug in pyzmq's stream.close()

  * 8ff37b3 Check for FDs attached to the IOLoops after test runs

  * 88ad56c Make sure to close sockets on deletion of pubchannels as well

  * 069af4b Destructors for the transport classes

  * 48095e1 More proactive cleanup in sync wrapper

  * 3971b72 Remove unused imports

  * 7433194 fix typo

  * 106f091 pylint cleanup

  * a85de89 pylint cleanup

  * 7674b1f pylint cleanup

  * 92ff4ff typo fixing!

  * 3b7170d Add initial transport docs

  * c47685f Correct comment of wire-protocol

  * ce850a3 pylint cleanup

  * f07840f pylint cleanup

  * 6a34d1d Remove AES key initing-- since we are mocking out _send_pub

  * 11e8a15 pylint cleanup

  * 4f46fa3 pylint cleanup

  * 1f963df pylint cleanup

  * e0e8868 Clean up flo zmq deed, since we have changed the MWorker

  * 7a3cca4 pylint cleanup

  * a2bc334 pylint cleanup

  * 10ec334 pylint cleanup

  * f6e239a pylint cleanup

  * 6b3d1bc pylint cleanup

  * 5c7df14 pylint cleanup

  * 4ee8c2e pylint cleanup

  * a30a0f8 pylint cleanup

  * 2683843 pylint cleanup

  * cc06dd6 Pylint

  * 171bd32 Pylint cleanup in TCP transport module

  * 9ad56d4 Pylint

  * 098515b Pylint

  * 348118f Mock/stub out _send_pub in ClearFuncs

  * bf97e8c Make sure to close server processes after each test.

  * f5e2650 Add basic tests for asyncEventpublisher

  * 0f4126a Cleanup AsyncEvent publisher

  * cb02d0e Remove "close()" api-- just use a destructor

  * d21e180 Fix race condition in integration test startup

  * dfd606a Add tornado dependancy

  * 1e38bd1 Fix merge

  * b673dcf Lint cleanup

  * 396f021 More cleanup of tcp wire framing-- pushing msgpacks down a layer

  * 0363cf3 Simplify TCP wire protocol

  * 2781cb8 Make sure to hand out RAET channels on the old interface

  * 3b5281f Term context of AsyncEventPublisher on destroy()

  * bedde63 SNDTIMEO is not implemented in pyzmq, and since we are using linger this gets us the same thing

  * d87c62b Make transport unit tests pull configs from test suite instead of from /etc/salt

  * d626d83 Handle case where we miss first sign-in

  * 02995a1 Fix calls to send() to not specify a callback of int

  * ec4a777 Share creds between all channels (if you can).

  * e17824a Change _handle_payload to return a future.

  * 9affc2d Overwrite the current IOLoop for blocking calls

  * e372de4 Cleanup auth future, and pass io_loop to instance

  * b330052 Better message_id handling

  * 98842a8 Fix zmq pub channels

  * 61eb58c Migrate zeromq req channel to async interfaces

  * cb92263 Attempt to return nice errors even if it wasn't properly msgpackd

  * b625b01 Properly bubble up auth failures to the future

  * d325de0 Fix exceptional case where no timeout is set

  * 49603ff Add weakref to SAuth

  * 8ec0729  Change the Auth base class to AsyncAuth

  * aac2337 Move syncwrapper to utils-- since we'll have more uses for it

  * e89da4e Make AsyncAuth singleton per io_loop

  * c6245c8 Reset asyncauth singleton in tests

  * 952d724 Switch tcp req channel over to async auth libraries

  * f7c7551 Remove sleep from saltmessageclient

  * cade95a Make Sync wrapper for async req channels

  * fd4fff8 Misc cleanup

  * c755328 Fix rebase collisions

  * 30f9d37 Merge cleanup

  * 98b53bd Fix mocking, not quite sure how this magic mock works

  * e04ef8b Always attempt to send errors to clients

  * 540710c Cleanup shutdown of tests

  * c855770 Fix misc tests

  * b1ca45d Refactor pub tests

  * 2ce0582 Add unregister tests

  * 9ec426b Add basic Asyncpubchannel tests to zmq

  * a68cf08 Remove remnants of old Sync pub channel

  * b470346 Change pubchannel over in zeromq

  * cd2c816 Fix syndic event forwarding

  * 181b12c Remove threading from MultiSyndic

  * a998eb0 Make destroy properly unload things

  * 50fc615 More cleanup

  * 2c36c95 Cleanup

  * bdc5d6d Remove threading from MultiMinion

  * 6410b40 We aren't doing singleton module loaders, lets not clear what we just made

  * bfeb3bf Misc cleanup to get the minion to use async sign_in

  * bdbf6a3 misc cleanup

  * 6ab5da8 Cleanup async

  * de26e7e Handle timeouts in auth/pub connect

  * 8c7ee31 Begin work on async auth/pub/req channels.

  * 1a88eee Add basic Pub channel tests

  * d619dfb Add initial req_channel tests

  * 00021ce Pylint

  * 4baec17 Remove unecessary imports

  * b9d03c5 Remove recv() from pub_channels (now we use on_recv)

  * 9094c10 Since each minion object handles its own events, lets not double send :)

  * 4dd74a1 Remove Event poller (since we are doing IOLoops now)

  * 9cda2f0 Cleanup multiminion to work on the ioloop

  * e11a914 Add support for un-registering the on_recv

  * 1392cd6 Add timeouts to tcp implementation

  * 5fb59c8 Cleanup some IOLoops

  * 714e61f Don't set 'enc' to clear on clear returns, some jobs don't return dicts

  * 71c8dea loop_interval is a float, lets leave it that way

  * 180408e Make publisher not wait for writes

  * 034df05 Last switch over to iter_transport_opts (support 1->N transports)

  * f22539d Make SaltMessageClient auto-reconnect

  * 78b69b1 Add scheduler

  * 54f4760 cleanup

  * 58982b0 Cleanup pub channel

  * 8ab5fdc Basic multisyndic working now

  * 798c062 Misc cleanup to single minion

  * 58c16f2 Rough-in of io_loop in minion

  * 8750875 Logging cleanup

  * 759f5b3 consolidate master-side transport parsing

  * b192602 Switch Req client over to tornado based client

  * d2bfe50 Very basic zmq and tcp support

  * c1b41b2 Migrate zeromq channel over to ioloop as well

  * 35977e4 Misc cleanup

  * 9d60629 Add un-tested SaltMessageClient

  * 5bee564 Switch ReqServer over to IOLoop

  * b1bb0d6 fix typo

  * 2336b33 Allow passing in of header

  * 0b03534 move publisher to IOLoop

  * 4ff4bfb Cleanup shutdown of publisher

  * 8815bf3 Fix socket recv_frame

  * ae0d92a Don't make a copy of the list to iterate (it might be very large). Instead keep a list of who to remove

  * de21707 cleanup

  * b7f4fc2 Remove rep_hwm (doesn't do anything)

  * fb107b0 Whitespace cleanup

  * 5492036 Misc cleanup

  * 543c56d Revert register poller, we'll just have the minion exit

  * 6d372d7 ReqChannel cleanup

  * 374d415 Re-work PubChannel

  * fc83b44 Major overhaul of tcp implementation

  * 11195c4 Cleanup pubchannel polling

  * 5731a01 Remove testing code

  * 4bd71f9 More hacking to get tcp working

  * 6fb0ec1 Initial addition of tcp channel

  * 0a0caf6 Hacking to fix various things broken in rebase

  * 8e0316d Misc cleanup

  * 0ddd4ec Migrate _auth logic into the ReqServerChannel

  * ea49cbc Change req_fun default to send (which is encrypted)

  * 422d1c2 Re-work req_channel in the master daemons, now we don't pass it down the stack, the master-side funcs need to return a dict of opts which specify which send_func to use

  * 8c66c4e Initial move of publisher into PubServerChannel

  * f128e47 Initial migration of master-side ReqChannels

  * 5ae95ff Rename channel to client

  * 1ffac59 Add local channel to factory

  * 5e661b0 Pull all fallback cleanup into its own function

  * 10e3ec8 Remove old refs to _init_context_and_poller

  * fef2e38 Remove some noe-deprecated and unused functions

  * 2b0d1e5 Refactor minion events to be their own class instead of spread throughout the minion classes

  * 21624eb Remove all final references to self.socket from minion.py

  * d406b2e Add "socket" interface to pub_channel, so we can wire it into regular pollers

  * 7bbfba2 More migration to PubChannel

  * 645eaf0 Cleanup print from debugging

  * 87fb069 Implement timeout for PubChannel.recv()

  * 3290c32 Remove some unused imports

  * 064896d Update commented out version as well

  * e376b28 Refactor the start_daemon function

  * 403c81c Move daemon init and execution into the same process.

  * 8996493 Misc cleanup after rebase

  * 62d9d3c Switch remaining uses of sreq to channel

  * 7c93360 More work to remove minion.authenticate()

  * fa94083 Consolidate socketopts into channel

  * e8b3105 Rebase in current develop, and add in recv_noblock

  * ce04827 A few hacks to get some basic pubchannel working

  * 3bf28b1 Refactor channel classes to have separate pub/req channels

- **PR** `#22577`_: (*claudiupopescu*) Boto VPC subnet within AZ
  @ *2015-04-13T15:11:12Z*

  * 89c166b Merge pull request `#22577`_ from claudiupopescu/boto_vpc_subnet_create_fix
  * bbb3884 Fixes subnet availability zone

- **PR** `#22572`_: (*The-Loeki*) Small docfix for GitPillar
  @ *2015-04-13T15:03:44Z*

  * 549ecd3 Merge pull request `#22572`_ from The-Loeki/patch-1
  * 9282960 Small docfix for GitPillar

- **PR** `#22567`_: (*nmadhok*) Adding list_snapshots() in vmware cloud driver to be able to list snapshots
  @ *2015-04-13T01:41:45Z*

  * b7362ee Merge pull request `#22567`_ from nmadhok/vmware-cloud-driver
  * 208f1df Be able to list snapshot only for a specific vm/template

  * 5caa7be Adding list_snapshots() to be able to list all snapshots for all VMs and templates across the VMware environment

  * b9c8992 Clean up

- **PR** `#22554`_: (*ezheidtmann*) Add `fetch_tags` option to state git.latest. See `#10141`_
  @ *2015-04-12T22:29:32Z*

  - **ISSUE** `#10141`_: (*Lothiraldan*) Git state doesn't fetch tags before trying to checkout to it
    | refs: `#22554`_
  * daaf8f9 Merge pull request `#22554`_ from ezheidtmann/fetch-tags-10141
  * 779951e Add `fetch_tags` option to state git.latest

- **PR** `#22551`_: (*basepi*) Make test.fib much more naive
  @ *2015-04-12T22:25:02Z*

  * 148ee03 Merge pull request `#22551`_ from basepi/test.fib
  * c4dd68b Force num to int

  * 5b6d410 Fix calltest

  * 99744b9 Fix lint

  * cc8785e Fix the test.fib tests

  * db76878 Fix lint

  * 361f407 Fix typo

  * 27768fc Get rid of timing delay by using helper method

  * 2095e4c Make test.fib much more naive

- **PR** `#22560`_: (*kiorky*) check if docker is running
  @ *2015-04-12T17:41:59Z*

  - **ISSUE** `#22559`_: (*kiorky*) docker module breaks current salt/develop
    | refs: `#22560`_
  * 765dda9 Merge pull request `#22560`_ from makinacorpus/d
  * 16ec10a check if docker is running

- **PR** `#22483`_: (*nmadhok*) Adding more features to vmware cloud driver
  @ *2015-04-12T00:31:03Z*

  * bbdf316 Merge pull request `#22483`_ from nmadhok/vmware-cloud-driver
  * ca0ffdc Lint fix

  * 0dfab26 Making the regular expression more accurate

  * 4ab84a6 Adding some documentation

  * 6dc128f Destroy should return a boolean True not a string

  * 8ea4c6d Merge branch 'develop' of https://github.com/saltstack/salt into vmware-cloud-driver

  * 9d57bfc Wait for ip first then return data

  * a869bff Adding list_nodes_full() and ability to bootstrap salt after getting ip

  * 16540a4 Removing more extra blank lines

  * abe6bf5 Removing extra blank lines

  * 48a37c0 Adding ability to assign static ip to nic or get ip from dhcp automatically

  * e77208e Listing datastore information as well for each hard disk

- **PR** `#22546`_: (*terminalmage*) Quiet noisy log entry in smbios execution module
  @ *2015-04-11T09:32:58Z*

  * 6ea0696 Merge pull request `#22546`_ from terminalmage/quiet-smbios-logging
  * 752cc48 clarify log message

  * 77d84b1 Quiet noisy log entry in smbios execution module

- **PR** `#22539`_: (*rallytime*) Python 3 compat fix
  @ *2015-04-10T21:56:53Z*

  * e4d96b0 Merge pull request `#22539`_ from rallytime/pylint-fix
  * 38e562a Python 3 compat fix

- **PR** `#22508`_: (*semarj*) allow disabling auth on webhook endpoint in rest_tornado
  @ *2015-04-10T20:26:09Z*

  * 02d6c52 Merge pull request `#22508`_ from semarj/add-disable-webhook-auth
  * 46a25b5 missed switch to build_tornado

  * d9ed9f1 fix linting errors

  * c56845e include mod_opts on tornado application, refactor get_app

  * 2f0041b fix test

  * 71f8eb8 allow disabling auth on webhook endpoint in rest_tornado

- **PR** `#22538`_: (*rallytime*) Fix some broken links on the contributing docs
  @ *2015-04-10T20:07:44Z*

  - **ISSUE** `#22537`_: (*gravyboat*) Broken link in contributing docs
    | refs: `#22538`_
  * 1fb5d49 Merge pull request `#22538`_ from rallytime/`fix-22537`_
  * ccfa9f8 Fix some broken links on the contributing docs

- **PR** `#22399`_: (*cachedout*) Add event returner to hipchat
  @ *2015-04-10T15:25:31Z*

  * e4d9da5 Merge pull request `#22399`_ from cachedout/hipchat_event_return
  * 75dd135 Lint

  * 5898cf5 Add event returner to hipchat

- **PR** `#22478`_: (*s0undt3ch*) Restore old single package query behaviour
  @ *2015-04-10T15:14:55Z*

  * 06a6945 Merge pull request `#22478`_ from s0undt3ch/hotfix/opensuse-pkg-tests
  * a5fb727 Restore old single package query behaviour

- **PR** `#22469`_: (*mgwilliams*) boto utils module
  @ *2015-04-10T15:14:20Z*

  * 71e14cb Merge pull request `#22469`_ from mgwilliams/boto_utils
- **PR** `#22465`_: (*tsaridas*) create_access_key state
  @ *2015-04-10T15:12:04Z*

  * 9e08959 Merge pull request `#22465`_ from tsaridas/iam_keys_state
  * 15c2d11 pylint

  * be83007 pylint

  * 3a254a6 create_access_key state

- **PR** `#22524`_: (*kwadrat*) Fix misspellings
  @ *2015-04-10T15:06:27Z*

  * 00cc27e Merge pull request `#22524`_ from kwadrat/develop
  * 6789306 Fix misspellings

- **PR** `#22519`_: (*dmyerscough*) DigitalOcean allow users to upload public keys
  @ *2015-04-10T11:51:07Z*

  * 673f4aa Merge pull request `#22519`_ from dmyerscough/digital-ocean-create-key
  * f1da369 DigitalOcean allow users to upload public keys

- **PR** `#22515`_: (*s0undt3ch*) Fix import
  @ *2015-04-10T02:49:59Z*

  * 5e7fba6 Merge pull request `#22515`_ from s0undt3ch/develop
  * 0651c06 Fix import

- **PR** `#22489`_: (*dmyerscough*) Firewalld initial state
  @ *2015-04-09T15:11:14Z*

  * 1616171 Merge pull request `#22489`_ from dmyerscough/firewalld-initial-state
  * 870a042 Firewalld state - allow users to run test mode

  * e0ef79a Initial Firewalld state

- **PR** `#22485`_: (*davidjb*) Correctly report disk usage on Windows
  @ *2015-04-09T04:49:45Z*

  - **ISSUE** `#16508`_: (*o1e9*) wrong disk.usage reported for very big RAID disk
    | refs: `#22485`_
  * 60add3e Merge pull request `#22485`_ from davidjb/develop
  * 91efc0f Correctly report disk usage on Windows. Fix `#16508`_

- **PR** `#22486`_: (*davidjb*) Update git URL & formatting for Windows install
  @ *2015-04-09T04:45:21Z*

  * a92d862 Merge pull request `#22486`_ from davidjb/patch-1
  * 22ad5d0 Update git URL & formatting for Windows install

- **PR** `#22481`_: (*clinta*) bad logic in checking for x509 extensions
  @ *2015-04-09T04:42:47Z*

  * 814697a Merge pull request `#22481`_ from clinta/x509
  * a827720 bad logic in checking for x509 extensions

- **PR** `#22480`_: (*thatch45*) Add sudo user docs into salt
  @ *2015-04-08T22:25:26Z*

  * 6265e21 Merge pull request `#22480`_ from thatch45/sudo_user_doc
  * 457ec17 Add sudo user docs into salt

- **PR** `#22479`_: (*s0undt3ch*) Get the first iteration the right way
  @ *2015-04-08T20:05:54Z*

  * 29bdce8 Merge pull request `#22479`_ from s0undt3ch/develop
  * 35b3cdc Get the first iteration the right way

- **PR** `#22458`_: (*The-Loeki*) Python 2.6 / Documentation fixes for smbios module
  @ *2015-04-08T15:09:00Z*

  - **ISSUE** `#22327`_: (*bradthurber*) latest develop branch syntax error on salt-master startup
    | refs: `#22331`_
  - **PR** `#22331`_: (*rallytime*) Fix python 2.6 syntax error in salt/grains/core.py
    | refs: `#22458`_
  * 2701e15 Merge pull request `#22458`_ from The-Loeki/smbios-module
  * 527e0ad Python2.6 fixes Documentation fixes

- **PR** `#22437`_: (*nmadhok*) Adding avail_images() and show_instance() to vmware cloud driver
  @ *2015-04-08T04:22:59Z*

  - **PR** `#22258`_: (*nmadhok*) Creating vmware cloud driver
    | refs: `#22437`_
  * 6fcdeb4 Merge pull request `#22437`_ from nmadhok/vmware-cloud-driver
  * df6711f Fixing lint

  * a532d9c Removing unwanted line

  * 1928bce Removing extra new line

  * fddee63 Adding show_instance() action to be able to show full details about the specified VM/template

  * 2631763 Adding avail_images() so that --list-images can be used

          * b3ec570 utils.boto: add convenience partials

        * 4976f86 utils.boto unit test -- use utf-8 encoding

        * baa97d3 utils.boto: use get_exception in the get_connection function

        * d642b5b utils.boto: fix missing import and add regression test

        * 526579c utils.boto: fix whitespace

        * 28f3e5d utils.boto: add get_exception

        * 0ef308f utils.boto: add docstring for cache_id

        * e222922 tests for utils.boto

        * 965d91f [WIP] utils.boto

- **PR** `#22438`_: (*garethgreenaway*) HTTP Return Code Cleanup
  @ *2015-04-07T22:34:54Z*

  * 54ce98a Merge pull request `#22438`_ from garethgreenaway/http_return_code_cleanup
  * e6b847e Swapping out hardcoded HTTP return code numbers for their values from salt.ext.six.moves.http_client. Some typos in some documention for returners.

- **PR** `#22424`_: (*jfindlay*) add wake-on-lan unit tests
  @ *2015-04-07T21:45:47Z*

  * 408cfb2 Merge pull request `#22424`_ from jfindlay/network_tests
  * 2ef39ed add wake-on-lan unit tests

- **PR** `#22430`_: (*cachedout*) Display documention when the CLI gets bad function args
  @ *2015-04-07T20:50:20Z*

  * 2ceea0e Merge pull request `#22430`_ from cachedout/display_docs
  * 4e6ed60 Lint

  * 83c69b6 Display documention when the CLI gets bad function args

- **PR** `#22421`_: (*terminalmage*) docker-ng module updates
  @ *2015-04-07T20:38:44Z*

  * caff269 Merge pull request `#22421`_ from terminalmage/docker-ng
  * 8ef2406 Lint fixes

  * d9f082a Remove extraneous comment

  * 57a6b32 Add IP address validation functions to salt.utils.network

  * 5c2d621 Add input validation, bugfixes

  * fdf0c1b Add new functions to assist with docker state/module

- **PR** `#22432`_: (*cachedout*) Minion lint
  @ *2015-04-07T20:12:45Z*

  * 5643c7f Merge pull request `#22432`_ from cachedout/minion_lint
  * e95e533 Minion lint

- **PR** `#22428`_: (*garethgreenaway*) ps beacon
  @ *2015-04-07T20:10:58Z*

  * 55f4348 Merge pull request `#22428`_ from garethgreenaway/adding_ps_beacon
  * 9ebcdea Adding a beacon to monitor if processes are running or not running, depending on value passed, then fire an event.

- **PR** `#22429`_: (*tsaridas*) create_access_key
  @ *2015-04-07T19:52:21Z*

  * 52ab4f6 Merge pull request `#22429`_ from tsaridas/iam_create_access_keys
  * c26088b create_access_key

- **PR** `#22414`_: (*syphernl*) Cloud: Do not look for disk underneath config in Proxmox driver
  @ *2015-04-07T19:13:54Z*

  - **ISSUE** `#22382`_: (*ghost*) The 'proxmox' cloud provider alias, for the 'proxmox' driver, does not define the function 'disk'".
    | refs: `#22414`_
  * ff04f10 Merge pull request `#22414`_ from syphernl/fix/proxmox_kvm
  * 6cfaeda Lint

  * 2634242 Do not look for disk underneath config

- **PR** `#22423`_: (*terminalmage*) Remove reference to package changes
  @ *2015-04-07T18:42:13Z*

  * 9120d7d Merge pull request `#22423`_ from terminalmage/state-change-reporting
  * d0d6770 Remove reference to package changes

- **PR** `#22422`_: (*garethgreenaway*) Fixes to gpg module
  @ *2015-04-07T18:29:00Z*

  - **ISSUE** `#22415`_: (*analogbyte*) gpg module does not work correctly with user 'salt'
    | refs: `#22422`_
  * 907ec24 Merge pull request `#22422`_ from garethgreenaway/22415_gpg_module_fixes
  * 057677e Fixing the case where user=salt and trust_key attempts to run the gpg binary as the user salt, which doesn't exist.  Instead we set the homeDir as config-location/gpgkeys and run the command as root.  Also updating documention to reflect location for default 'salt' controlled GPG keys as config-location/gpgkeys rather than config-location/gpg

- **PR** `#22398`_: (*cachedout*) Catch and log failed engine starts
  @ *2015-04-07T15:34:23Z*

  * 7c54036 Merge pull request `#22398`_ from cachedout/catch_failed_engine
  * 668fa35 Lint

  * 775b3dc Catch and log failed engine starts

- **PR** `#22347`_: (*tsaridas*) Boto cfn
  @ *2015-04-07T15:10:25Z*

  * 8c2878c Merge pull request `#22347`_ from tsaridas/boto_cfn
  * 4f2d368 remove newline

  * 5b19d11 pylint + syntax

  * 4906c75 pylint

  * e1024db pylint

  * 0b28af6 cfn module + state

  * ab883a5 version

  * 990c4f8 Show exceptions

  * 2afaa7c Pylint

  * c0f452b .. versionadded:: Beryllium

  * 983bbd0 update_stack

- **PR** `#22413`_: (*rallytime*) Merge `#22397`_ with pylint fix
  @ *2015-04-07T14:07:45Z*

  - **PR** `#22397`_: (*cachedout*) More overstate deprecation warnings
    | refs: `#22413`_
  * 5d2d040 Merge pull request `#22413`_ from rallytime/merge-22397
  * 012853a Whitespace fix

  * dd080aa More overstate deprecation warnings

- **PR** `#22394`_: (*nmadhok*) Adding ability to vmware cloud create() so extra_config can be specified
  @ *2015-04-06T23:51:59Z*

  * 305ce35 Merge pull request `#22394`_ from nmadhok/vmware-extra_config
  * 99bc6c9 Add some more examples for extra_config to documentation

  * a659a39 Add some more examples for extra_config to documentation

  * 3746d37 Adding ability to vmware cloud create() so extra_config can be specified.

- **PR** `#22355`_: (*whiteinge*) Added a `cmd` method to the Caller() class for consistency with *Clients
  @ *2015-04-06T17:26:11Z*

  * a19340d Merge pull request `#22355`_ from whiteinge/caller-cmd
  * 786c598 Added a `cmd` method to the Caller() class for consistency with *Clients

- **PR** `#22185`_: (*isbm*) Nagios module bugfix and additional refactoring
  @ *2015-04-06T17:23:11Z*

  * f8b35d7 Merge pull request `#22185`_ from isbm/isbm-nagios-module-opts
  * 548a2c0 Lintfix

  * 380b316 Refactor the underlying status query function

  * 6681c84 Bugfix and refactor: data was read twice from the request

  * 1abca1e Refactor service_status

  * 7af5fe3 Config is no longer needed in the interface function

  * 5e10237 Refactor host_status

  * b29fc49 Raise an exception if the initial parameters were wrong for service check

  * 8215d8d Raise an exception if the initial parameters were wrong for host check

  * 2634a99 Use exception on execution error

  * f012eaf Move config verification to the underlying function

  * 33ec5f5 Refactor

  * a07894d Verify URL in the config

  * 7caa2b6 Moved URL verification to the config processing

- **PR** `#22384`_: (*rallytime*) Pylint fixes for develop
  @ *2015-04-06T16:42:31Z*

  * 756bc15 Merge pull request `#22384`_ from rallytime/pylinting
  * c487476 Change longs to ints for python 3 compatibility

  * c2285c6 Move imports out of functions to top of file

- **PR** `#22373`_: (*nmadhok*) Vmware cloud driver refactors
  @ *2015-04-06T15:08:44Z*

  * 53ee793 Merge pull request `#22373`_ from nmadhok/vmware-cloud-driver
  * e106574 Doc changes and enhancements

  * d06295b Refactoring the way devices are created or configured

- **PR** `#22351`_: (*garethgreenaway*) Fix to salt/client/mixins.py
  @ *2015-04-06T14:22:07Z*

  - **ISSUE** `#22339`_: (*whiteinge*) Scheduler broken in 'develop': RuntimeError: dictionary changed size during iteration
    | refs: `#22351`_
  - **PR** `#22399`_: (*cachedout*) Add event returner to hipchat
  * 45b589c Merge pull request `#22351`_ from garethgreenaway/22339_kwargs_issue_in_mixins
  * ad26ca4 copying the kwargs argument to _kwargs, then iterating over that instead of kwargs.  Otherwise kwargs could change while we're iterating. `#22399`_

- **PR** `#22354`_: (*dmyerscough*) Unit test for firewalld features `#22292`_
  @ *2015-04-06T14:09:52Z*

  - **PR** `#22292`_: (*dmyerscough*) New features and bug fixes
    | refs: `#22354`_
  * 4a57d46 Merge pull request `#22354`_ from dmyerscough/firewalld-unittest
  * a42055d Remove duplicate test

  * 2aa0d85 Remove duplicate function

  * 38ce753 New features and updated unittests for new features

  * aefa84a Unittest for firewalld features 22292

- **PR** `#22362`_: (*msusta*) Fixed malformed locale string in localmod module
  @ *2015-04-06T14:07:46Z*

  * d3fe0fc Merge pull request `#22362`_ from msusta/bugfix/localemod-lang-string-malformed
  * 21ee817 Fixed malformed locale string in localmod module

- **PR** `#22367`_: (*lucacorti*) Add recursive database owner change to postgres module/state
  @ *2015-04-06T13:51:41Z*

  * 33ae6b6 Merge pull request `#22367`_ from lucacorti/develop
  * b574cc4 Merge branch 'develop' of https://github.com/saltstack/salt into develop

- **PR** `#22371`_: (*analogbyte*) make the redis-returner use a pipeline
  @ *2015-04-05T19:59:18Z*

  * 94a6b51 Merge pull request `#22371`_ from analogbyte/develop
  * 903e6f7 make the redis-returner use a pipeline

- **PR** `#22369`_: (*llua*) shell completion (zsh): bug fix and more improvements
  @ *2015-04-05T18:53:28Z*

  * 908885b Merge pull request `#22369`_ from llua/zsh-completion
  * c3feffd allow caching minions, modules, or salt_dir individually.

  * e384066 skip completing minions when -N or --grain-regex is used.

  * e419ce7 fix --doc, --return and --out from 68552fd4081311765a117aafda72c6cd828f23d1 by delaying the expansion of salt_dir.

- **PR** `#22363`_: (*nmadhok*) Adding functionality to create() in vmware cloud driver to be able to add/reconfigure network adapters
  @ *2015-04-05T14:32:42Z*

  - **PR** `#22340`_: (*nmadhok*) Adding functionality to create() in vmware cloud driver to be able to add/reconfigure hard disks
    | refs: `#22363`_
  * 9f2ada4 Merge pull request `#22363`_ from nmadhok/vmware-driver
  * c68a7cb Grammar correction in sentence

  * 4b7ac72 Adding versionadded to docs and author

  * 28fa708 Adding docs to be able to specify network adapter settings

  * 552a8d9 Ability to add new network adapter upon creation

  * dda5041 Refactoring and breaking things into simpler functions for reusability

  * 13163a3 Being able to change network on existing network adapter

    * b9b307f Fix postgres.db_alter test, add test for owner_recurse=True

    * 3aa4b3b Add recursive database owner change to postgres module/state

- **PR** `#22348`_: (*cachedout*) Document many core opts
  @ *2015-04-04T00:34:38Z*

  * 6ae9fe6 Merge pull request `#22348`_ from cachedout/document_core_opts
  * 3bc7450 Document many core opts

- **PR** `#22340`_: (*nmadhok*) Adding functionality to create() in vmware cloud driver to be able to add/reconfigure hard disks
  | refs: `#22363`_
  @ *2015-04-03T22:29:52Z*

  * 77f50bf Merge pull request `#22340`_ from nmadhok/drive-vmware
  * 3d54385 Lint

  * d8310c4 Forgot to uncommentcomment stuff

  * b227f3e Fixing a bug where hard disks where being added in random order

  * 6e93b11 Removing unnecessary warning. DRS is automatically applied if it is a cluster

  * 4203c1e Adding functionality to create to be able to add/reconfigure hard disks

- **PR** `#22307`_: (*EliRibble*) Fix issue `#22306`_
  @ *2015-04-03T20:59:04Z*

  - **ISSUE** `#22306`_: (*EliRibble*) S3 ext_pillar does not properly set pillar directory in multiple_env mode
  - **ISSUE** `#18355`_: (*mkotzev*) External pillar implementations do not allow multiple roots per environment
    | refs: `#22307`_
  * 64433d6 Merge pull request `#22307`_ from EliRibble/`fix-22306`_
  * d98136e Fix issue 22306

- **PR** `#22338`_: (*cachedout*) Drop noisy dmidecode logs down to trace and reformat them
  @ *2015-04-03T19:04:50Z*

  * 1cd0648 Merge pull request `#22338`_ from cachedout/dmi_log_format
  * 76f02a9 Drop noisy dmidecode logs down to trace and reformat them

- **PR** `#22333`_: (*cachedout*) Prevent process restart if event returner can't be reached
  @ *2015-04-03T18:54:18Z*

  * b12bbfd Merge pull request `#22333`_ from cachedout/catch_event_ret_exc
  * cebbad4 Prevent process restart if event retuerner can't be reached

- **PR** `#22334`_: (*jfindlay*) decrease specificity in schedule.modify unit test
  @ *2015-04-03T18:53:33Z*

  * d129122 Merge pull request `#22334`_ from jfindlay/fix_sched_test
  * 257a1ab decrease specificity in schedule.modify unit test

- **PR** `#22336`_: (*whiteinge*) Add new modules of all types to the module index
  @ *2015-04-03T18:52:50Z*

  * 4427915 Merge pull request `#22336`_ from whiteinge/doc-new-modules
  * 4cb33c9 Added autodoc generated pages for the new modules types

  * ef3893d Updated module index pages for each of the module types

- **PR** `#22331`_: (*rallytime*) Fix python 2.6 syntax error in salt/grains/core.py
  | refs: `#22458`_
  @ *2015-04-03T16:22:50Z*

  - **ISSUE** `#22327`_: (*bradthurber*) latest develop branch syntax error on salt-master startup
    | refs: `#22331`_
  * cfec0b4 Merge pull request `#22331`_ from rallytime/fix-syntax-error
  * ba440ed Fix python 2.6 syntax error in salt/grains/core.py

- **PR** `#22326`_: (*rallytime*) Patch decorators.which for network_test.test_arp
  @ *2015-04-03T15:44:37Z*

  * 74bc55a Merge pull request `#22326`_ from rallytime/fix_network_unittest
  * 39f3ff5 Patch decorators.which for network_test.test_arp

- **PR** `#22324`_: (*rallytime*) Add some versionadded infos to new firewalld funcs
  @ *2015-04-03T15:44:00Z*

  * d00a0e2 Merge pull request `#22324`_ from rallytime/versionadded_firewalld
  * 47a4f04 Add some versionadded infos to new firewalld funcs

- **PR** `#22323`_: (*rallytime*) Merge `#22248`_ with pylint fix
  @ *2015-04-03T15:43:09Z*

  - **PR** `#22248`_: (*mgwilliams*) make __utils__ available to execution modules
    | refs: `#22323`_
  * 75d21cc Merge pull request `#22323`_ from rallytime/merge-22248
  * fa434c5 Whitespace fix and remove duplicate import

  * 34edd21 make __utils__ available to execution modules

- **PR** `#22330`_: (*cachedout*) More to trace per comment in `#22303`_
  @ *2015-04-03T14:59:18Z*

  - **ISSUE** `#22204`_: (*dmyerscough*) Hostname unresolvable causes delays in grains
    | refs: `#22303`_
  - **PR** `#22303`_: (*dmyerscough*) Show what grains are being loaded when running debug level
  * 84fb57c Merge pull request `#22330`_ from cachedout/log_trace
  * 65b1183 More to trace per comment in `#22303`_

- **PR** `#22325`_: (*rallytime*) Fix pylint error for develop
  @ *2015-04-03T14:01:06Z*

  * f65f647 Merge pull request `#22325`_ from rallytime/fix-pylint
  * ea25e6c Fix pylint error for develop

- **PR** `#22292`_: (*dmyerscough*) New features and bug fixes
  | refs: `#22354`_
  @ *2015-04-03T12:41:48Z*

  * c22695d Merge pull request `#22292`_ from dmyerscough/firewalld-new-features
  * d7d669a Fix Lint Errors

  * e81ffa1 New features and bug fixes

- **PR** `#22310`_: (*rallytime*) Update sidebar and release candidate docs for rc2
  @ *2015-04-02T23:45:55Z*

  * 4374f4c Merge pull request `#22310`_ from rallytime/rc2_sidebar
  * 5cd2db2 Update sidebar and releasecandidate docs for rc2

- **PR** `#22305`_: (*cachedout*) Stream beacons and other events into Graphite
  @ *2015-04-02T23:43:23Z*

  * 4f881c4 Merge pull request `#22305`_ from cachedout/carbon_event
  * 121d937 Lint

  * 03be4f9 Change the load beacon slightly to normalize the data

  * f61ca21 It works!

- **PR** `#22303`_: (*dmyerscough*) Show what grains are being loaded when running debug level
  @ *2015-04-02T23:20:43Z*

  - **ISSUE** `#22204`_: (*dmyerscough*) Hostname unresolvable causes delays in grains
    | refs: `#22303`_
  * 3e6399d Merge pull request `#22303`_ from dmyerscough/22204-additional-logging
  * 485385d Show what grains are being loaded when running debug level

- **PR** `#22309`_: (*rallytime*) Add versionadded directive to file.line state
  @ *2015-04-02T23:11:25Z*

  * 6e77d85 Merge pull request `#22309`_ from rallytime/file-line-versionadded
  * c45f64c Add versionadded directive to file.line state

- **PR** `#22267`_: (*The-Loeki*) modify _hw core grains to use the new smbios module, add system uuid
  @ *2015-04-02T23:10:04Z*

  * 625cc26 Merge pull request `#22267`_ from The-Loeki/smbios-module
  * 5e4e4b8 little fixes

  * 48c8808 Reinsert comment

  * ed1e994 utilize new module in core grains

- **PR** `#22299`_: (*rallytime*) Python 3 compatibility changes for develop
  @ *2015-04-02T21:24:32Z*

  * 5376a13 Merge pull request `#22299`_ from rallytime/pylinting-develop
  * 9c2ebd1 Python 3 compatibility changes for develop

- **PR** `#22291`_: (*ticosax*) states.dockerio: Fix Bug introduced in cc1cd22471f39f9c3c56d105486feebd336a1fb9
  @ *2015-04-02T18:53:27Z*

  * b0f4077 Merge pull request `#22291`_ from ticosax/dockerio-fix-already-exists
  * 46481d3 Fix Bug introduce in cc1cd22471f39f9c3c56d105486feebd336a1fb9

- **PR** `#22289`_: (*achernev*) Expand glob patterns in the path argument of file.find
  @ *2015-04-02T18:53:07Z*

  - **ISSUE** `#16711`_: (*carlskii*) Calling file.find module from Python API with wildcards
    | refs: `#22289`_
  * 368bfa3 Merge pull request `#22289`_ from achernev/develop
  * fdf8825 Preserve previous behaviour when doing glob expansion in file.find

  * 56b88f2 Expand glob patterns in the path argument of file.find

- **PR** `#22293`_: (*cachedout*) Avoid key error when returner does not have func
  @ *2015-04-02T18:13:20Z*

  * f136470 Merge pull request `#22293`_ from cachedout/ret_key_error
  * 75e4e41 Avoid key error when returner does not have func

- **PR** `#22281`_: (*claudiupopescu*) Boto VPC routes support
  @ *2015-04-02T14:49:24Z*

  * 61b5ada Merge pull request `#22281`_ from claudiupopescu/boto_vpc_routes_support
  * 1012d83 Fixes pylint wrong indentation

  * 75c49de Added keys to some function calls

  * 1aef945 Adds support for routes in route_table_present

- **PR** `#22283`_: (*tsaridas*) Fix for `#22273`_
  @ *2015-04-02T14:41:59Z*

  - **ISSUE** `#22273`_: (*ryan-lane*) boto_iam state's delete_keys function doesn't support test mode
    | refs: `#22283`_ `#22826`_
  - **PR** `#22202`_: (*tsaridas*) update_stack
    | refs: `#22283`_
  * 5ae0918 Merge pull request `#22283`_ from tsaridas/add_test_boto_iam
  * cc581da Fix for `#22273`_

- **PR** `#22262`_: (*basepi*) Merge forward from 2015.2 to develop
  @ *2015-04-02T14:36:06Z*

  * d9369b1 Merge pull request `#22262`_ from basepi/merge-forward-develop
  * 5c9697f Fix data.cas test (mock dump)

  * 0b7ac98 Merge remote-tracking branch 'upstream/2015.2' into merge-forward-develop

- **PR** `#22282`_: (*rahulhan*) Adding puppet.py unit test cases
  @ *2015-04-02T13:55:39Z*

  * 4ee34f0 Merge pull request `#22282`_ from rahulhan/puppet_unit_test
  * 78667ca Adding puppet.py unit test cases

- **PR** `#22278`_: (*jayeshka*) adding network unit test case.
  @ *2015-04-02T13:52:12Z*

  * 65d685a Merge pull request `#22278`_ from jayeshka/network-unit-test
  * 1a9e6aa adding network unit test case.

- **PR** `#22258`_: (*nmadhok*) Creating vmware cloud driver
  | refs: `#22437`_
  @ *2015-04-02T13:31:50Z*

  * ba3f6bc Merge pull request `#22258`_ from nmadhok/vmware-cloud-driver
  * 5a5f394 Forgot to remove trailing spaces

  * 2a7c23e Fixing lint and formatting docs

  * 61f8c64 Forgot to remove extra parenthesis

  * 605982f Lint fix

  * 1e2a8c1 Adding more options that can be specified in create and docs for them

  * 4d6ac06 Adding ability to specify and override the default vCPUS and memory

  * 50f96bc Doc fixes

  * bfa4ef7 Merge branch 'develop' of https://github.com/saltstack/salt into vmware-cloud-driver

  * 931ece7 Fixing some spninx errors and violations

  * 3fa499f Adding Getting Started with VMware docs

  * 3d501b7 Docs fixes and adding VMware to core config docs

  * 7b562b5 Fail with error and message if clonefrom not specified. Currently only cloning is supported when creating vm

  * cc71373 Lots of refactoring and adding create() function which can clone from vm/template for now

  * 6630e2f Adding destroy() to vmware cloud

  * 3143a54 Excluding get_configured_provider() and script() from sphinx

  * 031a78b Adding script function to this driver and adding this driver to clouds docs

  * fd40c93 Adding suspend and reset functions to be able to suspend and reset the VM

  * 931dcd4 Adding start and stop functions to be able to power on/ power off a vm

  * 114cc53 Some minor doc-fixes

  * 8836d93 Adding list_folders() to be able to list all folders in environment

  * a496309 Refactoring all other functions to use the container based traversal for speed

  * 24a75b8 Refactoring everything to speed up return

  * 5231a7b Adding list_nodes() to be able to display basic information about all vms

  * f941024 Adding _get_si(), _get_vm_list() and list_nodes_min()

  * 2cea293 Doc formatting and adding notes in list_resourcepools()

  * 88f79ba Adding list_networks() to be able to list all networks

  * a31d6d7 Adding list_resourcepools() to be able to list all resource pools

  * 587a11d Adding note in list_hosts() for too many hosts

  * 73f7c9b Adding list_datastores() to be able to list all datastores

  * eb33fb8 Fix bug with list_clusters() where cluster name containing spaces wasn't being displayed

  * 459b272 Adding list_hosts() to be able to list all hosts in environment

  * 036e474 Adding list_datastore_clusters() to be able to list all datastore clusters and few more refactors

  * 1d3a11a Merge branch 'develop' of https://github.com/saltstack/salt into vmware-cloud-driver

  * 0f5f6e6 Adding list_clusters() to be able to list all clusters

  * 4954ae7 Adding _get_inv(), get_vcenter_version() and list_datacenters()

  * 66feee1 Minor doc fixes

  * eb307ed Minor doc fixes

  * 71c73d3 Adding salt.cloud.clouds.vmware to docs

  * f8f4b6b Adding code author

  * 3c2cd54 Importing required libs, adding virtual function etc

  * 1ba6918 Adding docs to vmware cloud driver

  * 38b87dc Adding empty vmware.py file in clouds

- **PR** `#22231`_: (*jayeshka*) adding rh_service unit test
  @ *2015-04-02T06:12:52Z*

  * b34d177 Merge pull request `#22231`_ from jayeshka/rh_service_unit_test
  * 79dafe7 changed FLAG to HAS_UPSTART

  * 6ff1022 removed error for CentOS

  * 7e920e1 adding rh_service unit test

- **PR** `#22277`_: (*rahulhan*) Adding nfs3.py unit test
  @ *2015-04-02T06:11:54Z*

  * e80d10c Merge pull request `#22277`_ from rahulhan/nfs3_unit_test
  * f1f2a1e Adding nfs3.py unit test

- **PR** `#22271`_: (*ryan-lane*) Add support for idle connection settings to boto_elb modules
  @ *2015-04-02T04:14:51Z*

  * 9e50986 Merge pull request `#22271`_ from lyft/add-connecting-settings-elb
  * 48908fd Show required version of boto in documentation

  * c7b3731 Add support for idle connection settings to boto_elb modules

- **PR** `#22264`_: (*rallytime*) Pylint dev
  @ *2015-04-01T22:42:23Z*

  * 922c8f4 Merge pull request `#22264`_ from rallytime/pylint-dev
  * d7cc79f Python 3 Compat for salt/states/x509.py

  * a0ffaf9 Use salt's OrderedDict for Python 2.6

  * e141c61 Python 3 Compat for salt/modules/x509.py

- **PR** `#22263`_: (*cachedout*) Prevent a load from being written if one already exists
  @ *2015-04-01T22:41:34Z*

  * 9bdfb1b Merge pull request `#22263`_ from cachedout/workaround_msgpack_corruption
  * 07191fe Prevent a load from being written if one already exists

- **PR** `#22260`_: (*dmyerscough*) Allow you to view the build arguments
  @ *2015-04-01T21:24:06Z*

  * 53c0333 Merge pull request `#22260`_ from dmyerscough/nginx-build-arguments
  * ce198a4 Only split values outside of single quotes

  * f70f462 Allow you to view the build arguments

- **PR** `#22259`_: (*techhat*) Add missing import for Azure
  @ *2015-04-01T20:51:01Z*

  * 2a99726 Merge pull request `#22259`_ from techhat/azurefix
  * cb14803 Add missing import for Azure

- **PR** `#22251`_: (*mgwilliams*) refactor boto_vpc to cache ids and eliminate duplicate code
  @ *2015-04-01T19:03:40Z*

  - **PR** `#22068`_: (*mgwilliams*) additional functionality for boto_vpc execution and state modules
    | refs: `#22251`_
  - **PR** `#21993`_: (*mgwilliams*) move connection code into boto_common
    | refs: `#22068`_
  * 6e54789 Merge pull request `#22251`_ from mgwilliams/boto_vpc2
  * 6349352 boto_vpc_test: fix name->subnet_name

  * 89870b9 fix typo in boto_vpc tests

  * f895627 stats.boto_vpc: remove duplicate definition of subnet_present

  * ff6db62 Merge remote-tracking branch 'origin/develop' into boto_vpc2

  * 046fc79 fix typo

  * 64f1fb5 refactor boto_vpc to cache ids and eliminate duplicate code

- **PR** `#22250`_: (*The-Loeki*) Contribution: An 'advanced' SMBIOS / dmidecoder parse module
  @ *2015-04-01T17:02:22Z*

  * c608f02 Merge pull request `#22250`_ from The-Loeki/smbios-module
  * f52c4eb Addition of SMBIOS / dmidecoder parse module

- **PR** `#22194`_: (*clinta*) New module and state: x509
  @ *2015-04-01T16:36:12Z*

  * c627637 Merge pull request `#22194`_ from clinta/x509
  * a354fa5 Merge branch 'develop' of https://github.com/saltstack/salt into x509

  * 93e7bb8 Better CRL handling, verify certificates and CRLs against keys in states

  * 2de64fd wrong quotes

  * 8e6c6d8 Merge branch 'develop' of https://github.com/saltstack/salt into x509

  * b75451e forgot CLI Example string

  * 29aa9ab lint

  * c1aabf5 Merge branch 'develop' of https://github.com/saltstack/salt into x509

  * 24672e7 fix test errors

  * a3afeb9 remove test state

  * ec36c7b remove unneeded runner

  * a3993f6 remove testing state

  * 51b32b8 remove x509 runner docs

  * 2fd9cf7 Merge branch 'develop' into x509

  * 9de069e lint

  * ac02f46 fix tests, and docs'

  * 2af6a65 return true on test

  * 38d6400 docs

  * 7192561 docs

  * 14824aa docs

  * d1d7562 docs

  * d224041 docs

  * 8de9c78 docs

  * cf8653b docs

  * 6d5e444 doc fix

  * 3384c49 lint

  * a148045 doc issues

  * d55f984 doc issues

  * 2b50510 doc issues

  * 0d108f6 doc issues

  * 3840e72 doc issues

  * 018509a added docs

  * 46f5f79 updated docs

  * 3fb98cd tests working

  * 22da936 add test state

  * 5faba3a refactored, struggling with publish kwargs

  * cc4cb8b about to convert to dynamic functions to use publish modules

  * 90a8801 add test state

  * 1670b36 initial tests working

  * aeb9696 dict conversion complete

  * 67438f7 before chaning to dict

  * 2d9b498 moved example to more appropriate location

  * 702b7e0 more docs, with complete example

  * e0b68c9 docs fixed up

  * 59eea7d added runner docs

  * 12fa695 added state docs

  * b17eb94 added state docs

  * aab3d37 added module to doc index

  * c53b313 moved files to correct location

  * 4f2a2a6 Merge ../x509 into x509

    * a455df4 linted

    * 4f96df6 working

    * 07278f3 almost there

    * ec63c4f added runner

    * 6914882 make pretty_hex prettier

    * cba4e9a working like a champ

    * a548b9d more progress

    * 28b6f3f fix merge issue

      * f97e960 CRLs working

      * 5fc67b6 syntax errors

      * 7252c70 added CRL module

      * 52edc26 module documented

      * 0b7949f fixed extension parsing bug

      * eb46424 pylint

      * 6f618a8 certificate managed working

      * 53a7698 execution is doing validation, don't need to in state

      * 0b91304 certificate_managed created

      * 657ea99 certificate_managed created

      * 88aeb07 progress on certificate_managed

      * 5d24d06 move functions around

      * ddaa490 signing csrs now works

      * 91a1989 reading csr works

    * 2230bf4 Merge branch 'edgerouter' into x509

    * ecf5397 merged everything

    * 6566e03 Refactored git repo to host both states and pillars

- **PR** `#22249`_: (*claudiupopescu*) Boto VPC describe route table
  @ *2015-04-01T16:35:29Z*

  * 9e9af6e Merge pull request `#22249`_ from claudiupopescu/boto_vpc_describe_route_table
  * 28597a5 Boto VPC describe route table

- **PR** `#22245`_: (*achernev*) Fix grains.get_or_set_hash to work with multiple entries under same key
  @ *2015-04-01T16:32:04Z*

  - **ISSUE** `#14888`_: (*djs52*) grains.get_or_set_hash  broken for multiple entries under the same key
    | refs: `#22245`_
  * 5dac199 Merge pull request `#22245`_ from achernev/develop
  * 81746bc Fix grains.get_or_set_hash to work with multiple entries under same key

- **PR** `#22242`_: (*claudiupopescu*) Boto VPC check if route exists
  @ *2015-04-01T15:36:12Z*

  * 6566a5d Merge pull request `#22242`_ from claudiupopescu/boto_vpc_route_exists
  * ecbb62d Allow to check if a route exists.

- **PR** `#22243`_: (*jayeshka*) adding schedule unit test
  @ *2015-04-01T15:34:13Z*

  * 8c4d064 Merge pull request `#22243`_ from jayeshka/schedule-unit-test
  * 07ee960 resolved error.

  * 2b6eccb adding schedule unit test

- **PR** `#22237`_: (*rahulhan*) Adding systemd.py unit tests
  @ *2015-04-01T15:17:44Z*

  * bdd543a Merge pull request `#22237`_ from rahulhan/systemd_unit_test
  * c50b842 Adding systemd.py unit tests

- **PR** `#22229`_: (*rahulhan*) Adding Reg.py unit test cases
  @ *2015-04-01T14:49:14Z*

  * 450276d Merge pull request `#22229`_ from rahulhan/reg_unit_tests
  * 7ef848e Adding Reg.py unit test cases

- **PR** `#22226`_: (*garethgreenaway*) Fixes to scheduler
  @ *2015-04-01T03:55:57Z*

  - **ISSUE** `#20107`_: (*belvedere-trading*) minion scheduling via pillar does not get applied some times
    | refs: `#22226`_
  * 20d8f75 Merge pull request `#22226`_ from garethgreenaway/20107_job_race_condition
  * 606a275 Fixing a bug that pops up randomly if you have multiple jobs with multiple threads, jobs would be processed in one thread but an attempt to process in another thread would be attempted.  The cache file would be removed after the other thread had gotten the list of cache file.  Adding some code to bypass the processing if the file is already gone.

- **PR** `#22213`_: (*rallytime*) Python 3 compat for salt/sdb/etcd_db.py
  @ *2015-03-31T21:19:29Z*

  * 4810090 Merge pull request `#22213`_ from rallytime/pylint
  * 1336796 Python 3 compat for salt/sdb/etcd_db.py

- **PR** `#22203`_: (*pass-by-value*) Add doc about reload modules on pip state
  @ *2015-03-31T19:32:41Z*

  * 9ffb8a6 Merge pull request `#22203`_ from pass-by-value/pip_state_doc_add
  * ea60814 Add doc about reload modules on pip state

- **PR** `#22197`_: (*cachedout*) Create an index for jids
  @ *2015-03-31T18:07:04Z*

  * ab44a43 Merge pull request `#22197`_ from cachedout/index_jids
  * 35201fc Whitespace

  * 5005a6a Create an index for jids

- **PR** `#22188`_: (*claudiupopescu*) Boto VPC subnet state
  @ *2015-03-31T18:05:45Z*

  * a03efac Merge pull request `#22188`_ from claudiupopescu/vpc_subnet_features
  * 5562422 Test parameters for delete_subnet

  * 5730275 Version and test fixes

  * 87d5f9d Subnet support for boto_vpc state

  * af7592c Allow subnet deletion by name

- **PR** `#22186`_: (*rahulhan*) Adding saltcloudmod.py unit test
  @ *2015-03-31T18:05:10Z*

  * 8efac4c Merge pull request `#22186`_ from rahulhan/saltcloudmod_unit_test
  * 0b7225a Adding saltcloudmod.py unit test

- **PR** `#22198`_: (*kiorky*) Fix syntaxerror
  @ *2015-03-31T17:49:07Z*

  * be9001e Merge pull request `#22198`_ from makinacorpus/fixe
  * e026b1b Fix syntaxerror

- **PR** `#22193`_: (*rallytime*) Revert "adding rh_service unit test"
  @ *2015-03-31T15:43:58Z*

  - **PR** `#22190`_: (*jayeshka*) adding rh_service unit test
    | refs: `#22193`_
  * 3cfc0a0 Merge pull request `#22193`_ from saltstack/revert-22190-rh_service-unit-test
  * 9412a83 Revert "adding rh_service unit test"

- **PR** `#22169`_: (*basepi*) Merge forward from 2015.2 to develop
  @ *2015-03-31T15:21:36Z*

  - **ISSUE** `#10`_: (*thatch45*) list jobs option
  * 44c7eb4 Merge pull request `#22169`_ from basepi/merge-forward-develop
  * 6e10cb5 Merge pull request `#10`_ from rallytime/merge-forward-develop

    * 88298c5 Add mock exception class to keystone unit test

  * 124ad51 Merge remote-tracking branch 'upstream/2015.2' into merge-forward-develop

- **PR** `#22190`_: (*jayeshka*) adding rh_service unit test
  | refs: `#22193`_
  @ *2015-03-31T12:48:36Z*

  * 33727a5 Merge pull request `#22190`_ from jayeshka/rh_service-unit-test
  * 0190f4a adding rh_service unit test

- **PR** `#22187`_: (*jayeshka*) adding sqlite3_test unit test
  @ *2015-03-31T12:47:35Z*

  * 7d47ede Merge pull request `#22187`_ from jayeshka/sqlite3-unit-test
  * bada2e2 adding sqlite3_test unit test

- **PR** `#22189`_: (*rallytime*) Revert "Adding state.py unit test"
  @ *2015-03-31T12:39:55Z*

  - **PR** `#22143`_: (*rahulhan*) Adding state.py unit test
    | refs: `#22189`_
  * a4e4b58 Merge pull request `#22189`_ from saltstack/revert-22143-state_unit_test
  * 0ea0f3d Revert "Adding state.py unit test"

- **PR** `#22180`_: (*jfindlay*) revise unit test documentation
  @ *2015-03-31T11:17:28Z*

  * c25b49f Merge pull request `#22180`_ from jfindlay/unit_test_docs
  * f50949e revise unit test documentation

- **PR** `#22176`_: (*dmyerscough*) Allow users to delete VMWare snapshots and fix PEP8 complaints
  @ *2015-03-31T05:59:10Z*

  * 524b311 Merge pull request `#22176`_ from dmyerscough/delete-vmware-snapshots
  * 1ebca45 Allow users to delete VMWare snapshots and fix PEP8 complaints

- **PR** `#22143`_: (*rahulhan*) Adding state.py unit test
  | refs: `#22189`_
  @ *2015-03-31T05:53:36Z*

  * 7b95940 Merge pull request `#22143`_ from rahulhan/state_unit_test
  * 9038fa2 Adding state.py unit test

- **PR** `#22151`_: (*ckochenower*) A Cassandra CQL returner
  @ *2015-03-31T02:26:51Z*

  * 1fd2daf Merge pull request `#22151`_ from ckochenower/develop
  * 05ae473 The last of the lint

  * da616b4 Fix lint errors

  * 51f7035 Merge branch 'develop' of https://github.com/ckochenower/salt into develop

    * 3813a7b Remove eroneous text causing test failures

    * 9d54dc5 Merge branch 'develop' of https://github.com/saltstack/salt into develop

    * 172400c Make nocache parameter an optional parameter

    * 0a640fa Merge remote-tracking branch 'upstream/develop' into develop

    * aa40b97 A Cassandra CQL returner

  * 398708f Remove eroneous text causing test failures

  * 9077c2e Make nocache parameter an optional parameter

  * 6e130a5 A Cassandra CQL returner

- **PR** `#22175`_: (*garethgreenaway*) Changes to nagios_rpc module
  @ *2015-03-31T00:46:23Z*

  * 45e11b7 Merge pull request `#22175`_ from garethgreenaway/nagios_rpc_changes
  * 0075362 Splitting status functions into one for host and another for service, per @thatch45.  Making errors a bit more obvious by returning them instead of logging.

- **PR** `#22127`_: (*tsaridas*) Boto iam delete_user module/state
  @ *2015-03-30T21:43:54Z*

  * 2ebd6d8 Merge pull request `#22127`_ from tsaridas/boto_iam
  * b1f91cf items()

  * 051d04c .. versionadded:: Beryllium

  * 84f595f pylint error

  * dca208d - Comments/Debug log

  * 987776c - Comments

  * 09664f4 - keys_absent state - user_absent state

  * 8228572 - get_all_access_keys function module - delete_access_key function module

  * 122109f show exceptions in state

  * a7c0641 delete user state

  * 62e56ff remove calls to functions in the same file with __salt__

  * 28ff081 delete_user function for module

- **PR** `#22157`_: (*garethgreenaway*) Updates to osquery module
  @ *2015-03-30T21:43:30Z*

  * d3472f7 Merge pull request `#22157`_ from garethgreenaway/osquery_module_updates
  * a0c8a74 Adding missing versionadded tags

  * cadc6ca General cleanup.  Returning errors and comments rather than just False when things go wrong.

- **PR** `#22114`_: (*dmyerscough*) Fixing KeyError when there are no additional pages
  @ *2015-03-30T21:36:02Z*

  * 1842cc5 Merge pull request `#22114`_ from dmyerscough/digital-ocean-list-nodes
  * e69d434 Catch KeyError

  * 47d4772 Fixing KeyError

  * 3c3ea84 Fix PEP8 complaint

  * d22572d Fixing KeyError when there are no additional pages

- **PR** `#22162`_: (*rallytime*) Pylinting dev
  @ *2015-03-30T21:05:12Z*

  * 23045fd Merge pull request `#22162`_ from rallytime/pylinting-dev
  * 10c1dbe Fix remaining pylint errors for cassandra_cql.py

  * 3c1bb40 Whitespace fix

  * 154f1fe Remove unused import

  * 0fd10ca Python 3 compat for nagios_rpc.py

  * 0c11fc9 Pylint clean up for cassandra_cql.py

- **PR** `#22166`_: (*rallytime*) Use lists, not dicts, for MagicMock side_effect
  @ *2015-03-30T20:58:55Z*

  * 28fb7df Merge pull request `#22166`_ from rallytime/fix_bluez_test
  * 8b1d3cd Use lists, not dicts, for MagicMock side_effect

- **PR** `#22165`_: (*skizunov*) Bugfix: Reactor missing import.
  @ *2015-03-30T20:31:27Z*

  - **ISSUE** `#21651`_: (*mimianddaniel*) reactor not firing after upgraded to rc2, 2015.2
    | refs: `#22165`_
  * 56fefa5 Merge pull request `#22165`_ from skizunov/develop
  * f25907f Bugfix: Reactor missing import.

- **PR** `#22163`_: (*johntron*) Improves example illustrating SLS-to-Python mapping
  @ *2015-03-30T20:26:29Z*

  * fe808b7 Merge pull request `#22163`_ from johntron/patch-1
  * 663b19e Improves example illustrating SLS-to-Python mapping

- **PR** `#22118`_: (*surajssd*) Datetime support for msgpack for issue-21721
  @ *2015-03-30T17:57:43Z*

  - **ISSUE** `#21721`_: (*deuscapturus*) datetime as value in pillar causes error
    | refs: `#22118`_
  * adb50ca Merge pull request `#22118`_ from surajssd/issue-21721
  * 95d14c3 Datetime support for msgpack for issue-21721

- **PR** `#21937`_: (*isbm*) LVM module bugfixes
  @ *2015-03-30T17:52:25Z*

  - **ISSUE** `#1`_: (*thatch45*) Enable regex on the salt cli
    | refs: `#21356`_ `#21328`_
  * 00749a5 Merge pull request `#21937`_ from isbm/isbm-lvm-fixes
  * 487e221 Merge pull request `#1`_ from jfindlay/lvm

    * d9375ad fix LVM tests for new LVM code

  * d795c8d Test fix: pvcreate raises an exception if no device found

  * ade6f32 Lintfix: Unnecessary parents after raise keyword

  * d86dc2b No need of back-referral within the same module

  * a858f6e Filter-out invalid devices and raise an exception, when asked via 'override' parameter

  * cb93f7b Remove buggy runner and its output

  * 78eb667 Bugfix: use exceptions for failure in pvcreate

  * 5b16538 Add an 'override' param to the pvremove so it will raise an exception only on explicit errors

  * 0ecde36 Add 'override' parameter, which will raise an exception on explicit error

  * 9e19c13 Bugfix: Removal should be either True on success or an exception on failure.

  * ab548a4 Add verification pvcremove ran successfully

  * d62e13d Bugfix: pvcreate returns nothing, once success.

  * 15d69d5 Verify pvcreate ran successfully

- **PR** `#22057`_: (*jfindlay*) remove default prefix of '-' in archive.tar and archive.cmd_unzip
  @ *2015-03-30T16:45:11Z*

  - **PR** `#21995`_: (*jkur*) Option handling for archive.tar fails with more uncommon options
    | refs: `#22057`_
  * 4538ea6 Merge pull request `#22057`_ from jfindlay/opts_prefix
  * 4b2ebfa document '-' prefix removal in Berrylium notes

  * 2dd34ab restore explicit '-' in unit tests

  * 0d655e6 remove '-' options prefix in archive.{tar|cmd_unzip}

- **PR** `#22129`_: (*terminalmage*) Add docker-ng module
  @ *2015-03-30T16:37:45Z*

  * 27465e0 Merge pull request `#22129`_ from terminalmage/docker-ng
  * 40b40f4 More docstring corrections/clarifications

  * 8c93dec Clarify container_resource docstring

  * e4cb5c0 Docstring tweak for clarification

  * 654e8ab Fix incorrect return data from docker-ng.stale

  * 271c921 Fix docker-ng.load when no tag passed

  * 0f8f9a1 One more lint fix

  * 768fc92 Lint fixes

  * 3143022 Add notice about the PID in run_all commands within containers

  * 08513c1 Rename exec_method to exec_driver

  * 35b376e Add docker-exec support for docker-ng module

  * a104faf Add docker-exec support to container_resource.copy_to

  * ec80f72 Add docker-exec support to container_resource.run

  * 6ecf9ae Add ability to copy files from salt:// fileserver to a container

  * 0b850ad Add notice of dockerio module deprecation path

  * 090d851 Quote nsenter command file paths

  * 4011cd0 Add docker-ng.layers

  * 2e823b8 Add docker-ng module

  * f7e6523 Add dockerng execution module docs to toctree

  * 6846d3e Update the exclude-members for lxc module

  * d9f0273 Update the exclude-members for nspawn module

  * bad7074 Update lxc module to use common code for copy_to function

  * f0cbf2c Update nspawn module to use common code for copy_to function

  * 681b3c4 Add copy_to function to container_resource

- **PR** `#22054`_: (*jfindlay*) convert custom LogRecord attribute formatting from {}- to %-style
  @ *2015-03-30T16:37:18Z*

  * adb8d5c Merge pull request `#22054`_ from jfindlay/log_color
  * 0e57aeb mention console log colors in beryllium release notes

  * 294dfe2 clarify and expand console log colors help

  * c2df42d speed up console log colors by using %-formatting

- **PR** `#22154`_: (*cachedout*) Small grammar fixup
  @ *2015-03-30T16:27:49Z*

  * 4ad94fb Merge pull request `#22154`_ from cachedout/language_fixup
  * b98269a Small grammar fixup

- **PR** `#22078`_: (*pengyao*) Adjust cli_summary
  @ *2015-03-30T16:25:05Z*

  * 8ff88d6 Merge pull request `#22078`_ from pengyao/summary
  * 88851da Adjust cli_summary

- **PR** `#22133`_: (*eliasp*) Implement 'map' mode in LDAP pillar module
  @ *2015-03-30T16:08:10Z*

  * 696065a Merge pull request `#22133`_ from eliasp/develop-pilar_ldap-map-support
  * 23278cb Improved documentation.

  * 4182551 Implemented 'map' mode.

  * f895fd1 Document LDAP pillar module.

  * 58f501b First improvements to example in doc.

  * c00c14f Initial documentation improvements for pillar.pillar_ldap

- **PR** `#22123`_: (*F30*) Fix custom Sphinx formatter for aliased functions
  @ *2015-03-30T16:05:20Z*

  - **PR** `#7885`_: (*loz-hurst*) Added note about methods with trailing underscores to module docs.
    | refs: `#22123`_
  * 98bc85a Merge pull request `#22123`_ from F30/autodoc-fix
  * 0869680 Fix custom Sphinx formatter for aliased functions

- **PR** `#22120`_: (*cr0hn*) Update vt.py
  @ *2015-03-30T16:01:18Z*

  * 0c95690 Merge pull request `#22120`_ from cr0hn/patch-1
  * 7122c77 Update vt.py

- **PR** `#22125`_: (*notpeter*) Add documentation for multiple Ubuntu PPAs. Fixes `#18822`_
  @ *2015-03-30T15:59:31Z*

  - **ISSUE** `#18822`_: (*notpeter*) Ubuntu PPA is missing 2014.1 binaries
  * 6fd00e3 Merge pull request `#22125`_ from notpeter/develop
  * 960df2b Add documentation for multiple Ubuntu PPAs. Fixes `#18822`_

- **PR** `#22135`_: (*garethgreenaway*) Adding a module to pull information from the osquery daemon.
  @ *2015-03-30T15:41:30Z*

  * 2211150 Merge pull request `#22135`_ from garethgreenaway/osquery_module
  * 64216de fixing lint error

  * 8287fd6 Adding a module to pull information from the osquery daemon.

- **PR** `#22140`_: (*claudiupopescu*) Boto VPC describe subnets
  @ *2015-03-30T15:27:04Z*

  * 3267b42 Merge pull request `#22140`_ from claudiupopescu/boto_describe_subnets_fix
  * 2112ee9 Describe a specific subnet only by providing ID

  * f93836f Describe all subnets

- **PR** `#22139`_: (*jayeshka*) adding supervisord unit test case
  @ *2015-03-30T13:19:29Z*

  * 229087b Merge pull request `#22139`_ from jayeshka/supervisord-unit-test
  * 28909e3 added requested change.

  * c8614e4 adding supervisord unit test case

* feb1aad Merge branch 'StepOneInc-cassandra-cql' into develop


  * f561506 Changes required for initial module acceptance

  * 7e90f1b Merge branch 'cassandra-cql' of https://github.com/StepOneInc/salt into StepOneInc-cassandra-cql

  * 133ee88 New cassandra module using cql.

- **PR** `#22134`_: (*zboody*) Fixes `#9960`_
  @ *2015-03-30T03:04:11Z*

  - **ISSUE** `#9960`_: (*jeteokeeffe*) salt virt.query errors out
  * f475b0a Merge pull request `#22134`_ from zboody/virt-query-error
  * c404e40 Fixes `#9960`_

- **PR** `#22107`_: (*ryan-lane*) Fix for grafana dict profiles
  @ *2015-03-28T17:17:25Z*

  * fb080b1 Merge pull request `#22107`_ from lyft/fix-grafana-dict-profile
  * f6c9b92 Fix for grafana dict profiles

- **PR** `#22096`_: (*basepi*) Add versionadded for ssh_auth.absent source argument
  @ *2015-03-27T22:06:11Z*

  * 3125264 Merge pull request `#22096`_ from basepi/ssh_auth.absent.source.versionadded
  * 68a68b3 Add versionadded for ssh_auth.absent source argument

- **PR** `#22070`_: (*dmyerscough*) systemd hostnamectl
  @ *2015-03-27T21:21:05Z*

  * 689e1ab Merge pull request `#22070`_ from dmyerscough/hostnamectl-change
  * feff926 Fixing lint error

  * e262173 systemd now provides a nice way to change your hostname using the hostnamectl command

- **PR** `#22092`_: (*kiorky*) lxc: reconfigure fixes
  @ *2015-03-27T20:11:02Z*

  * cca5adf Merge pull request `#22092`_ from makinacorpus/lxc
  * ab84acb lxc: reconfigure fix memory

  * 08c1125 lxc: reconfigure fix gateway

- **PR** `#22086`_: (*claudiupopescu*) Adds support for VPC internet gateways
  @ *2015-03-27T17:31:23Z*

  * eafc398 Merge pull request `#22086`_ from claudiupopescu/boto_vpc_internet_gateway
  * aa47228 Adds support for VPC internet gateways

- **PR** `#22079`_: (*jayeshka*) adding nftables unit test
  @ *2015-03-27T17:17:31Z*

  * 7bc4fc5 Merge pull request `#22079`_ from jayeshka/nftables-unit-test
  * 0cedee7 removed pylint errors

  * 3351e1c added python libs

  * 38abae5 adding nftables unit test

- **PR** `#21798`_: (*isbm*) Multiple bugixes for new "nagios_json" module
  @ *2015-03-27T16:54:22Z*

  - **PR** `#21793`_: (*garethgreenaway*) Clean up in the nagios_json module
    | refs: `#21798`_
  * 42e7bb8 Merge pull request `#21798`_ from isbm/isbm-nagios-module-fixes
  * 6310beb Lintfix.

  * 41afa66 Absense of status is rather "Unknown" than "Critical"

  * 0c0b44f Drop the idea to wrap-up the Nagios returns, but ask Nagios directly for the values.

  * 050700b Lint violation fixes

  * f8b071c Added ability to return either numeric or textual status

  * 7ed29b5 Doc adjustment

  * a1a2ce2 Signature change

  * 549781c Dropped the idea of boolean, but return an actual status, like Nagios does.

  * a66c4a0 Documentation adjustments

  * 02ef9a8 Replaced constant with the variable

  * dd0d8cf Added missing newline at the end of the file

  * 20ed1bd Bugfix: Nagios returns text in the status, instead of integers

  * 952cc45 Replaced specific protocol from the module name with the method of interaction

  * 6d8f5e3 Use the same function for multiple purposes

  * 6bfcaf3 Added error log message on wrong configuration

  * 95bc6ae Documentation adjustment

  * 0f39ad5 Complexity removal: status() can do both: host and service now.

  * 0a00639 Bugfix: logs should write to the appropriate channels

  * c45e126 Refactor _status_query()

  * 22468c1 Bugfix: crash on unexpected Nagios response. Removed unnecessary complexity.

  * 97b5448 Dropped buggy complexity: one method can do both checks instead.

  * 12a7471 Bugfix: error should be logged to appropriate log.

  * ecedde4 Refactor requests.request(...) call

  * 9093544 Refactor _config()

  * 12e27a6 Add more meaning to the import constraint and add log debug entry.

  * c4c35de Replace magic numbers with a standard constants.

  * 0a6d8f0 Adjust doc.

- **PR** `#22085`_: (*rallytime*) Python 3 compat for azurefs.py
  @ *2015-03-27T15:37:31Z*

  * 5c70cdd Merge pull request `#22085`_ from rallytime/pylinting
  * 2bd8465 Python 3 compat for azurefs.py

- **PR** `#22073`_: (*jayeshka*) adding publish unit test
  @ *2015-03-27T06:46:16Z*

  * 9deb7a2 Merge pull request `#22073`_ from jayeshka/publish-unit-test
  * 08440ab adding publish unit test

- **PR** `#22060`_: (*techhat*) Add azurefs external file server and supporting code and docs
  @ *2015-03-26T23:12:19Z*

  * 45827bc Merge pull request `#22060`_ from techhat/blobstorage
  * 0b23bad Linting

  * bd75fb3 Add azurefs external file server driver

  * 6ac0bcd Update docs for Azure blob management

  * 18d32f5 Look for correct strings for connection

  * ff16e68 Update docstrings for blob storage

  * 0a06579 Add blob storage management to Azure

- **PR** `#22062`_: (*rallytime*) Python 3 compatibility for pylint
  @ *2015-03-26T22:38:31Z*

  * 6a26ce7 Merge pull request `#22062`_ from rallytime/pylint_develop_branch
  * d6f921f Python 3 compatibility for pylint

- **PR** `#21996`_: (*isbm*) "file.line" minor fixes
  @ *2015-03-26T20:51:39Z*

  * 2d0e665 Merge pull request `#21996`_ from isbm/isbm-edit-line-fixes
  * a490659 Feature: use indent in insert/replace

  * b3707ee Feature use indent in 'ensure'

  * e7dd18c Feature: use indent in insert

  * 7338c2e Feature: Use indent

  * 8fcb944 Bugfix: add before, not after.

  * c8e32d9 Replace weird splitlines behavior.

  * 3cf0960 Rename variable to the real meaning

  * c608609 Signature change: indent support

  * 01ac78b Signature change: indent support

  * 2ef36d2 Add indent getter

  * d7287bc Bugfix: replace weird behaviour of 'splitlines' with an oldschool approach

  * f3c4bb9 Using matcher in 'delete'

  * 808208d Maintenance: proper indent in docstring

  * c80d3af Refactoring

  * 3835ed0 Maintenance: better exception handling for broken regexes

  * feda708 Maintenance: use proper exception class

  * 0093df4 One kitten saved.

  * 8808397 Bugfix: Possible file handler close before init.

  * 1efab85 Lintfix.

  * ec861ec Version correction

  * 215f7d7 Added dots at the end of the sentences

  * 16d6a8d Adjusted docstring for param 'quiet'.

  * b5e8052 Adjusted docstring for param 'quiet'.

  * 749ed13 Added notice for the added version

  * 76e3d19 Signature change: added parameter 'quiet'

  * 6b4c2f0 Signature change: added 'quiet' parameter

- **PR** `#21995`_: (*jkur*) Option handling for archive.tar fails with more uncommon options
  | refs: `#22057`_
  @ *2015-03-26T19:09:16Z*

  * 5b55c48 Merge pull request `#21995`_ from jkur/develop
  * 3e62675 option handling for archive.tar for multiple options

  * b096041 don't add dash to tar archive options, when options already starts with a dash

- **PR** `#22030`_: (*attiasr*) use port 445 instead of port 22 when bootstrapping windows
  @ *2015-03-26T18:33:29Z*

  * abe7a1e Merge pull request `#22030`_ from c0m4/patch-fix_default_windows_port
  * f733bfc added an example usage of smb_port

  * 1352979 use port 445 instead of port 22 when bootstrapping windows

- **PR** `#22045`_: (*UtahDave*) import salt.ext.six as six like main file.py
  @ *2015-03-26T16:19:13Z*

  - **ISSUE** `#21884`_: (*polliard-jmfe*) When running the 2015.2 windows minion there are several import/namespace issues
    | refs: `#22045`_
  * c75c320 Merge pull request `#22045`_ from UtahDave/develop
  * 7298fc9 import salt.ext.six as six like main file.py

- **PR** `#21988`_: (*mgwilliams*) states.boto_vpc: remove partially implemented salt_id code
  @ *2015-03-26T15:21:16Z*

  * 3b39f22 Merge pull request `#21988`_ from mgwilliams/boto
  * 369e519 states.boto_vpc: fix undefined var

  * 5a69e75 states.boto_vpc: add docstring for 'absent' state

  * ad71ff0 states.boto_vpc: remove partially implemented salt_id code

- **PR** `#21735`_: (*tsaridas*) add manage ec2 keys state
  @ *2015-03-26T15:00:28Z*

  * dd7de51 Merge pull request `#21735`_ from tsaridas/boto_manage_ec2_keys_state
  * 79cfc85 if not None

  * d75f9f7 Beryllium

  * 3db622e file not found

  * b4685d9 - pylint errors

  * 338f0ae - add support for salt://

  * 68cef3c - silly changes

  * 980f7bc - merge import & create - change function names to present & absent

  * de43ecd /created/imported/ import_key function

  * 29b9f82 - add manage ec2 keys state

- **PR** `#21767`_: (*tsaridas*) add multiple functions for iam module & state
  @ *2015-03-26T14:56:46Z*

  * 578d182 Merge pull request `#21767`_ from tsaridas/boto_iam_get_role
  * 49966aa  Fixes for account_policy

  * af061d8 Remove spaces

  * 3f5e490 Account policy is not enabled

  * 31a4ec3 Beryllium

  * 0da15dc remove multiple return false

  * 9f1a67f if created is not false

  * d37b666 os.linesep line seperator

  * 7a67d8a logical error

  * 16ff1b5 fix for log.error

  * f1143f7 dummy commit in order to rerun tests

  * 32b4444 delete server certificate

  * 68c6463 if policy if not string

  * 5397ca0 forgot to add tests

  * 2a91d56 File not found exception

  * 9d38657 upload server certificate function

  * 07e89cc - pylint fixes

  * 41fd873 - pylint error fixes

  * 53b35e9 - comments

  * 21e250b - account_policy fixes

  * c986cad - pylint fixes

  * f7aba65 - add test modes

  * 3204896 spelling mistake

  * 91ae92b - remove double leading underscore

  * 2be3a8a - urlib pylint error

  * f6900b7 - more pylint fixes

  * e27054d - pylint + small fixes

  * 904e88b - add state file

  * 33fbfa4 - changes to current functions - add function get_account_policy

  * 4a30bb3 update var not needed

  * 3820397 - create_login_profile - update_account_password_policy

  * cfa6a2a - add function put_group_policy - add function get_group_policy

  * d0eccef - add create_user function - add get_user function - add create_group function - add get_group function - add add_user_to_group function

  * 8fe37c5 - /nome/name/

  * e526b80 - error message from boto

  * 636a467 - return False if role does not exist.

  * aa4ff0c - add function to descripe a role and return its info

- **PR** `#22036`_: (*shwetabhs*) Removed aes and token_dir from def values() function
  @ *2015-03-26T14:29:37Z*

  * a49a912 Merge pull request `#22036`_ from shwetabhs/wheel/config.py-changes
  * 921a070 Removed aes and token_dir from def values() function

- **PR** `#22028`_: (*rahulhan*) adding bluez unit test case
  @ *2015-03-26T13:15:04Z*

  * a32b375 Merge pull request `#22028`_ from rahulhan/bluez-unit-test
  * 41f2564 Removed pylint errors

  * 430476e adding bluez unit test case

- **PR** `#22008`_: (*dmyerscough*) Allow users to create snapshots of their virtual machines
  @ *2015-03-25T23:44:19Z*

  * 32823a7 Merge pull request `#22008`_ from dmyerscough/create-snapshots-vmware
  * 478be3e Catch VIException

  * 2e45e39 Adding version

  * b7231a1 Allow users to create snapshots of their virtual machines

- **PR** `#22013`_: (*dmyerscough*) Snapshop list more details
  @ *2015-03-25T21:52:51Z*

  * b965a51 Merge pull request `#22013`_ from dmyerscough/snapshop-list-more-details
  * 53f9070 Adding version

  * 25d6c03 List more details about snapshots such as creation date/state/description etc.

- **PR** `#21999`_: (*basepi*) Merge forward from 2014.7 to 2015.2
  @ *2015-03-25T19:06:26Z*

  * add04c6 Merge pull request `#21999`_ from basepi/merge-forward-develop
  * b0fe5cc Merge remote-tracking branch 'upstream/2015.2' into merge-forward-develop

- **PR** `#21945`_: (*ticosax*) Enable soft reload for docker containers
  @ *2015-03-25T14:41:58Z*

  * 2c67539 Merge pull request `#21945`_ from ticosax/docker.running.signal
  * 4c23581 enable soft reload for running containers

  * ee7542e transmit signal argument to docker's client.kill()

- **PR** `#21973`_: (*deuscapturus*) Update fileclient.py
  @ *2015-03-25T14:41:03Z*

  * 23502fa Merge pull request `#21973`_ from deuscapturus/patch-2
  * 3c883ab Update fileclient.py

- **PR** `#21976`_: (*jayeshka*) adding pam unit test
  @ *2015-03-25T14:34:36Z*

  * dcf8e68 Merge pull request `#21976`_ from jayeshka/pam-unit-test
  * bb80e1d adding pam unit test

- **PR** `#21970`_: (*jayeshka*) adding runit unit test
  @ *2015-03-25T14:34:17Z*

  * 2b8789f Merge pull request `#21970`_ from jayeshka/runit-unit-test
  * 39e4b7f adding runit unit test

- **PR** `#21966`_: (*dmyerscough*) Display all VMs with snapshots and list the names of the snapshots
  @ *2015-03-25T01:49:54Z*

  - **ISSUE** `#21280`_: (*jryberg*) salt-cloud vSphere snapshot capabilities
    | refs: `#21966`_
  * fa4c1d7 Merge pull request `#21966`_ from dmyerscough/21280-list-snapshots
  * b9f26c1 Display all VMs with snapshots and list the names of the snapshots

- **PR** `#21964`_: (*rallytime*) Fix python 3 compatiblity for hg_pillar on develop
  @ *2015-03-25T01:27:56Z*

  * 46e9ef2 Merge pull request `#21964`_ from rallytime/pylint-y
  * cd97aab Fix python 3 compatiblity for hg_pillar on develop

- **PR** `#21959`_: (*giannello*) Changed argument name
  @ *2015-03-24T23:01:46Z*

  - **ISSUE** `#21956`_: (*giannello*) Reactor rendering error
    | refs: `#21959`_
  * 96e56bf Merge pull request `#21959`_ from giannello/patch-1
  * b2dc598 Changed argument name

- **PR** `#21951`_: (*johntron*) Fix second `unless` example
  @ *2015-03-24T20:31:41Z*

  * ecd2f70 Merge pull request `#21951`_ from johntron/patch-1
  * 6558d9e Fix `unless` example

- **PR** `#21950`_: (*dmyerscough*) Gracefully stop the Salt Master
  @ *2015-03-24T20:29:32Z*

  - **ISSUE** `#21610`_: (*jfindlay*) stopping a foreground salt-master results in stack traces
    | refs: `#21950`_
  * 060df31 Merge pull request `#21950`_ from dmyerscough/21610-fix-stacktrace-on-ctrl-c
  * bb98b09 Gracefully stop the Salt Master

- **PR** `#21947`_: (*dmyerscough*) Ensure nginx config check passes by checking the exit status
  @ *2015-03-24T19:11:50Z*

  * 40b99a2 Merge pull request `#21947`_ from dmyerscough/20625-Fixing-invalid-syntax
  * ac93e11 Ensure nginx config check passes by checking the exit status.... Nginx writes messages to stderr even when there are no errors

- **PR** `#21930`_: (*ptonelli*) add hg_pillar similar to git_pillar
  @ *2015-03-24T19:10:53Z*

  - **ISSUE** `#2`_: (*thatch45*) salt job queries
    | refs: `#22858`_
  - **ISSUE** `#1`_: (*thatch45*) Enable regex on the salt cli
    | refs: `#21356`_ `#21328`_
  * 8e4bf33 Merge pull request `#21930`_ from ptonelli/develop
  * 9bf65bd add version annotations

  * ab736e8 remove empty functions

  * 15f66d1 fix hg_pillar unittest lint errors

  * abc4e7f Merge pull request `#2`_ from gracinet/hg_pillar

    * e65e5e6 Reliable avoidance of infinite loops

  * 361f36b Merge pull request `#1`_ from gracinet/hg_pillar

    * 19986ab Conformance of docstrings with Salt coding style

  * ca4061b add hg_pillar and corresponding unit test

- **PR** `#21942`_: (*aspyatkin*) Do not parse state name with pip in editable mode
  @ *2015-03-24T18:43:28Z*

  - **ISSUE** `#21890`_: (*aspyatkin*) A bug in pip.installed state in editable mode?
    | refs: `#21942`_
  * 0675892 Merge pull request `#21942`_ from aspyatkin/fix-pip-install-editable
  * fdb6278 Do not parse state name with pip in editable mode

- **PR** `#21924`_: (*cdarwin*) Update virt.freemem documentation to clarify units
  @ *2015-03-24T03:02:53Z*

  * 56c4389 Merge pull request `#21924`_ from luciddg/0000-virt-freemem-docs
  * 7fac7bb Update virt.freemem documentation to clarify units

- **PR** `#21925`_: (*jfindlay*) fix tests for `#21752`_
  @ *2015-03-24T03:01:05Z*

  - **PR** `#21752`_: (*mgwilliams*) add describe_vpcs and cache connection in __context__ in boto_vpc
    | refs: `#21925`_
  * 5b659c7 Merge pull request `#21925`_ from jfindlay/boto
  * ebbb113 fix boto_vpc unit test and error message

  * 2a8ee17 fix bug in boto vpc ec2 conn caching; add/update boto functions

  * 69966fd fix lint

  * 92e11a3 add __context__ to boto_vpc test

  * a8d971d cache connection in __context__ in boto_vpc; remove debug line from boto_ec2

- **PR** `#21878`_: (*bechtoldt*) fix wrong file parsing in salt.modules.ssh.host_keys(), fixes `#21134`_
  @ *2015-03-24T01:24:51Z*

  - **ISSUE** `#21134`_: (*tjstansell*) salt.modules.ssh.host_keys only reads first line of key files
  - **ISSUE** `#20708`_: (*bechtoldt*) salt.modules.ssh.user_keys retval shouldn't contain newlines
  * 2bb4ecf Merge pull request `#21878`_ from bechtoldt/issue/21134
  * 92c67b7 simply strip public and private key files, too

  * 8f5380b fix wrong file parsing in salt.modules.ssh.host_keys(), fixes `#21134`_, refs `#20708`_

- **PR** `#21877`_: (*bechtoldt*) Skip private keys upon ssh.host_keys execution, closes `#20711`_
  @ *2015-03-24T01:23:36Z*

  - **ISSUE** `#20711`_: (*bechtoldt*) Enhance salt.modules.ssh.host_keys to skip private key file exports
  * e0dc59e Merge pull request `#21877`_ from bechtoldt/issue/20711
  * 71d3121 add arg `private` to salt.modules.ssh.host_keys() so it is possible to skip private keys upon ssh.host_keys execution, fixes `#20711`_

- **PR** `#21853`_: (*garethgreenaway*) additions to list_jobs in the jobs runner
  @ *2015-03-24T01:22:47Z*

  - **ISSUE** `#21810`_: (*UtahDave*) jobs.list_jobs should page results: Feature request
    | refs: `#21853`_
  * 83be0d3 Merge pull request `#21853`_ from garethgreenaway/21810_jobs_runner
  * a058b20 removing unused import.

  * e6a7778 Adding some docs for list_jobs parameters.

  * 9e08fec Adding ability for the list_jobs method in the jobs running to search jobs within a time range.  Some general cleanup for the other search options, looping over the list of jobs only once rather than looping over the list each time.

- **PR** `#21920`_: (*fellyns*) refactor nested outputter for much better performance
  @ *2015-03-24T01:19:34Z*

  * 4bff51b Merge pull request `#21920`_ from fellyns/nested-output-perf
  * 57187c7 refactor nested outputter for much better performance, especially with large datasets

- **PR** `#21915`_: (*rallytime*) Python 3 compat fix for states/archive_test.py
  @ *2015-03-24T01:08:46Z*

  * 0c4b281 Merge pull request `#21915`_ from rallytime/pylint_develop
  * 12aa7e1 Python 3 compat fix for states/archive_test.py

- **PR** `#21908`_: (*ryanwohara*) Verify the key has a value.
  @ *2015-03-24T01:08:35Z*

  * eeecdeb Merge pull request `#21908`_ from ryanwohara/develop
  * af37d85 Remove trailing whitespace

  * f3c8f08 https://github.com/saltstack/salt/issues/21391

- **PR** `#21906`_: (*jfindlay*) add system info to versions report
  @ *2015-03-24T01:08:15Z*

  * 2542718 Merge pull request `#21906`_ from jfindlay/versions
  * 1436d40 add versions_report update to release notes

  * a4ef246 test.versions alias to versions_report

  * 87d46e8 add system info to versions information/report

- **PR** `#21900`_: (*isbm*) Feature "line edit"
  @ *2015-03-24T01:07:49Z*

  * b84ce5a Merge pull request `#21900`_ from isbm/isbm-edit-line
  * 6e332cb Added state support for line edit

  * d1263b6 Added support for "line edit" for files

- **PR** `#21911`_: (*basepi*) [Salt-SSH] Fix py3 shim changes to be python 2.6 compatible
  @ *2015-03-23T22:06:20Z*

  - **PR** `#20913`_: (*aneeshusa*) Check python major version, add shell code py3 compat.
    | refs: `#21911`_
  * c591938 Merge pull request `#21911`_ from basepi/salt-ssh.python26.20913
  * 24f2615 Fix py3 shim changes to be python 2.6 compatible

- **PR** `#21914`_: (*rallytime*) Revert "Python 3 compat fix for pylint"
  @ *2015-03-23T21:44:01Z*

  - **PR** `#21895`_: (*rallytime*) Python 3 compat fix for pylint
    | refs: `#21914`_
  * d1015f1 Merge pull request `#21914`_ from saltstack/revert-21895-pylint_dev
  * 8ebf146 Revert "Python 3 compat fix for pylint"

- **PR** `#21895`_: (*rallytime*) Python 3 compat fix for pylint
  | refs: `#21914`_
  @ *2015-03-23T17:37:05Z*

  * 4316d61 Merge pull request `#21895`_ from rallytime/pylint_dev
  * 7bfa4ce Disable unused-import for py 3 compatibility

  * e5e287c Pythong 3 compat fix for pylint

- **PR** `#21891`_: (*gotcha*) Specify valid values for gitfs_provider option
  @ *2015-03-23T15:08:01Z*

  * 78640b3 Merge pull request `#21891`_ from gotcha/patch-2
  * ffe267a Specify valid values for gitfs_provider option

- **PR** `#21889`_: (*jayeshka*) adding random_org unit test
  @ *2015-03-23T14:21:49Z*

  * dabc336 Merge pull request `#21889`_ from jayeshka/random_org-unit-test
  * d27ab5c adding random_org unit test

- **PR** `#21885`_: (*mattwillsher*) Remove check for physical virt type for salt.modules.virt.is_kvm_hyper()
  @ *2015-03-23T04:05:57Z*

  * adc9977 Merge pull request `#21885`_ from mattwillsher/patch-1
  * f9300a3 Remove check for physical virt type for KVM

- **PR** `#21882`_: (*eliasp*) Added missing 'code-block' statement for 'reg.absent' example.
  @ *2015-03-22T18:39:08Z*

  * 489e3d3 Merge pull request `#21882`_ from eliasp/fix-reg.absent-code-block
  * 8d82b2a Added missing 'code-block' statement for 'reg.absent' example.

- **PR** `#21880`_: (*bechtoldt*) update references, fixes `#21879`_
  | refs: `#25019`_
  @ *2015-03-22T18:38:27Z*

  - **ISSUE** `#21879`_: (*bechtoldt*) Reference pages in documentation are outdated again
    | refs: `#25019`_
  * 73fd3eb Merge pull request `#21880`_ from bechtoldt/issue/21879
  * db38f80 update references, fixes `#21879`_

- **PR** `#21874`_: (*bvtreyperry*) Add support for explicit lazy inode table initialization when creating ext* file systems
  @ *2015-03-22T18:29:31Z*

  * b02c1a2 Merge pull request `#21874`_ from bvtreyperry/lazy-itable-init
  * 53be98d Adding in the missing trailing newline character

  * 30014ce Add support for lazy inode table initialization for ext* file systems

- **PR** `#21868`_: (*basepi*) Merge forward from 2015.2 to develop
  @ *2015-03-21T22:08:13Z*

  * 1ef636c Merge pull request `#21868`_ from basepi/merge-forward-develop
  * 3c5f9af Lint (blank lines)

  * 9f3837f Remove duplicate modified function

  * 7040686 Merge remote-tracking branch 'upstream/2015.2' into merge-forward-develop

- **PR** `#21862`_: (*jfindlay*) adding keystone unit test
  @ *2015-03-20T21:39:32Z*

  - **PR** `#21834`_: (*jayeshka*) adding keystone unit test
    | refs: `#21862`_
  * 665cb94 Merge pull request `#21862`_ from jfindlay/keystone
  * d838474 add mock of keystoneclient module

  * 8d44cc0 resolved pylint error

  * 66dad7d adding keystone unit test

- **PR** `#21836`_: (*ticosax*) improve detection of changes of docker.running
  @ *2015-03-20T18:30:01Z*

  * c3e2a13 Merge pull request `#21836`_ from ticosax/docker-running-old-image
  * 4990cd9 We should never rewrite `name` of the state.

  * 6c15d2c seems better with a new line

  * e4d7f2a pep8

  * cc1cd22 improve detection of changes of docker.running

- **PR** `#21856`_: (*rallytime*) Add versionadded tags to new functions in runners/manage.py
  @ *2015-03-20T18:26:21Z*

  * 80c5532 Merge pull request `#21856`_ from rallytime/versionadded_tags
  * 9099e12 Add versionadded tags to new functions in runners/manage.py

- **PR** `#21844`_: (*johanek*) Always check other OS release files if lsb_distrib_id grain not populated from /etc/lsb-release
  @ *2015-03-20T18:02:27Z*

  - **ISSUE** `#19953`_: (*johanek*) lsb_distrib grains on CentOS/RHEL
    | refs: `#21844`_
  * 729db77 Merge pull request `#21844`_ from johanek/redhat-lsb-core
  * 505e5d6 Always check other OS release files if lsb_distrib_id grain not populated from /etc/lsb-release

- **PR** `#21841`_: (*ticosax*) `override_params` contains the real list of allowed parameters
  @ *2015-03-20T17:46:03Z*

  * 1cad321 Merge pull request `#21841`_ from ticosax/log-more-in-case-error
  * 6df6b45 `override_params` contains the real list of allowed parameters

- **PR** `#21842`_: (*ticosax*) Add a note regarding pkg-config to install libgit2
  @ *2015-03-20T17:37:12Z*

  * cdf10e5 Merge pull request `#21842`_ from ticosax/docu-gitfs
  * b01dfa9 Add a note regarding pkg-config to install libgit2

- **PR** `#21830`_: (*basepi*) Merge forward from 2015.2 to develop
  @ *2015-03-20T14:58:50Z*

  * 25da1be Merge pull request `#21830`_ from basepi/merge-forward-develop
  * 5256c1a Remove duplicate entries in yumpkg.py

  * d82d764 Merge remote-tracking branch 'upstream/2015.2' into merge-forward-develop

- **PR** `#21833`_: (*thatch45*) Merge `#21825`_
  @ *2015-03-20T14:45:45Z*

  - **PR** `#21825`_: (*skizunov*) Add Windows support for salt-master
    | refs: `#21833`_
  * 794ed4b Merge pull request `#21833`_ from thatch45/skizunov-develop
  * 7302169 lint

  * 54e6df3 really? this lint check should ignore docstrings

  * 0af63f7 Add Windows support for salt-master

- **PR** `#21815`_: (*hal58th*) Update index.rst salt-ssh doc
  @ *2015-03-19T20:28:45Z*

  * 3196cc8 Merge pull request `#21815`_ from hal58th/salt-ssh-doc-fixes
  * cdd9407 Update index.rst salt-ssh doc

- **PR** `#21819`_: (*isbm*) Feature: Package diff for YUM
  @ *2015-03-19T20:28:17Z*

  - **PR** `#21769`_: (*isbm*) Feature: diff support for package managed files
    | refs: `#21819`_
  * 6cd508c Merge pull request `#21819`_ from isbm/isbm-yum-pkg-diff
  * 3713113 Added diff support for YUM.

  * cf7e627 Added package download support for YUM

- **PR** `#21808`_: (*ticosax*) Since tag argument has been introduced, ...
  @ *2015-03-19T17:13:31Z*

  * f8c12f5 Merge pull request `#21808`_ from ticosax/tag-everywhere
  * 2599e9d Since tag argument has been introduced, ...

- **PR** `#21806`_: (*ticosax*) usefull when docker.installed is not used
  @ *2015-03-19T17:13:14Z*

  * ca50510 Merge pull request `#21806`_ from ticosax/optional-param
  * 1315a27 Since container is optional, fallback on name if not provided

- **PR** `#21805`_: (*ticosax*) doc: fix typo
  @ *2015-03-19T17:13:05Z*

  * 07683b7 Merge pull request `#21805`_ from ticosax/docu-fix-dockerio
  * 53b5bd6 It should be a dict

- **PR** `#21804`_: (*ticosax*) expose objectify parameter
  @ *2015-03-19T17:12:57Z*

  * a2cb4d5 Merge pull request `#21804`_ from ticosax/expose-objectify-parameter
  * 46011b2 fix mocking

  * e7da29b expose objectify parameter

- **PR** `#21800`_: (*isbm*) Bugfix: "No package specified" if passing only unmanaged file(s)
  @ *2015-03-19T17:11:08Z*

  * 077dd79 Merge pull request `#21800`_ from isbm/ismb-zypper-diff-bugfix
  * f536adb Bugfix: "No package specified" if passing only unmanaged file(s)

- **PR** `#21792`_: (*terminalmage*) Change loglevel of virt-what message to debug
  @ *2015-03-19T03:34:18Z*

  * 1aefaa6 Merge pull request `#21792`_ from terminalmage/change-log-entry
  * 8e8285f Change loglevel of virt-what message to debug

- **PR** `#21778`_: (*bbhoss*) Add note about ldap module requirement
  @ *2015-03-18T20:19:56Z*

  * 51f03df Merge pull request `#21778`_ from bbhoss/patch-1
  * 05d06a5 Add note about ldap module requirement

- **PR** `#21772`_: (*rallytime*) More python 3 compatibility
  @ *2015-03-18T19:01:52Z*

  * 9e8eebe Merge pull request `#21772`_ from rallytime/pylint_develop
  * 7bea12f More python 3 compatibility

- **PR** `#21769`_: (*isbm*) Feature: diff support for package managed files
  | refs: `#21819`_
  @ *2015-03-18T17:48:47Z*

  * 77a9fcb Merge pull request `#21769`_ from isbm/isbm-zypper-diff
  * e6d3c9c Added CLI example.

  * 7f68fc7 Added CLI example.

  * 7128dad Typo fix.

  * 84c1eca Doc adjustment.

  * b273960 Added diff support between current and vendor file.

  * aa893a7 Multipackages support.

  * 6d5930b Bugfix: Typo.

  * e2fa663 Added diff between installed and originally packaged file.

  * 3e6d790 Added package download to the local disk

  * 4b484e2 Identation fixes

  * d24faba PEP8: closing bracked matching

- **PR** `#21753`_: (*garethgreenaway*) addition of nagion_json module
  @ *2015-03-18T17:46:12Z*

  * 59ebea0 Merge pull request `#21753`_ from garethgreenaway/nagios_json_module
  * 1a5c6ab Adding missing versionadded tag.

  * 3db8203 updating __virtual__ to ensure that requests is imported successfully.

  * 5e638cb Missing CLI examples.

  * 715081d Adding a module to check the status of a host or a service on a host by connecting to Nagios via it's json interface.

- **PR** `#21771`_: (*garethgreenaway*) Check for requests library
  @ *2015-03-18T16:49:02Z*

  * 97f4ec9 Merge pull request `#21771`_ from garethgreenaway/check_for_requests
  * d7ccb25 only load modules that rely on the requests library if the requests library is available.

- **PR** `#21768`_: (*rallytime*) Python 3 compatibility for new files in develop
  @ *2015-03-18T15:39:57Z*

  * 207a84c Merge pull request `#21768`_ from rallytime/pylint_develop
  * d7ec528 Python 3 compatibility for new files in develop

- **PR** `#21736`_: (*isbm*) Feature: support RPM modified files
  @ *2015-03-18T14:52:22Z*

  * 844a3f2 Merge pull request `#21736`_ from isbm/isbm-rpm-modified-files
  * 40ad5d0 Lintfix: regexp neets 'r' prefix

  * 140fa83 Support inspection of modified files in Yum

  * 906c78e Support inspection of modified files in Zypper

  * 05d31d2 Added inspection of modified files

- **PR** `#21754`_: (*techhat*) Add support for affinity groups to Azure
  | refs: `#21761`_
  @ *2015-03-18T13:14:19Z*

  - **ISSUE** `#15960`_: (*egilh*) Azure: salt-cloud should be able to set affinity group
    | refs: `#21754`_
  * 1babda7 Merge pull request `#21754`_ from techhat/azureaffinity
  * 665ab8f Fix docstring while I'm here

  * f0c0789 Removing forgotten return

  * a89f909 Typo fix

  * d909c9d Add support for affinity groups to Azure

- **PR** `#21763`_: (*whiteinge*) Replaced PDF link to RTD to the GitHub releases page
  @ *2015-03-18T06:41:30Z*

  - **ISSUE** `#13755`_: (*akshimassar*) Latest offline pdf documentation is broken
    | refs: `#21763`_
  * 078b849 Merge pull request `#21763`_ from whiteinge/doc-pdf-link
  * 2e426dd Replaced PDF link to RTD to the GitHub releases page

- **PR** `#21761`_: (*techhat*) Adding docs for new Azure functionality
  @ *2015-03-18T06:40:39Z*

  - **ISSUE** `#15960`_: (*egilh*) Azure: salt-cloud should be able to set affinity group
    | refs: `#21754`_
  - **PR** `#21754`_: (*techhat*) Add support for affinity groups to Azure
    | refs: `#21761`_
  * 9679735 Merge pull request `#21761`_ from techhat/azuredocs
  * 5686e64 Adding docs for new Azure functionality

- **PR** `#21759`_: (*jfindlay*) fix develop lint
  @ *2015-03-18T03:05:14Z*

  * de9f722 Merge pull request `#21759`_ from jfindlay/develop_lint
  * e3d8a4c fix develop lint

- **PR** `#21416`_: (*haim0n*) setup.py: fix "invalid command name" error from distutils.dist for write-salt-ssh-packaging-file and write-salt-version
  @ *2015-03-17T23:55:25Z*

  * cf1c77f Merge pull request `#21416`_ from haim0n/develop
  * c686c7b Merge remote-tracking branch 'upstream/develop' into develop

  * 178b610 setup.py: fix "invalid command name" error from distutils.dist for write-salt-ssh-packaging-file and write-salt-version

- **PR** `#21750`_: (*techhat*) Allow Azure to cleanup old services and disks
  @ *2015-03-17T23:52:19Z*

  - **ISSUE** `#14628`_: (*andrejohansson*) [salt-cloud][azure] Delete instance doesn't clear disks or cloud service
    | refs: `#21750`_
  * b041d4b Merge pull request `#21750`_ from techhat/azurecleanup
  * 1d15024 Allow Azure to cleanup old services and disks

- **PR** `#21745`_: (*GideonRed*) Fix postgres_local_cache handling of abnormal return data
  @ *2015-03-17T23:48:40Z*

  * 5c3c43d Merge pull request `#21745`_ from GideonRed/develop
  * 88f2f34 Fix postgres_local_cache handling of abnormal return data

- **PR** `#21739`_: (*ticosax*) If there no containers in the response it does not mean the command failed.
  @ *2015-03-17T23:48:11Z*

  * 94501ca Merge pull request `#21739`_ from ticosax/dockerio-list_containers-empty
  * 4b35c70 If there no containers in the response it does not mean the command failed.

- **PR** `#21731`_: (*rallytime*) Python 3 compat for linode driver
  @ *2015-03-17T23:10:41Z*

  * 578c7c2 Merge pull request `#21731`_ from rallytime/py3_compat
  * 3b603fb Too many lines!

  * 228646b Don't remove ignore statement

  * 69d84db Python 3 compat for linode driver

- **PR** `#21742`_: (*basepi*) Merge forward from 2015.2 to develop
  @ *2015-03-17T21:55:03Z*

  - **ISSUE** `#8`_: (*thatch45*) Network persistence
  * d491e12 Merge pull request `#21742`_ from basepi/merge-forward-develop
  * 6be1f22 Merge pull request `#8`_ from jfindlay/merge_develop

    * b1fe4f0 fix localemod unit tests for merge forward

    * 3f9fb68 group locale.gen_locale parameter docs together

  * 0997e3d Merge remote-tracking branch 'upstream/2015.2' into merge-forward-develop

- **PR** `#21614`_: (*PeterS242*) Updated list_users to query for 16 users as that is what DRACs support. ...
  @ *2015-03-17T19:30:22Z*

  - **ISSUE** `#16`_: (*thatch45*) Add introspection functions to the salt functions dict
  * fd7b0e3 Merge pull request `#21614`_ from PeterS242/develop
  * d2281e3 Changed 17 to 16; manually tested and verified this is correct.

  * 31f64f1 Merge remote-tracking branch 'remote_saltstack_salt_develop/develop' into develop

  * 926b417 Merge branch 'local_develop', remote branch 'remote_saltstack_salt_develop/develop' into develop

  * 4541e69 Merge remote branch 'remote_saltstack_salt_develop/develop' into develop

  * 639a3e0 Updated Unit test from 11 to 17, to support 16 Dell DRAC user entries.

  * 119abb4 In order to list User Index `#16`_, the range must end at 17.

  * 1b8b089 Merge remote branch 'origin' into develop

    * 74f80e2 Updated list_users to query for 16 users as that is what DRACs support.  Cleaned up the DRAC racadm output/input handling for list_users.

  * 79d2bfd In order to get User Index `#16`_, the range must be 17.

  * 218b893 Updated list_users to query for 16 users as that is what DRACs support.  Cleaned up the DRAC racadm output/input handling for list_users.

- **PR** `#21738`_: (*ticosax*) transmit socket parameter for inner function calls
  @ *2015-03-17T18:05:57Z*

  * d777e0a Merge pull request `#21738`_ from ticosax/haproxy-socket-fix
  * 789b687 transmit socket parameter for inner function calls

- **PR** `#21725`_: (*thatch45*) Sh beacon
  @ *2015-03-17T16:57:48Z*

  * 18b80d2 Merge pull request `#21725`_ from thatch45/sh_beacon
  * 32a2f77 Add virtual function to sh and a log line to cmd.shells

  * 6799a9c Add docs on the config

  * 4eea0ef file format

  * 6d7715d fix issue with the tag being compounded

  * f3fe88a track the correct var

  * 7b2e103 more sh beacon fixes

  * e70854b Add cmd,shells

  * 39eac78 Add sh beacon

- **PR** `#21733`_: (*techhat*) Support Windows VMs in Azure
  @ *2015-03-17T16:17:09Z*

  - **ISSUE** `#12487`_: (*andrejohansson*) Unable to spin up Windows based image in Azure
    | refs: `#21733`_
  * 1905558 Merge pull request `#21733`_ from techhat/azurewindows
  * 5ef5ff6 Support Windows VMs in Azure

- **PR** `#21730`_: (*johanek*) Mac grains
  @ *2015-03-17T15:48:10Z*

  * 92deff9 Merge pull request `#21730`_ from johanek/mac-grains
  * 67609a0 Add osmajorrelease grain for OSX

  * 5ec7a13 Add manufacturer grain for OSX

  * 0b75b95 Add productname grain for OSX

- **PR** `#21729`_: (*jayeshka*) adding pyenv unit test
  @ *2015-03-17T15:47:52Z*

  * 552760e Merge pull request `#21729`_ from jayeshka/pyenv-unit-test
  * 7a0e1bc adding pyenv unit test

- **PR** `#21682`_: (*ticosax*) Partial revert 20799
  @ *2015-03-17T15:47:25Z*

  - **PR** `#20799`_: (*jfindlay*) Adds docker.latest_running state
    | refs: `#21682`_
  - **PR** `#19837`_: (*ipmb*) Adds docker.latest_running state
    | refs: `#20799`_
  * 7ca8e91 Merge pull request `#21682`_ from ticosax/partial-revert-20799
  * 55fc4ec docker-py client is not used here.

  * 247ba05 Document how to run container with latest image available

  * 708c56e Revert "Adds docker.latest_running state"

- **PR** `#21715`_: (*basepi*) Merge forward from 2015.2 to develop
  @ *2015-03-17T00:42:13Z*

  * 92bf2a2 Merge pull request `#21715`_ from basepi/merge-forward-develop
  * 428a933 Apparently pylint doesn't like print statements as functions

  * 9c87ece more lint fix

  * 38638ae fix lint

  * 53f7d38 When unable to allocate a jid, return an error in the pub data

  * fd93491 Merge remote-tracking branch 'upstream/2015.2' into merge-forward-develop

- **PR** `#21695`_: (*isbm*) Add auto-import GPG keys options
  @ *2015-03-17T00:41:45Z*

  - **ISSUE** `#21507`_: (*aboe76*) Add option--gpg-auto-import-keys to  salt/modules/zypper.py
    | refs: `#21695`_
  * 415abb8 Merge pull request `#21695`_ from isbm/zypper-gpg-keys
  * 6e40cd8 Add auto-import GPG keys options

- **PR** `#21604`_: (*mdemmitt-lyft*) Add the ability to set default ASG scaling policies and notification pol...
  @ *2015-03-16T20:27:44Z*

  * 3c76046 Merge pull request `#21604`_ from lyft/update-asg-and-dynamo
  * 751d3ac add missing comma

  * 78aacdb add the ability to set default ASG scaling policies and notification policies in a pillar.  Small bugfix for the dynamo module

- **PR** `#21685`_: (*mgwilliams*) boto_ec2 module
  @ *2015-03-16T20:17:42Z*

  - **PR** `#21674`_: (*tsaridas*) boto ec2 in order to manage keys
    | refs: `#21685`_
  * b38e312 Merge pull request `#21685`_ from mgwilliams/boto_ec2
  * bf86b8f lint on boto_ec2

  * 359e03e boto_ec2: add missing docstring

  * 6d678f9 fix comment error

  * 6b86d9f fix import order

  * 19948e7 Merge remote-tracking branch 'origin/develop' into ec2

  * c70a179 Merge remote-tracking branch 'origin/develop' into ec2

  * a956c02 modules.boto_ec2: cache connections in context

  * 1628f15 add rudimentary boto_ec2 module

- **PR** `#21697`_: (*isbm*) Bugfix: method crashes when using '+' operand to dicts.
  @ *2015-03-16T19:09:45Z*

  * 2c1193f Merge pull request `#21697`_ from isbm/isbm-systemd-dicts-bug
  * d064e8f Bugfix: method crashes when using '+' operand to dicts.

- **PR** `#21673`_: (*tsaridas*) Fixes module and state rds
  @ *2015-03-16T18:39:32Z*

  * 123181b Merge pull request `#21673`_ from tsaridas/fixes_module_and_state_rds
  * 5519111 - replica exists

  * c5edeb7 - Removed calls that were already in module - Add tags in exists - Sync parameters to be the same as boto

- **PR** `#21693`_: (*techhat*) Fix hardcoded role in Azure input endpoints
  @ *2015-03-16T18:38:06Z*

  * 5aa2e7e Merge pull request `#21693`_ from techhat/azurerole
  * 09f86b3 Add requests doc clarification

  * f54079b Fix hardcoded role in Azure input endpoints

- **PR** `#21691`_: (*cachedout*) Add versionadded directives for new features in manage runner
  @ *2015-03-16T18:37:31Z*

  - **PR** `#19293`_: (*DmitryKuzmenko*) Support joined, allowed, alived and reaped runners.
    | refs: `#21691`_
  * 0d812d9 Merge pull request `#21691`_ from cachedout/versionadded_manage
  * f5f61bc Add versionadded directives for new features in manage runner

- **PR** `#21675`_: (*gracinet*) Tests for git_pillar
  @ *2015-03-16T18:35:15Z*

  - **ISSUE** `#21342`_: (*gracinet*) External pillars calling pillar_compile
    | refs: `#21675`_
  * f2d2348 Merge pull request `#21675`_ from gracinet/test_git_pillar
  * 458cc64 Pylint error + standalone launcher

  * 2901c98 git_test: credits

  * 0dae9df Tests for git_pillar

- **PR** `#21660`_: (*aneeshusa*) Pin SaltTesting dependency down to a specific version.
  @ *2015-03-16T18:32:13Z*

  - **ISSUE** `#21617`_: (*aneeshusa*) Pinning of all dependency versions
    | refs: `#21660`_
  * 36ecb42 Merge pull request `#21660`_ from aneeshusa/pin-salttesting-dependency
  * 17acede Pin SaltTesting dependency down to a specific version.

- **PR** `#21653`_: (*cachedout*) Logstash engine
  @ *2015-03-16T18:31:48Z*

  * 4f3b15b Merge pull request `#21653`_ from cachedout/logstash_engine
  * ad85e74 Logstash engine!

- **PR** `#21692`_: (*rallytime*) Python 3 compat for beacons/service.py
  @ *2015-03-16T17:46:02Z*

  * effd56c Merge pull request `#21692`_ from rallytime/pylint_dev
  * e54ec5d Python 3 compat for beacons/service.py

- **PR** `#21690`_: (*rominf*) Fixes `#21684`_
  @ *2015-03-16T17:45:28Z*

  * ceedb86 Merge pull request `#21690`_ from rominf/zypper_install_no_refresh
  * 4bada15 [modules/zypper] install with --no-refresh; restore accidently broken list_upgrades

  * 13122e6 [modules/zypper] install with --no-refresh; change refresh meaning

  * af2a302 [modules/zypper] install with --no-refresh; fix copying

- **PR** `#21665`_: (*nmadhok*) Adding start, stop, suspend, reset and status action in VMware environment
  @ *2015-03-16T17:35:26Z*

  * dd230a7 Merge pull request `#21665`_ from nmadhok/vsphere-additions
  * 0ee3509 Update vsphere.py

  * 42ebec7 Adding action to be able to display status of a VM

  * 1413368 Adding action to be able to reset a VM

  * 523c6dc Adding action to be able to suspend a VM

  * f8fe9b6 Logging as info instead of error when VM is already powere on/off

  * ac20070 Specifying that start/stop of VM can be done using name

  * f470a4d Adding start and stop actions to be able to power on/off instance in VMware environment

- **PR** `#21689`_: (*techhat*) Add input endpoint management to Azure
  @ *2015-03-16T16:28:41Z*

  * ff70b80 Merge pull request `#21689`_ from techhat/azureendpoints
  * a3b1431 Remove unused imports

  * 0bbc2fb Document a need for requests with old Python versions

  * 05fbfd2 Add input endpoint management to Azure

- **PR** `#21674`_: (*tsaridas*) boto ec2 in order to manage keys
  | refs: `#21685`_
  @ *2015-03-16T16:03:39Z*

  * 13163b0 Merge pull request `#21674`_ from tsaridas/boto_manage_ec2_keys
  * d378a2c - Remove trailing whitespaces.

  * 090c417 removing old file

  * 1c5b298 - Fix pylint errors

  * 7d54f25 - Rename file - Add comments

  * 2c88c43 - renamed and fixed pylint errors

  * 59176f3 - boto ec2 in order to manage keys

- **PR** `#21684`_: (*rominf*) [modules/zypper] install with --no-refresh
  @ *2015-03-16T15:22:06Z*

  * e43eda5 Merge pull request `#21684`_ from rominf/zypper_install_no_refresh
  * 2b13054 [modules/zypper] install with --no-refresh

- **PR** `#21681`_: (*jayeshka*) adding rabbitmq unit test
  @ *2015-03-16T14:16:41Z*

  * 77b06be Merge pull request `#21681`_ from jayeshka/rabbitmq-unit-test
  * a6f8676 adding rabbitmq unit test

- **PR** `#20913`_: (*aneeshusa*) Check python major version, add shell code py3 compat.
  | refs: `#21911`_
  @ *2015-03-15T19:30:32Z*

  * 58faaa5 Merge pull request `#20913`_ from aneeshusa/salt-ssh-py3
  * 56d08c2 Add lint ignore for missing encoding in shim file.

  * b2f661e Check python major version, add shell code py3 compat.

- **PR** `#21676`_: (*aneeshusa*) Add error messages when missing setting_name param.
  @ *2015-03-15T19:27:39Z*

  * 3a2a22c Merge pull request `#21676`_ from aneeshusa/decorate-raw-typeerrors-git-module
  * 345b2a7 Add error messages when missing setting_name param.

- **PR** `#21672`_: (*bertjwregeer*) which_bin requires an Iterable collection
  @ *2015-03-15T19:20:06Z*

  - **ISSUE** `#21671`_: (*bertjwregeer*) salt-ssh sysrc on FreeBSD
    | refs: `#21672`_
  * be102d1 Merge pull request `#21672`_ from bertjwregeer/fix.sysrc
  * cb17e1a which_bin requires an Iterable collection

- **PR** `#21666`_: (*ahus1*) RVM doesn't install as non-root, gems don't install for RVM
  @ *2015-03-15T19:16:14Z*

  - **ISSUE** `#20317`_: (*joshdover*) RVM is not a function for gem state
    | refs: `#21666`_
  - **ISSUE** `#6815`_: (*davepeck*) salt.modules.gem.install ignores ruby parameter if rvm is installed locally and runas is provided
    | refs: `#21666`_
  * 6d0cef9 Merge pull request `#21666`_ from ahus1/ahus1_fix_rvm
  * fcd6699 added tests to ensure commands are created accordingly (without additional single quotes)

  * 748d2eb separate command from arguments to avoid problems when adding quotes

- **PR** `#21659`_: (*pass-by-value*) Simplify function
  @ *2015-03-15T18:55:08Z*

  * 9f1f0f8 Merge pull request `#21659`_ from pass-by-value/beacon_function_refactor
  * 8c7f962 Simplify function

- **PR** `#21649`_: (*aspyatkin*) Make enhancements to htpasswd modules
  @ *2015-03-13T22:41:11Z*

  - **ISSUE** `#21533`_: (*aspyatkin*) Add option specifying user to run htpasswd module functions
    | refs: `#21649`_ `#21649`_
  * d8f1cff Merge pull request `#21649`_ from aspyatkin/htpasswd-enhancements
  * b23c0fa Make enhancements to htpasswd modules

- **PR** `#21652`_: (*cachedout*) Interactive test suite
  @ *2015-03-13T22:30:24Z*

  * 0ead51a Merge pull request `#21652`_ from cachedout/daemons_only
  * baf2c40 More helper text, refactor filehandles, clean up

  * d04062a Remove loop interval setting, was causing cpus to spin

  * 56650f7 Include parser option for --no-tests

- **PR** `#21646`_: (*techhat*) Add management certificate functions to Azure driver
  @ *2015-03-13T22:28:35Z*

  * 37925ce Merge pull request `#21646`_ from techhat/azuremanagecert
  * e03d09d Add management certificate functions to Azure driver

- **PR** `#21622`_: (*aneeshusa*) Teach file.check_perms to handle uids and gids.
  @ *2015-03-13T22:26:24Z*

  - **ISSUE** `#21423`_: (*roflmao*) Function file.managed is run everytime on user = number
    | refs: `#21622`_
  * 579d66f Merge pull request `#21622`_ from aneeshusa/check-perms-numeric-ids
  * 2888f3b Teach file.check_perms to handle uids and gids.

- **PR** `#21612`_: (*cachedout*) Begin refactoring ClearFuncs
  @ *2015-03-13T22:25:52Z*

  * 1eb0256 Merge pull request `#21612`_ from cachedout/refactor_clearfuncs
  * d2fe2da Lint

  * 8c22127 Pull jid generation into own priv method. Make prep_pub only return dict.

  * 93d5285 Lint

  * 1d1fd57 Collapse logic for token detection

  * 07f3ab1 Lint

  * 069a8b3 Break out publication step

  * c4f027e Return all necessary data back to localclient. Still needs work.

  * 2d3fe39 Typo in method creation

  * 929b7cb Capitalization typo

  * 71951d3 Move pub setup logic into private helper method

  * 2c1fa29 Move check against running user into AuthUser class

  * a1405d3 Lint

  * 1c199bb Add AuthUser class to represent user

  * cc0bdcc Pulled acl out of master and started on user auth

  * eac8e35 Managed to write one line before being interrupted :-/

  * 68c75fd Starting on clientacl class

- **PR** `#21643`_: (*pass-by-value*) Format ret list and update docstring for service beacon
  @ *2015-03-13T21:28:53Z*

  * 95fc1ae Merge pull request `#21643`_ from pass-by-value/service_beacon_update
  * 8ca9794 pacing

  * 7000d52 pylint

  * 4921d31 Format ret list and update docstring for service beacon

- **PR** `#21644`_: (*Linuturk*) Adding additional output to assist in troubleshooting. Fixes `#21638`_
  @ *2015-03-13T20:43:28Z*

  - **ISSUE** `#21638`_: (*Linuturk*) TLS Module Error Reporting
    | refs: `#21644`_
  * 34d48fb Merge pull request `#21644`_ from Linuturk/tls_error_reporting
  * 224b1a2 Adding additional output to assist in troubleshooting. Fixes `#21638`_

- **PR** `#21634`_: (*techhat*) Add service certificate management to Azure driver
  @ *2015-03-13T20:20:12Z*

  * 96a5ae2 Merge pull request `#21634`_ from techhat/azureservicecert
  * f68a3b2 Add service certificate management to Azure driver

- **PR** `#21627`_: (*techhat*) Remove hardcoded images, sizes from softlayer_hw driver
  @ *2015-03-13T18:12:10Z*

  * df52f85 Merge pull request `#21627`_ from techhat/softlayerhardcoded
  * 7bccf31 Remove cruft from dev work

  * f08b0fc Remove hardcoded images, sizes from softlayer_hw driver

- **PR** `#21132`_: (*jond64*) Enable reporting changes in test mode for cmd states when using stateful output
  @ *2015-03-13T15:37:08Z*

  * 702eae7 Merge pull request `#21132`_ from jond64/cmd-stateful-testmode
  * fc87b5c Fixed version added and lint error

  * e464ae3 Enable reporting changes in test mode for cmd states when stateful=True

  * 7f65a9f Support test mode for the cmd states when stateful=True (WIP)

  * 11c5645 Support test mode for the cmd states when stateful=True (WIP)

- **PR** `#21623`_: (*isbm*) Bugfix: enable download-only for both downgrades and installations.
  @ *2015-03-13T15:33:26Z*

  * 31b85be Merge pull request `#21623`_ from isbm/zypper-bugs
  * 4523fab Bugfix by rewrite: latest_version() is using new info() function and also always returns the same type

  * f1be5f4 Feature: added package info() function

  * af109da Bugfix: list_locks() crashes if no locks directory yet exists.

  * 517a097 Bugfix: broken list_products()

  * 96d2c95 Documentation adjustment.

  * d7f669d Documentation adjustment.

  * 7c60edf Do not return different types in the same function.

  * 5dc2503 Return updated information about repo modification.

  * 5a7973b Adjustment: latest_version() is no longer returns an empty string

  * f1c952e Typo fix.

  * 3c2a330 Bugfix: no "retcode" in STDOUT calls.

  * e36204a Bugfix: enable download-only for both downgrades and installations.

- **PR** `#21541`_: (*arthurlogilab*) [uptime] add __virtual__ to prevent loading when requests is not available
  @ *2015-03-13T15:30:58Z*

  * a0c748d Merge pull request `#21541`_ from arthurlogilab/uptime
  * df8788e fix empty lines (lint), fix documentation

  * c633e97 Merge branch 'develop' of https://github.com/saltstack/salt into uptime

  * de5c0c0 backport @rallytime's patch to make it mergeable

  * 2f114a3 [uptime] add __virtual__ to prevent loading when requests is not available

- **PR** `#21616`_: (*allmightyspiff*) update state dockerio.running docs to reflect reality
  @ *2015-03-13T15:16:38Z*

  * 26a98c7 Merge pull request `#21616`_ from allmightyspiff/dockerio-doc-update
  * 4ab2863 updated docks for dockerio.running to reflect reality

- **PR** `#21575`_: (*garethgreenaway*) Pushover
  @ *2015-03-13T15:12:32Z*

  * 279c9aa Merge pull request `#21575`_ from garethgreenaway/pushover_returner
  * 09cbab2 Final lint error.  Example missing in the pushover module for post_message

  * 7f3a458 Switching to use .get for pulling values from dictionaries.

  * 74aace3 missed some lint errors.

  * e9bd2e5 fixing more lint errors

  * 3e03b14 fixing some lint issues.

  * f2cf4bb Adding module and state module to send notifictions to pushover.net

  * 97e7143 initially adding a returner for pushover.com

- **PR** `#21608`_: (*rallytime*) Python 3 compat for msazure.py
  @ *2015-03-12T22:16:21Z*

  * 80e54f8 Merge pull request `#21608`_ from rallytime/pylint
  * 9a15eae Python 3 compat for msazure.py

- **PR** `#21595`_: (*matthb2*) Add network type to support InfiniBand interfaces on RHEL/CentOS
  @ *2015-03-12T21:06:18Z*

  - **ISSUE** `#21388`_: (*matthb2*) network.managed for IP over InfiniBand on RHEL7
    | refs: `#21595`_
  * 6c189e7 Merge pull request `#21595`_ from matthb2/add_infiniband_support
  * dca7ed7 rh_ip.py: fix indentation

  * 4794a5e Add network type to support InfiniBand interfaces on RHEL/CentOS

- **PR** `#21599`_: (*techhat*) Cleaning up Azure driver a bit
  @ *2015-03-12T20:40:36Z*

  * bf9f5e8 Merge pull request `#21599`_ from techhat/azurecleanup
  * e62a183 Cleaning up Azure driver a bit

- **PR** `#21594`_: (*techhat*) Add storage management to Azure
  @ *2015-03-12T18:37:51Z*

  * fece86c Merge pull request `#21594`_ from techhat/azurestorage
  * e47d85d Linting

  * 3460b9c Add storage management to Azure

- **PR** `#20779`_: (*cachedout*) Use declared yaml options
  @ *2015-03-12T18:03:16Z*

  - **ISSUE** `#20647`_: (*ryan-lane*) file.serialize fails to serialize due to ordered dicts
    | refs: `#20779`_
  - **ISSUE** `#6`_: (*thatch45*) Test module
  * 396e8a5 Merge pull request `#20779`_ from cachedout/issue_20647
  * 82dc90f Merge pull request `#6`_ from jfindlay/yaml_opts

    * fd829a9 compare OrderedDicts in serializer unit test

  * 6c23cf8 Just change serialize

  * 53881ac Use declared yaml options

- **PR** `#21386`_: (*quantonganh*) Allow to return the canonicalized absolute pathname
  @ *2015-03-12T17:46:57Z*

  * 04c041d Merge pull request `#21386`_ from quantonganh/file-readlink-canonicalize
  * 85c32e2 Allow to return the canonicalized absolute pathname

- **PR** `#21576`_: (*ryan-lane*) Have boto_elb state manage ELB security groups
  @ *2015-03-12T16:13:54Z*

  * c014512 Merge pull request `#21576`_ from lyft/elb-manage-secgroups
  * 8585c0f Have boto_elb state manage ELB security groups

- **PR** `#21586`_: (*techhat*) Add some service functions to the Azure driver
  @ *2015-03-12T15:35:56Z*

  * 62d4d2d Merge pull request `#21586`_ from techhat/azureservices
  * 4abe4d5 Update docstrings

  * 15ac8c7 Fix class detection

  * 5c76f18 Add some service functions to the Azure driver

- **PR** `#21590`_: (*cachedout*) Note change in yosemite max values and warn.
  @ *2015-03-12T15:29:49Z*

  - **ISSUE** `#21589`_: (*AnthonBerg*) OS X installation instructions "launchctl limit maxfiles 4096 8192" VERY BAD on Yosemite
    | refs: `#21590`_
  * eede117 Merge pull request `#21590`_ from cachedout/issue_21589
  * 5c59b4b Note change in yosemite max values and warn.

- **PR** `#21563`_: (*clinta*) add calculate_subnet to network module
  @ *2015-03-12T15:26:06Z*

  * fd730de Merge pull request `#21563`_ from clinta/develop
  * 9b4d766 add versionadded docstring

  * cd543ff lint

  * 3f149f1 add calculate_subnet to network module

- **PR** `#21396`_: (*garethgreenaway*) Additional logging for iptables module
  @ *2015-03-12T07:50:32Z*

  - **ISSUE** `#20818`_: (*gladiatr72*) iptables state + mod_aggregate: save -- non-functional
    | refs: `#21131`_ `#21396`_ `#21321`_
  - **PR** `#21321`_: (*jfindlay*) check for check then check, not check twice
    | refs: `#21396`_
  * 30dd026 Merge pull request `#21396`_ from garethgreenaway/20818_iptables_aggregate
  * e82a62b Adding fix for iptables --check that is currently in 2015.2 into develop.  Adding a log entry for testing aggregating iptables rules, should show that the save function that writes to disk is only called once and only called when necessary.

- **PR** `#21581`_: (*jayeshka*) adding qemu_nbd unit test
  @ *2015-03-12T07:49:27Z*

  * 2d05c5e Merge pull request `#21581`_ from jayeshka/qemu_nbd-unit-test
  * e4116bb adding qemu_nbd unit test

- **PR** `#21573`_: (*techhat*) Switch Azure to list sizes from API
  @ *2015-03-11T23:48:41Z*

  * 6ed603c Merge pull request `#21573`_ from techhat/azuresizes
  * 9a55852 Switch Azure to list sizes from API

- **PR** `#21571`_: (*basepi*) Merge forward from 2015.2 to develop
  @ *2015-03-11T22:26:33Z*

  * ad7c0bb Merge pull request `#21571`_ from basepi/merge-forward-develop
  * fec632a Merge remote-tracking branch 'upstream/2015.2' into merge-forward-develop

- **PR** `#21566`_: (*techhat*) Add some disk management functions for Azure
  @ *2015-03-11T21:50:44Z*

  * 76d2759 Merge pull request `#21566`_ from techhat/azuredisks
  * 88430f3 Add some disk management functions for Azure

- **PR** `#21553`_: (*ross-p*) Fix for issue `#21491`_ (composer install should always run)
  @ *2015-03-11T20:20:57Z*

  - **ISSUE** `#21491`_: (*martin-helmich*) composer.installed should not always "return True" when composer.lock is present
    | refs: `#21553`_
  * aef9701 Merge pull request `#21553`_ from xclusv/develop-`fix-21491`_
  * d15f867 composer.install module does not support always_check, only the state does.  Removing the test on the module.

  * cad2659 Fix lint issue.

  * 159d38e Fix for issue `#21491`_

- **PR** `#21554`_: (*rallytime*) Add versionadded directive to docker.lastest_running function
  @ *2015-03-11T19:33:20Z*

  - **ISSUE** `#21547`_: (*jasonm-makerbot*) docker.latest_running not in 2015.2
    | refs: `#21554`_
  * e3e455e Merge pull request `#21554`_ from rallytime/versionadded_docker_func
  * 1c3a764 Add versionadded directive to docker.lastest_running function

- **PR** `#21549`_: (*isbm*) Zypper download only
  @ *2015-03-11T18:11:50Z*

  * 4598538 Merge pull request `#21549`_ from isbm/zypper-download-only
  * a81310d Add documentation for download only feature.

  * 8f763ae Removing accidentally added file

  * 5026f6f Allows only to download package(s) to the /var/cache/zypp/packages/... without actual installation. Useful for offline installation later.

  * b97c5cf Merge remote branch 'upstream/develop' into develop

  * aa15560 Merge

  * 0bede50 Merge remote branch 'upstream/develop' into develop

  * 3ce754a Added enterprise product listing

- **PR** `#21526`_: (*twangboy*) Issue 15612
  @ *2015-03-11T17:47:18Z*

  * e5e757a Merge pull request `#21526`_ from twangboy/issue_15612
  * fedad96 Removed blank line at the end

  * 4b3593c Fixed Jenkins failures, white space, formatting, etc...

  * 251038b Removed print cmd line used for debugging

  * 4cc1513 Added service.create and service.delete

- **PR** `#21532`_: (*jayeshka*) adding poudriere unit test
  @ *2015-03-11T17:18:03Z*

  * 214f522 Merge pull request `#21532`_ from jayeshka/poudriere-unit-test
  * fc9a12e adding poudriere unit test

- **PR** `#21461`_: (*jfindlay*) Refactor unix crons
  @ *2015-03-11T15:52:28Z*

  * 13b7046 Merge pull request `#21461`_ from jfindlay/refactor_crons
  * 5dc09e7 update cron and cmd tests for cron runas changes

  * 31e749f fix incron module typos

  * d3ace06 modify incron module to use runas

  * ef383a9 modify cron module to use runas

  * 107ea90 add unix systems to runas _run test

- **PR** `#21539`_: (*guettli*) - changed name of internal variable for better readability
  @ *2015-03-11T15:50:12Z*

  * 4311b2c Merge pull request `#21539`_ from guettli/develop
  * 1443245 - changed name of internal variable for better readabiility (ret-->stdout)

- **PR** `#21534`_: (*aneeshusa*) Update salttesting pip requirement to develop branch.
  @ *2015-03-11T15:50:01Z*

  * a55aa59 Merge pull request `#21534`_ from aneeshusa/salttesting-requirement-branch
  * c8f55a1 Update salttesting pip requirement to develop branch.

- **PR** `#21531`_: (*whiteinge*) Switch the current release version back to 2014.7.2
  @ *2015-03-11T02:46:46Z*

  - **PR** `#21467`_: (*jacobhammons*) Updated man pages, updated copyright year in conf.py
    | refs: `#21531`_
  * 78dc256 Merge pull request `#21531`_ from whiteinge/doc-fix-current-release
  * 5f1feb8 Switch the current release version back to 2014.7.2

- **PR** `#21529`_: (*whiteinge*) Replace current release Jinja variable with rST substitution
  @ *2015-03-11T02:11:07Z*

  - **PR** `#21286`_: (*ahus1*) make latest 2014.7.x releases visible in documentation
    | refs: `#21529`_
  * c673e24 Merge pull request `#21529`_ from whiteinge/doc-current-release-shortcut
  * 43709e0 Replace current release Jinja variable with rST substitution

- **PR** `#21516`_: (*jfindlay*) fix contributing doc errors
  @ *2015-03-10T23:59:39Z*

  * cc52707 Merge pull request `#21516`_ from jfindlay/revise_contrib_doc
  * 0f631ab fix contributing doc errors

- **PR** `#21518`_: (*terminalmage*) Merge 2015.2 into develop
  @ *2015-03-10T23:58:42Z*

  * 26acc5c Merge pull request `#21518`_ from terminalmage/2015.2-develop
  * d25677e Merge branch '2015.2' into 2015.2-develop

- **PR** `#21517`_: (*llua*) shell completion (zsh): Fixed a few more minor things.
  @ *2015-03-10T23:22:13Z*

  * 5b8a31c Merge pull request `#21517`_ from llua/zsh-completion
  * 68552fd silent errors from salt-key, cache salt_dir and skip completing minions when -G or --grain is used.

- **PR** `#21513`_: (*rallytime*) Just use nested with statements instead of \\ continuation
  @ *2015-03-10T23:16:15Z*

  * c101f6f Merge pull request `#21513`_ from rallytime/fix_iptables_test
  * 8c55294 Remove pylint disable/enable comments

  * 254c17d Just use nested with statements instead of \\ contiuation

- **PR** `#21030`_: (*lorengordon*) File replace becomes hardlink friendly
  @ *2015-03-10T21:38:50Z*

  - **ISSUE** `#20969`_: (*lorengordon*) file.replace writes to a new inode, creating problems for hard links
    | refs: `#21030`_
  * 29b9bbe Merge pull request `#21030`_ from lorengordon/file-replace-becomes-hardlink-friendly
  * 3cf624c Update file.replace to be hardlink-friendly, fixes saltstack`#20969`_

- **PR** `#21493`_: (*thatch45*) Merge `#21455`_
  @ *2015-03-10T21:38:06Z*

  - **PR** `#21455`_: (*cro*) Add simple parser to return some activity numbers from our git log.
    | refs: `#21493`_
  * 142424d Merge pull request `#21493`_ from thatch45/cro-committerparser
  * 8d75a9f lint

  * 9bbe11e disable lint class inherit

  * 296b8a6 lint

  * 26fee96 Merge branch 'committerparser' of https://github.com/cro/salt into cro-committerparser

    * f587330 Moar Python3 compatibility.

    * ea70e82 Add statistics by committer by month, from future import

    * b95e5cd Add simple parser to return some activity numbers from our git log.

- **PR** `#21502`_: (*twellspring*) Clarify Mine Functions Aliases documentation
  @ *2015-03-10T21:01:56Z*

  * 6de51ef Merge pull request `#21502`_ from twellspring/patch-6
  * 6461b37 Clarify Mine Functions Aliases documentation

- **PR** `#21505`_: (*rallytime*) Another python 3 compatability fix
  @ *2015-03-10T19:26:53Z*

  * aa82fbe Merge pull request `#21505`_ from rallytime/pylinting
  * cc64a4f Another python 3 compatability fix

- **PR** `#21494`_: (*thatch45*) Merge `#21478`_
  @ *2015-03-10T17:19:00Z*

  - **ISSUE** `#21267`_: (*arthurlogilab*) state and module to monitor websites using uptime (open source web site monitoring)
    | refs: `#21478`_
  - **PR** `#21478`_: (*arthurlogilab*) [uptime] add execution modules and state modules for managing urls monitored by uptime
    | refs: `#21494`_
  * 2b1eab6 Merge pull request `#21494`_ from thatch45/arthurlogilab-uptime
  * 0a96d57 more lint

  * 4b92e77 Merge branch 'uptime' of https://github.com/arthurlogilab/salt into arthurlogilab-uptime

    * 05c8926 another pylint round

    * 56878e2 pylint round 2

    * 375e8c7 pylint round on uptime_test.py

    * 815a915 [uptime] add execution modules and state modules for managing urls monitored by uptime (open source nodejs/mongodb monitoring application)

- **PR** `#21489`_: (*pruiz*) Fix `#20787`_: YamlEx pillar merging fails when using gpg (even if pillar_source_merging_strategy is set to aggregate)
  @ *2015-03-10T17:15:29Z*

  - **ISSUE** `#20787`_: (*pruiz*) pillar_source_merging_strategy: smart not working when using more than one renderer at shebang line
    | refs: `#21489`_
  * 1048af7 Merge pull request `#21489`_ from pruiz/issue-20787
  * eb73d5b Avoid using list comprehensions while mutating elements inside gpg render, as to avoid breaking type inference for yamlex items.

- **PR** `#21468`_: (*pass-by-value*) Format load to have required keys
  @ *2015-03-10T16:50:37Z*

  * ef62e75 Merge pull request `#21468`_ from pass-by-value/update_laod
  * b80563e Handle case with module exec

  * d421c91 Change to update just fun and user

  * 7f22c6e Format load to have required keys

- **PR** `#21476`_: (*claudiupopescu*) Support for boto RDS storage type
  @ *2015-03-10T16:26:45Z*

  * d1c3721 Merge pull request `#21476`_ from claudiupopescu/boto-rds-storage-type
  * 9ec27dc Support for RDS storage type

- **PR** `#21473`_: (*mgwilliams*) fix bug in boto_sns module
  @ *2015-03-10T16:25:21Z*

  * b4897c2 Merge pull request `#21473`_ from mgwilliams/boto
  * 3bb6577 fix bug in boto_sns module

- **PR** `#21472`_: (*mgwilliams*) small improvements to engine modules
  @ *2015-03-10T16:24:56Z*

  * cd142b8 Merge pull request `#21472`_ from mgwilliams/engines
  * a8d3540 Merge branch 'develop' into engines

  * 9ccae0e handle queue connect failures in sqs_events engine

- **PR** `#21486`_: (*rallytime*) Pylint 3 compatability fix for payload.py
  @ *2015-03-10T16:04:18Z*

  * 821169b Merge pull request `#21486`_ from rallytime/pylint
  * 4370bd4 Pylint 3 compatability fix for payload.py

- **PR** `#21469`_: (*vdesjardins*) fixes `#20198`_: virt.get_graphics and virt.get_nics calls in module virt
  @ *2015-03-10T15:16:49Z*

  - **ISSUE** `#20198`_: (*jcftang*) virt.get_graphics, virt.get_nics are broken, in turn breaking other things
  * 827541e Merge pull request `#21469`_ from vdesjardins/develop
  * 40418ea fix pylint error in virt module.

  * 7e517a6 fixes `#20198`_: virt.get_graphics and virt.get_nics calls in module virt

* 6aa4989 Removed SaltConf banner


- **PR** `#21471`_: (*jayeshka*) adding znc unit test
  @ *2015-03-10T09:34:03Z*

  * 1903d4b Merge pull request `#21471`_ from jayeshka/znc-unit-test
  * 625b3f4 adding znc unit test

- **PR** `#21459`_: (*jfindlay*) de-cruft at.at command setup
  @ *2015-03-10T01:06:43Z*

  * e4daafc Merge pull request `#21459`_ from jfindlay/fix_at
  * e9e7d06 simplify at.at command setup

- **PR** `#21466`_: (*cachedout*) Lint syslog returner
  @ *2015-03-10T00:19:35Z*

  * 4e1c777 Merge pull request `#21466`_ from cachedout/syslog_lint
  * 757effe Lint syslog returner

- **PR** `#21334`_: (*tbaker57*) Documentation update. Resolves issue `#21060`_
  @ *2015-03-10T00:17:32Z*

  - **ISSUE** `#21060`_: (*tbaker57*) syslog returner: job data truncated
    | refs: `#21334`_
  * af074ac Merge pull request `#21334`_ from tbaker57/issue_21060
  * dcc60da Documentation update. Resolves issue `#21060`_

- **PR** `#21464`_: (*cachedout*) Change bootstrap instructions to two liner
  @ *2015-03-09T23:51:03Z*

  * 3ead144 Merge pull request `#21464`_ from cachedout/one_liner
  * 56bac36 Change bootstrap instructions to two liner

- **PR** `#21443`_: (*basepi*) Merge forward from 2015.2 to develop
  @ *2015-03-09T22:55:25Z*

  - **ISSUE** `#7`_: (*thatch45*) stats module
  - **ISSUE** `#6`_: (*thatch45*) Test module
  * 8ff95ac Merge pull request `#21443`_ from basepi/merge-forward-develop
  * 31c1d07 Merge pull request `#7`_ from jfindlay/merge

    * 7a49e3e fix test lint

  * b53eece Merge pull request `#6`_ from jfindlay/merge

    * 2c04a36 fix iptables tests

  * d17c908 Merge remote-tracking branch 'upstream/2015.2' into merge-forward-develop

- **PR** `#21447`_: (*thatch45*) MOAR beacons docs
  @ *2015-03-09T21:58:26Z*

  * fba2284 Merge pull request `#21447`_ from thatch45/beacon_doc
  * dc691ae Add return data example

  * bf20186 MOAR beacons docs

- **PR** `#21428`_: (*techhat*) Add get_operation_status() to Azure driver
  @ *2015-03-09T20:53:25Z*

  * 14981bf Merge pull request `#21428`_ from techhat/azureop
  * 66c075d Linting

  * 1e2ebc7 Add get_operation_status() to Azure driver

- **PR** `#21433`_: (*rallytime*) Latest Python 3 compat fixes, plus a versionadded tag
  @ *2015-03-09T20:28:30Z*

  * ffdce76 Merge pull request `#21433`_ from rallytime/pylint_fixes
  * b87ac90 It's incompatible-py3-code

  * 1cd73e8 Better pylint disable

  * 3620e4e Latest Python 3 compat fixes, plus a versionadded tag

- **PR** `#21445`_: (*rallytime*) Remove .rst from doc link
  @ *2015-03-09T20:16:59Z*

  - **ISSUE** `#21442`_: (*thusoy*) Bad reST link to usermode docs
    | refs: `#21445`_
  * b514da6 Merge pull request `#21445`_ from rallytime/fix_21442
  * a71aa68 Remove .rst from doc link

- **PR** `#21436`_: (*sjwoodr*) 21434: Support EC2 provider with non-standard ssh port
  @ *2015-03-09T19:27:40Z*

  * fa63b57 Merge pull request `#21436`_ from sjwoodr/21434_ec2-non-standard-ssh-port
  * 8a274d6 21434: Support EC2 provider with non-standard ssh port

- **PR** `#21279`_: (*minusf*) change to $HOME during startup (`#21241`_)
  @ *2015-03-09T17:16:08Z*

  - **ISSUE** `#21241`_: (*minusf*) minions not found when cwd not accessible
    | refs: `#21279`_
  * 2aeb82b Merge pull request `#21279`_ from minusf/issue_21241
  * dbc1fa1 change to $HOME during startup (`#21241`_)

- **PR** `#21314`_: (*arthurlogilab*) [modules/postgresql] modules for cluster management in postgresql (debian specific)
  @ *2015-03-09T17:09:56Z*

  - **ISSUE** `#21293`_: (*arthurlogilab*) Add support for clusters in the postgresql modules and states
    | refs: `#21314`_
  - **ISSUE** `#2`_: (*thatch45*) salt job queries
    | refs: `#22858`_
  - **ISSUE** `#1`_: (*thatch45*) Enable regex on the salt cli
    | refs: `#21356`_ `#21328`_
  * 268ee22 Merge pull request `#21314`_ from arthurlogilab/postgresql
  * 5f8d442 Merge pull request `#2`_ from makinacorpus/postgresql

    * 5f4905d fix tests

  * f34b2a3 Merge pull request `#1`_ from makinacorpus/postgresql

    * f1111bd lint

  * 592e0a1 [modules/postgresql] modules for cluster management in postgresql (debian specific)

- **PR** `#21430`_: (*thatch45*) Merge `#21400`_
  @ *2015-03-09T17:08:07Z*

  - **ISSUE** `#21399`_: (*VynceMontgomery*) fix grain template example
    | refs: `#21400`_
  - **PR** `#21400`_: (*VynceMontgomery*) finish changing variable name
    | refs: `#21430`_
  * a247ed7 Merge pull request `#21430`_ from thatch45/VynceMontgomery-develop
  * ecacdcb Merge branch 'develop' of https://github.com/VynceMontgomery/salt into VynceMontgomery-develop

  * 2723cb5 finish changing variable name

- **PR** `#21429`_: (*thatch45*) Merge `#21421`_
  @ *2015-03-09T17:03:28Z*

  - **ISSUE** `#20239`_: (*thedrow*) Create an acceptance test suite for salt
    | refs: `#21421`_
  - **ISSUE** `#8754`_: (*techhat*) [salt.cloud] Need test cases for salt.cloud providers
    | refs: `#21421`_
  - **PR** `#21421`_: (*junckritter*) Tests for cloud GCE provider
    | refs: `#21429`_
  * 0852db0 Merge pull request `#21429`_ from thatch45/junckritter-cloud-gce-tests
  * 0da8878 lint

  * d789f26 Merge branch 'cloud-gce-tests' of https://github.com/junckritter/salt into junckritter-cloud-gce-tests

  * daf06c1 Credit for test

  * 494d706 Working basic test for GCE cloud provider

  * ee00477 Template configs for GCE cloud provider

- **PR** `#21424`_: (*robin-wittler*) fix wrong mode handling in get_proc_dir and utils.fpopen
  @ *2015-03-09T16:54:27Z*

  - **PR** `#20715`_: (*robin-wittler*) fix file permission errors
    | refs: `#21424`_
  * ccff995 Merge pull request `#21424`_ from robin-wittler/develop
  * 2165b26 fix wrong mode handling in get_proc_dir

  * 29a7fba fix wrong mode handling

- **PR** `#21412`_: (*eliasp*) Suggest a separate repo for `top.sls`.
  @ *2015-03-09T16:51:39Z*

  * 76a976b Merge pull request `#21412`_ from eliasp/develop-doc-topics-tutorial-gitfs_separate_repo_for_top.sls
  * 583239b Suggest a separate repo for `top.sls`.

- **PR** `#21409`_: (*jquast*) Gracefully handle race condition of 'makedirs'
  @ *2015-03-09T16:50:42Z*

  * ab4d5b7 Merge pull request `#21409`_ from jquast/makedirs-race-condition
  * 5141052 Gracefully handle race condition in `makedirs'

- **PR** `#21420`_: (*jayeshka*) win_useradd unit test case
  @ *2015-03-09T16:03:25Z*

  * 7ed498d Merge pull request `#21420`_ from jayeshka/win_useradd-unit-test
  * 15b295e removed second pylint error

  * 529a57e removed pylint error

  * 51f00580 win_useradd unit test case

- **PR** `#21419`_: (*jayeshka*) pkgutil unit test case
  @ *2015-03-09T16:02:56Z*

  * b8cdbfe Merge pull request `#21419`_ from jayeshka/pkgutil-unit-test
  * f167faf pkgutil unit test case

- **PR** `#21410`_: (*PeterS242*) Update faq.rst
  @ *2015-03-08T15:14:50Z*

  * 6238c6c Merge pull request `#21410`_ from PeterS242/develop
  * d836b2b Update faq.rst

* 0aa1029 correction to grains example


- **PR** `#21371`_: (*pengyao*) fixed a typo for shadow.gen_password module
  @ *2015-03-06T18:33:58Z*

  * 45dae70 Merge pull request `#21371`_ from pengyao/shadow_typo
  * bace1c8 fixed a typo

- **PR** `#21324`_: (*rallytime*) Some pylint 3 compatibility fixes for develop
  @ *2015-03-06T17:52:31Z*

  * 5ba6437 Merge pull request `#21324`_ from rallytime/pylint_develop
  * 8198922 Pylint fix for real this time

  * 598b1b1 More pylint fixing

  * d9d30cc Pylint fix

  * dbdc12f Python 3 compat for joyent integration test file

  * 2590776 Python 3 compat for ec2_pillar

  * 76efa22 Python 3 compat for engines init and engines test

  * 81d1587 Python 3 compat fix for win_dacl.py

  * b9261e0 Python 3 compat for nspawn.py

- **PR** `#21375`_: (*mgwilliams*) engine updates
  @ *2015-03-06T17:11:29Z*

  * 5448b72 Merge pull request `#21375`_ from mgwilliams/engines
  * 577aa1a sqs_events engine: properly fire events when running on a minion

  * ac77a16 pack __runners__ for master engines

- **PR** `#21340`_: (*tsaridas*) fixes for rds replica state to work with keys
  @ *2015-03-06T15:58:16Z*

  * 8e01ee7 Merge pull request `#21340`_ from tsaridas/fixes_create_failing_with_key
  * d437a11 fixes for rds replica state to work with keys

- **PR** `#21347`_: (*torhve*) Fix IOError when using check_cmd
  @ *2015-03-06T15:57:41Z*

  * c74e67f Merge pull request `#21347`_ from torhve/fix-file-check_cmd
  * b27c176 Fix IOError when using check_cmd

- **PR** `#21351`_: (*garethgreenaway*) Adding the until flag into the schedule module.
  @ *2015-03-06T15:56:52Z*

  * 9d97cf3 Merge pull request `#21351`_ from garethgreenaway/missing_until_schedule_flag
  * 3e6d52b Adding the until flag into the schedule module.

- **PR** `#21356`_: (*eliasp*) Add support for 'virt-what' in the 'virtual' grain. Improve handling of ...
  @ *2015-03-06T15:47:08Z*

  - **ISSUE** `#1`_: (*thatch45*) Enable regex on the salt cli
    | refs: `#21356`_ `#21328`_
  - **PR** `#21328`_: (*eliasp*) Add support for 'virt-what' in the 'virtual' grain.
    | refs: `#21356`_
  * 7ec1eb7 Merge pull request `#21356`_ from eliasp/develop_grains_virt-what-support
  * 1c459e6 Add support for 'virt-what' in the 'virtual' grain. Improve handling of _cmds set.

- **PR** `#21357`_: (*rallytime*) Add versionadded tag to new jobs.last_run function
  @ *2015-03-06T15:46:34Z*

  * bbd526d Merge pull request `#21357`_ from rallytime/develop
  * 31795e1 Add versionadded tag to new jobs.last_run function

- **PR** `#21358`_: (*ross-p*) Fix composer, issue `#21349`_
  @ *2015-03-06T15:46:22Z*

  - **ISSUE** `#21349`_: (*ross-p*) Salt composer state now broken due to apparent change in PHP Composer's output
    | refs: `#21358`_
  * 06f9ce8 Merge pull request `#21358`_ from xclusv/fix-php-composer
  * a806412 Fixed lint complaints.

  * 2673f80 Added CLI example to composer.did_composer_install

  * ca56462 Merge branch 'develop' of https://github.com/saltstack/salt into fix-php-composer

  * d6545d1 Fixed syntax error.

  * 3cf3ccf Fix module: composer.install so it doesn't care what kind of output is returned by composer, and it relies exclusively on the return code instead. Add module: composer.update Add module: composer.selfupdate Fix state: composer.installed to support test mode Add state: composer.update Updated tests.

- **PR** `#21364`_: (*mgwilliams*) engine changes
  @ *2015-03-06T15:44:53Z*

  * 954bb8d Merge pull request `#21364`_ from mgwilliams/engines
  * 6078618 allow engines opt as dict or list

  * f703958 fix sqs_events engine docs

  * edeae4f engines: pack runners or minion mods into __salt__

  * f3fd1af Merge remote-tracking branch 'origin/develop' into engines

  * 8ebe941 fix bad wait timeout for sqs_events engine

  * 9161d62 add documentation for sqs_event engine

- **PR** `#21368`_: (*jimmystewpot*) Updated EC2/AWS provider documentation to reflect undocumented features regarding static PrivateIpAddress
  @ *2015-03-06T15:40:56Z*

  * 760b8a2 Merge pull request `#21368`_ from jimmystewpot/develop
  * f18dc55 Merge branch 'develop' of https://github.com/jimmystewpot/salt into develop

- **PR** `#21322`_: (*garethgreenaway*) Adding a beacon to monitor diskusage.
  @ *2015-03-05T14:44:23Z*

  * 24f1302 Merge pull request `#21322`_ from garethgreenaway/disk_usage_beacon
  * 62814b5 Adding a beacon to monitor diskusage.

- **PR** `#21335`_: (*garethgreenaway*) Adding a beacon to monitor network interface information.
  @ *2015-03-05T14:41:59Z*

  * 7cb208b Merge pull request `#21335`_ from garethgreenaway/beacons_network_info
  * 74f4eca Adding a beacon to monitor network interface information.

- **PR** `#21339`_: (*schwing*) Update Slack documentation
  @ *2015-03-05T13:38:17Z*

  * d4a8b9c Merge pull request `#21339`_ from schwing/slack_documentation
  * 6fecdfe Update Slack state module documentation

  * c71932f Update Slack module documentation

- **PR** `#21338`_: (*arthurlogilab*) typo fix in log s/Cloud/Could/
  @ *2015-03-05T13:37:45Z*

  * 9c342a0 Merge pull request `#21338`_ from arthurlogilab/patch-4
  * 31db428 typo fix in log s/Cloud/Could/

- **PR** `#21323`_: (*tsaridas*) add key_id
  @ *2015-03-05T04:14:23Z*

  * eccbfe6 Merge pull request `#21323`_ from tsaridas/add_key_id
  * c37e0f4 add key_id

- **PR** `#21327`_: (*ndenev*) Detect if we're running FreeBSD under KVM even if dmidecode is not installed
  @ *2015-03-05T04:13:14Z*

  * 53a776e Merge pull request `#21327`_ from ndenev/develop
  * 7415ea2 Detect if we're running FreeBSD even if dmidecode is not installed

- **PR** `#21331`_: (*nmadhok*) Replacing provider aws with ec2 fixes `#21274`_
  @ *2015-03-05T04:09:35Z*

  - **ISSUE** `#21274`_: (*nmadhok*) AWS providers new configuration format lists provider as `aws` instead of `ec2` causing error
  * dfc19ed Merge pull request `#21331`_ from nmadhok/doc-fix
  * b9cdd2b Replacing provider aws with ec2 fixes `#21274`_

- **PR** `#21330`_: (*mgwilliams*) add sqs_events engine
  @ *2015-03-05T02:16:43Z*

  * eba7f69 Merge pull request `#21330`_ from mgwilliams/engines
  * e9b331a add sqs_events engine; pass engine config to start func

- **PR** `#21306`_: (*terminalmage*) Add function to bootstrap salt onto an nspawn container
  @ *2015-03-04T22:16:39Z*

  * 699ec1b Merge pull request `#21306`_ from terminalmage/nspawn
  * 9f8183e remove call to nonexistant function

  * 011c387 nspawn: Add boostrap_salt function

  * efe74d5 Formatting fixes

- **PR** `#21319`_: (*garethgreenaway*) Adding a last_run function to the jobs runner.
  @ *2015-03-04T22:14:34Z*

  * f4fb7c6 Merge pull request `#21319`_ from garethgreenaway/jobs_runner_last_run
  * 764dbf7 Adding a last_run function to the jobs runner.

- **PR** `#21243`_: (*jfindlay*) fix develop lint
  @ *2015-03-04T17:06:46Z*

  * 025cddd Merge pull request `#21243`_ from jfindlay/develop_lint
  * cfd0395 fix develop lint

- **PR** `#21291`_: (*mgwilliams*) add engines to minion (raet only)
  @ *2015-03-04T16:17:25Z*

  * d94c659 Merge pull request `#21291`_ from mgwilliams/engines
  * 7880eea fix lint on engines.test

  * fda32e7 use the same test engine for master and minion

  * 565ceff remove unused imports

  * 8a8b5c8 add engines to minion (raet only)

- **PR** `#21283`_: (*gtmanfred*) Fix openstack cloud driver to work with only bootstrapping
  @ *2015-03-04T16:05:55Z*

  - **ISSUE** `#20932`_: (*dtoubelis*) Exception when calling create method on openstack cloud provider from reactor sls
    | refs: `#21283`_
  * 4bb0d32 Merge pull request `#21283`_ from gtmanfred/develop
  * 46dff88 remove extra log.debug

  * 9093bbb change deafult for kwargs

  * 24403b7 pass kwargs so that fixed networks can be set

  * 35e9b79 split out setting up networks

  * 5c3aebe need to use data for changing password

  * a76152d use ex_set_password

  * 877044c use ex_get_node_details if instance_id is specified

- **PR** `#21297`_: (*douardda*) Remove useless 'run_cmd' argument from _run_psql in postgresql module
  @ *2015-03-04T16:05:12Z*

  * 33ce399 Merge pull request `#21297`_ from douardda/patch-1
  * aec1803 Remove useless argument from _run_psql

- **PR** `#21295`_: (*Lothiraldan*) Update salt_token name
  @ *2015-03-04T15:47:30Z*

  * c7c0b92 Merge pull request `#21295`_ from Lothiraldan/patch-8
  * e97a34c Update salt_token name

- **PR** `#21290`_: (*mgwilliams*) do not prepare ZMQ publisher if ZMQ is not installed; fix missing import
  @ *2015-03-04T15:38:39Z*

  * 9853229 Merge pull request `#21290`_ from mgwilliams/raet
  * 7a1e8be do not prepare ZMQ publisher if ZMQ is not installed; fix missing import

- **PR** `#21286`_: (*ahus1*) make latest 2014.7.x releases visible in documentation
  | refs: `#21529`_
  @ *2015-03-04T06:19:26Z*

  * a52ebda Merge pull request `#21286`_ from ahus1/ahus1_releasedocs
  * 0887dfe make latest 2014.7.x releases visible in documentation

- **PR** `#21285`_: (*pravka*) fix ca creation in tls module
  @ *2015-03-04T06:17:34Z*

  * b7d4232 Merge pull request `#21285`_ from atbell/fix_ca_creation
  * 855df03 Merge remote-tracking branch 'upstream/develop' into fix_ca_creation

  * 8390c23 fixing index for ret

- **PR** `#21148`_: (*terminalmage*) Fill out the systemd-nspawn support
  @ *2015-03-04T04:44:59Z*

  * 97e8631 Merge pull request `#21148`_ from terminalmage/nspawn
  * f3280d3 docker index URL is a required parameter

  * ec2fe0d Add nspawn.remove function

  * 046a8fe Add compatibility function "remove"

  * 10d9963 Add missing CLI examples

  * 902d533 Fix lint failures

  * 450ac25 Update nspawn top-level docstring

  * 0a077c1 Update test_valid_docs for nspawn compatibility funcs

  * cb1dd50 Fill out more functionality in nspawn module

  * 75c5300 Use new utils function to check systemd version

  * ee570cf Add RST file for nspawn

  * 7ed18e2 Add function to get systemd version

  * 84b6c05 Fill out some functonality in nspawn module

  * 876042c Improve config.get docstring

  * 4f1ef1c add nspawn.stop

  * 3fe0f75 Fix nspawn.bootstrap

- **PR** `#21273`_: (*thatch45*) Service beacon
  @ *2015-03-04T04:43:21Z*

  * a80e9b3 Merge pull request `#21273`_ from thatch45/service_beacon
  * d600041 initial service beacon

  * 36ddf6d I thought I changed the to 2048 a while ago....

- **PR** `#21255`_: (*jayeshka*) adding win_timezone unit test case
  @ *2015-03-03T16:58:51Z*

  * cd475c3 Merge pull request `#21255`_ from jayeshka/win_timezone-unit-test
  * 323c195 adding win_timezone unit test case

- **PR** `#21234`_: (*thatch45*) Beacons modules
  @ *2015-03-03T16:36:23Z*

  * 051c944 Merge pull request `#21234`_ from thatch45/beacons_modules
  * 05a34c3 send functions into the beacon loader

  * 8baf83a Send execution modules into the beacons system

- **PR** `#21230`_: (*ryan-lane*) Fix ARN lookup when using IAM roles in boto_iam module
  @ *2015-03-03T16:36:14Z*

  * cb83fd5 Merge pull request `#21230`_ from lyft/fix-arn-lookup-for-iam-roles
  * f9947e5 Fix ARN lookup when using IAM roles in boto_iam module

- **PR** `#21229`_: (*thatch45*) Engines
  @ *2015-03-03T16:35:48Z*

  - **ISSUE** `#7`_: (*thatch45*) stats module
  * 3467622 Merge pull request `#21229`_ from thatch45/master_service
  * eaea4b0 Merge branch 'master_service' of github.com:thatch45/salt into master_service

    * e1d995a Merge pull request `#7`_ from whiteinge/doc-engines-mod-index

      * b001cb6 Added engine modules to modules index in docs

  * 073c9ee i always forget these...

  * 99ea2ba change engine loader to be raw, no filter func

  * 62e0ecb Add Salt engines to zmq

  * 3e01f43 clean up engine init

  * fba2e90 import engines in core.py

  * 578dce9 fix main for proc_mgr

  * a4eb64c Merge branch 'develop' into master_service

  * b30432e hook the engine start into raet

  * 896d008 init the engines with a function

  * 4dea1d8 Add engine start interface

  * 5343af1 Initial test engine

  * 9a4f02b make the engines pass the start function

  * 41f00d0 rinish rename to engine

  * c0463ac reanme plugin dir to engines

  * ebf7c75 Add msrvc plugin dir

  * 67b444e add msrvc loader function

- **PR** `#21247`_: (*whiteinge*) Added new modules to the module indexes
  @ *2015-03-03T05:15:22Z*

  * 7f6053a Merge pull request `#21247`_ from whiteinge/doc-new-modules
  * 714921a Added autosummary placeholders for new models

  * b6c1b26 Added new modules to the module indexes

- **PR** `#21235`_: (*whiteinge*) Merge 2015.2 forward
  @ *2015-03-02T22:50:02Z*

  * 6d02715 Merge pull request `#21235`_ from whiteinge/merge-2015.2-forward
  * 1399949 Merge remote-tracking branch 'upstream/2015.2' into develop

- **PR** `#21208`_: (*cro*) Merge forward 2015.2->develop
  @ *2015-03-02T14:55:38Z*

  * dff484c Merge pull request `#21208`_ from cro/2015-03-01-2015.2-develop
  * c880eb5 Lint fix.

  * f171df4 Merge forward 2015.2->develop

- **PR** `#21210`_: (*steverweber*) Ipmi doc fix
  @ *2015-03-02T05:45:15Z*

  * a933b6c Merge pull request `#21210`_ from steverweber/ipmifix
  * d180d86 doc fix

  * 3f07240 doc fix

- **PR** `#21128`_: (*lomeroe*) Add win dacl
  @ *2015-03-02T04:14:57Z*

  - **ISSUE** `#8539`_: (*emmellee*) Windows:  file.directory  users and permissions?
    | refs: `#21128`_
  * 76bd9b5 Merge pull request `#21128`_ from lomeroe/add_win_dacl
  * b8149f9 Lint...sigh

  * 8bb8e64 Added test functionality to state module.  Modified daclConstants to allow more flexibility.

  * f350b3b lint fix - unused import

  * f134466 EOL Fixes...

  * 59e0db8 In-code documentation fixes

  * a7a1102 Added win_dacl module and state, allows managing DACLs on Windows Files/Directories/Registry Keys

- **PR** `#21195`_: (*dmyerscough*) Incorrect example in comment
  @ *2015-03-02T04:05:44Z*

  * 779dbc2 Merge pull request `#21195`_ from dmyerscough/master-finger-typo
  * 822c5ea The -F options shows all key fingerprints, -f allows you to filter out a specific key

- **PR** `#21186`_: (*tsaridas*) Added function create rds read replica
  @ *2015-03-01T19:27:49Z*

  * 2aaf361 Merge pull request `#21186`_ from tsaridas/rds_read_replica
  * 6b206e1 fix pylint error

  * 23ae228 Added create replica state

  * 796fa60 Small correction

  * 6e17352 Fix to the correct if ... if not

  * 54c8dad Fix pylint errors

  * 7c8caf1 Added function create rds read replica

* 2397e6c Optimizations for `#20124`_

  - **PR** `#20124`_: (*cgtx*) add init system to default grains

- **PR** `#20124`_: (*cgtx*) add init system to default grains
  @ *2015-03-01T02:35:59Z*

  * ef5ebb5 Merge pull request `#20124`_ from cgtx/grain_init
  * 8a1df6c add init system to default grains (resolve `#20124`_)

- **PR** `#21143`_: (*mnguyen1289*) Fix ordering of generated interfaces in the /etc/network/interface file
  @ *2015-03-01T02:18:27Z*

  * abd9e4e Merge pull request `#21143`_ from mnguyen1289/fix-debian-ip-ordering
  * 5abbafb Fix ordering of generated interfaces in the /etc/network/interface file

- **PR** `#21171`_: (*tsaridas*) Fix for boto_secgroup state `#21168`_
  @ *2015-03-01T02:16:06Z*

  - **ISSUE** `#21168`_: (*tsaridas*) bug in state boto_secgroup.py
    | refs: `#21171`_
  * 3e3ed2d Merge pull request `#21171`_ from tsaridas/fix_boto_secgroup.py_state
  * 5f09551 Fix for boto_secgroup state `#21168`_

- **PR** `#21155`_: (*steverweber*) service mod_watch init_delay
  @ *2015-03-01T02:15:40Z*

  * 91317b4 Merge pull request `#21155`_ from steverweber/service_init_delay
  * 4b6e620 service mod_watch init_delay

- **PR** `#21173`_: (*UtahDave*) fix code block formatting
  @ *2015-03-01T00:49:03Z*

  * 6b8a00e Merge pull request `#21173`_ from UtahDave/develop
  * 5487366 fix code block formatting

- **PR** `#21157`_: (*c-nixon*) Add support for git remote helpers to gitfs
  @ *2015-02-28T23:30:21Z*

  * 39d635d Merge pull request `#21157`_ from c-nixon/GitPython-git-remote-helper-support
  * 9b5be19 Add support for git remote helpers to gitfs

- **PR** `#21159`_: (*kiorky*) lxc: reintroduce reboot/reconfigure
  @ *2015-02-28T22:59:03Z*

  * e7f5efc Merge pull request `#21159`_ from makinacorpus/lxc_reconfigure2
  * db280ff lxc: reintroduce reboot/reconfigure

- **PR** `#21141`_: (*llua*) shell completion: test the correct cache for minions
  @ *2015-02-28T21:50:55Z*

  * 65633c1 Merge pull request `#21141`_ from llua/zsh-completion-caching
  * 3a45315 shell completion: test the correct cache for minions

- **PR** `#21166`_: (*whiteinge*) Avoid TypeError if Tornado is not installed
  @ *2015-02-28T21:49:37Z*

  * d958387 Merge pull request `#21166`_ from whiteinge/rest_tornado_version_check_traceback
  * 90b481b Avoid TypeError if Tornado is not installed

- **PR** `#21163`_: (*s0undt3ch*) Lint fixes for `#21158`_
  @ *2015-02-28T21:44:28Z*

  * b74d8eb Merge pull request `#21163`_ from s0undt3ch/develop
  * ca1814f Py3 compat and remove unused imports

  * 51150d2 Fix `_text_type` references

- **PR** `#21158`_: (*terminalmage*) Merge 2015.2 branch into develop
  @ *2015-02-28T19:25:35Z*

  * 60b28a0 Merge pull request `#21158`_ from terminalmage/2015.2-develop
  * 94d5588 Resolve merge conflicts

- **PR** `#21153`_: (*rallytime*) Merge `#21142`_ with Pylint Fix
  @ *2015-02-28T15:47:21Z*

  - **PR** `#21142`_: (*garethgreenaway*) Fixes to debian_ip
    | refs: `#21153`_
  * d7bd2c3 Merge pull request `#21153`_ from rallytime/merge-21142
  * 554aaa4 Pylint fix

  * cd5234e Fixing a typo in the debian_ip module.

- **PR** `#21131`_: (*garethgreenaway*) fixes to iptables state module
  @ *2015-02-27T21:01:09Z*

  - **ISSUE** `#20818`_: (*gladiatr72*) iptables state + mod_aggregate: save -- non-functional
    | refs: `#21131`_ `#21396`_ `#21321`_
  * abfd1a8 Merge pull request `#21131`_ from garethgreenaway/iptables_aggregate_fix_save
  * 478b205 Fixing a bug when using the aggregate functionality where rules were not being saved even when specified in the state files.

- **PR** `#21129`_: (*pravka*) tls module: missing subdir in path check for create_ca_signed_cert
  @ *2015-02-27T21:00:57Z*

  * c965a4d Merge pull request `#21129`_ from atbell/fix_cert_check_in_tls
  * e1078a0 missing subdir in path check

- **PR** `#21099`_: (*tsaridas*) Added boto_elb.register_instances state function
  @ *2015-02-27T21:00:14Z*

  * 8328522 Merge pull request `#21099`_ from tsaridas/boto_elb.register_instances_state
  * 2f31e45 Added verion + codeblock to comments

  * 867c902 Fixed pr-lint issiues

  * 0efb1d1 Added boto_elb.register_instances state function

- **PR** `#21086`_: (*steverweber*) restart service on mod_watch
  @ *2015-02-27T17:03:59Z*

  * 7aa9819 Merge pull request `#21086`_ from steverweber/service_restart
  * dd60432 extra safe

  * 61ed479 restart service on mod_watch

- **PR** `#21111`_: (*s0undt3ch*) Merge branch 2015.2 into develop
  @ *2015-02-27T17:02:18Z*

  * 85d8526 Merge pull request `#21111`_ from s0undt3ch/develop
  * 62f868a Merge branch '2015.2' into develop

- **PR** `#21115`_: (*llua*) shell completion: allow caching of modules and minions
  @ *2015-02-27T17:01:57Z*

  * 6c2abf6 Merge pull request `#21115`_ from llua/zsh-completion-caching
  * 4b9868b shell completion: allow caching of modules and minions

- **PR** `#21106`_: (*polliard*) Issue `#21105`_ - Added code in the class Key list_keys(self) to test for t...
  @ *2015-02-27T04:14:28Z*

  - **ISSUE** `#21105`_: (*polliard*) Hidden files should not be considered valid minion keys
  * 43e69d2 Merge pull request `#21106`_ from polliard/issue-21105
  * 7181714 Issue `#21105`_ - Added code in the class Key list_keys(self) to test for the filename/dirname that starts with '.'

- **PR** `#21102`_: (*garethgreenaway*) Adding missing debian_source template
  @ *2015-02-27T04:13:33Z*

  * 53a2c35 Merge pull request `#21102`_ from garethgreenaway/missing_debian_source
  * e8cdea9 Adding missing debian_source template, used when adding sources to the /etc/network/interfaces file, eg. source /etc/network/interfaces.d/*

- **PR** `#21101`_: (*cachedout*) Beacon intervals
  @ *2015-02-27T01:11:09Z*

  * c7bf08e Merge pull request `#21101`_ from cachedout/beacon_schedule
  * 7cb5500 Document becaon intervals

  * db15788 Beacon interval scheduling

- **PR** `#21100`_: (*garethgreenaway*) Nagios Returner
  @ *2015-02-27T01:10:34Z*

  - **ISSUE** `#13876`_: (*aboe76*) Nagios nrdp returner
    | refs: `#21100`_
  * 3001029 Merge pull request `#21100`_ from garethgreenaway/nagios_returner
  * 15c0494 Initially adding a nagios returner that uses the NRDP nagios addon.

- **PR** `#21090`_: (*aboe76*) Updated salt spec file for 2014.7.2
  @ *2015-02-27T00:04:40Z*

  * 834916d Merge pull request `#21090`_ from aboe76/update_suse_spec
  * 7b6a222 Updated salt spec file for 2014.7.2

- **PR** `#21087`_: (*steverweber*) fix little opps
  @ *2015-02-26T21:35:26Z*

  * 4fa2de0 Merge pull request `#21087`_ from steverweber/funwith_nacl
  * 77177f2 fix little opps

- **PR** `#21088`_: (*rallytime*) Python 3 compat for nspawn.py and systemd.py
  @ *2015-02-26T20:56:28Z*

  * 2c1bc0a Merge pull request `#21088`_ from rallytime/pylint_develop
  * 9cb1f1c Python 3 compat for nspawn.py and systemd.py

- **PR** `#21062`_: (*rfairburn*) yumpkg.py: sort updates for latest_package to always actually get latest...
  @ *2015-02-26T18:08:22Z*

  * 65e47b4 Merge pull request `#21062`_ from rfairburn/yumpkg_version
  * c3a7ece yumpkg.py: sort updates for latest_package to always actually get latest available

- **PR** `#21072`_: (*Lothiraldan*) Add support for mongod indexes in mongo_future_return
  @ *2015-02-26T18:07:36Z*

  * cf4209c Merge pull request `#21072`_ from tinyclues/mongo_future_return_indexes
  * c10335c Add support for mongod indexes in mongo_future_return

- **PR** `#21040`_: (*thatch45*) Start on the nspawn module
  @ *2015-02-26T16:25:23Z*

  * e63a6db Merge pull request `#21040`_ from thatch45/pacstrap
  * d89894d spell example correctly

  * 4413206 fix some tests

  * 15b4ed1 move to systemd utils file code

  * 8fd39ef don't need to re-specify "sd"

  * 83657c7 Use the new systemd utils

  * 1ecb594 Add systemd utils module

  * 0717edf Add initial nspawn module

  * 4c90c74 Add Salt specific exit code

- **PR** `#21061`_: (*cvrebert*) utils.http.query(): use list instead of tuple since `handlers` gets mutated
  @ *2015-02-26T14:07:30Z*

  * de3b6b3 Merge pull request `#21061`_ from cvrebert/cant-mutate-tuples
  * a44d28f utils.http.query: use list instead of tuple since `handlers` gets mutated

- **PR** `#21056`_: (*freimer*) Irole docupdate
  @ *2015-02-26T04:55:30Z*

  * 839dbd5 Merge pull request `#21056`_ from freimer/irole_docupdate
  * f94a3cb Fix quote

  * 376e4a6 Added documentation information concerning the ability to use instance role credentials

- **PR** `#21046`_: (*jfindlay*) fix ssh test error
  @ *2015-02-25T23:26:40Z*

  - **PR** `#21006`_: (*steverweber*) use key from dict
    | refs: `#21046`_
  * 9f8e22c Merge pull request `#21046`_ from jfindlay/fix_ssh_test
  * 581247f fix ssh test error

- **PR** `#21044`_: (*cachedout*) TCP keepalives on the ret side
  @ *2015-02-25T23:14:34Z*

  * ae8f44d Merge pull request `#21044`_ from cachedout/ret_keepalive
  * 54f3f16 TCP keepalives on the ret side

- **PR** `#20999`_: (*lorengordon*) File.replace handles missing files more gracefully
  @ *2015-02-25T23:14:01Z*

  * bfe74c3 Merge pull request `#20999`_ from fleet-it/file-replace-ignoreifmissing
  * 079fe6b Add version, fix spelling typo

  * 8f32bb9 pylint

  * cfbb8d8 File.replace handles missing files more gracefully

- **PR** `#21033`_: (*kiorky*) TLS: fix root directory retrieval (context)
  @ *2015-02-25T23:12:41Z*

  - **ISSUE** `#20908`_: (*kiorky*) develop: highstate interfers with __opts__ (breaks at least tls mod)
    | refs: `#21033`_ `#20914`_
  - **PR** `#20914`_: (*kiorky*) Loader: Also pack opts
    | refs: `#21033`_
  * b954d4d Merge pull request `#21033`_ from makinacorpus/tls
  * 36c9e33 TLS: fix root directory retrieval (context)

- **PR** `#21042`_: (*jfindlay*) revise saltstack/salt contrib documentation
  @ *2015-02-25T23:11:56Z*

  * d8270d5 Merge pull request `#21042`_ from jfindlay/revise_contrib_doc
  * 7925556 revise saltstack/salt contrib documentation

- **PR** `#20943`_: (*aneeshusa*) File.replace module gains symlink awareness
  @ *2015-02-25T23:10:54Z*

  - **ISSUE** `#20910`_: (*lorengordon*) file.replace overwrites symbolic links
    | refs: `#20943`_
  * c526ad1 Merge pull request `#20943`_ from aneeshusa/file-replace-symlink-noclobber
  * 0e2c2a7 Fix indentation.

  * 7a2ba4a File.replace module gains symlink awareness; fixes `#20910`_.

- **PR** `#20938`_: (*kiorky*) Restore python_shell for onlyif/unless
  @ *2015-02-25T23:10:26Z*

  - **ISSUE** `#20936`_: (*kiorky*) critical: develop: onlyif/unless is broken (python_shell=False)
    | refs: `#20938`_
  * 157a934 Merge pull request `#20938`_ from makinacorpus/oif
  * 6b816b0 Restore python_shell for onlyif/unless

- **PR** `#21031`_: (*rallytime*) Merge `#21024`_ with pylint fix
  @ *2015-02-25T23:09:11Z*

  - **PR** `#21024`_: (*ptonelli*) fix set_locale when no locale is defined initially in RedHat family
    | refs: `#21031`_
  * 7904a14 Merge pull request `#21031`_ from rallytime/merge-21024
  * d134234 Pylint fix

  * 4b9f26e use file.replace instead of file.sed

  * 05feb81 fix set_locale when locale file does not exist (in RedHat family)

- **PR** `#21038`_: (*baweaver*) More informative 400 message
  @ *2015-02-25T22:16:59Z*

  * a59ed4d Merge pull request `#21038`_ from baweaver/patch-2
  * 7cd18a8 More informative 400 message

- **PR** `#21037`_: (*ryan-lane*) Add missing boto docs
  @ *2015-02-25T21:47:26Z*

  * 42ae84a Merge pull request `#21037`_ from lyft/add-missing-boto-docs
  * 1bc840a Add missing boto docs

- **PR** `#21026`_: (*steverweber*) remove dot to reduce confusion
  @ *2015-02-25T18:00:31Z*

  * e2ec567 Merge pull request `#21026`_ from steverweber/pkg_extra_dot
  * 2fa5265 remove dot to reduce confusion

- **PR** `#21020`_: (*favadi*) fix pkgrepo.absent with ppa
  @ *2015-02-25T17:21:09Z*

  * 41452e5 Merge pull request `#21020`_ from favadi/pkgrepo-absent-ppa
  * 062363e fix pkgrepo.absent with ppa

- **PR** `#20995`_: (*cachedout*) A CouchDB sdb interface
  @ *2015-02-25T17:01:46Z*

  * 13d13aa Merge pull request `#20995`_ from cachedout/couchdb_sdb
  * 2ab6313 kwargs

  * fac99d1 Return the save tuple

  * f483bc6 A CouchDB sdb interface

- **PR** `#20974`_: (*JohannesEbke*) Fix expr_match usage in salt.utils.check_whitelist_blacklist
  @ *2015-02-25T16:45:47Z*

  * 59469e9 Merge pull request `#20974`_ from JohannesEbke/fix_whitelist_blacklist
  * a748f31 Fix expr_match usage in salt.utils.check_whitelist_blacklist

- **PR** `#20981`_: (*kiorky*) postgres: role update support
  @ *2015-02-25T16:35:15Z*

  - **ISSUE** `#20980`_: (*kiorky*) postgresql: user roles are never updated
    | refs: `#20981`_
  * b4bd491 Merge pull request `#20981`_ from makinacorpus/psql
  * 126e29c pgsql: fix tests

  * 9242d60 postgres: role update support

- **PR** `#21006`_: (*steverweber*) use key from dict
  | refs: `#21046`_
  @ *2015-02-25T16:33:23Z*

  * d80c656 Merge pull request `#21006`_ from steverweber/sshhost
  * 50e6ccd use key from dict

- **PR** `#21018`_: (*jayeshka*) adding win_ntp unit test case
  @ *2015-02-25T16:19:37Z*

  * dd17969 Merge pull request `#21018`_ from jayeshka/win_ntp-unit-test
  * 5e851b3 adding win_ntp unit test case

- **PR** `#21019`_: (*jayeshka*) adding win_shadow unit test case
  @ *2015-02-25T16:16:22Z*

  * 69a2fa6 Merge pull request `#21019`_ from jayeshka/win_shadow-unit-test
  * d7a0ca9 adding win_shadow unit test case

- **PR** `#21005`_: (*UtahDave*) Add Twilio text message beacon
  @ *2015-02-25T16:15:33Z*

  * b4b7e27 Merge pull request `#21005`_ from UtahDave/add_twilio_beacon
  * 09c2fe3 fix pylint issue.

  * c543345 Add Twilio text message beacon

- **PR** `#20987`_: (*joehoyle*) Fix typo in s3fs fix
  @ *2015-02-25T03:28:24Z*

  * cd1908f Merge pull request `#20987`_ from joehoyle/fix-typo-s3fs
  * 0a0a2f6 Simple typo, doh!

- **PR** `#21007`_: (*ngrennan-inflection*) Fixing examples to avoid problem where there is always a change
  @ *2015-02-25T03:21:58Z*

  * 18b7ea7 Merge pull request `#21007`_ from ngrennan-inflection/develop
  * e92f807 Fixing examples to avoid problem where there is always a change

- **PR** `#20996`_: (*rallytime*) Python 3 compat for ipmi files
  @ *2015-02-24T23:41:45Z*

  * 17624b7 Merge pull request `#20996`_ from rallytime/pylint_develop
  * 516f1f6 Python 3 compat for ipmi files

- **PR** `#20994`_: (*basepi*) Merge forward from 2015.2 to develop
  @ *2015-02-24T23:39:50Z*

  * d9cde34 Merge pull request `#20994`_ from basepi/merge-forward-develop
  * 6cad96a Merge remote-tracking branch 'upstream/2015.2' into merge-forward-develop

- **PR** `#20968`_: (*jayeshka*) adding win_firewall unit test case
  @ *2015-02-24T23:23:40Z*

  * 35f1266 Merge pull request `#20968`_ from jayeshka/win_firewall-unit-test
  * d5b70b5 adding win_firewall unit test case

- **PR** `#20975`_: (*evilNullPointer*) Add Artifactory classifier support
  @ *2015-02-24T21:38:29Z*

  * c61c3c1 Merge pull request `#20975`_ from FrimaStudio/add_artifactory_classifier
  * b0c33c5 Fix pylint W8292 : no newline at end of file

  * 8af2d59 Added classifier support to modules/artifactory.py

  * d0b9884 Fixed a malformed return when an error occur in states/artifactory.py

- **PR** `#20972`_: (*JohannesEbke*) Fix interface cleanup when using AssociatePublicIpAddress in `#19288`_
  | refs: `#25326`_
  @ *2015-02-24T19:28:01Z*

  - **ISSUE** `#19288`_: (*oba11*) AssociatePublicIpAddress doesnt work with salt-cloud 2014.7.0
    | refs: `#20972`_ `#25326`_
  * 20e4278 Merge pull request `#20972`_ from JohannesEbke/develop
  * 3727819 Also fix cleanup of interfaces when using AssociatePublicIpAddress in `#19288`_

- **PR** `#20963`_: (*kiorky*) Only softfail with a state kwarg mismatch
  @ *2015-02-24T19:07:00Z*

  - **ISSUE** `#20962`_: (*kiorky*) stupid states hardfail behavior change: Reopening of `#20227`_ reverted without good reason
    | refs: `#20963`_
  * 30e79a6 Merge pull request `#20963`_ from makinacorpus/soft
  * 7171ed1 state arg mismatch: raising to critical

  * f36f6c5 Only softfail with a state kwarg mismatch

- **PR** `#20966`_: (*favadi*) fix wrong raven client argument name in sentry log handler
  @ *2015-02-24T18:47:35Z*

  * 317c89c Merge pull request `#20966`_ from favadi/sentry-log-handler
  * d50113d fix wrong raven client argument name

- **PR** `#20959`_: (*cachedout*) Fix a traceback when a runner tries a function that is not available.
  @ *2015-02-24T18:32:27Z*

  * 7f4a6f0 Merge pull request `#20959`_ from cachedout/runner_bad_func_err
  * 50475cf Fix a traceback when a runner tries a function that is not available.

- **PR** `#20948`_: (*cachedout*) Load beacon
  @ *2015-02-24T18:32:00Z*

  * 698c24b Merge pull request `#20948`_ from cachedout/load
  * 26cae36 Spelling (thanks @kiorky)

  * 6aeb8f5 Ensure float

  * 6fec366 Load beacon

  * 9ab9212 Show beacon exceptions correctly

- **PR** `#20942`_: (*cachedout*)   Context cache
  @ *2015-02-24T18:30:11Z*

  * cd07287 Merge pull request `#20942`_ from cachedout/context_cache
  * 26b3ec0 Context cache decorator

  * 9507c31 First pass at context caching implementation

- **PR** `#20940`_: (*tsaridas*) Added get host for instance and group
  @ *2015-02-24T18:29:43Z*

  * 6c20615 Merge pull request `#20940`_ from tsaridas/elasticache_get_host
  * 0a8bdca Added get host for instance and group

- **PR** `#20905`_: (*jacksontj*) Fix for `#20869`_
  @ *2015-02-24T18:24:06Z*

  - **ISSUE** `#20898`_: (*kiorky*) event teardown is broken in develop
    | refs: `#20899`_
  - **ISSUE** `#20869`_: (*kiorky*) runners seem again broken in develop
    | refs: `#20899`_
  - **PR** `#20899`_: (*kiorky*) Improve event teardown
  * 7a08161 Merge pull request `#20905`_ from jacksontj/develop
  * 16f0409 Pylint fix

  * 972147b Better *fix* for `#20899`_

  * d92d76f Fix typo

  * 77964ec Fix for `#20869`_

- **PR** `#20717`_: (*steverweber*) add ipmi support
  @ *2015-02-24T18:22:59Z*

  * 406302d Merge pull request `#20717`_ from steverweber/ipmi
  * 0445a9c add virtual

  * 8667b94 add ipmi support

- **PR** `#20901`_: (*aspyatkin*) Add Bower execution and state modules
  @ *2015-02-24T04:40:10Z*

  - **ISSUE** `#20587`_: (*aspyatkin*) Bower state module
    | refs: `#20901`_
  * a38c17e Merge pull request `#20901`_ from aspyatkin/feature-bower
  * b4f1630 Add Alexander Pyatkin to AUTHORS

  * 5edb6cb Implement Bower state module

  * c408c93 Implement Bower execution module

- **PR** `#20946`_: (*basepi*) Merge forward from 2015.2 to develop
  @ *2015-02-23T23:36:45Z*

  - **ISSUE** `#5`_: (*thatch45*) cmd module
  * 8552dd5 Merge pull request `#20946`_ from basepi/merge-forward-develop
  * beaf9ef Merge pull request `#5`_ from jfindlay/merge

    * ebc6a1f fix matcher tests for 2015.2->develop merge

  * c8eb2d4 Merge remote-tracking branch 'upstream/2015.2' into merge-forward-develop

- **PR** `#20935`_: (*rallytime*) Fix pylint errors on develop
  @ *2015-02-23T19:58:53Z*

  * 8a1667e Merge pull request `#20935`_ from rallytime/pylint_develop
  * 0e57d8f Fix pylint errors on develop

- **PR** `#20927`_: (*hobakill*) adding the file paths for 2014.7.2
  @ *2015-02-23T17:28:50Z*

  * ceee052 Merge pull request `#20927`_ from hobakill/develop
  * fbedbf7 adding the file paths for 2014.7.2

- **PR** `#20930`_: (*rallytime*) Add url back in for __query_ip_address callback and add a pylint ignore
  @ *2015-02-23T17:10:58Z*

  - **ISSUE** `#20929`_: (*george-makerbot*) __query_ip_address() takes exactly 1 argument (2 given)
    | refs: `#20930`_
  * 02d0dac Merge pull request `#20930`_ from rallytime/add_url_arg
  * a66b1d6 Add url back in for __query_ip_address callback and add a pylint ignore

- **PR** `#20919`_: (*cvrebert*) Fix unidiomatic typechecks
  @ *2015-02-23T11:54:58Z*

  * e60b2b8 Merge pull request `#20919`_ from cvrebert/fix-unidiomatic-typechecks
  * 3d5b217 use `is` instead of `==` for class equality checks

  * 24c70b4 use isinstance() instead of type() for typechecks

- **PR** `#20917`_: (*mudfly*) Add 'Getting Started With vSphere' documentation
  @ *2015-02-22T20:01:44Z*

  * 72ab2d8 Merge pull request `#20917`_ from mudfly/getting-started-with-vsphere-doc
  * 309f977 Add 'Getting Started With vSphere' documentation

- **PR** `#20893`_: (*cvrebert*) re-enable pylint instead of disabling it twice
  @ *2015-02-21T08:29:16Z*

  * c85d38c Merge pull request `#20893`_ from cvrebert/pylint-enable
  * ea02ef5 re-enable pylint instead of disabling it twice

- **PR** `#20889`_: (*cvrebert*) Avoid shadowing list type in modules.darwin_pkgutil
  @ *2015-02-21T06:31:01Z*

  - **ISSUE** `#20120`_: (*cvrebert*) darwin_pkgutil.list() shadows built-in list type
    | refs: `#20889`_
  * 17824a9 Merge pull request `#20889`_ from cvrebert/darwin-pkgutil-list-unshadow
  * 2a52d54 Avoid shadowing list type in modules.darwin_pkgutil; fixes `#20120`_

- **PR** `#20892`_: (*cvrebert*) cli/batch.py: re-enable pylint instead of disabling it twice
  @ *2015-02-21T05:33:54Z*

  * 06cfc4e Merge pull request `#20892`_ from cvrebert/patch-1
  * 4daeae3 cli/batch.py: re-enable pylint instead of disabling it twice

- **PR** `#20891`_: (*jfindlay*) pylint `#20814`_
  @ *2015-02-21T05:29:40Z*

  * b2bb5ff Merge pull request `#20891`_ from jfindlay/synology
  * b9c386d fix lint

  * ef75c5f Fix disk.usage for Synology OS

- **PR** `#20888`_: (*jfindlay*) pylint `#20885`_
  @ *2015-02-21T05:00:19Z*

  * 93c282c Merge pull request `#20888`_ from jfindlay/s3fs
  * af68f01 fix lint

  * 5d8ba4a Trim the env base off the dest file path in the s3fs fileserver

- **PR** `#20726`_: (*claudiupopescu*) Boto VPC state draft proposal
  @ *2015-02-21T01:10:54Z*

  * aa96665 Merge pull request `#20726`_ from claudiupopescu/boto-vpc-state
  * 251c510 Fixes state if VPC already present

  * bbcfece Fixes pylint

  * 6c07091 Cleaned the code and nesting.

  * a1b5a4c Using tags as anchor and describe for changes.

  * 3a7bfa9 Boto VPC state draft proposal

- **PR** `#20627`_: (*claudiupopescu*) Boto rds state draft
  @ *2015-02-21T01:09:29Z*

  * 093854f Merge pull request `#20627`_ from claudiupopescu/boto-rds-state
  * e88de21 Fixes lint

  * b079748 Refactoring and preparing for tags

  * 12d5f52 Wrong location for boto_rds

  * 71c1aab Removing boto module since it should be in a different branch

  * e6b05fb Merge branch 'boto-rds-state' of github.com:claudiupopescu/salt into boto-rds-state

    * 8f527fc Initial draft for boto rds state

    * ba5756f Merge branch 'develop' of https://github.com/saltstack/salt into boto-rds-state

  * 4377a25 Initial draft for boto rds state

- **PR** `#20586`_: (*claudiupopescu*) Boto rds module
  @ *2015-02-21T01:08:36Z*

  * ee62332 Merge pull request `#20586`_ from claudiupopescu/boto-rds
  * d07cceb Fixes lint error

  * b1d21ee Refactoring and preparing for tags

  * ec0f4b8 Merge branch 'develop' into boto-rds

  * 524bd19 Added get_endpoint and describe

  * 7fa4bc3 Renaming exists functions

  * aacc65c Fixes lint errors

  * f221616 Moving access credentials at the end for state compatibility

  * df37592 Cleaned ast since it is not needed anymore

  * 87c80a1 Final working boto rds module

  * a0bb726 Merge branch 'develop' of https://github.com/saltstack/salt into boto-rds

  * f2da9dd Merge branch 'develop' of https://github.com/saltstack/salt into boto-rds

  * 62e53a9 Duplicating another module for rds

- **PR** `#20870`_: (*yesimon*) Use plist from pkg in launchd runner.
  @ *2015-02-21T00:51:52Z*

  * 740af3c Merge pull request `#20870`_ from yesimon/merge_plists
  * 23f078d Use plist from pkg in launchd runner.

- **PR** `#20835`_: (*rallytime*) Merge `#20782`_ with pylint fix
  @ *2015-02-20T18:21:16Z*

  - **PR** `#20782`_: (*deuscapturus*) Add or remove path from salt-minon or salt-call enviroment.  Issue 17062
    | refs: `#20835`_
  * a920b85 Merge pull request `#20835`_ from rallytime/merge-20782
  * fa5e991 Pylint fix

  * 71b96b8 use correct variable

  * f69628e proper indentation

  * 402449d issue 17062

  * 0af6e3a test

  * 159c7f6 test

  * 791446a test

  * f35f5cb update path for salt-minion or salt-call

  * 95aa387 update path for salt-minion or salt-call

  * a5c8a55 rollback

  * 6222f9c Added os

  * 86a0999 fix syntax error

  * 5456233 update for issue 17062

- **PR** `#20861`_: (*jayeshka*) adding win_autoruns unit test case
  @ *2015-02-20T18:20:57Z*

  * 1d6e932 Merge pull request `#20861`_ from jayeshka/win_autoruns-unit-test
  * 014ce11 adding win_autoruns unit test case

- **PR** `#20853`_: (*dunz0r*) Moved ipcidr-doc to ipcidr() instead of compound()
  @ *2015-02-20T18:20:44Z*

  * 7f18365 Merge pull request `#20853`_ from dunz0r/ipcidr-doc-fix
  * 320ba04 Moved ipcidr-doc to ipcidr() instead of compound()

- **PR** `#20843`_: (*matdrapeau*) Adding current module directory to the sys.path when loading a module
  @ *2015-02-20T18:20:32Z*

  * 9099472 Merge pull request `#20843`_ from matdrapeau/16556/ImportError_custom_dep
  * 4bf1d68 Adding current module directory to the sys.path in order to avoid dependencies import errors for other modules at the same level. (https://github.com/saltstack/salt/issues/16556)

- **PR** `#20822`_: (*peresadam*) Fixed dict unpacking in salt.utils.format_call
  @ *2015-02-20T18:19:38Z*

  * df0371e Merge pull request `#20822`_ from peresadam/fix_format_call
  * 44a3777 Fixed dict unpacking in salt.utils.format_call

- **PR** `#20821`_: (*claudiupopescu*) Adds boto VPC describe subnets
  @ *2015-02-20T18:19:27Z*

  * dc3e6b1 Merge pull request `#20821`_ from claudiupopescu/boto-vpc-describe-subnets
  * 6a8c538 Adds boto VPC describe subnets

- **PR** `#20837`_: (*viktorkrivak*) Fix multi comps and multi dist bugs
  @ *2015-02-19T20:20:52Z*

  * a0440c6 Merge pull request `#20837`_ from viktorkrivak/develop
  * a714d2f Fix multi comps and multi dist bugs

- **PR** `#20829`_: (*cachedout*) Re-use minion token for mine_send
  @ *2015-02-19T17:41:40Z*

  * 16e1d5c Merge pull request `#20829`_ from cachedout/mine_tok
  * 2f334fd Re-use minion token for mine_send

- **PR** `#20830`_: (*clinta*) Elasticsearch Timestamp in UTC
  @ *2015-02-19T17:39:23Z*

  * 48ea69e Merge pull request `#20830`_ from clinta/patch-1
  * e84b5c5 Elasticsearch Timestamp in UTC

- **PR** `#20827`_: (*cachedout*) Better error message for first_auth
  @ *2015-02-19T16:50:54Z*

  * b578e58 Merge pull request `#20827`_ from cachedout/key_clean
  * 52339a3 Include full salt-key command.

  * cf6cfa6 Provide a hint for new users on minions with pending keys.

- **PR** `#20832`_: (*basepi*) Update latest release in docs to 2014.7.2
  @ *2015-02-19T16:23:00Z*

  * ffbdbe5 Merge pull request `#20832`_ from basepi/2014.7.2release
  * 6338b4f Update latest release in docs

- **PR** `#20819`_: (*jayeshka*) adding slack_notify unit test case
  @ *2015-02-19T15:21:30Z*

  * b70ffe2 Merge pull request `#20819`_ from jayeshka/slack_notify-unit-test
  * 6efb71f adding slack_notify unit test case

- **PR** `#20820`_: (*jayeshka*) adding rpm unit test case
  @ *2015-02-19T15:20:49Z*

  * 4c196c5 Merge pull request `#20820`_ from jayeshka/rpm-unit-test
  * 93d5a32 adding rpm unit test case

- **PR** `#20825`_: (*opdude*) Added force_x86 to chocolatey install
  @ *2015-02-19T15:18:45Z*

  * 7fcca3c Merge pull request `#20825`_ from Unity-Technologies/chocolatey-forcex86
  * 56a271c Added force_x86 to chocolatey install

- **PR** `#20817`_: (*mzupan*) fixing the doc for get_master_status return
  @ *2015-02-19T05:03:21Z*

  * 16fb2e2 Merge pull request `#20817`_ from mzupan/develop
  * 7e6f286 fixing the doc for get_master_status return

- **PR** `#20815`_: (*terminalmage*) Add versionadded directives to new state/module
  @ *2015-02-19T01:48:12Z*

  * fac949e Merge pull request `#20815`_ from terminalmage/add-versionadded-rst
  * 2e30218 Add versionadded directives to new state/module

- **PR** `#20803`_: (*basepi*) Merge forward from 2015.2 to develop
  @ *2015-02-19T00:16:37Z*

  * 06a5085 Merge pull request `#20803`_ from basepi/merge-forward-develop
  * ccf9af5 Fix lint

  * d654279 Fix lint errors

  * f00465a Merge remote-tracking branch 'upstream/2015.2' into merge-forward-develop

- **PR** `#20808`_: (*rfairburn*) Allow pagerduty module to work with config in pillar
  @ *2015-02-18T21:34:24Z*

  * f2aa1c0 Merge pull request `#20808`_ from rfairburn/pagerduty_pillar
  * 89dab0f Allow pagerduty module to work with config in pillar

- **PR** `#20804`_: (*jfindlay*) fix py3 lint
  @ *2015-02-18T20:58:18Z*

  * d1d8e98 Merge pull request `#20804`_ from jfindlay/py3_lint
  * 3252c01 fix py3 lint

- **PR** `#20798`_: (*cachedout*) Document the bug reporting procedure
  @ *2015-02-18T19:06:08Z*

  * 9ff7df1 Merge pull request `#20798`_ from cachedout/bug_doc
  * 970c32a Document the bug reporting procedure

- **PR** `#20799`_: (*jfindlay*) Adds docker.latest_running state
  | refs: `#21682`_
  @ *2015-02-18T17:55:16Z*

  - **PR** `#19837`_: (*ipmb*) Adds docker.latest_running state
    | refs: `#20799`_
  * acd5e36 Merge pull request `#20799`_ from jfindlay/docker
  * 94995c6 config gate dockerio state

  * 8d201fb Adds docker.latest_running state

- **PR** `#20796`_: (*cachedout*) Minor refactor of minion tune_in
  @ *2015-02-18T16:55:25Z*

  * 4e9c88b Merge pull request `#20796`_ from cachedout/minion_clean
  * b471011 Lint

  * 754fb93 Pass socks to event_poller

  * 447c095 Refactoring tune_in

- **PR** `#20792`_: (*tsaridas*) changes & additions to elasticache
  @ *2015-02-18T16:54:30Z*

  * 00698d6 Merge pull request `#20792`_ from tsaridas/elasticache_state_module
  * e241345 changes & additions to elasticache

- **PR** `#20784`_: (*steverweber*) add module nacl
  @ *2015-02-18T16:53:15Z*

  * 7637daf Merge pull request `#20784`_ from steverweber/funwith_nacl
  * f966b34 add module nacl

- **PR** `#20768`_: (*vladislav-jomedia*) "dictionary changed size during iteration" issue fixed in config.py for ...
  @ *2015-02-18T16:37:17Z*

  * d22e10c Merge pull request `#20768`_ from vladislav-jomedia/develop
  * cb80a4f Update config.py

  * 6abe1e7 "dictionary changed size during iteration" issue fixed in config.py for salt-cloud

- **PR** `#20780`_: (*jfindlay*) revert dict comprehension back to loop for py-2.6
  @ *2015-02-18T00:43:44Z*

  * 6fedc52a9 Merge pull request `#20780`_ from jfindlay/fix_mongolog
  * a1b588e revert dict comprehension back to loop for py-2.6

- **PR** `#20776`_: (*rallytime*) Python 3 compat for new log4mongo_mod.py file
  @ *2015-02-17T23:09:26Z*

  * baad4dc Merge pull request `#20776`_ from rallytime/pylint_fix
  * cbddd32 Python 3 compat for new log4mongo_mod.py file

- **PR** `#20774`_: (*cachedout*) ZeroMQ socket monitoring
  @ *2015-02-17T23:03:29Z*

  * ff4eb29 Merge pull request `#20774`_ from cachedout/monitor
  * ec60d03 ZeroMQ socket monitoring

- **PR** `#20771`_: (*thatch45*) remove redundant import
  @ *2015-02-17T21:43:27Z*

  * 9f8739c Merge pull request `#20771`_ from thatch45/mongo_log
  * 466afa5 remove redundant import

- **PR** `#20772`_: (*baweaver*) Fix typo
  @ *2015-02-17T21:17:45Z*

  * 4380a9f Merge pull request `#20772`_ from baweaver/patch-1
  * 894d8d8 Fix typo

- **PR** `#20770`_: (*thatch45*) use virtualname and gate the mongo import
  @ *2015-02-17T20:41:33Z*

  * bc157ba Merge pull request `#20770`_ from thatch45/mongo_log
  * 2c1ee34 use virtualname and gate the mongo import

- **PR** `#20769`_: (*rhealitycheck*) Update mongo_future_return.py
  @ *2015-02-17T20:02:44Z*

  * 78bb985 Merge pull request `#20769`_ from rhealitycheck/feature-update-mongo-future-return
  * 4876b6d Update mongo_future_return.py

- **PR** `#20760`_: (*tensorproduct*) adding a new logging handler to support log4mongo
  @ *2015-02-17T17:49:28Z*

  * d2ec0e0 Merge pull request `#20760`_ from tensorproduct/develop
  * 62bd84f adding a new logging handler to support log4mongo

- **PR** `#20698`_: (*thatch45*) Shell jobber
  @ *2015-02-17T17:04:57Z*

  * f527cc9 Merge pull request `#20698`_ from thatch45/shell_jobber
  * 160b60e Merge branch 'develop' into shell_jobber

  * c44abb3 fix up the remaing errors

  * 4d487a9 Add the shell jobber to the minion flo script

  * 8edd617 Add jobber to the top of the impoted behaviors

  * d0f9c82 pass the msg into the tracking value

  * bdcbd3b remove unused shellthread jobber

  * 1c6f58f Move jobbers into jobber.py, add shell jobber

- **PR** `#20715`_: (*robin-wittler*) fix file permission errors
  | refs: `#21424`_
  @ *2015-02-17T16:14:29Z*

  * 85e23f0 Merge pull request `#20715`_ from robin-wittler/fix_file_permission_errors
  * fc97210 fix pylint issues

  * b5f851e fix file permission errors

- **PR** `#20694`_: (*cachedout*) Allow saltutil.refresh_modules to wait for completion
  @ *2015-02-17T16:10:58Z*

  * 59640a0 Merge pull request `#20694`_ from cachedout/sync_module_async
  * 6acdd30 Lint

  * cb7d765 Allow saltutil.refresh_modules to wait for completion

- **PR** `#20755`_: (*jayeshka*) adding modjk unit test case
  @ *2015-02-17T15:38:47Z*

  * e190909 Merge pull request `#20755`_ from jayeshka/modjk-unit-test
  * 17796ca adding modjk unit test case

- **PR** `#20756`_: (*jayeshka*) adding npm unit test case
  @ *2015-02-17T15:38:26Z*

  * 0c6b89e Merge pull request `#20756`_ from jayeshka/npm-unit-test
  * b25fc47 adding npm unit test case

- **PR** `#20754`_: (*jayeshka*) adding swift unit test case
  @ *2015-02-17T15:37:51Z*

  * c398669 Merge pull request `#20754`_ from jayeshka/swift-unit-test
  * 5098a63 adding swift unit test case

- **PR** `#20753`_: (*jayeshka*) adding sdb unit test case
  @ *2015-02-17T15:36:52Z*

  * 87b019b Merge pull request `#20753`_ from jayeshka/sdb-unit-test
  * 35a25e1 adding sdb unit test case

- **PR** `#20752`_: (*jayeshka*) adding ret unit test case
  @ *2015-02-17T15:36:42Z*

  * d1068f5 Merge pull request `#20752`_ from jayeshka/ret-unit-test
  * f38fe3a adding ret unit test case

- **PR** `#20751`_: (*jayeshka*) adding openstack_config unit test case
  @ *2015-02-17T15:35:42Z*

  * 1a5c187 Merge pull request `#20751`_ from jayeshka/openstack_config-unit-test
  * 0e3a86f adding openstack_config unit test case

- **PR** `#20758`_: (*mrchilds*) Added required update
  @ *2015-02-17T14:34:45Z*

  * 0fb6423 Merge pull request `#20758`_ from mrchilds/develop
  * 020b869 Added required update

- **PR** `#20746`_: (*rallytime*) Remove unused url arg from __query_ip_address in ec2.py
  @ *2015-02-17T04:57:40Z*

  - **ISSUE** `#18457`_: (*cvrebert*) Unused 'url' argument in internal method in EC2 cloud module
    | refs: `#20746`_
  * 535e9f0 Merge pull request `#20746`_ from rallytime/remove_url_arg
  * ecaff63 Remove unused url arg from __query_ip_address in ec2.py

- **PR** `#20738`_: (*donjohnson*) Allow for indented/pretty-printed json output from jinja/simplejson
  @ *2015-02-17T04:51:56Z*

  * 14d9c95 Merge pull request `#20738`_ from donjohnson/patch-1
  * b0bbe67 Allow for indented/pretty-printed json output from jinja/simplejson

- **PR** `#20744`_: (*cachedout*) Fix lint errors and typos
  @ *2015-02-17T03:08:34Z*

  - **PR** `#20700`_: (*thatch45*) Procmgr ioflo
    | refs: `#20744`_
  * 3ba763c Merge pull request `#20744`_ from cachedout/flo_lint
  * b6bb06c Fix lint errors and typos

- **PR** `#20745`_: (*cachedout*) Remove trailing whitespace
  @ *2015-02-17T02:33:00Z*

  * 2d47da0 Merge pull request `#20745`_ from cachedout/lint_boto
  * ac0f72f Remove trailing whitespace

- **PR** `#20722`_: (*claudiupopescu*) Adding DNS support to boto vpc creation
  @ *2015-02-17T02:31:19Z*

  * bc67e2e Merge pull request `#20722`_ from claudiupopescu/boto-vpc-dns-support
  * c259a36 Adding DNS support to VPC creation

- **PR** `#20730`_: (*tsaridas*) Elasticache get cache nodes
  @ *2015-02-17T02:30:32Z*

  * 7a35f1a Merge pull request `#20730`_ from tsaridas/elasticache_get_cache_nodes
  * 237b313 adding name

  * 4e6f2be removing functions parameters @ create and add @ get_config

  * a487760 setting show_cache_node_info as True in order to avoid conflicts

  * 8c87ee3 elasticache_get_cache_nodes

  * 7d2d947 elasticache_get_cache_nodes

- **PR** `#20741`_: (*tsaridas*) add option create_replication_group to elasticache
  @ *2015-02-17T02:29:37Z*

  * 8a4e725 Merge pull request `#20741`_ from tsaridas/replication_group
  * 79c7015 remove trailing whitespaces

  * 61d283c add option create_replication_group to elasticache

- **PR** `#20699`_: (*thatch45*) Beacon events
  @ *2015-02-17T01:16:07Z*

  * 0f24402 Merge pull request `#20699`_ from thatch45/beacon_events
  * 13c0c30 Add beacon event firing on the minion

  * 2e761c2 Add beacon events to the minion event bus - raet

- **PR** `#20700`_: (*thatch45*) Procmgr ioflo
  | refs: `#20744`_
  @ *2015-02-17T01:05:15Z*

  * e63815d Merge pull request `#20700`_ from thatch45/procmgr_ioflo
  * 4c63616 Add process manager object to the raet minion

  * c4d6379 Add proc manager setup to master floscript

  * e984dfe Add reactor to the raet minion

  * 9e698ed Add event return to master floscript

  * a40c617 Add event return fork behavior

  * 7649412 Add reactor fork to master floscript

  * 50a79a1 Add reactor module to the main ioflo imports

  * 363d411 Add a reactor ioflo behavior file

  * 173943f Aff the zmq ret process to the process manager

  * 4f87412 move proc to usr

  * 07f34c8 make the workers use the process manager

  * 0205736 change maintinence process to use the process manager

  * 566c5c0 Add process manager creation behavior

- **PR** `#20731`_: (*opdude*) Updated docs for chocolatey
  @ *2015-02-16T20:47:46Z*

  * 9e7c377 Merge pull request `#20731`_ from Unity-Technologies/choco-install-args
  * 2670802 Updated docs for chocolatey

- **PR** `#20728`_: (*twellspring*) Note eAuth PAM requires root salt-master
  @ *2015-02-16T20:44:10Z*

  * 6cf085e Merge pull request `#20728`_ from twellspring/patch-5
  * 7ac3a18 Note eAuth PAM requires root salt-master

- **PR** `#20707`_: (*russellballestrini*) state.archive recursively set group
  @ *2015-02-16T20:36:34Z*

  * c47beea Merge pull request `#20707`_ from russellballestrini/rb-state-archive-user-group
  * 78f96e9 fixes for pylint

  * 4407de8 fixes a pylint pep error about whitespace.

  * 31dabae Deprecated archive_user in favor of standard user

  * 91eac96 recursively set group owner, archive_user to user

- **PR** `#20733`_: (*lovell*) Docs: ensure up/down examples include iface_type
  @ *2015-02-16T19:07:46Z*

  * b44f34b Merge pull request `#20733`_ from lovell/debian-ip-iface-type-doc
  * 413b3fb Ensure up/down examples include iface_type

- **PR** `#20723`_: (*opdude*) Added installArgs/overrideArgs to chocolatey
  @ *2015-02-16T17:02:59Z*

  * f836fbc Merge pull request `#20723`_ from Unity-Technologies/choco-install-args
  * b7ea79c Added install/override arguments to chocolatey methods that can take them

  * d7dd8bd Added the ability to override the install arguments to chocolatey packages

  * d582e58 Added the ability to pass install arguments to chocolatey packages

- **PR** `#20714`_: (*favadi*) add cabal module and state
  @ *2015-02-16T15:45:47Z*

  * 8d51d54 Merge pull request `#20714`_ from favadi/cabal
  * a8a8915 add cabal module and state

- **PR** `#20710`_: (*favadi*) do not clean_file in test mode
  @ *2015-02-16T15:39:43Z*

  * f36d29d Merge pull request `#20710`_ from favadi/pkgrepo-clean-file
  * d438ce7 do not clean_file in test mode

- **PR** `#20709`_: (*tsaridas*) Added monit state file
  @ *2015-02-16T15:37:36Z*

  * fd117fb Merge pull request `#20709`_ from tsaridas/add_monit_state
  * e7c016d Added monit state file

- **PR** `#20706`_: (*Achimh3011*) Make systemd impl. of service.running aware of legacy service units
  @ *2015-02-16T15:36:27Z*

  * 99bb17c Merge pull request `#20706`_ from Achimh3011/add-systemd-support-for-legacy-units
  * 5d31309 Fix pep8 issues.

  * 8f6ff5f Make systemd implementation of service.running aware of legacy service units.

- **PR** `#20725`_: (*claudiupopescu*) Fixes boto VPC delete by passing connection details
  @ *2015-02-16T15:30:54Z*

  * 063b988 Merge pull request `#20725`_ from claudiupopescu/boto-module-vpc-delete
  * 97e0720 Fixes boto VPC delete by passing connection details

- **PR** `#20721`_: (*dunz0r*) More clear documentation on how to use ipcidr-matches
  @ *2015-02-16T15:26:06Z*

  * 2105ef1 Merge pull request `#20721`_ from dunz0r/ipcidr-doc
  * 91f58fd Spelling error

  * 5d3dd81 Compound match example added

  * 66c2184 Added to main documentation

  * 78b8353 Document how to use ipcidr in pillar

- **PR** `#20713`_: (*freimer*) Develop aws irole
  @ *2015-02-15T19:57:32Z*

  * 97380f7 Merge pull request `#20713`_ from freimer/develop-aws-irole
  * 9b4b683 fix pylint spacing, plus sig2 uses provider, not prov_dict

  * 0be592e global not needed in sig2 and sig4

  * ad95960 Bad cut and paste, use providers instead of prov_dict

  * 65609c8 Added Fred Reimer to AUTHORS

  * e9511c2 Updated documentation for instance role credential use

  * 32ea28e Added instance role credentials capability

  * 6b69952 Fixed headers spelling

  * 96ab422 Declare globals

  * fe3b195 Fixed assignment statement

  * fd5999c Added instance role credentials capability

- **PR** `#20712`_: (*dnshl*) Change Spelling of Github to GitHub
  @ *2015-02-15T14:30:29Z*

  * 6cfaf69 Merge pull request `#20712`_ from dnshl/change-spelling-to-GitHub
  * 478f42d Change Github to GitHub

- **PR** `#20693`_: (*rhealitycheck*) Feature update mongo future return and mongo return
  @ *2015-02-13T23:46:09Z*

  * 5f8f0a5 Merge pull request `#20693`_ from rhealitycheck/feature-update-mongo-future-return
  * 3ff59ab Update mongo_return.py

  * a272b12 Update mongo_future_return.py

  * 06779f5 Update mongo_future_return.py

  * 9222108 Update mongo_future_return.py

  * 97a98b9 Update mongo_return.py

- **PR** `#20692`_: (*rallytime*) Add some python 3 compatibility fixes for new test files
  @ *2015-02-13T19:05:20Z*

  * 3131eb0 Merge pull request `#20692`_ from rallytime/pylint_develop
  * 1f7d257 Add some python 3 compatibility fixes for new test files

- **PR** `#20679`_: (*dsumsky*) - added default values to key and keyid parameters of salt.pillar.s3
  @ *2015-02-13T17:43:38Z*

  - **ISSUE** `#20539`_: (*nathanlburns*) salt.pillar.s3 should support IAM Role based authentication like s3fs does
    | refs: `#20679`_
  * 4d509c3 Merge pull request `#20679`_ from dsumsky/s3_pillar_iam_role
  * 8a2858d - documentation update of salt.pillar.s3 module

  * 2d86362 - added default values to key and keyid parameters of salt.pillar.s3   module - documentation update of salt.pillar.s3 module

- **PR** `#20665`_: (*rhealitycheck*) Update mongo_future_return.py
  @ *2015-02-13T17:43:01Z*

  * ccaab16 Merge pull request `#20665`_ from rhealitycheck/feature-update-mongo-future-return
  * 7a32020 Update mongo_future_return.py

  * 1e1e034 Update mongo_future_return.py

  * 78e5558 Update mongo_future_return.py

- **PR** `#20676`_: (*jayeshka*) rest_sample unit test case
  @ *2015-02-13T15:48:21Z*

  * 47ac489 Merge pull request `#20676`_ from jayeshka/rest_sample-unit-test
  * 1e7f2e7 rest_sample unit test case

- **PR** `#20675`_: (*jayeshka*) adding neutron unit test case
  @ *2015-02-13T15:46:39Z*

  * 9328406 Merge pull request `#20675`_ from jayeshka/neutron-unit-test
  * a988606 adding neutron unit test case

- **PR** `#20674`_: (*jayeshka*) adding rdp unit test case
  @ *2015-02-13T15:44:35Z*

  * a7f380b Merge pull request `#20674`_ from jayeshka/rdp-unit-test
  * dd72026 adding rdp unit test case

- **PR** `#20666`_: (*cachedout*) Returner context
  @ *2015-02-13T00:30:05Z*

  * 290b921 Merge pull request `#20666`_ from cachedout/returner_context
  * 065d5b8 Persistant connections (cleanup)

  * 42dd4e6 First stab at mysql pools with context

  * 89f1bc9 Add __context__ to returner loader

- **PR** `#20644`_: (*basepi*) Merge forward from 2015.2 to develop
  @ *2015-02-12T23:35:25Z*

  * bbb7ae9 Merge pull request `#20644`_ from basepi/merge-forward-develop
  * 7082c50 Remove unused six import

  * 7e34346 Merge remote-tracking branch 'upstream/2015.2' into merge-forward-develop

- **PR** `#20659`_: (*pravka*) GH-20657: fixing import function in gpg module
  @ *2015-02-12T23:32:36Z*

  - **ISSUE** `#20657`_: (*pravka*) Import function in gpg module is broken
    | refs: `#20659`_
  * 5fa20ff Merge pull request `#20659`_ from atbell/fix_import_in_gpg_module
  * bf73397 GH-20657: fixing import function

- **PR** `#20668`_: (*cachedout*) Lint
  @ *2015-02-12T23:25:53Z*

  * c79bbe1 Merge pull request `#20668`_ from cachedout/lint_puppet
  * 7075cee Lint

- **PR** `#20667`_: (*belvedere-trading*) Added plugin-sync capabilities to the puppet module.
  @ *2015-02-12T23:24:46Z*

  * a7b38bd Merge pull request `#20667`_ from belvedere-trading/develop
  * dc12f50 Merge "Added plugin-sync capabilities to the puppet module." into develop

    * 6ad3bf5 Added plugin-sync capabilities to the puppet module.

- **PR** `#20654`_: (*thatch45*) Revert "fix mysql returner for syndic master job cache"
  @ *2015-02-12T23:19:22Z*

  - **PR** `#19933`_: (*toddtomkinson*) fix mysql returner for syndic master job cache
    | refs: `#20654`_
  * 2b93b9d Merge pull request `#20654`_ from saltstack/revert-19933-fix_mysql_returner_for_syndic_master_job_cache
  * 2d7b6b9 Revert "fix mysql returner for syndic master job cache"

- **PR** `#20658`_: (*cxfcxf*) range interface support for vlan
  @ *2015-02-12T23:18:07Z*

  - **PR** `#20649`_: (*cxfcxf*) add range interface support for vlan
    | refs: `#20658`_ `#20658`_
  - **PR** `#20618`_: (*cxfcxf*) add ranged interface support for bond interface
    | refs: `#20658`_ `#20649`_
  - **PR** `#20602`_: (*cxfcxf*) adding range interface support and ability to turn arpcheck off to redhat related system,
    | refs: `#20618`_ `#20658`_ `#20649`_
  * 84fc28b Merge pull request `#20658`_ from cxfcxf/develop
  * 4ddc1b1 range interface support for vlan

- **PR** `#20655`_: (*SmithSamuelM*) Support for Raet 0.6.0 with enums
  @ *2015-02-12T23:16:40Z*

  * 95ca766 Merge pull request `#20655`_ from SmithSamuelM/sam_20150212
  * 19acf45 Support for Raet 0.6.0 with enums

- **PR** `#20653`_: (*tomashavlas*) onchages/onfail update for pyobjects
  @ *2015-02-12T23:14:02Z*

  - **ISSUE** `#20652`_: (*tomashavlas*) pyobjects renderer doesn't support onchanges/onfail requisites
    | refs: `#20653`_
  * dde8052 Merge pull request `#20653`_ from tomashavlas/patch-1
  * 27868d6 onchages/onfail update for pyobjects

- **PR** `#20645`_: (*dsumsky*) - log_level_logfile and log_level configuration options inheritance docu...
  @ *2015-02-12T19:56:49Z*

  - **ISSUE** `#20628`_: (*mgubik*) Windows salt-minion logging defaults inherited
    | refs: `#20645`_
  * 26c3c14 Merge pull request `#20645`_ from dsumsky/log_level_logfile_docu
  * 6d797f5 - log_level_logfile and log_level configuration options inheritance docu updated

- **PR** `#20624`_: (*DmitryKuzmenko*) Test for Stats Eventer deed
  @ *2015-02-12T19:43:14Z*

  * bd3121f Merge pull request `#20624`_ from DSRCompany/stats_runner
  * 7f6b072 Test for Stats Eventer deed

- **PR** `#20623`_: (*DmitryKuzmenko*) Raise KeyError for None key in lazy loader
  @ *2015-02-12T19:35:13Z*

  * c204a57 Merge pull request `#20623`_ from DSRCompany/lazy_loader_non_key_fix
  * 787f43e Raise KeyError for None key in lazy loader

- **PR** `#20636`_: (*rallytime*) Merge `#20622`_ with whitespace fix
  @ *2015-02-12T17:46:21Z*

  - **ISSUE** `#20621`_: (*thedrow*) The Boto VPC module does not support deleting by name or tags
    | refs: `#20622`_
  - **PR** `#20622`_: (*thedrow*) Added the ability to delete a VPC by name and tags
    | refs: `#20636`_
  * e39d389 Merge pull request `#20636`_ from rallytime/merge-20622
  * 10520b9 Whitespace fix

  * 03793ab Added the ability to delete a VPC by name and tags. Fixes `#20621`_.

- **PR** `#20618`_: (*cxfcxf*) add ranged interface support for bond interface
  | refs: `#20658`_ `#20649`_
  @ *2015-02-12T17:39:33Z*

  - **PR** `#20602`_: (*cxfcxf*) adding range interface support and ability to turn arpcheck off to redhat related system,
    | refs: `#20618`_ `#20658`_ `#20649`_
  * 598f119 Merge pull request `#20618`_ from cxfcxf/develop
  * ef58955 add ranged interface support for bond and fix typo on rh6_eth.jinja

- **PR** `#20593`_: (*thusoy*) Refactor iptables
  @ *2015-02-12T17:38:37Z*

  - **ISSUE** `#18745`_: (*steverweber*) iptables.set_pocity KeyError: 'table' ubuntu 14.04
    | refs: `#20593`_
  * 174bc41 Merge pull request `#20593`_ from thusoy/iptables-refactor
  * 5e05fd7 Quote iptables args with leading/trailing spaces

  * 99aa865 Set default iptables table to filter

  * 9f6dfb5 Remove lots of string concatenation in iptables module

  * 943be9f Remove a lot of duplication in iptables module

  * ccfeeb7 Don't print to error log if iptables -C 'fails' 1

  * 9afc8fc Add support for iptables --log-* arguments

  * aeb91b0 Refactor after_jump handling in iptaples module

- **PR** `#20617`_: (*cachedout*) Minor style cleanup
  @ *2015-02-12T17:10:18Z*

  * d053745 Merge pull request `#20617`_ from cachedout/cleanup
  * 876efa4 Revert change in salt.cli.salt

  * f564f81 Indentation typo

  * 8101057 Remove unused function in doc runner

  * d16fd18 Cleaning empty pass statements

* dc07c02 Merge branch 'cxfcxf-develop' into develop


  * bb02e54 lint

  * daca04f Merge branch 'develop' of https://github.com/cxfcxf/salt into cxfcxf-develop

  * fad3fb0 fix Exception and giving status to range interface file

  * 26eda7c add range interface support for redhat system

  * 2d28640 add ability to turn off arpcheck

- **PR** `#20609`_: (*l2ol33rt*) Consistent logging for pcre match in flat roster
  @ *2015-02-12T01:04:41Z*

  * 22efff8 Merge pull request `#20609`_ from l2ol33rt/logging_pcre_roster_flat
  * 7db9554 Consistent logging for pcre match

- **PR** `#20607`_: (*cachedout*) Support masterless mode for RAET
  @ *2015-02-12T01:04:08Z*

  - **ISSUE** `#20503`_: (*cachedout*) Masterless mode does not work with RAET
    | refs: `#20607`_
  * 51a8fc1 Merge pull request `#20607`_ from cachedout/masterless_raet
  * 78bb2ce Support masterless mode for RAET

- **PR** `#20608`_: (*cachedout*) Avoid trying to deserialize empty files
  @ *2015-02-12T00:04:10Z*

  * acb3401 Merge pull request `#20608`_ from cachedout/msgpack_empty
  * 389e02b Avoid trying to deserialize empty files

- **PR** `#20606`_: (*rallytime*) Python 3 compat for archive.py
  @ *2015-02-11T23:11:20Z*

  * 6020258 Merge pull request `#20606`_ from rallytime/pylinting
  * ec80933 Python 3 compat for archive.py

- **PR** `#20577`_: (*cachedout*) RAET performance testing
  @ *2015-02-11T22:51:19Z*

  * b0ff607 Merge pull request `#20577`_ from cachedout/ioflo_dummy
  * 517a85f More lint

  * e316b18 Simplify to just loop. No need for calibration since it doesn't max out.

  * e8472ed Pylint

  * 2befd35 Iterate over workers directly

  * 716fa25 Remove servicequeue because ioflo does this

  * 463f95c Rough, but it works

  * 5a730b1 Better ioflo routing

  * 81221ea ioflow routing to dummy behaviour

- **PR** `#20605`_: (*jfindlay*) fix tar check
  @ *2015-02-11T22:04:27Z*

  * a1043ab Merge pull request `#20605`_ from jfindlay/tar
  * 8b68244 chmod -x tests/runtests.py

  * 7c6b8f1 clean up lint messages

  * bc101bc simplified code after review

  * c05aae9 added archive test script

  * c193bed Changing file permissions for test runner to match manual

  * 8673a60 Using cmd.retcode with an exit code different from zero will taint the '--retcode-passthrough' option. using python's regex instead of grep.

- **PR** `#20598`_: (*thatch45*) Merge `#20572`_ with fixes
  @ *2015-02-11T20:12:32Z*

  - **PR** `#20572`_: (*cachedout*) Minor style cleanup
    | refs: `#20598`_
  * 0c3d97c Merge pull request `#20598`_ from thatch45/cachedout-unecessary_nest
  * 776e64c Lint

  * 821d52a Merge branch 'unecessary_nest' of https://github.com/cachedout/salt into cachedout-unecessary_nest

    * 9f23ac8 Indentation

    * 5eab799 Remove unnecessary parens

    * c4c9fd4 Cleanup unecessary parens

    * f95da00 Fix unecessary nest in incron state

    * 3fb4f54 Fix unecessary nest in drac module

- **PR** `#20600`_: (*rallytime*) Add release candidate notification to docs sidebar
  @ *2015-02-11T19:33:43Z*

  * fc52384 Merge pull request `#20600`_ from rallytime/rc_candidate_docs
  * 3c2dd7d Change the releasecnadidates doc to reflect 2015.2.0rc1

  * a42a5fb Add release candidate notification to docs sidebar

- **PR** `#20594`_: (*basepi*) Merge forward from 2015.2 to develop
  @ *2015-02-11T18:40:15Z*

  - **ISSUE** `#4`_: (*thatch45*) pacman module
  * a572be2 Merge pull request `#20594`_ from basepi/merge-forward-develop
  * b8efc6e Merge pull request `#4`_ from jfindlay/merge_dev

    * 657b799 fix iptables unit tests for merge forward

  * 01a4dc6 Fix lint for gitfs.py

  * 8358785 Reset to develop version of loader.py for develop

  * 58c6f90 Merge remote-tracking branch 'upstream/2015.2' into merge-forward-develop

  * 1e5bd7e Merge remote-tracking branch 'upstream/2015.2' into merge-forward-develop

- **PR** `#20543`_: (*dmyerscough*) Initial Kerberos Management
  @ *2015-02-11T18:22:14Z*

  * b63cba0 Merge pull request `#20543`_ from dmyerscough/kerberos
  * 98a296a Fix pylint errors

  * 4ee43e9 Initial Kerberos Management

- **PR** `#20589`_: (*opdude*) Added the ability to filter chocolatey packages by local only
  @ *2015-02-11T15:51:41Z*

  * ce01b26 Merge pull request `#20589`_ from Unity-Technologies/choco-local-installed
  * 1635766 Added the ability to filter chocolatey packages by local only

- **PR** `#20584`_: (*dnshl*) Change Adjective in Starting States Tutorial
  @ *2015-02-11T15:25:27Z*

  * ec54d4a Merge pull request `#20584`_ from dnshl/change-adjective-in-tutorial
  * 5cf8e38 Change Adjective in Starting States Tutorial

- **PR** `#20580`_: (*kaithar*) Layman improvements
  @ *2015-02-11T02:55:57Z*

  - **ISSUE** `#20564`_: (*kaithar*) Layman module issues
    | refs: `#20580`_
  - **PR** `#19238`_: (*jfindlay*) update cmd state and module integration tests
    | refs: `#20580`_
  * 2936138 Merge pull request `#20580`_ from kaithar/issue/layman-improvements
  * fa59dd3 PEP fix

  * aee0a7b Capture results and raise an exception appropriately.

  * 485082d Check if the overlay actually exists before trying to add it.

  * d722a56 Add an execution function to get a list of all overlays.

- **PR** `#20582`_: (*cachedout*) Lint btrfs test
  @ *2015-02-11T01:39:15Z*

  * 14e2f9f Merge pull request `#20582`_ from cachedout/btrfs_lint
  * 5db9172 Lint btrfs test

- **PR** `#20573`_: (*cachedout*) Remove dead code
  @ *2015-02-11T00:28:20Z*

  * e718cad Merge pull request `#20573`_ from cachedout/core_pass
  * 7c80971 Remove dead code

- **PR** `#20566`_: (*bdrung*) Make log file group readable
  @ *2015-02-11T00:13:57Z*

  - **PR** `#20469`_: (*bdrung*) Log file group
    | refs: `#20566`_
  * a49420d Merge pull request `#20566`_ from bdrung/log-file-group-v2
  * 7cd688e Make log file group readable

- **PR** `#20514`_: (*jayeshka*) adding btrfs unit test case
  @ *2015-02-10T21:32:44Z*

  * 679d704 Merge pull request `#20514`_ from jayeshka/btrfs-unit-test
  * 511a496 resolved the error

  * 16503cb adding btrfs unit test case

- **PR** `#20571`_: (*cachedout*) gitfs test lint fix
  @ *2015-02-10T21:25:59Z*

  * 55e4227 Merge pull request `#20571`_ from cachedout/lint_gitfs
  * c508117 gitfs test lint fix

- **PR** `#20569`_: (*cachedout*) Lint tls module
  @ *2015-02-10T20:53:46Z*

  * d579bc2 Merge pull request `#20569`_ from cachedout/lint_tls
  * 85c9df9 Lint tls module

- **PR** `#20568`_: (*cachedout*) Last time with find removed
  @ *2015-02-10T20:09:09Z*

  * d49533b Merge pull request `#20568`_ from cachedout/more_git_test
  * 78309a0 Last time with find removed

- **PR** `#20525`_: (*DmitryKuzmenko*) Stats runner
  @ *2015-02-10T19:49:00Z*

  * 746da48 Merge pull request `#20525`_ from DSRCompany/stats_runner
  * 5291fa6 Fixed lint errors

  * de3b50a Added road_stats and lane_stats runners

  * b7187c2 Manage get_stats runner implementation.

- **PR** `#20567`_: (*cachedout*) Remove another test.
  @ *2015-02-10T18:22:40Z*

  * b083a94 Merge pull request `#20567`_ from cachedout/more_git_test
  * dbd74fb Remove another test.

- **PR** `#20563`_: (*thatch45*) Merge `#20382`_
  @ *2015-02-10T17:57:59Z*

  - **ISSUE** `#20340`_: (*RobertFach*) gem state should support adding/removing a gem source
    | refs: `#20382`_
  - **PR** `#20382`_: (*RobertFach*) implemented&tested gem state sources_add, sources_remove, added test cas...
    | refs: `#20563`_
  * d196ad2 Merge pull request `#20563`_ from thatch45/RobertFach-feature-20340-gem-sources
  * 54de4cc Merge branch 'feature-20340-gem-sources' of https://github.com/RobertFach/salt into RobertFach-feature-20340-gem-sources

    * ea02a15 corrected pylint indentation issues

    * 71d3e34 implemented&tested gem state sources_add, sources_remove, added test cases

- **PR** `#20495`_: (*jcockhren*) Fixed language describing the two ways to enable the gpg renderer
  @ *2015-02-10T16:57:13Z*

  - **ISSUE** `#20490`_: (*jcockhren*) Clarify GPG renderer setup docs
    | refs: `#20495`_
  * bd4bbd1 Merge pull request `#20495`_ from jcockhren/gpg-renderer-doc-update
  * a3bd69d fixed trailing whitespace

  * f266031 fixed language describing the two ways to configure the gpg renderer.

- **PR** `#20476`_: (*pravka*) get certs in tls module
  @ *2015-02-10T16:56:34Z*

  * c8a1e6c Merge pull request `#20476`_ from atbell/get_signed_cert_in_tls_module
  * 3b25ff1 fixing for lint

  * 530eba8 get certs in tls module

- **PR** `#20562`_: (*s0undt3ch*) Add W1202(logging-format-interpolation) to disabled PyLint checks
  @ *2015-02-10T16:44:34Z*

  * a122a78 Merge pull request `#20562`_ from s0undt3ch/develop
  * dd17598 Add W1202(logging-format-interpolation) to disabled PyLint checks

- **PR** `#20559`_: (*rallytime*) Fix python 3 compat errors that were inadvertently reverted
  @ *2015-02-10T16:39:38Z*

  * 182fc23 Merge pull request `#20559`_ from rallytime/pylinting
  * 66cb14c Fix python 3 compat errors that were inadvertently reverted

- **PR** `#20561`_: (*cachedout*) Disable gitfs test that does not produce valuable data
  @ *2015-02-10T16:34:40Z*

  * 80720f9 Merge pull request `#20561`_ from cachedout/gitfs_disable
  * 1e14c9d Disable gitfs test that does not produce valuable data

- **PR** `#20556`_: (*cachedout*) Fix loader pylint
  @ *2015-02-10T15:47:46Z*

  * 0341fdc Merge pull request `#20556`_ from cachedout/fix_loader_pylint
  * c15756b Fix loader pylint

- **PR** `#20553`_: (*cachedout*) Fix mod_random test on older distros
  @ *2015-02-10T15:47:05Z*

  * 2e9dfe8 Merge pull request `#20553`_ from cachedout/fix_random_test
  * f8aeef2 Fix mod_random test on older distros

- **PR** `#20541`_: (*toppur*) Update formulas.rst
  @ *2015-02-10T15:29:11Z*

  * 9e1ae52 Merge pull request `#20541`_ from toppur/develop
  * cdbaff6 Update formulas.rst

- **PR** `#20542`_: (*rallytime*) Revert "More python 3 compatibility changes"
  @ *2015-02-10T04:51:06Z*

  - **PR** `#20537`_: (*rallytime*) More python 3 compatibility changes
    | refs: `#20542`_
  - **PR** `#20443`_: (*SmithSamuelM*) Fixed bug and reverted some unnecessary changes where .six.itervalues was applied
    | refs: `#20542`_
  * f232f7f Merge pull request `#20542`_ from saltstack/revert-20537-py-3-compat
  * a0d5c3d Revert "More python 3 compatibility changes"

- **PR** `#20538`_: (*s0undt3ch*) Disable the modernize pylint plugin dict fixes
  @ *2015-02-10T02:57:09Z*

  * 31fd25b Merge pull request `#20538`_ from s0undt3ch/hotfix/disable-py3-dict-fixes
  * b6101f7 Disable the modernize pylint plugin dict fixes

- **PR** `#20481`_: (*jacksontj*) Add submodule support to LazyLoader
  @ *2015-02-10T02:52:33Z*

  - **PR** `#20473`_: (*jacksontj*) Add "disabled" support
    | refs: `#20481`_
  - **PR** `#20274`_: (*jacksontj*) Loader overhaul to LazyLoader
    | refs: `#20446`_ `#20473`_
  - **PR** `#12327`_: (*jacksontj*) Add a LazyLoader class which will lazily load modules (with the given lo...
    | refs: `#20274`_
  * f122c9f Merge pull request `#20481`_ from jacksontj/loader
  * cf5157c Support arbitrarily deep modules

  * 7ea33b2 Change modulekey for submodule test-- to avoid namespace collisions

  * ee69948 pylint

  * d869ce7 Add support for submodules to LazyLoader

- **PR** `#20537`_: (*rallytime*) More python 3 compatibility changes
  | refs: `#20542`_
  @ *2015-02-10T01:32:52Z*

  * 4b862f5 Merge pull request `#20537`_ from rallytime/py-3-compat
  * 8b3a764 Python 3 compat for flo/core.py

  * 4f1abf8 More Python 3 compat for linodepy.py

  * 3aa934a Python 3 compat for haproxyconn_test.py

  * bcafb57 Python 3 compat for osxdesktop_test.py

- **PR** `#20524`_: (*rallytime*) Fix influx_test mocking
  @ *2015-02-09T19:45:59Z*

  - **ISSUE** `#20496`_: (*highlyunavailable*) Failhard and OnFail requisite interaction
    | refs: `#20497`_
  - **PR** `#20497`_: (*highlyunavailable*) Fix influx API name warnings and user delete bug
    | refs: `#20524`_
  * b0808ac Merge pull request `#20524`_ from rallytime/influx_test_Fix
  * a162e6b Fix influx_test mocking

- **PR** `#20519`_: (*rallytime*) Pylint fixes for Develop
  @ *2015-02-09T19:06:56Z*

  * 73785a2 Merge pull request `#20519`_ from rallytime/pylint_develop
  * 0134543 Pylint fix for linodepy.py

  * bb9843d Don't forget the wait_for_sync arg in delete_record

  * 169ab05 Python 3 compat for ssh_auth.py

  * 23ab69d Python 3 compat for salt/modules/status.py

  * 15a64f0 Python 3 compat for flo/core.py

  * 1b3a89b Python 3 compat for win_status.py

  * 5708e05 Python 3 compat for new linode driver

- **PR** `#20521`_: (*umeboshi2*) don't use empty string as command parameter
  @ *2015-02-09T19:03:21Z*

  * 530036d Merge pull request `#20521`_ from umeboshi2/fix-lvm-display-command
  * ab7346b don't use empty string as command parameter

- **PR** `#20473`_: (*jacksontj*) Add "disabled" support
  | refs: `#20481`_
  @ *2015-02-09T18:09:32Z*

  - **PR** `#20274`_: (*jacksontj*) Loader overhaul to LazyLoader
    | refs: `#20446`_ `#20473`_
  - **PR** `#12327`_: (*jacksontj*) Add a LazyLoader class which will lazily load modules (with the given lo...
    | refs: `#20274`_
  * 9b9a546 Merge pull request `#20473`_ from jacksontj/develop
  * 07de054 Correct tag name in loader tests

  * 504b601 Cleanup the py3 stuff, __globals__ is in both

  * 4e592f3 Add "disabled" support

  * 88d2747 Fix botched py3 compat change

- **PR** `#20520`_: (*jfindlay*) add support for upgrade in apt list upgrades
  @ *2015-02-09T18:00:04Z*

  * 2f5fdd5 Merge pull request `#20520`_ from jfindlay/add_upgrade
  * 09b36a6 add support for upgrade in apt list upgrades

- **PR** `#20457`_: (*cachedout*) Iterate over the socket copy
  @ *2015-02-09T17:12:35Z*

  * 97f91e5 Merge pull request `#20457`_ from cachedout/more_socket_iter
  * 54d92f8 Use list instead

  * 0e4482b Iterate over the socket copy

- **PR** `#20287`_: (*garethgreenaway*) Changes to gpg.py module
  @ *2015-02-09T17:08:27Z*

  - **ISSUE** `#20033`_: (*Diaoul*) gpg module restricts homedir to a user directory
    | refs: `#20287`_
  * 75e3751 Merge pull request `#20287`_ from garethgreenaway/20033_specify_gpghome
  * 16e5a1e Ability to specify the location where GPG related files are kept.

- **PR** `#20513`_: (*GregMSThompson*) Added the option to-source to the after_jump list, to enable the config...
  @ *2015-02-09T15:29:20Z*

  * e0ceb40 Merge pull request `#20513`_ from GregMSThompson/add_to_source_ip_tables
  * 41039e0 Added the option to-source to the after_jump list, to enable the configuration of SNAT rules with the iptables module.

- **PR** `#20517`_: (*rupeshta*) implemented unit test cases for nagios module
  @ *2015-02-09T15:28:24Z*

  * fea95c0 Merge pull request `#20517`_ from rupeshta/nagios_unit_tests
  * 264b63b implemented unit test cases for nagios module

- **PR** `#20516`_: (*jayeshka*) adding haproxyconn unit test case
  @ *2015-02-09T15:26:47Z*

  * 2349467 Merge pull request `#20516`_ from jayeshka/haproxyconn-unit-test
  * d72afef adding haproxyconn unit test case

- **PR** `#20515`_: (*jayeshka*) adding osxdesktop unit test case
  @ *2015-02-09T15:23:30Z*

  * e1eabff Merge pull request `#20515`_ from jayeshka/osxdesktop-unit-test
  * d610170 adding osxdesktop unit test case

- **PR** `#20501`_: (*gtmanfred*) include rackconnectv3 variable
  @ *2015-02-08T03:01:21Z*

  * dc73c30 Merge pull request `#20501`_ from gtmanfred/develop
  * a123e93 add note about rackconnectv3 variable

  * 9448494 fix rackconnect v3 implementation

- **PR** `#20497`_: (*highlyunavailable*) Fix influx API name warnings and user delete bug
  | refs: `#20524`_
  @ *2015-02-07T23:49:32Z*

  - **ISSUE** `#20496`_: (*highlyunavailable*) Failhard and OnFail requisite interaction
    | refs: `#20497`_
  * b8deab5 Merge pull request `#20497`_ from highlyunavailable/feature/influxdb_fixes
  * cda2b65 Fix more errors.

  * 8bea024 Fix incorrect variable name

  * 826f328 Fix lint errors and make check more specific

  * df7c09e Fix influx API name warnings and user delete bug

- **PR** `#20491`_: (*bechtoldt*) add some cosmetic changes to the state requisites article
  @ *2015-02-07T23:37:39Z*

  * 3d64e24 Merge pull request `#20491`_ from bechtoldt/requisites_article
  * 88dea95 add some cosmetic changes to the state requisites article

- **PR** `#20486`_: (*l2ol33rt*) Allow Linux Mint to use upstart
  @ *2015-02-07T03:51:52Z*

  * 654de6b Merge pull request `#20486`_ from l2ol33rt/fix_mint_17
  * fbf2241 Allow mint to use upstart

* 60b960c Merge remote-tracking branch 'upstream/2015.2' into develop


- **PR** `#20482`_: (*basepi*) Merge forward from 2015.2 to develop
  @ *2015-02-06T23:59:27Z*

  * 4afaccf Merge pull request `#20482`_ from basepi/merge-forward-develop
  * 75cf0a6 Merge remote-tracking branch 'upstream/2015.2' into merge-forward-develop

  * 244c916 Merge remote-tracking branch 'upstream/2015.2' into merge-forward-develop

- **PR** `#20477`_: (*rallytime*) Pylint fix for develop
  @ *2015-02-06T22:39:53Z*

  * c75ec86 Merge pull request `#20477`_ from rallytime/pylint
  * dd413f4 Move integration import after ensure_in_syspath call

  * e256943 Pylint fix for develop

- **PR** `#20470`_: (*jacksontj*) Fix botched py3 compat change
  @ *2015-02-06T20:48:17Z*

  * 6d689d1 Merge pull request `#20470`_ from jacksontj/loader
  * 3332ad0 Fix botched py3 compat change

- **PR** `#20478`_: (*basepi*) Merge forward from 2015.2 to develop
  @ *2015-02-06T20:11:14Z*

  - **ISSUE** `#3`_: (*thatch45*) libvirt module
  * af21033 Merge pull request `#20478`_ from basepi/merge-forward-develop2
  * bba0193 Merge pull request `#3`_ from jfindlay/locale_test_fix

    * b59a164 fix merge forward localemod tests

  * 06e1a4f Merge remote-tracking branch 'upstream/2015.2' into merge-forward-develop2

- **PR** `#20474`_: (*djcrabhat*) add sudo, sudo_password params to vsphere deploy to allow for non-root deploys
  @ *2015-02-06T18:19:48Z*

  * fc9f379 Merge pull request `#20474`_ from djcrabhat/vsphere-sudo-deploy
  * bb91693 add sudo, sudo_password params to deploy to allow for non-root deploys

- **PR** `#20454`_: (*scream3*) RVM user-only installation is broken
  @ *2015-02-06T17:35:33Z*

  * 3b1ff44 Merge pull request `#20454`_ from scream3/develop
  * 3f7f50b Fix wrong check for rvm script existence

- **PR** `#20443`_: (*SmithSamuelM*) Fixed bug and reverted some unnecessary changes where .six.itervalues was applied
  | refs: `#20542`_
  @ *2015-02-06T17:33:32Z*

  * de71e5f Merge pull request `#20443`_ from SmithSamuelM/sam_20150205
  * 1c780e8 fixed bug where not using the random master if enabled

  * 3e5690a revert six.itervalues where not appropriate (most cases)

  * 209fc21 Fixed regression

- **PR** `#20400`_: (*Azidburn*) Fix for feature requests `#3817`_ , `#10258`_ in develop branch
  @ *2015-02-06T17:29:45Z*

  - **ISSUE** `#10258`_: (*pwaller*) ssh_auth.present using options with `source: salt://`
  - **ISSUE** `#3817`_: (*jcollie*) ssh_auth.absent should have a "source" option as well.
  * babebda Merge pull request `#20400`_ from Azidburn/develop
  * afec316 fix pylint errors

  * f3bc5e3 Fix for feature requests `#3817`_ , `#10258`_ in develop branch

- **PR** `#20348`_: (*oeuftete*) Add wait_for_sync option to route53 commands
  @ *2015-02-06T17:24:53Z*

  - **ISSUE** `#20016`_: (*kitplummer*) boto_route53 timing out, waiting for replication
    | refs: `#20348`_
  * bf91b4f Merge pull request `#20348`_ from analyzere/boto-skip-sync-option
  * 042e831 Add wait_for_sync option to route53 commands

- **PR** `#20461`_: (*cachedout*) Reset env at end of test
  @ *2015-02-06T17:15:19Z*

  * a34770b Merge pull request `#20461`_ from cachedout/environ_isolate
  * 7dd8aef Typo

  * 5a90fcf Use cls attr

  * 8459819 Reset env at end of test

- **PR** `#20458`_: (*cachedout*) Fix locale gen on suse
  @ *2015-02-06T16:56:54Z*

  * 386a5a0 Merge pull request `#20458`_ from cachedout/locale_suse
  * 7630e1b Typos

  * 8673a2a Fix typo

  * d1b333b Fix locale gen on suse

- **PR** `#20452`_: (*rudeb0t*) Add IN_NO_LOOP incron mask type.
  @ *2015-02-06T16:52:28Z*

  * c43438c Merge pull request `#20452`_ from rudeb0t/develop
  * 28e62b5 Merge remote-tracking branch 'upstream/develop' into develop

  * 2e76723 Add IN_NO_LOOP incron mask type.

- **PR** `#20455`_: (*rupeshta*) Mod random unit tests
  @ *2015-02-06T16:49:45Z*

  * 0971e87 Merge pull request `#20455`_ from rupeshta/mod_random_unit_tests
  * 7b79128 added some imports

  * 4c19fb6 implementd unit test cases for mod_random module

- **PR** `#20456`_: (*rupeshta*) Monit unit tests
  @ *2015-02-06T16:48:56Z*

  * 881a42a Merge pull request `#20456`_ from rupeshta/monit_unit_tests
  * 6e0134f added some imports

  * 3484419 implementd unit test cases for monit module

- **PR** `#20189`_: (*Narcolapser*) Windows Status Addendum
  @ *2015-02-06T16:46:58Z*

  - **ISSUE** `#1`_: (*thatch45*) Enable regex on the salt cli
    | refs: `#21356`_ `#21328`_
  * e1c09dd Merge pull request `#20189`_ from Narcolapser/develop
  * 48f7fbc some minor bugs

  * 88ed56d lint lint lint

  * 6c63f68 anti-entropy

  * a3f8f05 COPY PASTE OUT THE LINT

  * ef2850e De-linting

  * 30d64c6 cleaning the lint screen

  * 2c63774 Update win_status.py

  * 28255bb Update win_status.py

  * 3e5adc4 Update win_status.py

  * 71bd164 Merge pull request `#1`_ from saltstack/develop

- **PR** `#20463`_: (*cachedout*) __virtual__ for cron module
  @ *2015-02-06T16:38:47Z*

  - **ISSUE** `#20384`_: (*cachedout*) cron state throws traceback if cron is not installed
    | refs: `#20463`_
  * 744d30a Merge pull request `#20463`_ from cachedout/issue_20384
  * c7c5b13 __virtual__ for cron module

- **PR** `#20459`_: (*rallytime*) Python 3 compatibility changes to make pylint happy
  @ *2015-02-06T15:47:40Z*

  * bd74090 Merge pull request `#20459`_ from rallytime/pylinting_develop
  * eaa879a Python 3 compat for tests/integration/loader/globals.py

  * 135ee5a Python 3 compat for mine_test.py and other testing import needs

  * 9fcec04 Python 3 compat for salt/utils/lazy.py

  * 10e6587 Python 3 compat for salt/renderers/pyobjects.py

  * 530ca01 Python 3 compat for salt/minion.py

  * 6b67e2d Python 3 compat for salt/loader.py

  * 3857927 Moved tests/unit/loader.py to tests/integration/loader/loader.py

- **PR** `#20446`_: (*jacksontj*) Fix mis-naming from pylint cleanup
  @ *2015-02-06T03:55:17Z*

  - **PR** `#20274`_: (*jacksontj*) Loader overhaul to LazyLoader
    | refs: `#20446`_ `#20473`_
  - **PR** `#12327`_: (*jacksontj*) Add a LazyLoader class which will lazily load modules (with the given lo...
    | refs: `#20274`_
  * 67473c5 Merge pull request `#20446`_ from jacksontj/loader
  * c8fdc9a Fix mis-naming from pylint cleanup

- **PR** `#20444`_: (*cachedout*) Use correct outputter in asynclient mixin
  @ *2015-02-06T03:20:04Z*

  * 3c82175 Merge pull request `#20444`_ from cachedout/async_client_outputter
  * 7f2f0e8 Fix double-call (thanks @s0undt3ch)

  * 1202c36 Use correct outputter in asynclient mixin

- **PR** `#20274`_: (*jacksontj*) Loader overhaul to LazyLoader
  | refs: `#20446`_ `#20473`_
  @ *2015-02-05T22:50:19Z*

  - **PR** `#12327`_: (*jacksontj*) Add a LazyLoader class which will lazily load modules (with the given lo...
    | refs: `#20274`_
  * 640b662 Merge pull request `#20274`_ from jacksontj/loader
  * f01a5c5 Pylint

  * b762c72 Add test for __func__alias__

  * e2184bd Remove some old unused code

  * 87d90bf More loader tests

  * f2dea6a Add loader tests

  * 19132b1 Since clear() removes all modules, reloads are unecessary

  * d163f7b Minor performance improvement

  * fb43ca4 If you have the module loaded, lets not require another hit to disk

  * 307e5c1 Check that __context__ is always present, since it now is (properly)

  * 259be3a remove old deprecated mechanism

  * 9404575 Fix process_virtual error_reasons

  * 1c13697 Misc cleanup

  * dcf4550 Cleanup FunctionWrapper

  * 0f77253 Remove unecessary format, a string is always a string

  * 33597d2 Move "pack" over to a dict

  * ac6046c Inject globals after verifying the function-- because it might not exist!

  * 5b6f31a Attempt dict access

  * 95dd62f Conditionally inject context (if no one else has)

  * 686ec05 Remove test as well

  * b23a076 Remove grains outputter

  * 9339b14 Some more cleanup to grains outputter, closer to working

  * 7b03fad Rename NewLazyLoader to LazyLoader (since the old one was deleted)

  * 69f73df __salt__ is not a lazydict object, not a dict.

  * 3840dbc Rename func, since it overlaps (works because of ordering, but still...)

  * a3bee1b Pylint

  * 3001d88 Proper precedence of file extensions

  * d5bcdce Make the pyobjects loader ignore virtual (it did before)

  * adef299 Migrate to new loader

  * 01fa6af Change default to false, since everyone seems to pass them in

  * c12d7c8 Make LazyLoader's singleton-ness optional

  * f47663a Fix pyobjects renderer to use new loader

  * 6cd7cee Fix namespacing of modules in dependency dict

  * 132008e pylint some more

  * 6423228 Pylint fix

  * fa84d72 Stop caching grains globally in memory.

  * 39d8991 Misc other loader globals fixes

  * 509b435 Pack modules to runners

  * b16d828 Fix import namespacing

  * 4260d21 Fix call() in loader

  * 234b9c2 More pylint fixes

  * 258c978 whitespace pylint cleanup

  * a08ab22 Reload submodules after initial load

  * 1916823 Pass in "kind" to cleanup in depends decorator instead of guessing

  * cb43d86 Support proxy modules, and misc pylint fixup

  * 589eb58 Add support for non-virtual loader dicts and remove old loader class

  * 583fa3d Remove majority of *old* loader code

  * db3d1a7 Move to clear() for new loader

  * ebf6782 Use clear() to reload

  * 480ee98 Fix type error

  * bf89ca1 Add depends support to new lazyloader

  * 586b713 Add support for multiple types of functions by namespacing out the dep dict

  * ab2cbd9 Catch case where 'return' not in opts, or other ways to get an empty returner (as it will just fail anyways)

  * f79a04c pylint

  * 1402496 Re-add pyx support

  * c346737 Handle disk better

  * 329c015 Fix grains caching

  * 5f271dd Migrate everything over to NewLazyLoader

  * 4660080 Some major hacking of the loader, don't really like it... but i guess i'll keep it around for a while

- **PR** `#20431`_: (*SmithSamuelM*) Changed test from str to basestring
  @ *2015-02-05T21:09:14Z*

  * ef3fd7c Merge pull request `#20431`_ from SmithSamuelM/sam_20150124
  * c7530eb Changed test from str to basestring in order to support python3 raet now may have unicode strings in msgs.

- **PR** `#20375`_: (*rupeshta*) Mine unit tests
  @ *2015-02-05T21:01:12Z*

  * 6683046 Merge pull request `#20375`_ from rupeshta/mine_unit_tests
  * 236f1ad implemented unit test cases for mine module

- **PR** `#20371`_: (*cournape*) DOC: add certifi to get proper https support.
  @ *2015-02-05T21:00:44Z*

  * 854165c Merge pull request `#20371`_ from cournape/fix_https_handling_windows_installer
  * 6847e05 DOC: add certifi to get proper https support.

- **PR** `#20357`_: (*cachedout*) Don't try to compile empty pillars
  @ *2015-02-05T20:53:32Z*

  * bf8d519 Merge pull request `#20357`_ from cachedout/pillar_compile
  * b8cc827 Don't try to compile empty pillars

- **PR** `#20350`_: (*cachedout*) Avoid socket list changing during iteration
  @ *2015-02-05T20:50:23Z*

  * 9af5ee2 Merge pull request `#20350`_ from cachedout/socket_iter
  * 4dac466 Avoid socket list changing during iteration

- **PR** `#20429`_: (*cachedout*) Fix broken state.orch prereqs
  @ *2015-02-05T20:26:20Z*

  * c4e7bd6 Merge pull request `#20429`_ from cachedout/prereq_keywords
  * a55f556 Fix broken state.orch prereqs

- **PR** `#20386`_: (*cachedout*) Don't run cron as a user with -u on Linux
  @ *2015-02-05T19:23:03Z*

  - **ISSUE** `#19916`_: (*steverweber*) cron.present is not working correctly.
    | refs: `#20386`_
  * f1c3c63 Merge pull request `#20386`_ from cachedout/issue_19916
  * f7d72c4 Don't run cron as a user with -u on Linux

- **PR** `#20395`_: (*jfindlay*) mv zsh completion to pkg/
  @ *2015-02-05T19:20:04Z*

  - **ISSUE** `#19892`_: (*jfindlay*) move scripts/completion/zsh_completion.zsh to pkg/zsh_completion.zsh
    | refs: `#20395`_
  * c4cec24 Merge pull request `#20395`_ from jfindlay/mv_zsh_cmp
  * 8605281 mv zsh completion to pkg/

- **PR** `#20415`_: (*shahn*) Update Macports Portfile
  @ *2015-02-05T19:18:08Z*

  * 969315b Merge pull request `#20415`_ from shahn/develop
  * 122e253 Update Macports Portfile

- **PR** `#20427`_: (*kaithar*) Fix for mysql pillar's ignore_null
  @ *2015-02-05T19:17:33Z*

  - **PR** `#14924`_: (*jond64*) ignore_null option for mysql external pillar
    | refs: `#20427`_
  * 6539930 Merge pull request `#20427`_ from kaithar/issue/mysql-null-test-fix
  * 529f4f6 Compare against None rather than basing off anything that evaluates true

- **PR** `#20402`_: (*cachedout*) Copy perms of destination file when backing up
  @ *2015-02-05T19:08:30Z*

  - **ISSUE** `#19643`_: (*pille*) file_backup insecure permissions
    | refs: `#20402`_
  * cf2bc2d Merge pull request `#20402`_ from cachedout/issue_19643
  * 51f2e94 Copy perms of destination file when backing up

- **PR** `#20367`_: (*robmessick*) Add list_upgrades method to salt.modules.gem
  @ *2015-02-05T19:07:09Z*

  * 7da1181 Merge pull request `#20367`_ from robmessick/gem_list_upgrades
  * 4a04211 Add method list_upgrades (modeled on the salt.modules.pip). Calls 'gem outdated' and returns a dictionary containing gem names and the version number of the latest gem.

  * 70be021 Log and raise CommandExecutionError if gem command retcode != 0

  * 0375df0 import logging and setup logger

- **PR** `#20414`_: (*borgstrom*) Update documentation & tests following `#18911`_
  @ *2015-02-05T19:02:17Z*

  - **ISSUE** `#18910`_: (*tomashavlas*) pyobjects renderer import as statement
    | refs: `#18911`_
  - **PR** `#18911`_: (*tomashavlas*) created support from from module import object as alias in pyobjects ren...
  * 4932cf6 Merge pull request `#20414`_ from borgstrom/pyobjects-import-as
  * a43920b Update documentation & tests following `#18911`_

- **PR** `#20359`_: (*patrickshan*) ignore null string from blkid output
  @ *2015-02-05T18:55:22Z*

  * ab9ec6b Merge pull request `#20359`_ from patrickshan/develop
  * ca2da67 ignore blank lines of blkid output

- **PR** `#20413`_: (*rallytime*) Fix remaining pylint errors on develop
  @ *2015-02-05T15:50:43Z*

  * be9e00f Merge pull request `#20413`_ from rallytime/pylint_dev
  * c25e88b Don't forget the pylint ignore

  * 02d3235 Fix remaining pylint errors on develop

- **PR** `#20380`_: (*rallytime*) Merge `#20374`_ with some fixes
  @ *2015-02-04T18:24:14Z*

  - **PR** `#20374`_: (*rupeshta*) Match unit tests
    | refs: `#20380`_
  * ced4bfc Merge pull request `#20380`_ from rallytime/merge-20374
  * e882a6d Merge `#20374`_ with some fixes

  * 535247d implemented unit test cases for match module

  * a1efeb5 implemented unit test cases for lvs module

* b77880a Some pylint disables


- **PR** `#20349`_: (*rallytime*) Develop pylint
  @ *2015-02-04T11:58:39Z*

  * 62e9407 Merge pull request `#20349`_ from rallytime/develop_pylint
  * a550015 Add list to six.iteritems

  * ec25dc1 Python 3 compat for mixins.py and http.py

  * 2f9dc14 More Python 3 compat changes to new test modules

  * 244ba09 Python 3 compat for several new test files

  * d2d42e5 Python 3 compat and additions to ldapmod_test

  * 79e6ea9 Python 3 compat for sudo.py

  * fab28bb Python 3 compat for mixins.py

  * c523448 Python 3 compatability for schedule.py

- **PR** `#20354`_: (*jfindlay*) Fix iptables test
  @ *2015-02-03T22:27:48Z*

  * bc0cbb7 Merge pull request `#20354`_ from jfindlay/fix_iptables_test
  * 3342451 add mocks to fix test when iptables cmd is absent

  * cc2f6c9 normalizing iptables.check for easier testing

- **PR** `#20338`_: (*pakdel*) MS SQL Execution module
  @ *2015-02-03T21:03:31Z*

  * 9937702 Merge pull request `#20338`_ from pakdel/mssql
  * 6335864 PyLint adjustments in modules/mssql.py

  * f6a4457 Even more PyLint adjustments in modules/mssql.py

  * e50e495 PyLint adjustments in modules/mssql.py

  * 576c518 PyLint adjustments in modules/mssql.py

  * 2a617ea Added db_* and user_* functions to mssql module

  * eabb8a2 Added MS SQL execution module

- **PR** `#20281`_: (*MrMarvin*) fixes a bug which broke eauth with group permissions
  @ *2015-02-03T19:18:55Z*

  - **ISSUE** `#2215`_: (*techhat*) 'list' object has no attribute 'difference' in static command
    | refs: `#20281`_ `#20281`_
  * c0a1078 Merge pull request `#20281`_ from MrMarvin/fix/eauth_group_permissions_mess
  * 6e0f205 fixes weird wording in comment

  * 16804c2 fixes a bug which broke eauth with group permissions

- **PR** `#20339`_: (*salekseev*) Fixed race condition in fluent_log_handler
  @ *2015-02-03T19:12:25Z*

  * 168df9d Merge pull request `#20339`_ from salekseev/fix/fluent_log_handler_race_condition
  * 32d0e8d Fixed race condition in fluent_log_handler

- **PR** `#20343`_: (*rallytime*) Make sure all exits are blocked and mocked
  @ *2015-02-03T18:44:30Z*

  * f82e2fd Merge pull request `#20343`_ from rallytime/fix_keyboard_tests
  * 19680fc Make sure all exits are blocked and mocked

- **PR** `#20333`_: (*errge*) Fix ambiguity and typo in test.fib documentation
  @ *2015-02-03T13:20:31Z*

  * bb58c37 Merge pull request `#20333`_ from errge/patch-1
  * 5130c31 Fix ambiguity and typo in test.fib documentation

- **PR** `#20332`_: (*westurner*) DOC: topics/tutorials/walkthrough.rst: then > than
  @ *2015-02-03T13:20:10Z*

  * e742d99 Merge pull request `#20332`_ from westurner/patch-2
  * 203f5c3 DOC: topics/tutorials/walkthrough.rst: then > than

- **PR** `#20331`_: (*jayeshka*) adding etcd_mod unit test case
  @ *2015-02-03T13:19:43Z*

  * 20bbd01 Merge pull request `#20331`_ from jayeshka/etcd_mod-unit-test
  * d91b36a adding etcd_mod unit test case

- **PR** `#20330`_: (*jayeshka*) adding memcached unit test case
  @ *2015-02-03T13:19:33Z*

  * 46b3a24 Merge pull request `#20330`_ from jayeshka/memcached-unit-test
  * 697099c adding memcached unit test case

- **PR** `#20327`_: (*jayeshka*) adding ldapmod unit test case
  @ *2015-02-03T13:18:40Z*

  * 9fe7c36 Merge pull request `#20327`_ from jayeshka/ldapmod-unit-test
  * b1bf62a adding ldapmod unit test case

- **PR** `#20326`_: (*jayeshka*) adding munin unit test
  @ *2015-02-03T13:18:20Z*

  * 3e6370c Merge pull request `#20326`_ from jayeshka/munin-unit-test
  * 8745225 adding munin unit test

- **PR** `#20325`_: (*jayeshka*) adding moosefs unit test
  @ *2015-02-03T13:17:27Z*

  * 0aed9b3 Merge pull request `#20325`_ from jayeshka/moosefs-unit-test
  * 24c9004 adding moosefs unit test

- **PR** `#20324`_: (*jayeshka*) adding logrotate unit test
  @ *2015-02-03T13:17:08Z*

  * 06d314b Merge pull request `#20324`_ from jayeshka/logrotate-unit-test
  * f9d43f5 resolved pylint errors

  * ec88812 adding logrotate unit test

- **PR** `#20323`_: (*pravka*) Fixes `#20322`_, check for existing cert, return CN (not ca_name)
  @ *2015-02-03T13:16:58Z*

  - **ISSUE** `#20322`_: (*pravka*) tls module should check if certificate already exists
    | refs: `#20323`_
  * 8857026 Merge pull request `#20323`_ from atbell/GH-20322_fix_cert_creation_in_tls_module
  * 8e0bd5a Fixes `#20322`_, check for existing cert, return CN (not ca_name)

- **PR** `#20321`_: (*jayeshka*) adding keyboard unit test case
  @ *2015-02-03T13:13:56Z*

  * 78a613a Merge pull request `#20321`_ from jayeshka/keyboard-unit-test
  * 9d2dd05 adding keyboard unit test case

- **PR** `#20294`_: (*jayeshka*) adding introspect unit test case
  @ *2015-02-03T13:12:38Z*

  * 82d6677 Merge pull request `#20294`_ from jayeshka/introspect-unit-test
  * f021c43 adding introspect unit test case

- **PR** `#20320`_: (*jayeshka*) adding locate unit test case
  @ *2015-02-03T13:11:28Z*

  * ff1312e Merge pull request `#20320`_ from jayeshka/locate-unit-test
  * 3ad563d adding locate unit test case

- **PR** `#20319`_: (*jayeshka*) adding iptables unit test case
  @ *2015-02-03T13:10:55Z*

  * 4487925 Merge pull request `#20319`_ from jayeshka/iptables-unit-test
  * d1b4fce removed pylint error

  * 1ae0154 adding iptables unit test case

- **PR** `#20315`_: (*jodv*) fix syndic getting user from kwarg
  @ *2015-02-03T12:59:51Z*

  * 1ca7813 Merge pull request `#20315`_ from jodv/fix-syndic-user-passing
  * 2caf780 fix syndic getting user from kwarg

- **PR** `#20313`_: (*basepi*) Merge forward from 2015.2 to develop
  @ *2015-02-03T12:55:49Z*

  * c192b36 Merge pull request `#20313`_ from basepi/merge-forward-develop
  * 068a23e Merge remote-tracking branch 'upstream/2015.2' into merge-forward-develop

- **PR** `#20302`_: (*theonlypippo*) add 'ipv6-localhost/loopback' to punish list
  @ *2015-02-03T12:55:05Z*

  * e26a29e Merge pull request `#20302`_ from theonlypippo/patch-1
  * 7d6b856 add 'ipv6-localhost/loopback' to punish list

- **PR** `#20292`_: (*diegows*) Documentation: How to store Minion config options on Pillars.
  @ *2015-02-03T12:53:23Z*

  * 1bf4067 Merge pull request `#20292`_ from flugel-it/develop
  * e6f6401 How to store Minion config options on Pillars.

  * 11bf6dd Merge branch 'develop' of https://github.com/saltstack/salt into develop

  * 19bd682 Merge branch 'develop' of https://github.com/saltstack/salt into develop

  * 920c2f2 Merge branch 'develop' of https://github.com/saltstack/salt into develop

  * 6c6be8a Provisional fix when using extends for credentials.

- **PR** `#20286`_: (*garethgreenaway*) Changes to debian_ip.py
  @ *2015-02-03T12:51:16Z*

  - **ISSUE** `#19898`_: (*kt97679*) no way to configure /etc/network/interfaces.d via network.managed
    | refs: `#20286`_
  * e6af13d Merge pull request `#20286`_ from garethgreenaway/debian_source_interface
  * edcb4cf Fixing pylint error

  * 5499ea3 Iinitially adding the ability to specify a source line in the Debian interfaces file. Finished up support for specifying a source in /etc/network/interfaces. Also initial support for managing interface config files under /etc/network/interfaces.d

- **PR** `#20311`_: (*jacksontj*) Switch to compiled regex's
  @ *2015-02-03T07:13:10Z*

  * 3ecaee3 Merge pull request `#20311`_ from jacksontj/develop
  * 48637b8 Switch to compiled regex's

- **PR** `#20310`_: (*jacksontj*) Typo fix
  @ *2015-02-02T21:47:53Z*

  * d1c0e06 Merge pull request `#20310`_ from jacksontj/develop
  * 77ea42e Typo fix

- **PR** `#20269`_: (*rallytime*) Fix broken localemod_test on develop
  @ *2015-02-02T19:56:56Z*

  * 4b94cfb Merge pull request `#20269`_ from rallytime/refactor_localemod_tests
  * a99b030 Mock salt.utils.which call

  * 3dbe1b3 Fix broken localemod_test on develop

- **PR** `#20283`_: (*CameronNemo*) Add Upstart job for salt-api
  @ *2015-02-02T18:41:36Z*

  * ef0b32c Merge pull request `#20283`_ from CameronNemo/CameronNemo-patch-1
  * ffe1ba6 Add Upstart job for salt-api

- **PR** `#20277`_: (*mzupan*) this supports complex grain types for map.jinja lookups
  @ *2015-01-31T15:37:26Z*

  * 3462081 Merge pull request `#20277`_ from mzupan/develop
  * 0d875bf this supports complex grain types

- **PR** `#17883`_: (*s0undt3ch*) [Don't merge yet] Py3 compat changes & Update pylintrc to load the py3modernize plugin
  @ *2015-01-31T10:13:53Z*

  * cefb78e Merge pull request `#17883`_ from s0undt3ch/features/pylint-py3-modernize
  * cc064fd Py3 compatibility

  * 0bc6640 Py3 compatibility

  * 44e255f Py3 compatibility

  * 4443cba Py3 compatibility

  * 04db610 Py3 compatibility

  * f0f3fb2 Add `__instance_id__` as a known global variable

  * b9aaf9f Py3 compatibility

  * f6e465f Py3 compatibility

  * 322f26a Py3 compatibility

  * a817a42 Py3 compatibility

  * 21cb7e2 Py3 compatibility

  * 661a8eb Py3 compatibility

  * 9e2f3ab Py3 compatibility

  * f538947 Py3 compatibility

  * 29b519f Py3 compatibility

  * c7961d3 Py3 compatibility

  * 4781f89 Stop PyLint from complaining

  * f708b80 Make the check conditional to the python version

  * a983495 Py3 compatibility

  * 98a61ff Py3 compatibility

  * 6030335 Py3 compatibility

  * 92d321b Py3 compatibility

  * 95ef4fd Py3 compatibility

  * c3a543b Fix bug introduced while linting

  * 2a850bc Options should not be globally defined. Do the right thing.

  * ea7381b Typos

  * 4d6f173 Fix wrong iteration from PY3 compat changes

  * 56ec784 Convert into dict(lost in PY3 refactoring)

  * 1c8490b Py3 compatibility

  * da39293 Py3 compatibility

  * 5c8e966 Py3 compatibility

  * 319e7a5 Py3 compatibility

  * ddc242e Py3 compatibility

  * 1c470d3 Remove unused import

  * 0837615 Remove unused import

  * 354fb92 Add function keyword lost in a merge conflict

  * 36d1715 Py3 compatibility

  * 2f7c55d Fix variable name

  * 34c75b1 The dictionary changes while iterating. Run over a list of keys.

  * 51c2823 Py3 compatibility

  * c1215a2 Py3 compatibility

  * ccf0cda Py3 compatibility

  * fd7452b Py3 compatibility

  * ddad0bc Py3 compatibility

  * 4324550 Py3 compatibility

  * 0edc28b Py3 compatibility and proper assert

  * 42ec407 Py3 compatibility

  * 7668c95 Py3 compatibility

  * 5a40a71 Py3 compatibility

  * 25f5234 Py3 compatibility

  * 7b27074 Py3 compatibility

  * 95ba9d1 Py3 compatibility

  * 2b3df93 Py3 compatibility

  * 64918c3 Py3 compatibility

  * c5ea080 Py3 compatibility

  * 74801c8 Py3 compatibility

  * 582d21b Py3 compatibility

  * a262f5e Py3 compatibility

  * 49878a9 Py3 compatibility

  * a124936 Py3 compatibility

  * 26337ad Py3 compatibility

  * 822cc12 Py3 compatibility

  * cedf7f0 Py3 compatibility

  * 4be7c0e Py3 compatibility

  * 60f556d Py3 compatibility

  * 20e6ccd Py3 compatibility

  * 43f4a9b Py3 compatibility

  * db20280 Py3 compatibility

  * 102a6ce Py3 compatibility

  * 8aa6280 Py3 compatibility

  * dc434a2 Py3 compatibility

  * 2f1ebc8 Py3 compatibility

  * 2961c07 Py3 compatibility

  * ac15f12 Py3 compatibility

  * 4a25daa Py3 compatibility

  * ff63624 Py3 compatibility

  * 151c74a Py3 compatibility

  * b906731 Py3 compatibility

  * 6a807f1 Py3 compatibility

  * 0b38e6e Py3 compatibility

  * d3bbfdb Py3 compatibility

  * a708cf9 Py3 compatibility

  * 2a22727 Py3 compatibility

  * ff1d397 Py3 compatibility

  * ad5fd99 Py3 compatibility

  * 59a25a8 Py3 compatibility

  * f483756 Remove unused imports

  * a912d0b Fix the `__jid_event__` removed during the rebase

  * 2344ead The string module is not deprecated, only some functions of it.

  * 47fef41 Py3 compatibility

  * 89d283f Py3 compatibility

  * 030fbeb Py3 compatibility

  * a655f36 Py3 compatibility

  * d861316 Py3 compatibility

  * b0cd239 Bring loop into context

  * ade27a2 Remove unused import

  * 2751807 No reports

  * 8af3e9b Revert "Reuse existing `.pylintrc` and only change what's necessary."

  * 8990e37 Reuse existing `.pylintrc` and only change what's necessary.

  * 4c68041 Py3 compatibility

  * 0120aca Py3 compatibility

  * 00efed4 Py3 compatibility

  * 6f61a08 Py3 compatibility

  * bae0d9d Py3 compatibility

  * f43a60d Py3 compatibility

  * fed632f Py3 compatibility

  * 509aa12 Py3 compatibility

  * 9d5d292 Py3 compatibility

  * e4a4410 Py3 compatibility

  * a2ae43a Py3 compatibility

  * 8e4c784 Py3 compatibility

  * e465353 Py3 compatibility

  * 931acec Py3 compatibility

  * 482016e Py3 compatibility

  * 6b0c88e Py3 compatibility

  * 26bb8d8 Py3 compatability

  * fe1561c Py3 compatability

  * b1a346e Py3 compatability

  * 971655a Py3 compatability

  * 3eadc15 Py3 compatability

  * 438da06 Py3 compatability

  * 6066e3f Py3 compatability

  * 6ecd1df Py3 compatability

  * 6810bf7 Py3 compatability

  * 1d6c795 Py3 compatability. Lint.

  * cfb0106 Py3 compatability

  * 12024a4 Py3 compatability

  * 231e1ba Py3 compatability. Single quotes.

  * ac8457d Py3 compatability

  * 1efe740 Py3 compatability

  * f60e3c7 Py3 compatability

  * 04f65c5 Fix references

  * 4953576 Py3 compatability

  * 87e2cfc Py3 compatability

  * 47a7225 Py3 compatability

  * cbc45e3 Py3 compatability

  * ffed054 Remove unused imports

  * e13336e Py3 compatability

  * a81f668 Py3 compatability

  * f51672a Update PyLint RC files to support 1.4.0 options

  * 3787524 Make pylint ignore `invalid-sequence-index`

  * 336b081 Properly handle `distutils.version` for PyLint

  * 7791067 Lint fix

  * f44327d Iterate over a copy.

  * 04302a4 Remove the list cast

  * afaf028 Py3 compatibility fixes. Skip tests if no mock available.

  * 4831efc Py3 compatibility fixes. Proper test module imports setup.

  * 6ccbccc Py3 compatibility fixes.

  * 36d058b Py3 compatibility fixes. Skip tests if no mock available.

  * 03763d6 Py3 compatibility fixes. Skip tests if no mock available.

  * ca06f27 Py3 compatibility fixes.

  * 1a4a300 Disable PyLint import error

  * 5ede88c Py3 compatibility fixes.

  * ce7e403 Fix variable name

  * 89bfab1 Py3 compatibility fixes.

  * 3942da1 Py3 compatibility fixes.

  * 0ace482 Py3 compatibility fixes.

  * de0e80c Py3 compatibility fixes. Dos 2 Unix line breaks. Lint.

  * de60a78 Py3 compatibility fixes.

  * 82f0b06 Py3 compatibility fixes.

  * c91f0ab Py3 compatibility fixes.

  * b3c6f37 Py3 compatibility fixes.

  * b4d45f0 Py3 compatibility fixes.

  * c5a4fd8 Py3 compatibility fixes. Dos 2 Unix line breaks.

  * b583fb8 Join absolute imports

  * 7950cc1 Py3 compatibility fixes.

  * e9a8481 Add removed import

  * 5dab3e0 Py3 compatibility fixes.

  * dc2d3b8 The imports do work!

  * 1bcda11 Py3 compatibility fixes.

  * b3807f5 Py3 compatibility fixes.

  * 788bb91 Py3 compatibility fixes.

  * 84b520a Py3 compatibility fixes.

  * 1a2f2b8 Py3 compatibility fixes.

  * 66db170 Py3 compatibility fixes.

  * 26fa3ca Py3 compatibility fixes.

  * b6f61d6 Py3 compatibility fixes.

  * 7d64e36 Py3 compatibility fixes.

  * e33e6ec Py3 compatibility fixes.

  * e760a98 Py3 compatibility fixes.

  * ab5c5c1 Py3 compatibility fixes.

  * 57b69be Py3 compatibility fixes.

  * df76a05 Py3 compatibility fixes.

  * 47412fc Py3 compatibility fixes.

  * e4467f5 Py3 compatibility fixes.

  * cc28141 Py3 compatibility fixes.

  * 3b0774c Py3 compatibility fixes.

  * 6388010 Py3 compatibility fixes.

  * 09e0cd8 Py3 compatibility fixes.

  * 937ab16 Py3 compatibility fixes.

  * a1f83e6 Py3 compatibility fixes.

  * 451d84c Py3 compatibility fixes.

  * 940e0b4 Py3 compatibility fixes.

  * 47457ab Py3 compatibility fixes.

  * c35f50e Py3 compatibility fixes.

  * 748037e Py3 compatibility fixes.

  * a25a8ab Py3 compatibility fixes.

  * ca42795 Py3 compatibility fixes.

  * f4f323e Py3 compatibility fixes.

  * 02d6394 Py3 compatibility fixes.

  * b5c0ee1 Move import

  * 412e444 Py3 compatibility fixes.

  * d36fce5 Py3 compatibility fixes.

  * 2262f4a Py3 compatibility fixes. Lint.

  * f6af99b Py3 compatibility fixes.

  * 8c4204e Py3 compatibility fixes.

  * b1e7fa4 Py3 compatibility fixes.

  * 0d9117d Py3 compatibility fixes.

  * 1765829 Py3 compatibility fixes.

  * ebcb8cd Py3 compatibility fixes.

  * 4883692 Py3 compatibility fixes.

  * 2d71cd7 Py3 compatibility fixes.

  * c7502ef Py3 compatibility fixes.

  * 8c418e0 Py3 compatibility fixes.

  * be8e880 Py3 compatibility fixes.

  * f1e86e1 Py3 compatibility fixes.

  * eb5533b Py3 compatibility fixes.

  * b076e27 Py3 compatibility fixes.

  * b36d48b Move `salt.modules.fsutils` to `salt.utils.fsutils`. It's not a salt module.

  * d19fcbb Py3 compatibility fixes.

  * a45f35b No broad exception use

  * 3251a46 Py3 compatibility fixes.

  * 196fe3c Py3 compatibility fixes.

  * 1b661f7 Py3 compatibility fixes.

  * 1ee6f1f Py3 compatibility fixes.

  * 443462d Py3 compatibility fixes.

  * f62d580 Py3 compatibility fixes.

  * e1ef37c Py3 compatibility fixes. Lint.

  * 205100f Py3 compatibility fixes. Lint.

  * de1cfe1 Py3 compatibility fixes.

  * 470bfb4 Py3 compatibility fixes.

  * d70d52e Py3 compatibility fixes.

  * 9993664 Py3 compatibility fixes.

  * dde7c9c Py3 compatibility fixes. LINT!

  * 3f70799 Py3 compatibility fixes.

  * 6f078c7 Py3 compatibility fixes.

  * 858f490 Py3 compatibility fixes.

  * 3c3e0b1 Py3 compatibility fixes.

  * 142a4a2 Py3 compatibility fixes.

  * 7d0e0c2 Py3 compatibility fixes.

  * 98247f2 Py3 compatibility fixes.

  * a353765 Py3 compatibility fixes.

  * 7a3480a Py3 compatibility fixes.

  * e749dd9 Py3 compatibility fixes.

  * b8ac582 Py3 compatibility fixes.

  * c3e662d Make use of the `smartup` PyLint plugin.

  * 2b79368 Py3 compatibility fixes.

  * e7d0c54 Py3 compatibility fixes.

  * 427affb Py3 compatibility fixes. Double to single quotes.

  * 6e0eb0f Py3 compatibility fixes.

  * 5764ad9 Remove old code. `OptionParser` should also subclass `object`.

  * 75ac029 Py3 compatibility fixes.

  * 79be964 We need to write something, even an empty string

  * e6ab1d4 Fix import

  * 3fdb3a2 Complete Py3 compatibility fixes.

  * fdd2a3e Correct the iteration

  * f9ae69c Remove the list casting

  * 3dd1246 Iterate on a copy

  * 428029f Py3 compatibility fixes.

  * 40d6ac4 Fix six import.

  * a5e060a Py3 compatibility fixes.

  * 705ff1b Py3 compatibility fixes.

  * f314d15 Py3 compatibility fixes.

  * 0e771b5 Py3 compatibility fixes.

  * 7dd0784 Py3 compatibility fixes.

  * 70ecf41 Py3 compatibility fixes.

  * ca1f469 Py3 compatibility fixes.

  * f7ec47f Py3 compatibility fixes.

  * 524779f Py3 compatibility fixes.

  * ecbd90e Properly define SORTED_LOG_LEVELS

  * e890bda Py3 compatibility fixes.

  * 314ce44 Py3 compatibility fixes.

  * c3403bb Py3 compatibility fixes.

  * 42d1bc4 Py3 compatibility fixes.

  * dc836d4 Py3 compatibility fixes.

  * 17b93e4 Py3 compatibility fixes.

  * 200eed0 Py3 compatibility fixes.

  * b5e1525 Py3 compatibility fixes.

  * cb4aa40 Py3 compatibility fixes.

  * 7c81f6d Py3 compatibility fixes.

  * 83cdb11 Py3 compatibility fixes.

  * 263a8ef Py3 compatibility fixes.

  * d68e383 Py3 compatibility fixes.

  * 4e1f36e Py3 compatibility fixes.

  * fb07bbe Py3 compatibility fixes.

  * f905a4e Py3 compatibility fixes.

  * f26fb64 Py3 compatibility fixes.

  * e1f499a Py3 compatibility fixes.

  * e500f2f Py3 compatibility fixes.

  * b47e34d Py3 compatibility fixes.

  * f568c1f Py3 compatibility fixes.

  * 3c4a997 Py3 compatibility fixes.

  * 03d74dd Py3 compatibility fixes.

  * eff50e4 Py3 compatibility fixes.

  * ae824a7 Py3 compatibility fixes.

  * b8fc031 Py3 compatibility fixes.

  * 4c0efa3 Py3 compatibility fixes.

  * 867a1ae Py3 compatibility fixes.

  * e068eb4 Py3 compatibility fixes. Lint fixes. No need to cast to str, format does that already

  * debd7ba Py3 compatibility fixes.

  * a576e85 Py3 compatibility fixes.

  * ccd03e6 Py3 compatibility fixes.

  * 5d2cccd Py3 compatibility fixes.

  * 5e2c679 Py3 compatibility fixes.

  * fb26e46 Py3 compatibility fixes.

  * 2c2eab2 Py3 compatibility fixes.

  * e6a5ecb Py3 compatibility fixes.

  * 4bda9a8 Py3 compatibility fixes.

  * 7593628 Py3 compatibility fixes.

  * 884b2a8 Py3 compatibility fixes.

  * f762ab1 Py3 compatibility fixes.

  * 4561444 Py3 compatibility fixes.

  * 1f77a7c Py3 compatibility fixes.

  * 9f6e22b Py3 compatibility fixes.

  * 32cd2c4 Py3 compatibility fixes. Fix variable name.

  * 2ebc8a1 Py3 compatibility fixes

  * 84955b4 Py3 compatibility fixes

  * de4a9fe Py3 compatibility fixes

  * 63dc6ae Py3 compatibility fixes

  * 0037eda Py3 compatibility fixes

  * 6d04942 Py3 compatibility fixes

  * fd04035 Py3 compatibility fixes

  * d3acb19 Py3 compatibility fixes

  * 5242e72 Py3 compatibility fixes

  * f13718f Py3 compatibility fixes

  * 72654ad Py3 compatibility fixes

  * 85b66a4 Py3 compatibility fixes

  * a8ff8fa Py3 compatibility fixes

  * 8081170 Py3 compatibility fixes

  * 0ead7d0 Py3 compatibility fixes

  * a8bc298 Py3 compatibility fixes

  * 282aeb1 Py3 compatibility fixes

  * fee4a62 Py3 compatibility fixes

  * 46add23 Py3 compatibility fixes

  * 403abc8 Py3 compatibility fixes

  * 91d1851 Py3 compatibility fixes

  * 5d57056 Py3 compatibility fixes

  * 665127c Py3 compatibility fixes

  * fda912f Py3 compatibility fixes

  * 7360164 Py3 compatibility fixes

  * fcd9832 Py3 compatibility fixes

  * ec93519 Py3 compatibility fixes

  * f07427a Py3 compatibility fixes

  * b54c029 Py3 compatibility fixes

  * 8fa37d6 Py3 compatibility fixes

  * cb65312 Py3 compatibility fixes

  * b555ddf Py3 compatibility fixes

  * b791dd6 Py3 compatibility fixes

  * 81ae50f Py3 compatibility fixes

  * eca6f73 Py3 compatibility fixes

  * 207f3dd Py3 compatibility fixes

  * 4ae7e91 Py3 compatibility fixes

  * f592806 Py3 compatibility fixes

  * 3624b91 Py3 compatibility fixes

  * a75470a Py3 compatibility fixes

  * 56840f9 Py3 compatibility fixes

  * aa5eaea Py3 compatibility fixes

  * 88ddd58 Py3 compatibility fixes

  * ce57acd Py3 compatibility fixes

  * 21b15c9 Py3 compatibility fixes

  * bf411c3 Py3 compatibility fixes

  * 1af3764 Py3 compatibility fixes

  * 0eebd95 We only need the values, iterate them only

  * f33dd64 Py3 compatibility fixes

  * 3f24dcf Import six at a later stage

  * cca8da7 Add `absolute_import` where needed.

  * 192907f Py3 compatibility fixes

  * a86a0dd Py3 compatibility fixes

  * fb164e5 Py3 compatibility fixes

  * 7f443f9 Py3 compatibility fixes

  * 45bac63 Py3 compatibility fixes

  * 733956a Py3 compatibility fixes

  * e0e6d57 Py3 compatibility fixes

  * e0549ca Fix import

  * fe454d4 Py3 compatibility fixes

  * c0dd556 Py3 compatibility fixes

  * c3d922b Py3 compatibility fixes

  * 0726464 Py3 compatibility fixes

  * 1a779fd Py3 compatibility fixes

  * 309876e Py3 compatibility fixes

  * f3bc5bd Py3 compatibility fixes

  * fdc467b Py3 compatibility fixes

  * a4e48e8 Py3 compatibility fixes

  * 2d8b216 Py3 compatibility fixes

  * 53a5f4b Py3 compatibility fixes

  * f59d669 Py3 compatibility fixes

  * 4eadb88 Py3 compatibility fixes

  * 0bc4413 Py3 compatibility fixes

  * 0577610 Py3 compatibility fixes

  * dd146ca Py3 compatibility fixes

  * 5bc0c15 Py3 compatibility fixes

  * 60f215f Add `from __future__ import absolute_import`

  * 0e3dc48 Py3 compatibility fixes

  * e3d230c Py3 compatibility fixes & Lint

  * 842c63f Py3 compatibility fixes & Lint

  * 05aa95f Py3 compatibility fixes

  * 36bc86b Py3 compatibility fixes

  * e27ac3e Py3 compatibility fixes

  * 1f68974 Py3 compatibility fixes

  * 5bb6878 Py3 compatibility fixes

  * 01395ab Py3 compatibility fixes

  * 198ee3d Py3 compatibility fixes

  * e612b95 Py3 compatibility fixes

  * 7c98084 Py3 compatibility fixes

  * 7479e44 Py3 compatibility fixes

  * aaa1500 Py3 compatibility fixes

  * a767fef Py3 compatibility fixes

  * e70d34d Py3 compatibility fixes

  * 619b9e1 Py3 compatibility fixes

  * d220178 Py3 compatibility fixes

  * fb056b4 Py3 compatibility fixes

  * 268788b Py3 compatibility fixes

  * ccf573b Py3 compatability fixes

  * 31da005 Update pylintrc to load the python 3 modernize plugin

- **PR** `#20272`_: (*s0undt3ch*) Revert "Only softfail with a state kwarg mismatch"
  @ *2015-01-31T00:48:29Z*

  - **ISSUE** `#20227`_: (*kiorky*) Recent behavior in develop about state kwarg enforcement
    | refs: `#20257`_
  - **PR** `#20257`_: (*kiorky*) Only softfail with a state kwarg mismatch
    | refs: `#20272`_
  * 8539c82 Merge pull request `#20272`_ from saltstack/revert-20257-arghotfix
  * bb3162f Revert "Only softfail with a state kwarg mismatch"

- **PR** `#20270`_: (*rallytime*) Pylint disable StrictVersion import error
  @ *2015-01-31T00:33:20Z*

  * d0cec3b Merge pull request `#20270`_ from rallytime/pylint_fix
  * 310e907 Pylint disable StrictVersion import error

- **PR** `#20264`_: (*mzupan*) Added the default directory that gpg imports to
  @ *2015-01-30T23:41:46Z*

  * 4d3b810 Merge pull request `#20264`_ from mzupan/develop
  * a104956 Added the default directory that gpg imports to

- **PR** `#20266`_: (*cachedout*) Tornado version detect
  @ *2015-01-30T23:03:18Z*

  * eef6519 Merge pull request `#20266`_ from cachedout/tornado_version_detect
  * 710bb63 Typo

  * 69c5e1f Better detection for minimum pyzmq version

- **PR** `#20263`_: (*JohannesEbke*) Make AssociatePublicIpAddress work to fix `#19288`_
  @ *2015-01-30T21:12:04Z*

  - **ISSUE** `#19288`_: (*oba11*) AssociatePublicIpAddress doesnt work with salt-cloud 2014.7.0
    | refs: `#20972`_ `#25326`_
  * 4ce02f9 Merge pull request `#20263`_ from JohannesEbke/develop
  * 6a13a44 Make AssociatePublicIpAddress work to fix `#19288`_

- **PR** `#20265`_: (*rallytime*) Fix pylint on develop
  @ *2015-01-30T19:58:39Z*

  * d83f54c Merge pull request `#20265`_ from rallytime/pylint_develop
  * 4648530 Fix pylint on develop

- **PR** `#20262`_: (*cachedout*) If tornado is not installed, raise error that will be seen
  @ *2015-01-30T18:05:59Z*

  * b69a46b Merge pull request `#20262`_ from cachedout/tornado_error
  * 8162411 Also error and exit cleanly if saltnado can't be loaded

  * 7cbf3d7 If tornado is not installed, raise error that will be seen

- **PR** `#20257`_: (*kiorky*) Only softfail with a state kwarg mismatch
  | refs: `#20272`_
  @ *2015-01-30T17:53:35Z*

  - **ISSUE** `#20227`_: (*kiorky*) Recent behavior in develop about state kwarg enforcement
    | refs: `#20257`_
  * aa791d4 Merge pull request `#20257`_ from makinacorpus/arghotfix
  * 81212b4 state kw mismatch: increase to critical loglevel

  * f35869a Only softfail with a state kwarg mismatch

- **PR** `#20253`_: (*rbjorklin*) Fixed problem with tags occuring twice with docker.pulled
  @ *2015-01-30T17:40:04Z*

  * f4b1688 Merge pull request `#20253`_ from rbjorklin/fix_docker_pulled_double_tag
  * 7497d71 Fixed problem with tags occuring twice with docker.pulled

- **PR** `#20252`_: (*jayeshka*) adding incron unit test case
  @ *2015-01-30T17:38:27Z*

  * dc8aecc Merge pull request `#20252`_ from jayeshka/incron-unit-test
  * 378d965 adding incron unit test case

- **PR** `#20251`_: (*jayeshka*) adding ilo unit test case
  @ *2015-01-30T17:38:09Z*

  * 7f72eb9 Merge pull request `#20251`_ from jayeshka/ilo-unit-test
  * 9a48449 adding ilo unit test case

- **PR** `#20249`_: (*rupeshta*) implemented unit test cases for logadm module
  @ *2015-01-30T17:37:41Z*

  * 487394a Merge pull request `#20249`_ from rupeshta/logadm_unit_tests
  * 24536cc implemented unit test cases for logadm module

- **PR** `#20248`_: (*rupeshta*) implemented unit test cases for localemod module
  @ *2015-01-30T17:37:28Z*

  * b407b62 Merge pull request `#20248`_ from rupeshta/localemod_unit_tests
  * 3e2b08c implemented unit test cases for localemod module

- **PR** `#20247`_: (*rupeshta*) implemented unit test cases for launchctl module
  @ *2015-01-30T17:37:18Z*

  * dc09c54 Merge pull request `#20247`_ from rupeshta/launchctl_unit_tests
  * 2c07dbe implemented unit test cases for launchctl module

- **PR** `#20230`_: (*rallytime*) Merge 2015.2 into develop
  @ *2015-01-30T17:33:59Z*

  * 267d165 Merge pull request `#20230`_ from rallytime/merge_forward_develop
  * 9898fcf Merge branch '2015.2' into 'develop'

- **PR** `#20216`_: (*steverweber*) fix returning docs when some minions did not return
  @ *2015-01-30T17:31:45Z*

  * f494de9 Merge pull request `#20216`_ from steverweber/return_docs
  * 44ca51e fix returning docs when some minions did not return

- **PR** `#20222`_: (*jacksontj*) More specific error message.
  @ *2015-01-30T17:29:39Z*

  * 77198d4 Merge pull request `#20222`_ from jacksontj/develop
  * a4e35de More specific error message.

- **PR** `#20236`_: (*joejulian*) Issue `#20235`_: blockdev.format fails when succeeding
  @ *2015-01-30T17:17:01Z*

  - **ISSUE** `#20235`_: (*joejulian*) blockdev.format state can fail even if it succeeds
  * 2b2d98d Merge pull request `#20236`_ from joejulian/develop
  * d83bf53 Issue `#20235`_: blockdev.format fails when succeeding

- **PR** `#20175`_: (*kiorky*) runner: Force mminion loading not to clutter output
  @ *2015-01-30T17:05:37Z*

  * 9bbc256 Merge pull request `#20175`_ from makinacorpus/c
  * b00fd8e lint

  * 2820148 runner: Force mminion loading not to clutter output

- **PR** `#20232`_: (*jacksontj*) Remove unecessary finish() calls
  @ *2015-01-30T02:34:53Z*

  - **PR** `#20221`_: (*cachedout*) Remove finish [DO NOT MERGE]
    | refs: `#20232`_
  * 2988b0d Merge pull request `#20232`_ from jacksontj/saltnado
  * 641c76e Remove unecessary finish() calls

- **PR** `#20213`_: (*cachedout*) Add username/password to expected args
  @ *2015-01-29T21:47:36Z*

  * fcec870 Merge pull request `#20213`_ from cachedout/expected_args
  * 449e991 Add username/password to expected args

- **PR** `#20178`_: (*jacksontj*) Saltnado performance improvements
  @ *2015-01-29T19:42:54Z*

  * bf9c989 Merge pull request `#20178`_ from jacksontj/saltnado
  * 8ea041b Massive speedup to saltnado

  * c89262c Lazily load functions, since lots of clients don't even execute runners

- **PR** `#20186`_: (*kiorky*) Add a compat layer on zc.buildout state.
  @ *2015-01-29T17:40:14Z*

  - **ISSUE** `#20184`_: (*kiorky*) zc.buildout module broken in develop ...
    | refs: `#20186`_
  * 1fc9a52 Merge pull request `#20186`_ from makinacorpus/f
  * 8cbeeff Lint

  * 8a99dc4 Add a compat layer on zc.buildout state.

- **PR** `#20183`_: (*jayeshka*) adding htpasswd unit test case
  @ *2015-01-29T17:39:55Z*

  * 50aeea2 Merge pull request `#20183`_ from jayeshka/htpasswd-unit-test
  * 0b1bade resolved the error

  * 8cedb4b adding htpasswd unit test case

- **PR** `#20181`_: (*jayeshka*) adding hipchat test case
  @ *2015-01-29T17:39:36Z*

  * 6a6bc56 Merge pull request `#20181`_ from jayeshka/hipchat-unit-test
  * 2ab996d adding hipchat test case

- **PR** `#20180`_: (*jayeshka*) adding guestfs unit test case
  @ *2015-01-29T17:39:20Z*

  * 9698e49 Merge pull request `#20180`_ from jayeshka/guestfs-unit-test
  * acf1f5f adding guestfs unit test case

- **PR** `#20179`_: (*russellballestrini*) Added hg identity argument to state and module
  @ *2015-01-29T17:38:43Z*

  * a525c43 Merge pull request `#20179`_ from russellballestrini/hg-identity-refactor
  * eaf87e6 	modified:   salt/modules/hg.py

  * acaafda BUG: Removed extra quotes in hg.clone (not needed as cmd is already split as list) which was causing hg to abort on non-local repos like "ssh://...."

  * 3763e05 Added hg identity argument to state and module

- **PR** `#20172`_: (*jacksontj*) Fix for `#20170`_
  @ *2015-01-29T17:32:38Z*

  - **ISSUE** `#20170`_: (*kiorky*) grains.setval broken in develop
  * b469df1 Merge pull request `#20172`_ from jacksontj/develop
  * 975dee5 Remove test as well

  * 1547906 Remove grains outputter

  * aa8b694 Some more cleanup to grains outputter, closer to working

  * 7951622 Fix for `#20170`_

- **PR** `#20171`_: (*plastikos*) Minor: Improve thin and shim warnings and comments.
  @ *2015-01-29T17:31:00Z*

  * 504cbd9 Merge pull request `#20171`_ from plastikos/develop
  * 6fc4cd1 Minor: Improve thin and shim warnings and comments.

- **PR** `#20202`_: (*cachedout*) Add some logging to flaky test
  @ *2015-01-29T17:29:39Z*

  * d6250e9 Merge pull request `#20202`_ from cachedout/log_flaky_zmq_test
  * d772ddb Add some logging to flaky test

- **PR** `#20133`_: (*gweis*) webutil.useradd throws exception KeyError: 'out'
  @ *2015-01-28T22:43:28Z*

  * 28b584a Merge pull request `#20133`_ from gweis/develop
  * 6d1d0a4 webutil.useradd throws exception KeyError: 'out'

- **PR** `#20166`_: (*cachedout*) Catch all exceptions in reactor
  @ *2015-01-28T22:28:46Z*

  * 64ced62 Merge pull request `#20166`_ from cachedout/reactor_exc_catch
  * cd2aa33 Catch all exceptions in reactor

- **PR** `#20161`_: (*cachedout*) Init default args/kwargs if none are supplied in netap
  @ *2015-01-28T22:05:50Z*

  * 04288b3 Merge pull request `#20161`_ from cachedout/api_runner_defaults
  * b4c5b4f Init default args/kwargs if none are supplied in netap

- **PR** `#20142`_: (*quantonganh*) Allow to add extensions to a certificate
  @ *2015-01-28T21:59:58Z*

  * 29ac504 Merge pull request `#20142`_ from quantonganh/tls-module-cert-extensions
  * 91aa686 Allow to add extensions to a certificate

- **PR** `#20134`_: (*gerl1ng*) Extended mysql_user and mysql_grants documentation
  @ *2015-01-28T21:57:43Z*

  * 7cb71df Merge pull request `#20134`_ from gerl1ng/extend-mysql-state-documentation
  * 71e2067 Extended mysql_user and mysql_grants documentation

- **PR** `#20118`_: (*kitsemets*) salt.states.cmd: fixed 'unless' behaviour in case of multiple commands are given
  @ *2015-01-28T21:49:26Z*

  - **ISSUE** `#14634`_: (*Sacro*) 'unless' documentation isn't logically plausible
    | refs: `#16044`_
  - **ISSUE** `#11879`_: (*pille*) cmd.run: unless/onlyif should show return code in debug loglevel
    | refs: `#11898`_
  - **PR** `#16044`_: (*rallytime*) Clarify unless and onlyif docs
    | refs: `#20118`_
  - **PR** `#11898`_: (*rallytime*) Onlyif return codes added to debug log
    | refs: `#20118`_ `#20118`_
  * 89d47fe Merge pull request `#20118`_ from kitsemets/fix-unless-in-cmd-state
  * 6677a0a salt.states.cmd: fixed 'unless' behaviour in case of multiple unless commands are given

- **PR** `#20099`_: (*matyunin*) Code block start comment typo
  @ *2015-01-28T21:47:29Z*

  * 54c472b Merge pull request `#20099`_ from matyunin/develop
  * 91200a2 Remove breaking "Static" word on line 647

  * 71cc779 Code block start comment typo

- **PR** `#19729`_: (*jacksontj*) Runner compatibility
  @ *2015-01-28T21:29:42Z*

  - **ISSUE** `#19707`_: (*kiorky*) runners broken in current develop
    | refs: `#19729`_
  * f71714f Merge pull request `#19729`_ from jacksontj/develop
  * bfae9f9 Lazily load masterminion and keep it around.

  * 4db0248 Pass opts not an ImmutableDict of opts

  * 619c2a4 Fix typo from 37619f0e

  * 4272b3c Already prints out the output if run in sync mode, and async already has this in the ret event

  * f8256d1 Misc style cleanup

  * 8b343a6 Rework a bit the runner completion log

  * 60ec7b6 Removing useless cruft

  * 1c4435a runner: unclutter the output from mminion loading

  * 51e6431 runner: Fix job store

  * 5196c5e runner return: also add tgt to the payload

  * b41ef37 runner/master Store jobs in cache, & factorization

  * 0b516d0 runner: Print out correctly jid, both in sync/async

  * e806ae9 Don't *pop* the outputter, just pass opts of None

  * f4cc211 Keep the stamp

  * 9225a56 Conditionally pop _stamp

  * 274d999 Pylint cleanup

  * 41aca76 Nicer error handling for runner execution

  * de43c53 Remove unused code

  * 711d294 Revert "Fix two problems with runners"

  * 19f3139 Rework the runner CLI to not use threads

  * 44e8c47 Pylint cleanup

  * 6759d5f Remove unused import

  * d70aa25 Inject globals into *all* runners' global namespace

  * 6acbd36 Make non-async runner executions happen in a thread instead of a daemonized process.

- **PR** `#20139`_: (*jayeshka*) adding drbd unit test case
  @ *2015-01-28T19:40:59Z*

  * 16da23c Merge pull request `#20139`_ from jayeshka/drbd-unit-test
  * 3eda02a adding drbd unit test case

- **PR** `#20127`_: (*cachedout*) Use the nested outputter to display docs with -d
  @ *2015-01-28T19:32:43Z*

  * 77e71fd Merge pull request `#20127`_ from cachedout/doc_outputter
  * 845a7bf Use the nested outputter to display docs with -d

- **PR** `#20153`_: (*rallytime*) Merge `#20144`_ with pylint fix
  @ *2015-01-28T19:16:24Z*

  - **PR** `#20144`_: (*pille*) fix doc cli markup
    | refs: `#20153`_
  * 5b8dd2a Merge pull request `#20153`_ from rallytime/merge_20144
  * ec7ece4 Whitespace fix

  * 1967888 fix doc cli markup

- **PR** `#20146`_: (*rupeshta*) implemented unit test cases for key module
  @ *2015-01-28T19:13:00Z*

  * be9cac8 Merge pull request `#20146`_ from rupeshta/key_unit_tests
  * ac4dd17 implemented unit test cases for key module

- **PR** `#20140`_: (*jayeshka*) adding glusterfs unit test case
  @ *2015-01-28T15:58:58Z*

  * cfe10ed Merge pull request `#20140`_ from jayeshka/glusterfs-unit-test
  * 1718a96 adding glusterfs unit test case

- **PR** `#20147`_: (*cachedout*) Fix sed test
  @ *2015-01-28T13:33:23Z*

  * 2ee0118 Merge pull request `#20147`_ from cachedout/fix_sed_tests
  * 3dcc41d Fix sed test

- **PR** `#20130`_: (*cachedout*) Quote strs
  @ *2015-01-28T03:10:37Z*

  * 6bb599b Merge pull request `#20130`_ from cachedout/fix_fstab
  * ba37d40 Quote strs

- **PR** `#20126`_: (*cachedout*) Check for empty hostname
  @ *2015-01-27T21:59:53Z*

  * a5e0137 Merge pull request `#20126`_ from cachedout/fix_debian_ip
  * a213563 Check for empty hostname

- **PR** `#20114`_: (*jfindlay*) fix ddns_test for py26, broken for py3
  @ *2015-01-27T21:56:31Z*

  * 401f949 Merge pull request `#20114`_ from jfindlay/fix_ddns_tests
  * b178ee1 lint fixes

  * 41dd330 fix ddns_test for py26, broken for py3

- **PR** `#20123`_: (*cvrebert*) etcd_return.get_load(): fix str.join() call
  @ *2015-01-27T21:33:29Z*

  * 1a1fe23 Merge pull request `#20123`_ from cvrebert/patch-4
  * 088a822 etcd_return.get_load(): fix str.join() call

- **PR** `#20122`_: (*cvrebert*) mount.set_fstab: don't use vars()
  @ *2015-01-27T21:33:01Z*

  * e736adf Merge pull request `#20122`_ from cvrebert/patch-3
  * 7af1865 mount.set_fstab: don't use vars()

- **PR** `#20125`_: (*cachedout*) Avoid file cache problem in pydsl tests
  @ *2015-01-27T21:32:21Z*

  * 2fc1452 Merge pull request `#20125`_ from cachedout/pydsl_copy
  * dc53885 Avoid file cache problem in pydsl tests

- **PR** `#20121`_: (*cvrebert*) grains.ssds: rm redundant import
  @ *2015-01-27T21:24:04Z*

  * 9ba6d44 Merge pull request `#20121`_ from cvrebert/patch-2
  * c3b1725 grains.ssds: rm redundant import

- **PR** `#20117`_: (*cvrebert*) utils.verify.verify_env(): fix "defulats" typo
  @ *2015-01-27T21:19:33Z*

  * d783dd2 Merge pull request `#20117`_ from cvrebert/patch-1
  * 55325d5 utils.verify.verify_env(): fix "defulats" typo

- **PR** `#20115`_: (*TaiSHiNet*) DO APIv1 issue Closes `#19306`_
  @ *2015-01-27T20:18:38Z*

  - **ISSUE** `#19306`_: (*TaiSHiNet*) DigitalOcean API v1 private_networking is set to True instead of 'true'
  * b96b852 Merge pull request `#20115`_ from TaiSHiNet/patch-1
  * 19af330 DO APIv1 issue Closes `#19306`_

- **PR** `#20104`_: (*rupeshta*) implemented unit test cases for junos module
  @ *2015-01-27T17:37:55Z*

  * 6bb744c Merge pull request `#20104`_ from rupeshta/junos_unit_tests
  * db0d10f implemented unit test cases for junos module

- **PR** `#20103`_: (*rupeshta*) implemented unit test cases for ipset module
  @ *2015-01-27T17:37:47Z*

  * 6e43cfa Merge pull request `#20103`_ from rupeshta/ipset_unit_tests
  * 6b8eb2a implemented unit test cases for ipset module

- **PR** `#20073`_: (*cachedout*) GPG test fix
  @ *2015-01-27T17:31:34Z*

  * f7f4966 Merge pull request `#20073`_ from cachedout/gpg_test
  * 6660c8b Catch constructor errors in gpg

  * e3bf4bb GPG test fix

- **PR** `#20094`_: (*basepi*) Merge forward from 2015.2 to develop
  @ *2015-01-27T17:04:51Z*

  * bf397d1 Merge pull request `#20094`_ from basepi/merge-forward-develop
  * 808b9b0 Revise mixins

  * c4da7bd Merge remote-tracking branch 'upstream/2015.2' into merge-forward-develop

- **PR** `#20062`_: (*cachedout*) Increae default runner timeout to 60s
  @ *2015-01-27T16:54:54Z*

  * 4ab2489 Merge pull request `#20062`_ from cachedout/test_runner_timeout
  * 0b38efa Increae default runner timeout to 60s

- **PR** `#19950`_: (*jayeshka*) adding unit test case for debian_ip
  @ *2015-01-27T16:53:58Z*

  * 14b23cf Merge pull request `#19950`_ from jayeshka/debian_ip-unit-test
  * 229a35b resolved the errors

  * a870cb0 removed get_interface error

  * 7e7afe3 adding unit test case for debian_ip

- **PR** `#20095`_: (*colincoghill*) Handle pkgrepo keyids that have been converted to int.  `#19737`_
  @ *2015-01-27T03:42:02Z*

  - **ISSUE** `#19737`_: (*Reiner030*) pkgrepo.managed could better handle long keyids
    | refs: `#20095`_
  * e166f00 Merge pull request `#20095`_ from colincoghill/develop
  * 36671c6 Handle pkgrepo keyids that have been converted to int.  `#19737`_

- **PR** `#20081`_: (*ryan-lane*) Recursively generate yaml for boto_asg cloud-config
  @ *2015-01-27T03:40:03Z*

  * 9791243 Merge pull request `#20081`_ from lyft/fix-boto-asg-cloud-config
  * 3acc6b6 Recursively generate yaml for boto_asg cloud-config

- **PR** `#20064`_: (*jfindlay*) fix ddns tests
  @ *2015-01-27T03:36:37Z*

  * e5c5144 Merge pull request `#20064`_ from jfindlay/fix_ddns_tests
  * 89d27d3 refactor ddns_test test_update

  * f057367 fix skipIf logic for DDNSTestCase

  * bf24db2 fix ddns tests

- **PR** `#20054`_: (*opdude*) Fix checking of active mounts on OS X
  @ *2015-01-26T22:39:22Z*

  * 7792b57 Merge pull request `#20054`_ from Unity-Technologies/develop
  * 24ff873 Fix checking of active mounts on OS X

- **PR** `#20052`_: (*hobakill*) adding the salt-api binary to the list of dependency requirements
  @ *2015-01-26T22:38:39Z*

  * 80e71bc Merge pull request `#20052`_ from hobakill/develop
  * 80b7787 changing verbage from 'binary' to 'package'

  * c25601d fixing the syntax as per whiteinge comment

  * db98521 adding the salt-api binary to the list of dependency requirements

- **PR** `#20042`_: (*jodv*) Allow relative paths for --config-dir with daemonized minions
  @ *2015-01-26T22:30:50Z*

  * d64c225 Merge pull request `#20042`_ from jodv/fix-relpath-daemonized-minion
  * 97975f4 Allow relative paths for --config_dir with daemonized minions

- **PR** `#20083`_: (*basepi*) Default to nested for outputter of ''
  @ *2015-01-26T22:21:28Z*

  - **ISSUE** `#20077`_: (*basepi*) Outputter errors on 2015.2 for any command without an explicit outputter
    | refs: `#20083`_
  * 9b4840c Merge pull request `#20083`_ from basepi/outputtererror20077
- **PR** `#20039`_: (*bechtoldt*) completing some doc references
  | refs: `#25019`_
  @ *2015-01-26T19:15:38Z*

  * bfc6ead Merge pull request `#20039`_ from bechtoldt/doc_various_fixes
  * 439f253 adding runners to doc salt.runners reference

  * 4e72fde adding returners to doc salt.returners reference

  * 2ad37d0 adding renderers to doc salt.renderers reference

  * 020ca98 adding output to doc salt.output reference

  * eeeff3b adding states to doc salt.states reference

  * 7724073 adding modules to doc salt.modules reference

- **PR** `#20037`_: (*bechtoldt*) add missing file_tree and virtkey in pillar index doc, refs `#19262`_
  @ *2015-01-26T19:15:02Z*

  - **ISSUE** `#19262`_: (*bechtoldt*) salt.pillar.file_tree doesn't appear in the documentation
    | refs: `#25019`_
  * 5cc9a7c Merge pull request `#20037`_ from bechtoldt/fix_19262
  * 73cbbf0 those files seem to be required, too

  * 0ab5f51 add missing file_tree and virtkey in pillar index doc, refs `#19262`_

- **PR** `#20035`_: (*hazaelsan*) Fix valid ipv6 netmask values in debian_ip.py.
  @ *2015-01-26T19:14:47Z*

  * ad32a7c Merge pull request `#20035`_ from hazaelsan/fix_20034
  * 11c69a5 Fix valid ipv6 netmask values in debian_ip.py.

- **PR** `#20032`_: (*cachedout*) The docker state is not in beta
  @ *2015-01-26T19:14:35Z*

  * d3cb66e Merge pull request `#20032`_ from cachedout/remove_beta
  * f996504 The docker state is not in beta

- **PR** `#20031`_: (*cachedout*) Change misleading error message
  @ *2015-01-26T19:13:26Z*

  * f1dd8a9 Merge pull request `#20031`_ from cachedout/error_to_warning
  * ab256a5 Change misleading error message

- **PR** `#20029`_: (*bechtoldt*) Add pkg runner, list available pkg upgrades and group by packages
  @ *2015-01-26T19:13:12Z*

  * 0365409 Merge pull request `#20029`_ from bechtoldt/pkg_runner
  * fc5714c rename function group_upgrades -> list_upgrades, add style argument

  * 61a909b there might be several versions of a pkg

  * 0716e0b add pkg runner, list available pkg upgrades and group by packages

- **PR** `#20058`_: (*rallytime*) Fix pylint on develop
  @ *2015-01-26T18:54:02Z*

  * 645bab9 Merge pull request `#20058`_ from rallytime/pylint
  * 7926bed Fix pylint on develop

- **PR** `#20059`_: (*cachedout*) Forcefully reset the highstate stack on each pydsl test
  @ *2015-01-26T17:46:49Z*

  * 61f8a9c Merge pull request `#20059`_ from cachedout/pydsl_nuclear
  * c30c3ac Forcefully reset the highstate stack on each pydsl test

- **PR** `#20028`_: (*bechtoldt*) adding new argument dataset_pillar to salt.states.file.serialize()
  @ *2015-01-26T17:28:40Z*

  - **PR** `#18952`_: (*techhat*) Add serial commas to the style guide
  * 702b01a Merge pull request `#20028`_ from bechtoldt/file_serialize_contents_pillar
  * 5583ca5 bring back serial comma due to decision in `#18952`_

  * f082df3 highlighting names of arguments in err msg

  * db38172 adding new argument dataset_pillar to salt.states.file.serialize()

* a17c371 Merge remote-tracking branch 'upstream/2015.2' into develop


- **PR** `#20038`_: (*SmithSamuelM*) Fixed some bugs added config option more preparatory work for master cluster
  @ *2015-01-24T21:13:46Z*

  * 3b030bb Merge pull request `#20038`_ from SmithSamuelM/sam_20150122
  * 2b864be Change extract_masters to optional to raise error if empty So master cluster can use

  * 79fee04 changed joiner so master will attempt to join to other masters Added raet_clear_remote_masters config option

- **PR** `#20026`_: (*s0undt3ch*) Switch to rich comparison for Py3 support
  @ *2015-01-24T05:21:29Z*

  - **ISSUE** `#20014`_: (*s0undt3ch*) Make SaltStackVersion Py3 Compatible
    | refs: `#20026`_
  * 61ca222 Merge pull request `#20026`_ from s0undt3ch/hotfix/saltstackversion-py3-compat
  * f0eeef5 Switch to rich comparison for Py3 support

- **PR** `#20018`_: (*cachedout*) Split a test out into its own class to keep it from colliding
  @ *2015-01-24T00:14:55Z*

  * a8544af Merge pull request `#20018`_ from cachedout/pydsl_separate
  * b2ef529 Lint

  * ffa004a Fix exception that happens inside jinja renderer during test run

  * df4b369 Split a test out into its own class to keep it from colliding

- **PR** `#20002`_: (*jacksontj*) Don't let exit()'s within modules stop the daemons.
  @ *2015-01-24T00:13:48Z*

  * 4faca4f Merge pull request `#20002`_ from jacksontj/loader
  * 1cac52f pylint again

  * db554ab Remove exit() from testing

  * b0b0630 Split out error message for SystemExit

  * 9fd9098 Don't let exit()'s within modules stop the daemons.

- **PR** `#20020`_: (*jfindlay*) reenable ddns_test
  @ *2015-01-23T23:59:19Z*

  * fdc7618 Merge pull request `#20020`_ from jfindlay/fix_ddns_tests
  * 63369b0 reenable ddns_test

- **PR** `#20011`_: (*basepi*) Merge forward from 2015.2 to develop
  @ *2015-01-23T22:40:58Z*

  * efd529a Merge pull request `#20011`_ from basepi/merge-forward-develop
  * dd61682 Fix runtests permissions

  * ab41da0 Satisfy OCD

  * 8bba4bb Merge remote-tracking branch 'upstream/2015.2' into merge-forward-develop

- **PR** `#20017`_: (*SmithSamuelM*) Removed debug statement
  @ *2015-01-23T22:20:46Z*

  * 2d90561 Merge pull request `#20017`_ from SmithSamuelM/sam_20150122
  * 20b3967 Merge remote-tracking branch 'upstream/develop' into sam_20150122

- **PR** `#20008`_: (*rallytime*) Pylint fix for develop
  @ *2015-01-23T21:02:25Z*

  * 6d9244f Merge pull request `#20008`_ from rallytime/pylint_develop
  * 523295f Pylint fix for develop

- **PR** `#20007`_: (*cachedout*) Let's see if this is any better in jenkins
  @ *2015-01-23T18:58:48Z*

  * 41aac97 Merge pull request `#20007`_ from cachedout/fix_environ_test
  * 545e17c Let's see if this is any better in jenkins

- **PR** `#19995`_: (*rupeshta*) implemented unit test cases for influx module
  @ *2015-01-23T17:41:43Z*

  * d7a0405 Merge pull request `#19995`_ from rupeshta/influx_unit_tests
  * 3cb7b87 implemented unit test cases for influx module

- **PR** `#19989`_: (*steverweber*) accept installing no packages
  @ *2015-01-23T17:40:38Z*

  * 45b743d Merge pull request `#19989`_ from steverweber/develop
  * b89485d accept installing no packages

- **PR** `#19987`_: (*jacksontj*) Remove verify_* from all the non-daemon CLI scripts
  @ *2015-01-23T17:39:39Z*

  * 15e9c2f Merge pull request `#19987`_ from jacksontj/aes_cleanup
  * 7fa1a9c Remove verify_* from all the non-daemon CLI scripts

- **PR** `#19327`_: (*jmdcal*) top file error checking
  @ *2015-01-23T03:20:45Z*

  - **ISSUE** `#19326`_: (*jmdcal*) No warning on an empty top file provided
    | refs: `#19327`_
  * 94e441e Merge pull request `#19327`_ from jmdcal/error_reporting
  * 6b17639 top file error checking

- **PR** `#19986`_: (*s0undt3ch*) Log the daemons start ups and shut downs.
  @ *2015-01-23T03:19:13Z*

  - **ISSUE** `#19764`_: (*syedaali*) Salt master should log to /var/log/salt/master upon startup and shutdown
    | refs: `#19986`_
  * 5a9e8cb Merge pull request `#19986`_ from s0undt3ch/issues/19764
  * c08dbd7 Log the daemons start ups and shut downs.

- **PR** `#19967`_: (*alxbse*) multiple source files in windows repo to fix saltstack/salt`#9028`_
  @ *2015-01-23T03:04:58Z*

  - **ISSUE** `#9028`_: (*dimm037*) Extend Salt Windows Package Manager to Multiple Source Files
  * 2e48f6a Merge pull request `#19967`_ from alxbse/win_repo_multiple_sources
  * e5c59de added support for multiple source files in windows repo to fix saltstack/salt`#9028`_

- **PR** `#19976`_: (*oldmantaiter*) Add compatibility to mount by label
  @ *2015-01-23T03:00:42Z*

  * dc3bf87 Merge pull request `#19976`_ from oldmantaiter/mount-by-label
  * e314bd6 Add compatibility to mount by label

- **PR** `#19985`_: (*cachedout*) Fix two problems with runners
  @ *2015-01-23T02:58:14Z*

  * 7a6c9f0 Merge pull request `#19985`_ from cachedout/runner_linger
  * 389fb7e Fix two problems with runners

- **PR** `#19966`_: (*rallytime*) Merge 2015.2 forward to develop
  @ *2015-01-23T00:54:21Z*

  * c851b98 Merge pull request `#19966`_ from rallytime/merge_forward_develop
  * 2fc1cdc Merge branch '2015.2' into merge_forward_develop

- **PR** `#19965`_: (*zimathias*) Support sns subscriptions
  @ *2015-01-23T00:53:28Z*

  * 54a394d Merge pull request `#19965`_ from lyft/support-sns-subscriptions
  * f4c7537 Make sure boto_sns state is idempotent.

  * 416ad2c Propagate AWS credentials when calling other modules.

  * 85ec021 Merge remote-tracking branch 'upstream/develop' into support-sns-subscriptions

  * 4128b7a Fix return value statement.

  * b79756b Support subscriptions in sns topic state.

- **PR** `#19984`_: (*jasonm-makerbot*) Update index.rst
  @ *2015-01-23T00:47:57Z*

  * 5897e79 Merge pull request `#19984`_ from jasonm-makerbot/patch-1
  * 64e8162 Update index.rst

            * a967ea9 removed debug import

- **PR** `#19979`_: (*SmithSamuelM*) Fixed conflict  More preparatory work for master cluster
  @ *2015-01-22T23:03:47Z*

  * 98ab9af Merge pull request `#19979`_ from SmithSamuelM/sam_20150122
  * 29d7059 Merge remote-tracking branch 'upstream/develop' into sam_20150122

- **PR** `#19956`_: (*rupeshta*) implemented unit test cases for hadoop module
  @ *2015-01-22T19:41:08Z*

  * 2a7505e Merge pull request `#19956`_ from rupeshta/hadoop_unit_tests
  * 3a2ced7 implemented unit test cases for hadoop module

- **PR** `#19955`_: (*rupeshta*) implemented unit test cases for img module
  @ *2015-01-22T19:40:51Z*

  * 4ebc8c8 Merge pull request `#19955`_ from rupeshta/img_unit_tests
  * e4cb6ca implemented unit test cases for img module

- **PR** `#19952`_: (*rupeshta*) implemented unit test cases for http module
  @ *2015-01-22T19:40:16Z*

  * d488c06 Merge pull request `#19952`_ from rupeshta/http_unit_tests
  * 2493ccc implemented unit test cases for http module

- **PR** `#19951`_: (*rupeshta*) implemented unit test cases for hg module
  @ *2015-01-22T19:39:32Z*

  * 70cdb3e Merge pull request `#19951`_ from rupeshta/hg_unit_tests
  * c93c21e implemented unit test cases for hg module

- **PR** `#19940`_: (*jayeshka*) adding dpkg unit test case
  @ *2015-01-22T19:26:28Z*

  * 37fc882 Merge pull request `#19940`_ from jayeshka/dpkg-unit-test
  * a685e2e adding dpkg unit test case

- **PR** `#19933`_: (*toddtomkinson*) fix mysql returner for syndic master job cache
  | refs: `#20654`_
  @ *2015-01-22T19:23:41Z*

  * 745221c Merge pull request `#19933`_ from toddtomkinson/fix_mysql_returner_for_syndic_master_job_cache
  * 4438e70 fix mysql returner for syndic master job cache

- **PR** `#19896`_: (*colincoghill*) Fix saltstack/salt`#19415`_ pkgrepo.managed not enabling disabled ppas
  @ *2015-01-22T19:21:32Z*

  - **ISSUE** `#19415`_: (*sparrc*) pkgrepo.managed not enabling disabled ppas
  * e9120e9 Merge pull request `#19896`_ from colincoghill/develop
  * 031167f linting

  * 5c5f0b3 Fix saltstack/salt`#19415`_ pkgrepo with apt doesn't support "enabled"

- **PR** `#19843`_: (*alex-leonhardt*) Feature 19608 inline script for cloud profiles
  @ *2015-01-22T19:18:34Z*

  - **ISSUE** `#19608`_: (*alex-leonhardt*) Feature: enable salt-cloud to run a list of commands defined in a cloud profile
  * 978ede8 Merge pull request `#19843`_ from alex-leonhardt/feature-19608-inline_script_for_cloud_profiles
  * ff79515 Merge branch 'develop' into feature-19608-inline_script_for_cloud_profiles

  * e959d51 Consolidate deploy_kwargs (kind of) and try clean up some lint issues. Also fix issue when deploy is disabled/false, to still execute the inline_script commands.

  * 21f3909 Consolidate deploy_kwargs (kind of) and try clean up some lint issues.

  * 59b6d88 Merge remote-tracking branch 'origin/feature-19608-inline_script_for_cloud_profiles' into feature-19608-inline_script_for_cloud_profiles

    * 7447d33 Merge branch 'develop' into feature-19608-inline_script_for_cloud_profiles

  * 01d9acf Merge branch 'develop' into feature-19608-inline_script_for_cloud_profiles

  * b7efe6f Enable the use of inline_script inside profiles

  * ed27ab3 REVERT: ec2 subnetId issue:

  * 9a2995d ec2 subnetId issue:

  * fd40264 Initial commit to add feature of `#19608`_

- **PR** `#19943`_: (*rallytime*) Fix another pylint error
  @ *2015-01-22T07:31:45Z*

  * b61817d Merge pull request `#19943`_ from rallytime/pylint_develop
  * 5af605b Fix another pylint error

- **PR** `#19941`_: (*rallytime*) Pylint fix for develop
  @ *2015-01-22T07:09:50Z*

  * e047464 Merge pull request `#19941`_ from rallytime/pylint_develop
  * f191a3c Pylint fix for develop

          * 72b95f9 even more predatory ;)  master cluster work

          * f7efdc5 fixed bug in behaviors spurious loop around list comprehension added test for master kind

          * 4c29bb9 updated caller.flo to be like minion.flo for master cluster fixed bug in allower behaviors

          * 3ad7a68 refactor behaviors a little add bootstrap framer to master for bootstrapping into master cluster

          * 707e56a refactor use the term 'usher' to refer to initial master that bootstraps into road in multimaster it does not change in master cluster the ushers are eventually replaced with the master cluster sent from one of the ushers

- **PR** `#19931`_: (*SmithSamuelM*) More preparatory work on master cluster
  @ *2015-01-22T00:07:31Z*

  * 332beea Merge pull request `#19931`_ from SmithSamuelM/sam_20150121
  * ca02c6c more prep work for master cluster

  * 6792509 more prep work for master cluster

- **PR** `#19929`_: (*SmithSamuelM*) Predatory work on the master cluster
  @ *2015-01-21T23:18:44Z*

  * 4424d64 Merge pull request `#19929`_ from SmithSamuelM/sam_20150121
  * 30365c1 Prepatory work on the master cluster

  * 25d2ab7 removed obsolete method

  * 87c9a0e Added new opts for master cluster

- **PR** `#19925`_: (*SmithSamuelM*) Changed the now deprecated .postinitio to ._prepare
  @ *2015-01-21T21:34:02Z*

  * e162ce8 Merge pull request `#19925`_ from SmithSamuelM/sam_20150120
  * 1a9ff99 Changed the now deprecated .postinitio to ._prepare

- **PR** `#19915`_: (*cachedout*) Fix some performance regressions
  @ *2015-01-21T20:18:15Z*

  * fa1903e Merge pull request `#19915`_ from cachedout/fix_perf
  * 9bfe83b Fix some performance regressions

- **PR** `#19918`_: (*jfindlay*) fix ddns tests
  @ *2015-01-21T20:16:49Z*

  * 8f8ff4e Merge pull request `#19918`_ from jfindlay/fix_ddns_tests
  * d4547bc fix skipIf typo

  * 5f3f2f3 fix ddns tests

- **PR** `#19895`_: (*syedaali*) add tuned execution and state module
  @ *2015-01-21T19:21:45Z*

  * 28a6a78 Merge pull request `#19895`_ from syedaali/develop
  * 4dbaae5 add tuned execution and state module

- **PR** `#19867`_: (*rupeshta*) implemented unit test cases for module grub_legacy
  @ *2015-01-21T19:20:51Z*

  * 0eff1e4 Merge pull request `#19867`_ from rupeshta/grub_legacy_unit_tests
  * b18b188 implemented unit test cases for module grub_legacy

* 9446633 Merge remote-tracking branch 'upstream/2015.2' into merge-forward-develop


- **PR** `#19900`_: (*jayeshka*) adding git unit test case
  @ *2015-01-21T17:57:26Z*

  * f365e89 Merge pull request `#19900`_ from jayeshka/git-unit-test
  * 6b7ff5d adding git unit test case

- **PR** `#19893`_: (*thatch45*) Clean up an import mistake
  @ *2015-01-21T17:22:02Z*

  * 96245cf Merge pull request `#19893`_ from thatch45/mhead_clean
  * 48465a6 Merge branch 'develop' into mhead_clean

- **PR** `#19903`_: (*techhat*) Revert "Allow joyent api host suffix to be configurable"
  @ *2015-01-21T16:39:57Z*

  - **ISSUE** `#19671`_: (*pannon*) Feature: Joyent private cloud SDC (Smart Data Center) integration
    | refs: `#19687`_
  - **PR** `#19687`_: (*techhat*) Allow joyent api host suffix to be configurable
    | refs: `#19903`_
  * d244624 Merge pull request `#19903`_ from saltstack/revert-19687-joyent
  * 27adbbe Revert "Allow joyent api host suffix to be configurable"

- **PR** `#19894`_: (*s0undt3ch*) Lint fixes
  @ *2015-01-21T15:12:26Z*

  * 8989c48 Merge pull request `#19894`_ from s0undt3ch/develop
  * 8dbb739 White-space lint fix

  * e41f052 Lint fix. Multiple exceptions should be enclosed in parens

  * 3e7903e Py3 compatibility

  * 01de65c Strip trailing white-space

  * 4390999 White-space lint fix

  * 7008cd3 Use print function, and Salt's `fopen`

  * 4194830 Call super class

  * 2efb930 White-space lint fixes

  * d5d9228 White space lint fixes

  * b0920b2 We still support Python 2.6, so, we need indexes.

  * f8563ed Lint fixes

- **PR** `#19891`_: (*UtahDave*) better error, including stacktrace
  @ *2015-01-21T00:35:36Z*

  * 7bb1599 Merge pull request `#19891`_ from UtahDave/develop
  * 201fd4c better error, including stacktrace

- **PR** `#19841`_: (*dandye*) BugFix
  @ *2015-01-21T00:34:13Z*

  * 2260671 Merge pull request `#19841`_ from clever-crow-consulting/develop
  * fa764ea BugFix

- **PR** `#19890`_: (*ryan-lane*) Revert "Fixes secgroup return for EC2-VPC"
  @ *2015-01-21T00:31:20Z*

  * e70c72b Merge pull request `#19890`_ from ryan-lane/revert-19782-boto-secgroup-vpc-return
  * 738a0f2 Revert "Fixes secgroup return for EC2-VPC"

      * 54f699f Clean soem extra blank lines

      * 55de4b0 move the floworker base class into master.py

      * 2a3079a fix dependency issue in multi head master

- **PR** `#19882`_: (*garethgreenaway*) Feature addition to jobs runner.
  @ *2015-01-20T23:12:54Z*

  - **ISSUE** `#19739`_: (*wt*) Please add StartTime field to jobs.active entries
    | refs: `#19882`_
  * 86db326 Merge pull request `#19882`_ from garethgreenaway/19739_start_time_jobs_active
  * 9da62c4 removing logging statement.

  * b7d5bf5 Adding the StartTime to the output of the jobs.active runner.

- **PR** `#19877`_: (*twellspring*) Add how service is determined to be running/dead
  @ *2015-01-20T23:10:56Z*

  * c8f938a Merge pull request `#19877`_ from twellspring/patch-4
  * f7fc31e Add how service is determined to be running/dead

- **PR** `#19874`_: (*rakai93*) fixes `#19871`_
  @ *2015-01-20T23:10:34Z*

  - **ISSUE** `#19871`_: (*rakai93*) Bug in manage.bootstrap runner
  * 08f5e0c Merge pull request `#19874`_ from rakai93/iss19871
  * 74ff9aa fixes `#19871`_

- **PR** `#19868`_: (*rupeshta*) implemented unit test cases for glance module
  @ *2015-01-20T23:09:34Z*

  * a41b20f Merge pull request `#19868`_ from rupeshta/glance_unit_tests
  * 87eba66 implemented unit test cases for glance module

- **PR** `#19863`_: (*jayeshka*) adding djangomod unit test case
  @ *2015-01-20T23:06:35Z*

  * c49361a Merge pull request `#19863`_ from jayeshka/djangomod-unit-test
  * 346eb73 adding djangomod unit test case

- **PR** `#19859`_: (*twellspring*) Documentation fix for Issue 19513.
  @ *2015-01-20T23:06:03Z*

  * dca509e Merge pull request `#19859`_ from twellspring/develop
  * e62e36d Update include.rst

  * 59c6747 Create sls_filename_cant_contain_period.rst

  * cb2bfd6 Update states_pt1.rst

  * b78dff7 Update starting_states.rst

- **PR** `#19858`_: (*RyPeck*) Update timeout help to indicate it is in seconds
  @ *2015-01-20T23:04:47Z*

  * cfb6bef Merge pull request `#19858`_ from RyPeck/develop
  * 1c53dc3 Update timeout help to indicate it is in seconds

- **PR** `#19857`_: (*mirath*) Added a cmd flag for the state_output_diff variable
  @ *2015-01-20T23:04:30Z*

  * 97c1757 Merge pull request `#19857`_ from mirath/state_output_diff_cmdflag
  * 5dec2aa Merge branch 'develop' of https://github.com/saltstack/salt into state_output_diff_cmdflag

  * 7032006 Added a cmd flag for the state_output_diff variable

- **PR** `#19855`_: (*colincoghill*) Fix for docker login saltstack/salt`#18673`_
  @ *2015-01-20T23:00:20Z*

  - **ISSUE** `#18673`_: (*dennisfoconnor*) docker.login module is failing
  * b489dfa Merge pull request `#19855`_ from colincoghill/develop
  * f4c7a6b Fix for docker login saltstack/salt`#18673`_

- **PR** `#19851`_: (*rominf*) [linux_acl] add mask support
  @ *2015-01-20T22:59:40Z*

  * 32f062d Merge pull request `#19851`_ from rominf/linux_acl_mask
  * 8b0e6fa [states/linux_acl] add mask support

  * 9242432 [modules/linux_acl] add mask support

- **PR** `#19829`_: (*AlexanderHaase*) Fix for issue `#17198`_
  @ *2015-01-20T22:43:14Z*

  * 7ea840f Merge pull request `#19829`_ from AlexanderHaase/develop
  * 42af1e1 Another pass over modules/mount.py against pylint....

  * aac56b1 Another pass over modules/mount.py against pylint....

  * cc2b03d Merge https://github.com/saltstack/salt into develop

  * 35e690a More pylint fixes for changes to modules/mount.py

  * 3e252cf PEP style compliance for changes to states/mount.py

  * 810e1ce PEP style compliance for changes to modules/mount.py

  * 6a0906d Updating modules/mount.py (mount.fstab) to produce an array for opts, rather than the opts string literal. Allows mount to pass unit tests

  * acb87f3 Fixed whitespace error, ran unit tests

  * 4e4c10c Merge https://github.com/saltstack/salt into develop

  * 0a814d8 Normalizing white space to four spaces to remedy pylint errors

  * 9de6fa5 Merge branch 'develop' of https://github.com/AlexanderHaase/salt into develop

    * 660d24f Debugged & moderately tested match_on functionality for modules/mount and states/mount with relation to fstab.

  * 9063ab3 Debugged & moderately tested match_on functionality for modules/mount and states/mount with relation to fstab.

  * df19b40 Adding rework for mount match-on criteria. Implimented core class in mount/modules to represent and match fstab entries. Re-implimented related methods in DRY compliance.

- **PR** `#19888`_: (*SmithSamuelM*) Added local test runner for salt daemons on raet unittests
  @ *2015-01-20T22:16:06Z*

  * f2317b0 Merge pull request `#19888`_ from SmithSamuelM/sam_20150120
  * 7a2ff7f added lint exceptions

  * 5fe6b16 Added local test runner for daemons raet unit tests

  * b24e326 Merge remote-tracking branch 'upstream/develop' into sam_20150120

- **PR** `#19844`_: (*DmitryKuzmenko*) Don't run deeds in SetUp, use enter and recur.
  @ *2015-01-20T21:58:31Z*

  * 53d003c Merge pull request `#19844`_ from DSRCompany/raet_presence_test
  * ed1e87e Don't run deeds in SetUp, use enter and recur.

- **PR** `#19812`_: (*matthew-muscat*) Update hosts file creation for consistency and improved readability
  @ *2015-01-20T21:52:02Z*

  * 8bfb79c Merge pull request `#19812`_ from matthew-muscat/develop
  * f44d674 Update hosts module test

  * b82001f Update hosts file creation for consistency and better readability

      * c0fbaa1 Merge remote-tracking branch 'upstream/develop' into sam_20150120

* 6d126d6 Merge branch '2015.2' into develop


      * 0a014df fix pedro bug

      * 068c5a7 Merge remote-tracking branch 'upstream/develop' into sam_20150120

- **PR** `#19883`_: (*thatch45*) Add an error to the master log for failed pillar builds
  @ *2015-01-20T20:58:01Z*

  * b0d4fa1 Merge pull request `#19883`_ from thatch45/pillar_error
  * 653aa46 Add an error to the master log for failed pillar builds

      * 923e062 Fixed problems when aes not setup on conventional minion not one meant for multi-headed

      * 0c65488 Merge remote-tracking branch 'upstream/develop' into sam_20150120

- **PR** `#19814`_: (*thatch45*) Mkey cli
  @ *2015-01-20T17:22:09Z*

  * 89ef860 Merge pull request `#19814`_ from thatch45/mkey_cli
  * b993e0a Add hidden multikey to opts for salt multikey

  * 688a2a1 Add indentation to the key outputter for multi key

  * 8a180d3 make the outputs consistent

  * adc6348 multikey works, still needs some tuning...

  * fd98239 Make a cli system for the multi key interface

- **PR** `#19831`_: (*TronPaul*) Fix iptables regex issue
  @ *2015-01-18T14:51:21Z*

  - **ISSUE** `#19830`_: (*TronPaul*) iptables eats n,o,t characters when negating rule.
    | refs: `#19831`_
  * 5f00166 Merge pull request `#19831`_ from TronPaul/iptables_bang_not_fix
  * 4910822 fix regex issue

- **PR** `#19786`_: (*jayeshka*) Adding defaults unit test case
  @ *2015-01-18T03:35:37Z*

  * 8133907 Merge pull request `#19786`_ from jayeshka/defaults-unit-test
  * bb6e229 Adding defaults unit test case

- **PR** `#19685`_: (*rupeshta*) test ddns module
  @ *2015-01-18T03:34:28Z*

  * d04dee8 Merge pull request `#19685`_ from rupeshta/ddns_unit_tests
  * 721fffa fix pylint errors

  * f8f2858 test ddns module

- **PR** `#19821`_: (*jfindlay*) fix debian service unit tests
  @ *2015-01-18T00:47:18Z*

  * d7d15e3 Merge pull request `#19821`_ from jfindlay/debian_service_unit_tests
  * 555dbd6 fix debian_service unit tests

  * 73ccbf6 Implemented unit test cases fordebian_service module

- **PR** `#19822`_: (*jfindlay*) fix dnsmasq unit tests
  @ *2015-01-18T00:44:47Z*

  * 8ea53a7 Merge pull request `#19822`_ from jfindlay/dnsmasq_unit_test
  * 9202cbb fix dnsmasq unit tests

  * e5bdbf5 Implemented unit test cases for dnsmasq module

- **PR** `#19819`_: (*jfindlay*) fix environ unit tests
  @ *2015-01-17T22:42:21Z*

  * b42029b Merge pull request `#19819`_ from jfindlay/environ_unit_tests
  * 770258e fix environ module unit tests

  * 7a83039 removed unused import

  * 09b6088 Implemented unit test cases for module environ

- **PR** `#19817`_: (*jfindlay*) fix cassandra unit tests
  @ *2015-01-17T22:10:25Z*

  * 4234a76 Merge pull request `#19817`_ from jfindlay/cassandra_unit_tests
  * 9d18f7a fix cassandra unit tests

  * 843b719 column_family_definition requires keyspace, column_family args

  * 0de948f Implemented unit test cases for cassandra module

  * 8c5148a writing unit test cases for cassandra module

- **PR** `#19790`_: (*cachedout*) Fix multi-master event handling bug
  @ *2015-01-17T16:45:47Z*

  * 5c2ce4c Merge pull request `#19790`_ from cachedout/mm_event
  * 86e4ccf Remove unnecessary comment

  * ad02d09 Fix multi-master event handling bug

- **PR** `#19792`_: (*rallytime*) Merge 2015.2 forward into develop
  @ *2015-01-17T16:39:02Z*

  * 1569520 Merge pull request `#19792`_ from rallytime/merge_forward_develop
  * d724ed3 Merge branch '2015.2' into 'develop'

- **PR** `#19793`_: (*cachedout*) Provide an option to service.running to wait for a service to fully init
  @ *2015-01-17T00:06:11Z*

  - **ISSUE** `#19084`_: (*mitar*) Wait for a service to really start in service.running
    | refs: `#19793`_
  * ee18559 Merge pull request `#19793`_ from cachedout/service_wait
  * 9f4d5dc Provide an option to service.running to wait for a service to fully init

- **PR** `#19783`_: (*jayeshka*) adding deb_apache unit test
  @ *2015-01-17T00:02:07Z*

  * 3edd84a Merge pull request `#19783`_ from jayeshka/deb_apache-unit-test
  * f245aec resolved pylint error

  * ede0a37 adding deb_apache unit test

- **PR** `#19782`_: (*claudiupopescu*) Fixes secgroup return for EC2-VPC
  @ *2015-01-17T00:01:45Z*

  * 7f4a2c7 Merge pull request `#19782`_ from claudiupopescu/boto-secgroup-vpc-return
  * a835135 Fixes secgroup return for EC2-VPC

- **PR** `#19778`_: (*thatch45*) Multi Headed Master
  @ *2015-01-17T00:00:01Z*

  * 391cf6b Merge pull request `#19778`_ from thatch45/zmq_ioflo
  * 96c84e6 Merge branch 'develop' into zmq_ioflo

  * 61d0ad9 zmq publish works now!

  * 4e6fad2 Add the zmq pub packet setup routines

  * a519614 Add metadata etc to raet publish

  * 18d6fd6 Clean up the publisher

  * 421368e create the crypticle on the worker so we don't need to serialize

  * d14df0a forward the mkey into the worker processes

  * 2daf8a8 move crypt key gen for zmq into postinitio

  * b00664d add log message for port binding

  * d564329 backport fix to this branch

  * 7fc1420 don't recreate the salt access keys in the zmq behaviors

  * 25e6075 fix bad refs to opts in zmq ioflo behaviors

  * 4585767 Fix typo in ioflo ref to worker behavior

  * 2e516f4 re-enable the exploding opts into .salt.etc

  * 996c116 don't remote the aes key if runnign a dual head

  * 9fd2794 no longer in a loop

  * bfec7e2 not in a loop anymore!

  * 80dfa87 Add floscript for zmq publisher

  * 46192cb fill out the salt zmq publisher behavior

  * 4fc76b3 Add the start of the publisher and fix up the floscripts

- **PR** `#19774`_: (*DmitryKuzmenko*) Presenter test using FrameIofloTestCase
  @ *2015-01-16T23:59:32Z*

  * 602517e Merge pull request `#19774`_ from DSRCompany/raet_presence_test
  * 79daaa5 .flo script based presence test

  * 637a5aa Presenter test using FrameIofloTestCase

- **PR** `#19768`_: (*ryan-lane*) Initial grafana state and elasticache execution modules
  @ *2015-01-16T23:59:09Z*

  * c3b4dd5 Merge pull request `#19768`_ from lyft/grafana-module
  * a1421e6 CLI examples and docstrings

  * 0c000cc Fix lint error

  * 6b105f1 Initial grafana state and elasticache execution modules

- **PR** `#19746`_: (*zimathias*) Add boto_sns module and state.
  @ *2015-01-16T23:58:09Z*

  * fab600a Merge pull request `#19746`_ from lyft/add-boto-sns-module
  * effc948 Merge branch 'develop' of github.com:saltstack/salt into add-boto-sns-module

  * 057d4cd Add documentation.

  * 2ef1b40 Document remaining module functions.

  * 64cf74e Fix style.

  * 6ffc9f8 Fix style.

  * e5ab359 Fix style issues.

  * 5c631d5 Remove reference to SQS.

  * 6f9fbe2 Add boto_sns module and state.

- **PR** `#19808`_: (*jfindlay*) Mount unit tests
  @ *2015-01-16T23:57:12Z*

  * d95ec63 Merge pull request `#19808`_ from jfindlay/mount_unit_tests
  * bcdab12 fix mount module unit tests

  * 27a28e0 bug fixing

  * 42d6a26 implimented unit test cases for mount module

- **PR** `#19806`_: (*cvrebert*) Fix typos with the help of https://github.com/vlajos/misspell_fixer
  @ *2015-01-16T23:36:58Z*

  * 1d2279a Merge pull request `#19806`_ from hulu/typos
  * 19e262b Fix typos with the help of https://github.com/vlajos/misspell_fixer

- **PR** `#19810`_: (*ezheidtmann*) Remove XMPP from docs for salt.states.smtp
  @ *2015-01-16T23:35:11Z*

  * 2c649be Merge pull request `#19810`_ from ezheidtmann/patch-1
  * c9f1e22 Remove XMPP from docs for salt.states.smtp

- **PR** `#19803`_: (*twellspring*) cloud timeout doc updates
  @ *2015-01-16T21:08:04Z*

  * 8b5b50a Merge pull request `#19803`_ from twellspring/cloud_timeouts_fix
  * 99114ee cloud timeout doc updates

- **PR** `#19780`_: (*rupeshta*) test event tests
  @ *2015-01-16T07:23:44Z*

  * 0b3c3f8 Merge pull request `#19780`_ from rupeshta/event_unit_tests
  * 74015f9 test event tests

- **PR** `#19779`_: (*rupeshta*) test gnomedesktop tests
  @ *2015-01-16T07:05:04Z*

  * e472b25 Merge pull request `#19779`_ from rupeshta/gnomedesktop_unit_tests
  * 64b2903 test gnomedesktop tests

- **PR** `#19759`_: (*garethgreenaway*) Additions to scheduler.
  @ *2015-01-15T22:41:30Z*

  * 41d0c1a Merge pull request `#19759`_ from garethgreenaway/schedule_until_feature
  * eb8b6c7 Typo in documentation

  * 16c6959 Adding the job name the log message so we know what job was skipped.

  * afbb073 Fixing the versionadded

  * f6f3e14 Adding the ability to the salt schedule to specify an "until" option for jobs.

- **PR** `#19765`_: (*terminalmage*) Fix spurious log message
  @ *2015-01-15T21:08:48Z*

  * afb7faa Merge pull request `#19765`_ from terminalmage/fix-render-logging
  * 7177fd3 Fix spurious log message

- **PR** `#19762`_: (*cachedout*) Fix broken test
  @ *2015-01-15T17:49:14Z*

  * e93be2b Merge pull request `#19762`_ from cachedout/fix_event_test
  * bb3c171 Style fixes

  * 6d14d4e Fix broken test

- **PR** `#19750`_: (*techhat*) Move --set-xmark after iptables jump
  @ *2015-01-15T17:13:27Z*

  - **ISSUE** `#19749`_: (*saxonww*) iptables --set-xmark placed too early
    | refs: `#19750`_
  * 2fd489d Merge pull request `#19750`_ from techhat/xmark
  * f42d697 Move --set-xmark after iptables jump

- **PR** `#19760`_: (*cachedout*) Fix broken test
  @ *2015-01-15T17:07:03Z*

  * bbecb0f Merge pull request `#19760`_ from cachedout/fix_genesis_test
  * 0399fc3 Fix broken test

- **PR** `#19684`_: (*jayeshka*) adding chef unit test case
  @ *2015-01-15T14:57:20Z*

  * f526f61 Merge pull request `#19684`_ from jayeshka/chef-unittest
  * 87baaa9 adding chef unit test case

- **PR** `#19735`_: (*zimathias*) Add get_account_id function boto_iam
  @ *2015-01-14T23:20:36Z*

  * 3a89e67 Merge pull request `#19735`_ from lyft/add-aws-account-id-function
  * 97d0f93 Fix coding style.

  * 30625a0 Skip boto_iam integration tests if boto is not available

  * a39df43 Fix coding style violations.

  * 61eeac5 Add comment.

  * 3ff36a9 Add get_account_id function boto_iam

- **PR** `#19744`_: (*cachedout*) Remove a documentation surprise
  @ *2015-01-14T23:18:15Z*

  * c070a57 Merge pull request `#19744`_ from cachedout/doc_fix
  * 0ac3e62 Remove a documentation surprise

- **PR** `#19733`_: (*cachedout*) Fix malformed exception handling
  @ *2015-01-14T19:41:23Z*

  * 0b6a1ff Merge pull request `#19733`_ from cachedout/pydsl_fixing
  * 6a2330a Fix malformed exception handling

- **PR** `#19725`_: (*rupeshta*) test firewalld tests
  @ *2015-01-14T19:18:59Z*

  * 7041530 Merge pull request `#19725`_ from rupeshta/firewalld_unit_tests
  * 8dc9287 test firewalld tests

- **PR** `#19723`_: (*jayeshka*) Added unit test for data
  @ *2015-01-14T19:18:31Z*

  * bc639a9 Merge pull request `#19723`_ from jayeshka/data_unit_tests
  * a17dfc9 Added unit test for data

- **PR** `#19717`_: (*sjansen*) Enable salt-cloud bootstrap with ssh gateway
  @ *2015-01-14T19:15:16Z*

  * 4e79364 Merge pull request `#19717`_ from sjansen/patch-4
  * b5d7127 Enable salt-cloud bootstrap with ssh gateway

- **PR** `#19713`_: (*cachedout*) Some docs on runners
  @ *2015-01-14T19:11:45Z*

  * 4aae1ec Merge pull request `#19713`_ from cachedout/runner_doc
  * 8284f0d Some docs on runners

- **PR** `#19724`_: (*rupeshta*) test genesis tests
  @ *2015-01-14T15:17:58Z*

  * 559c52b Merge pull request `#19724`_ from rupeshta/genesis_unit_tests
  * 2ab5d0b test genesis tests

- **PR** `#19662`_: (*basepi*) Merge forward from 2015.2 to develop
  @ *2015-01-13T22:23:09Z*

  * 63e207e Merge pull request `#19662`_ from basepi/merge-forward-develop
  * 8363db9 Merge remote-tracking branch 'upstream/2015.2' into merge-forward-develop

  * f570314 Merge remote-tracking branch 'upstream/2015.2' into merge-forward-develop

- **PR** `#19704`_: (*cachedout*) Fix key error preventing master start
  @ *2015-01-13T19:49:44Z*

  * 8e26499 Merge pull request `#19704`_ from cachedout/aes_fix
  * 3d1f02d Fix key error preventing master start

- **PR** `#19693`_: (*cachedout*) Fix up transport __init__
  @ *2015-01-13T19:10:15Z*

  * e354b69 Merge pull request `#19693`_ from cachedout/transport_fix
  * 40bc220 Fix up transport __init__

- **PR** `#19696`_: (*cachedout*) More linting
  @ *2015-01-13T18:16:23Z*

  * 5c8c7da Merge pull request `#19696`_ from cachedout/lint
  * 845271d More linting

- **PR** `#19695`_: (*cachedout*) Ignore some auto-generated files in test dir
  @ *2015-01-13T18:03:25Z*

  * e04952b Merge pull request `#19695`_ from cachedout/more_gitignore
  * 8e504f0 Ignore some auto-generated files in test dir

- **PR** `#19688`_: (*rominf*) [fish shell completion] adopt for non-interactive usage (e.g. from scripts)
  @ *2015-01-13T15:30:51Z*

  * 231bd75 Merge pull request `#19688`_ from rominf/fish-completion
  * 0b4f052 [fish shell completion] updated comments

  * 2d7e1d4 [fish shell completion] adopt for non-interactive usage (e.g. from scripts)

- **PR** `#19687`_: (*techhat*) Allow joyent api host suffix to be configurable
  | refs: `#19903`_
  @ *2015-01-13T15:30:30Z*

  - **ISSUE** `#19671`_: (*pannon*) Feature: Joyent private cloud SDC (Smart Data Center) integration
    | refs: `#19687`_
  * 9d377a9 Merge pull request `#19687`_ from techhat/joyent
  * 11d802d Allow joyent api host suffix to be configurable

- **PR** `#19680`_: (*jayeshka*) adding cpan test case
  @ *2015-01-13T15:26:31Z*

  * a16824e Merge pull request `#19680`_ from jayeshka/cpan-unit-tests
  * d2a5eda resolved pylint error

  * 2aa6479 adding cpan test case

- **PR** `#19677`_: (*aneeshusa*) Remove obsolete unreferenced tuple of static outputters.
  @ *2015-01-13T15:25:37Z*

  - **PR** `#6608`_: (*s0undt3ch*) `--out-file` and doc fixes/updates
    | refs: `#19677`_
  * 49f98ff Merge pull request `#19677`_ from aneeshusa/output-subsystem
  * b828add Add blank line to conform with PEP8 (E302).

  * 9aa5f2d Remove obsolete unreferenced tuple of static outputters.

- **PR** `#19675`_: (*nmadhok*) Adding missing import so that new caller instance can be instantiated without AttributeError
  @ *2015-01-13T15:21:22Z*

  - **ISSUE** `#19674`_: (*nmadhok*) Cannot instantiate a new Caller() instance using a file system path to the minion config file
    | refs: `#19675`_
  * 941eff3 Merge pull request `#19675`_ from nmadhok/patch-1
  * 94e1d5f Adding missing import causing new caller instance from being instantiated. Fixes `#19674`_

- **PR** `#19667`_: (*cachedout*) Fix tests
  @ *2015-01-13T15:14:34Z*

  * f1391fb Merge pull request `#19667`_ from cachedout/ssh_tests
  * fc9a647 Remove assert:

  * cba0d6d Fix tests

- **PR** `#19615`_: (*h4ck3rm1k3*) template debugging
  @ *2015-01-13T15:07:07Z*

  * 9942ca2 Merge pull request `#19615`_ from h4ck3rm1k3/template_debugging
  * 182665e removing prints

  * c65af6a template debugging

- **PR** `#19665`_: (*cachedout*) Fix tornado tests
  @ *2015-01-13T05:15:03Z*

  * c368b88 Merge pull request `#19665`_ from cachedout/tornado_test_timeout
  * 74501f5 Fix tornado tests

* cb5103b get rid of assert


- **PR** `#19641`_: (*aurynn*) Adds fire_master to the Salt Event library, for use in 3rd-party code.
  @ *2015-01-12T21:42:16Z*

  * 6f552fd Merge pull request `#19641`_ from aurynn/fire_master
  * f4b3339 Merging to finish rebase of fire_master to tip

    * 1612bc7 Adds fire_master to the Salt Event library, for use in 3rd-party code.

  * b7ae486 Adds fire_master to the Salt Event library, for use in 3rd-party code.

- **PR** `#19655`_: (*s0undt3ch*) Fix requirements files paths
  @ *2015-01-12T21:00:31Z*

  * 29a2304 Merge pull request `#19655`_ from s0undt3ch/develop
  * 74e513f Fix requirements files paths

- **PR** `#19550`_: (*cachedout*) Properly compare ssh keys.
  @ *2015-01-12T20:52:32Z*

  - **ISSUE** `#8240`_: (*LeeBrown*) non optimal behaviour salt.modules.ssh.set_known_host
    | refs: `#19550`_
  * dd070f3 Merge pull request `#19550`_ from cachedout/issue_8240
  * c381f8c Properly compare ssh keys.

- **PR** `#19614`_: (*h4ck3rm1k3*) Localtransport
  @ *2015-01-12T20:35:06Z*

  * 5f8e21b Merge pull request `#19614`_ from h4ck3rm1k3/localtransport
  * f9b152f local transport

- **PR** `#19633`_: (*ether42*) lxc module: kwarg shadowing in run_cmd provokes unexpected return value
  @ *2015-01-12T19:04:54Z*

  * 8d45f14 Merge pull request `#19633`_ from ether42/develop
  * 95b508a lxc module: kwarg shadowing provokes unexpected return value

- **PR** `#19058`_: (*cournape*) Add darwin pkg support
  @ *2015-01-12T18:43:44Z*

  * b7899b2 Merge pull request `#19058`_ from cournape/add_darwin_pkg_support
  * 509bc7f STY: add encoding in test module as well.

  * e494da7 ENH: add an CLI example for every darwin_pkgutil command.

  * 236ec08 FEAT: first short at installing .pkg/.mpkg on OS X.

- **PR** `#19640`_: (*TronPaul*) Add s3 to protocols for remote source_hash
  @ *2015-01-12T18:38:01Z*

  - **ISSUE** `#15209`_: (*hubez*) file.manage: source_hash not working with s3:// (2014.7.0rc1)
    | refs: `#19640`_
  * 2c065ac Merge pull request `#19640`_ from TronPaul/s3_source_hash
  * af4aee8 Add s3 to protocols for remote source_hash

* 41eb958 Merge branch 'aurynn-develop' into develop


  * bc74de8 Merge branch 'develop' of https://github.com/aurynn/salt into aurynn-develop

  * e1dbd4c Removes spurious text

  * 7e4f563 Updates Salt SSH roster documentation, adding thin_dir and a note on setting persistent grains

- **PR** `#19637`_: (*s0undt3ch*) Merge branch '2015.2' into develop
  @ *2015-01-12T18:33:14Z*

  * c79871e Merge pull request `#19637`_ from s0undt3ch/develop
  * eeb6dad Merge branch '2015.2' into develop

  * 229fa20 Merge branch 'develop' of github.com:saltstack/salt into develop

  * c3bc043 Merge branch '2015.2' into develop

- **PR** `#19634`_: (*DmitryKuzmenko*) Slightly refactored Salt Raet Presenter code
  @ *2015-01-12T18:32:08Z*

  * f7f564e Merge pull request `#19634`_ from DSRCompany/raet_presence_requests
  * e5b8fa2 Slightly refactored Salt Raet Presenter code

- **PR** `#19253`_: (*jacksontj*) Refactor of evented runners (`#17283`_)
  @ *2015-01-12T17:51:16Z*

  - **ISSUE** `#18256`_: (*jacksontj*) Reactor cmd/local infinite recursion
  - **ISSUE** `#15759`_: (*pass-by-value*) Cache runner and wheel jobs
    | refs: `#17283`_
  - **ISSUE** `#9444`_: (*malinoff*) Feature: --out option in salt-run
    | refs: `#19253`_
  - **PR** `#17283`_: (*cachedout*) Evented runners
    | refs: `#19253`_
  * 7406b77 Merge pull request `#19253`_ from jacksontj/runner_event
  * d29f175 Add missing import

  * c5b86e2 Fix typo

  * 4ad53c7 Workaround for race condition in SaltEvent() creation and the zmq socket actually connecting

  * a1dc11f Cleanup, we don't always need an "event" object, so lets not always create one

  * add997f For some reason having the event init in the shared subclass causes problems.

  * 9c7d157 Revert function calls

  * 7abf26e Don't spin waiting for runner return, just use get_event (it has a poller)

  * eff95e8 Add a blacklist of suffixes for the client mixin to print out

  * d71f407 Pylint and style cleanup

  * 3885773 Re-add call_func backwards compat func

  * 223f3a0 Add a return to the async method (jid)

  * e320c94 Fix runner returns

  * e35c7ac cleanup "Caste jid as str (its an int all over), and change runner tag to correct prefix"

  * 80f764c Remove PID since the process is daemonized afterwards, meaning that pid isn't correct

  * 38be13b Clean up comments

  * 45ae85a Backwards compatibility with args as well.

  * 496eb26 Add backwards compatibility to "low" function-- since the object isn't well documented we have apparently used it in all possible ways ;)

  * 06fd7b3 Style cleanup

  * 169e3df Fix typo

  * d352057 Pylint fix

  * 1e11072 Remove __progress__ from lint checks, and add in jid_event

  * a2fcfc2 Change to new event fire_event markup

  * c2c1457 Change how we print out events from runner/wheel calls

  * 6cd18c3 Add __init__ arg to Runner(), and call self.async (since its a subclass)

  * 33d6413 Cleanup __init__, since outputters are only needed in run()

  * 1060793 Fix builtin access

  * 2e03224 Pylint cleanup

  * 94b720a Remove local testing file

  * 73537dd Remove some local files that somehow got added

  * 50d9570 Pylint

  * 13f4222 Switch to module, instead of global (for compatibility)

  * 6df0cd1 Cleanup docs some

  * 229cb0b Add missing import

  * ff32601 Consolidate some of the __init__  logic

  * f6f8a24 Consolidate to mixin funcs

  * 2ba4b32 Consolidate to mixins funcs

  * ab6de62 Consolidate more code between runner and wheel modules

  * f1bb694 Make the callers of this function parse their args correctly

  * a9a9dd5 Pass in args/kwargs

  * b809c09 Clean up arg parsing in runner client

  * b58bf7d Add sleep to test runner

  * 2251f56 Clean up arg parsing (a little), since the low that is passed does not have a "kwargs" section

  * 5649b1b replace l_fun with self.function[fun], since the local no longer exists

  * cfa8299 - Change event name for print - include old print in new evented print - support having the args parsed and *not* parsed in low()

  * 3c28d13 add doc string

  * 1823f49 Add stdout_print test function (to test overriding print func). Also include __jid_event__.fire_event (instead of __progress__)

  * abb3222 Inject a "print" function into runners, and clean up (a little) the event printout handling.

  * 520d541 Cleanup suffix determination

  * 65ed000 Move get_async_returns to mixin

  * eaff834 Style cleanup

  * e2c3c7e include pid in async log line

  * 33d1a51 Pylint cleanup

  * 30c3e57 Fix for `#18256`_

  * 1843eb0 Remove RunnerEvent

  * b8dc9a3 Add a convenience wrapper for __progress__

  * 6e8d25f Switch to using utils.jid to generate jid

  * 11c417b Inject globals without the sys module

  * b010bca Swallow exceptions on __del__ of event

  * 4da4ef4 Refactor-- now all the event firing is done within low()

  * bd7312d Add a "namespacedevent" object, this give a convinent wrapper for firing events within a specific namespace

  * 3397922 Move "low" to separate line-- everything else is

  * f455281 Misc cleanup

  * 89cbd19 Consolidate the cmd() func to just use low(), since its all redundant (and most of the old arg parsing was redundant)

  * 4ed4aca Make Async really async-- and always create another process to execute the runner

  * c17462d Caste jid as str (its an int all over), and change runner tag to correct prefix

  * 5e59781 Remove local multiprocessing, and use the aync client mixin

- **PR** `#19599`_: (*fayetted*) Fix ssh_auth test mode, compare lines not just key
  @ *2015-01-12T16:13:24Z*

  - **ISSUE** `#19598`_: (*fayetted*) ssh_auth.present test=true incorectly reports changes will be made
    | refs: `#19599`_
  * 2fe1757 Merge pull request `#19599`_ from fayetted/Issue_19598
  * 1fee1ad Fix ssh_auth test mode, compare lines not just key

- **PR** `#19429`_: (*ryan-lane*) Add new ignore_missing option to pillar top
  @ *2015-01-12T16:06:15Z*

  * 86a3bf3 Merge pull request `#19429`_ from lyft/ignore-missing-for-pillars
  * c6922ec Add new ignore_missing option to pillar top

- **PR** `#19621`_: (*howardroark*) Adding Hjson renderer.
  @ *2015-01-11T17:12:24Z*

  - **ISSUE** `#19374`_: (*howardroark*) Consider HJSON as a new renderer option.
    | refs: `#19621`_
  * b859999 Merge pull request `#19621`_ from stackstrap/develop
  * be78528 Adding Hjson renderer.

- **PR** `#19605`_: (*jacksontj*) Fixes for develop
  @ *2015-01-10T15:54:59Z*

  - **PR** `#19545`_: (*jacksontj*) Cleanup and performance tweaks (redo `#19318`_ )
    | refs: `#19605`_
  - **PR** `#19318`_: (*jacksontj*) Cleanup and performance tweaks
    | refs: `#19544`_ `#19545`_
  * 0e93548 Merge pull request `#19605`_ from jacksontj/develop
  * 925afac Temporarily change this test to work around race condition in the runnerclient

  * df3655d Don't spin waiting for runner return, just use get_event (it has a poller)

  * 6d29d66 Join the async process, otherwise we leave zombies (which looks like a memory leak).

- **PR** `#19601`_: (*rallytime*) Fix pylint on develop branch
  @ *2015-01-10T04:05:59Z*

  * f2b63b8 Merge pull request `#19601`_ from rallytime/pylint
  * d5d0e75 Fix pylint on develop branch

- **PR** `#19600`_: (*cachedout*) Typ fix
  @ *2015-01-10T01:15:18Z*

  * 710c455 Merge pull request `#19600`_ from cachedout/cleanup_jboss
  * dfb8810 Typo

- **PR** `#19561`_: (*favadi*) add pkgrepo.managed clean_file option
  @ *2015-01-10T00:51:35Z*

  * 8ec6d4a Merge pull request `#19561`_ from favadi/clean_file
  * 65ee96b add pkgrepo.managed clean_file option

- **PR** `#19585`_: (*cachedout*) Async flag for test run
  @ *2015-01-10T00:50:53Z*

  * 98cc0f8 Merge pull request `#19585`_ from cachedout/async_flag_for_test_run
  * 7aec24e Typo

  * 9d7990f Async flag and test cleanup

- **PR** `#19583`_: (*basepi*) Merge forward from 2015.2 to develop
  @ *2015-01-10T00:49:43Z*

  * cad85fd Merge pull request `#19583`_ from basepi/merge-forward-develop
  * 3559641 Merge remote-tracking branch 'upstream/2015.2' into merge-forward-develop

- **PR** `#19582`_: (*manonthemat*) url fix of dependency in installation guide
  @ *2015-01-10T00:47:46Z*

  * 02251ae Merge pull request `#19582`_ from manonthemat/develop
  * e59f5b3 url fix http://docs.saltstack.com/en/latest/topics/installation/index.html linked to msgpack-python version 0.1.12. The fix links to the latest version (which is version 0.4.4 at the time of this commit), since not a specific version of msgpack-python was written down as a dependency.

- **PR** `#19581`_: (*jacksontj*) Remove clear() method
  @ *2015-01-10T00:44:14Z*

  * 6cce713 Merge pull request `#19581`_ from jacksontj/develop
  * d26f6f3 Disable gc while deserializing msgpack messages

  * 6cb3eb8 Remove clear() method

- **PR** `#19595`_: (*thatch45*) Merge `#19580`_ with fixes
  @ *2015-01-10T00:39:01Z*

  - **PR** `#19580`_: (*traxair*) Fix azure cloud service
    | refs: `#19595`_
  * f8f7867 Merge pull request `#19595`_ from thatch45/Trax-air-fix-azure-cloud-service
  * 20555c9 Merge branch 'develop' into Trax-air-fix-azure-cloud-service

- **PR** `#19594`_: (*thatch45*) Merge `#19566`_
  @ *2015-01-10T00:25:10Z*

  - **ISSUE** `#19569`_: (*traxair*) Azure: using create_virtual_machine_deployment triggers conflicts when deployment already exists
  - **ISSUE** `#19518`_: (*traxair*) Azure: change the SSH port when creating other VMs under the same cloud service
  - **ISSUE** `#19162`_: (*traxair*) Permanent disk on Azure
  - **ISSUE** `#1`_: (*thatch45*) Enable regex on the salt cli
    | refs: `#21356`_ `#21328`_
  - **PR** `#19566`_: (*traxair*) Salt add azure volume support
    | refs: `#19594`_
  * 2aa9b97 Merge pull request `#19594`_ from thatch45/Trax-air-salt-add-azure-volume
  * 4c56245 lint

  * 80197a0 Merge branch 'salt-add-azure-volume' of https://github.com/Trax-air/salt into Trax-air-salt-add-azure-volume

  * d3fc846 `#19162`_ added disks to Azure VM creation. Only new empty disks are supported. Add a line volumes:   - { size: 10 (default 100), lun: [0-15](default: 0), disk_label: <label>(default: <role-name>-disk-<lun>) }

    * 83fab27 lint (and single quotes when I see them :) )

    * 0990057 Merge branch 'fix-azure-cloud-service' of https://github.com/Trax-air/salt into Trax-air-fix-azure-cloud-service

    * 0b06808 `#19518`_ SSH port can be configured from the map file `#19569`_ deployment is now separate from VM and add_role is used when deployment already exists. Decoupling the VM and service however breaks show_instance

  * 6a8fdf0 Merge pull request `#1`_ from saltstack/develop

- **PR** `#19562`_: (*rupeshta*) Implemented unit test cases for debconfmod module
  @ *2015-01-10T00:14:56Z*

  * 91d0b5b Merge pull request `#19562`_ from rupeshta/debconfmod_unit_tests
  * 84afffc Implemented unit test cases for debconfmod module

- **PR** `#19593`_: (*cachedout*) Give event-based mines time to propogate
  @ *2015-01-10T00:14:18Z*

  * 402eb97 Merge pull request `#19593`_ from cachedout/mine_sleep
  * 3eefb8e Give event-based mines time to propogate

- **PR** `#19557`_: (*cachedout*) Cleanup jboss module
  @ *2015-01-10T00:12:54Z*

  - **ISSUE** `#18600`_: (*cvrebert*) modules.jboss7 pylint issues
    | refs: `#19557`_
  * ba3b7c7 Merge pull request `#19557`_ from cachedout/cleanup_jboss
  * 1b78f40 Use __func_alias__

  * b5c0dbe Cleanup jboss module

- **PR** `#19545`_: (*jacksontj*) Cleanup and performance tweaks (redo `#19318`_ )
  | refs: `#19605`_
  @ *2015-01-09T18:57:09Z*

  - **PR** `#19318`_: (*jacksontj*) Cleanup and performance tweaks
    | refs: `#19544`_ `#19545`_
  * 5b7660b Merge pull request `#19545`_ from jacksontj/develop
  * dcabee3 Rework to expose __authenticate()

  * aad2df6 Log AES rotation in the master daemon

  * fb747fa Refactor SAuth() to return singletons for each master/minion pair.

  * 48aa021 Cache channel auth based on master_uri and minion_id

  * f5347be Revert "Revert "Cleanup and performance tweaks""

- **PR** `#19578`_: (*jacksontj*) Change log message from #e6e7ab6c from error to debug
  @ *2015-01-09T18:56:37Z*

  * 1cb74f9 Merge pull request `#19578`_ from jacksontj/child_watch
  * 5222ffe Change log message from #e6e7ab6c from error to debug

- **PR** `#19574`_: (*rallytime*) Cleaner and actual fix for the failing weird pip test for CentOS 5
  @ *2015-01-09T18:39:42Z*

  * 1526d1e Merge pull request `#19574`_ from rallytime/better_test_fix
  * 28cb062 Cleaner and actual fix for the failing weird pip test for CentOS 5

- **PR** `#19576`_: (*cachedout*) Adjust for a possible subtle bug in zeromq
  @ *2015-01-09T18:12:28Z*

  * 0794e27 Merge pull request `#19576`_ from cachedout/sreq_test_adjust
  * cc6c282 Adjust for a possible subtle bug in zeromq

- **PR** `#19558`_: (*cachedout*) Don't let sys exits bubble into the reactor.
  @ *2015-01-09T00:42:49Z*

  * 6b24117 Merge pull request `#19558`_ from cachedout/reactor_exit
  * a0cf68a Don't let sys exits bubble into the reactor.

- **PR** `#19555`_: (*cachedout*) Check cwd before running saltcmd
  @ *2015-01-09T00:04:28Z*

  - **ISSUE** `#18073`_: (*cachedout*) Starting salt CLI from non-existant directory stacktraces
    | refs: `#19555`_
  * 783de95 Merge pull request `#19555`_ from cachedout/check_cwd
  * 9a717bc Check cwd before running saltcmd

- **PR** `#19511`_: (*gracinet*) Provide modules.pillar.obfuscate and modules.pillar.ls
  @ *2015-01-08T23:56:53Z*

  - **ISSUE** `#19329`_: (*gracinet*) More pillar introspection commands
    | refs: `#19511`_
  * 4ff285a Merge pull request `#19511`_ from gracinet/19329-pillar-introspection
  * e94fe6d Mark function as private

  * 905a038 Proper versionadded tags

  * eb70dcf Provide modules.pillar.obfuscate and modules.pillar.ls

- **PR** `#19553`_: (*cachedout*) Minor doc issue
  @ *2015-01-08T23:52:30Z*

  - **ISSUE** `#16227`_: (*rominf*) user.present: rename gid to group
    | refs: `#19553`_
  * 864b09a Merge pull request `#19553`_ from cachedout/issue_16227
  * 5f6f52f Minor doc issue

- **PR** `#19544`_: (*cachedout*) Revert "Cleanup and performance tweaks"
  @ *2015-01-08T21:57:57Z*

  - **PR** `#19318`_: (*jacksontj*) Cleanup and performance tweaks
    | refs: `#19544`_ `#19545`_
  * 372cd76 Merge pull request `#19544`_ from saltstack/revert-19318-develop
  * 86e231b Revert "Cleanup and performance tweaks"

- **PR** `#19318`_: (*jacksontj*) Cleanup and performance tweaks
  | refs: `#19544`_ `#19545`_
  @ *2015-01-08T19:27:29Z*

  * ed8737f Merge pull request `#19318`_ from jacksontj/develop
  * 712311c Fix syndics, the tag isn't a jid its something like salt/job/JID/ret/MID

  * d1ba301 On the master _handle_aes needs to return something not properly encrypted to let the minion know it was incorrect.

  * 1e1dc77 Clear auth correctly on auth failure

  * 62e693b Consolidate minion authenticate() to just use SAuth class, since the code is almost identical

  * 1f1c097 Cache the auth object between channels.

  * b0c0f37 Consolidate duplicate lines-- no reason to assign then pop, since pop returns the object as well

  * 1c295b2 Cleanup of old comments, and style

- **PR** `#19536`_: (*rallytime*) Don't run weird pip install test on CentOS 5
  @ *2015-01-08T19:21:08Z*

  * ca9a871 Merge pull request `#19536`_ from rallytime/pip_test_fix
  * 71ef3f7 Keep package name the same

  * a0f801f Skip this test when we are running on centOS 5

  * 5490530 Change the install package to fix pip tests

* a60fa6b Merge branch '2015.2' into develop


- **PR** `#19531`_: (*cachedout*) Let's get more debug info about how often refreshes are happening
  @ *2015-01-08T18:09:16Z*

  * 432776e Merge pull request `#19531`_ from cachedout/log_refresh
  * 3ce17f2 Let's get more debug info about how often refreshes are happening

- **PR** `#19529`_: (*cachedout*) Lint
  @ *2015-01-08T17:57:23Z*

  * e884956 Merge pull request `#19529`_ from cachedout/lint_gpg
  * dd64751 Lint

- **PR** `#19526`_: (*cachedout*) Another missed quote
  @ *2015-01-08T17:18:40Z*

  * 1b4f06a Merge pull request `#19526`_ from cachedout/postgres_fix_quote
  * 68b6815 Another missed quote

- **PR** `#19523`_: (*cachedout*) Try giving some rest tornado requests a little more time
  @ *2015-01-08T17:05:04Z*

  * 3ffb761 Merge pull request `#19523`_ from cachedout/tornado_timeouts
  * d6ce858 Try giving some rest tornado requests a little more time

- **PR** `#19510`_: (*JensRantil*) doc(dev-bootstrap): Sphinx 1.3b2
  @ *2015-01-08T16:57:42Z*

  * 0529136 Merge pull request `#19510`_ from JensRantil/sphinx-1.3b2
  * 9e92864 doc(dev-bootstrap): Sphinx 1.3b2

- **PR** `#19495`_: (*twellspring*) Add documentation for renderes in pillar files
  @ *2015-01-08T16:57:19Z*

  * 9d8e6ca Merge pull request `#19495`_ from twellspring/patch-2
  * 22ebbe5 Add documentation for renderes in pillar files

- **PR** `#19517`_: (*traxair*) Azure: fixes VM creation under another service name
  @ *2015-01-08T16:36:17Z*

  - **ISSUE** `#15959`_: (*egilh*) Azure: salt-cloud should be able to set specific cloud service for VM
    | refs: `#19155`_
  - **PR** `#19155`_: (*techhat*) Allow service_name to be specified for azure
  * 74da8a3 Merge pull request `#19517`_ from Trax-air/fix-azure-cloud-service
  * ea2b826 Azure: catch a benign WindowsAzureConflictError when trying to create a service that already exists. In delete if kwargs is None, set it to an empty dict. `#19155`_

- **PR** `#19507`_: (*cachedout*) Fix postgres test
  @ *2015-01-08T05:39:43Z*

  * 335516e Merge pull request `#19507`_ from cachedout/postgres_fix
  * 96fdbc4 Fix postgres test

- **PR** `#19506`_: (*cachedout*) Lint
  @ *2015-01-08T05:36:11Z*

  * ab7b9d9 Merge pull request `#19506`_ from cachedout/lint
  * d1e8666 Lint

- **PR** `#19500`_: (*rallytime*) Merge 2015.2 into develop
  @ *2015-01-08T04:12:01Z*

  * 409d845 Merge pull request `#19500`_ from rallytime/merge_forward_develop
  * 8bf6edc Merge branch '2015.2' into merge_forward_develop

  * 74a1861 Merge branch '2015.2' into merge_forward_develop

- **PR** `#19489`_: (*cvrebert*) minion.py:Minion.__init__(): fix broken ref to ProxyMinion
  @ *2015-01-07T23:06:45Z*

  * b429938 Merge pull request `#19489`_ from cvrebert/patch-1
  * cffe5f7 minion.py:Minion.__init__(): fix broken ref to ProxyMinion

- **PR** `#19486`_: (*s0undt3ch*) Merge `#19161`_
  @ *2015-01-07T23:06:24Z*

  - **PR** `#19161`_: (*h4ck3rm1k3*) rooted config
  * 4713574 Merge pull request `#19486`_ from s0undt3ch/merge/19161
  * 575ff9a Let's simplify since the values are not to be configurable through setup.

  * 23bed0e Some imports "prettyfication".

  * 1ce6910 Some fixes to `#19161`_

  * a952d46 Merge branch 'develop' of https://github.com/h4ck3rm1k3/salt into merge/19161

    * e6e7ab6 rooted config

- **PR** `#19490`_: (*cvrebert*) modules.splunk_search: avoid shadowing built-in list type
  @ *2015-01-07T22:48:27Z*

  * 4fb929d Merge pull request `#19490`_ from hulu/splunk_search-list-shadow
  * c72c55d modules.splunk_search: avoid shadowing built-in list type

- **PR** `#19482`_: (*JensRantil*) Development bootstrap documentation improvements
  @ *2015-01-07T21:55:43Z*

  * 35af81b Merge pull request `#19482`_ from JensRantil/warn-socketpath-early
  * 30978b1 doc(bootstrap-dev): mention short virtualenv path early

  * 4666b29 doc(bootstrap-dev): make long socket path warning a note

- **PR** `#19481`_: (*JensRantil*) one less command to get started when bootstrapping
  @ *2015-01-07T20:51:33Z*

  * e6ee51a Merge pull request `#19481`_ from JensRantil/less-bootstrapping
  * fee650b one less command to get started when bootstrapping

- **PR** `#19471`_: (*cachedout*) Fix lint error
  @ *2015-01-07T19:07:03Z*

  * 242d4d4 Merge pull request `#19471`_ from cachedout/pylint_status
  * 8d7961a Fix lint error

- **PR** `#19447`_: (*blueicefield*) Fix an error in the comments which generates a wrong display in the documentation
  @ *2015-01-07T17:21:26Z*

  * 9fadb0b Merge pull request `#19447`_ from blueicefield/feature_mongodb-roles
  * a982869 Correction of an error in the comments which generates a wrong display in the documentation

- **PR** `#19445`_: (*rupeshta*) Implemented unit test cases devmap module
  @ *2015-01-07T17:21:12Z*

  * c9b003a Merge pull request `#19445`_ from rupeshta/devmap_unit_tests
  * f231b5d Implemented unit test cases devmap module

- **PR** `#19443`_: (*rupeshta*) Implemented unit test cases for bridge module
  @ *2015-01-07T17:20:17Z*

  * f5572a3 Merge pull request `#19443`_ from rupeshta/bridge_unit_tests
  * 94f6372 Implemented unit test cases for bridge module

- **PR** `#19442`_: (*rupeshta*) Implemented unit test cases for module daemontools
  @ *2015-01-07T17:20:02Z*

  * 48097d7 Merge pull request `#19442`_ from rupeshta/daemontools_unit_tests
  * a760eae Implemented unit test cases for module daemontools

- **PR** `#19441`_: (*rupeshta*) Implemeted unit test cases for module composer
  @ *2015-01-07T17:19:16Z*

  * 3252ca9 Merge pull request `#19441`_ from rupeshta/composer_unit_tests
  * 24e1e40 Implemeted unit test cases for module composer

- **PR** `#19412`_: (*derekslager*) Making newer file module functions available on Windows, issue `#19410`_.
  @ *2015-01-07T17:11:11Z*

  - **ISSUE** `#19410`_: (*derekslager*) New file module functions in 2014.7.0 unavailable on Windows
  * 50dc1da Merge pull request `#19412`_ from derekslager/develop
  * cb8a485 Making newer file module functions available on Windows, issue `#19410`_.

- **PR** `#19380`_: (*felskrone*) improve master.status to work with host fqdns/hostnames as well as ips
  @ *2015-01-07T17:08:35Z*

  - **ISSUE** `#19080`_: (*ferreol*) multi master failover mode looping indefinitely
    | refs: `#19380`_
  * f61d91a Merge pull request `#19380`_ from felskrone/fix_master_alive_status
  * d74e7eb improve master.status to work with host fqdns/hostnames as well as ips

- **PR** `#19377`_: (*jayeshka*) adding augeas_cfg unit test case
  @ *2015-01-07T17:08:03Z*

  * 58fd3cc Merge pull request `#19377`_ from jayeshka/augeas_cfg_unit_test
  * 2d3e40d added check for augeas python package

  * 508ec1a removed pylint error in augeas_cfg unit test case

  * 2edf731 adding augeas_cfg unit test case

- **PR** `#19422`_: (*Seveland12*) Fixed spelling of "below" in 9 different files.
  @ *2015-01-07T16:32:44Z*

  * f329ec9 Merge pull request `#19422`_ from Seveland12/develop
  * 342608d Fixed spelling of "below" in 9 different files.

- **PR** `#19449`_: (*rallytime*) Merge forward 2015.2 into develop
  @ *2015-01-07T16:27:51Z*

  * 658bebe Merge pull request `#19449`_ from rallytime/merge_forward_develop
  * 98a290a Fix file permissions pylint error

  * 5f6af88 Merge branch '2015.2' into 'develop'

- **PR** `#19446`_: (*MrMarvin*) fixes very minor typo of "True" as "Trur"
  @ *2015-01-07T15:17:54Z*

  * dda3b0d Merge pull request `#19446`_ from MrMarvin/fix/very_minor_typo
  * 755cfa8 fixes very minor typo of "True" as "Trur"

- **PR** `#19432`_: (*cachedout*) Allow for variations in distros in group test
  @ *2015-01-07T05:05:53Z*

  * 1700450 Merge pull request `#19432`_ from cachedout/fix_group_test
  * 309f91a Allow for variations in distros in group test

- **PR** `#19431`_: (*cachedout*) Fix import in zypper
  @ *2015-01-07T04:47:46Z*

  * 8b8555b Merge pull request `#19431`_ from cachedout/urlparse_fix
  * e53103e Fix import in zypper

- **PR** `#19427`_: (*cachedout*) Skip kmod test if /etc/modules isn't present
  @ *2015-01-07T03:37:39Z*

  * f06b5ae Merge pull request `#19427`_ from cachedout/kmod_skip
  * 22ccbf0 Skip kmod test if /etc/modules isn't present

- **PR** `#19418`_: (*rallytime*) Fix blockdev module unit tests
  @ *2015-01-07T01:19:43Z*

  - **PR** `#19368`_: (*rallytime*) Changes and additions of python shell kwargs
    | refs: `#19414`_ `#19418`_
  * 5abf095 Merge pull request `#19418`_ from rallytime/fix_more_develop_tests
  * cb53750 Change file perms back to executable

  * c504027 Change file perms on runtests.py

  * 69d484d pylint fix

  * f40affd Fix blockdev module unit tests

- **PR** `#19424`_: (*cachedout*) Revert "Fix failing blockdev test"
  @ *2015-01-07T01:03:03Z*

  - **PR** `#19423`_: (*cachedout*) Fix failing blockdev test
    | refs: `#19424`_
  * 12f5d2f Merge pull request `#19424`_ from saltstack/revert-19423-fix_blockdev_test
  * 98e07c0 Revert "Fix failing blockdev test"

- **PR** `#19423`_: (*cachedout*) Fix failing blockdev test
  | refs: `#19424`_
  @ *2015-01-07T01:01:28Z*

  * 89695d4 Merge pull request `#19423`_ from cachedout/fix_blockdev_test
  * 72c5e01 Fix failing blockdev test

- **PR** `#19421`_: (*rallytime*) Fix my pylint errors
  @ *2015-01-07T00:29:24Z*

  * e786060 Merge pull request `#19421`_ from rallytime/pylint
  * 194c069 Fix my pylint errors

- **PR** `#19414`_: (*rallytime*) Fix djangomod.py integration test failures
  @ *2015-01-06T22:32:34Z*

  - **PR** `#19368`_: (*rallytime*) Changes and additions of python shell kwargs
    | refs: `#19414`_ `#19418`_
  * 869f64b Merge pull request `#19414`_ from rallytime/dev_test_fix
  * ed3a346 Fix djangomod.py integration test failures

- **PR** `#19409`_: (*basepi*) Merge forward from 2015.2 to develop
  @ *2015-01-06T21:54:00Z*

  * b37464d Merge pull request `#19409`_ from basepi/merge-forward-develop
  * c5cdc57 Merge branch '2015.2' into merge-forward-develop

- **PR** `#19368`_: (*rallytime*) Changes and additions of python shell kwargs
  | refs: `#19414`_ `#19418`_
  @ *2015-01-06T21:17:27Z*

  * e595b3b Merge pull request `#19368`_ from rallytime/python_shell
  * d8667fb freebsd_sysctl module python shell kwarg additons

  * 73a2525 freebsdservice module python shell kwarg additions

  * a0501ec extfs module python shell kwarg additions

  * d84e041 dpkg module python shell kwarg additions

  * 842d345 django module python_shell=False additions

  * c08939a disk module python_shell=False addition

  * 4034e66 debconfmod module python_shell=False addition

  * 603ba43 daemontools module python_shell=False additions

  * 515252b composer module python_shell=False additon

  * 199f4e0 brew module python_shell=False addition

  * ba82cce blockdev module python_shell=False addition

- **PR** `#19408`_: (*thedrow*) Rbenv documentation fix
  @ *2015-01-06T21:08:56Z*

  * d88cb37 Merge pull request `#19408`_ from thedrow/patch-2
  * 27a84c5 Removed a duplicate dependecy and added libffi which is needed according to https://github.com/sstephenson/ruby-build/wiki#build-failure-of-fiddle-with-ruby-220

- **PR** `#19407`_: (*cachedout*) Tweak arch db upgrade
  @ *2015-01-06T20:47:21Z*

  * 520b709 Merge pull request `#19407`_ from cachedout/more_arch
  * acca71a Tweak arch db upgrade

- **PR** `#19406`_: (*cachedout*) Default transport in ckminions
  @ *2015-01-06T20:40:27Z*

  * d2d1085 Merge pull request `#19406`_ from cachedout/batch_fix
  * aa12ac9 Default transport in ckminions

- **PR** `#19403`_: (*cachedout*) Backport arch and centos fixes into deploy bootstrap
  @ *2015-01-06T20:22:29Z*

  * b5e948e Merge pull request `#19403`_ from cachedout/backport_bootstrap
  * b49e7b1 Backport arch and centos fixes into deploy bootstrap

- **PR** `#19323`_: (*jacksontj*) Make AES key never hit disk on the master
  @ *2015-01-06T18:53:56Z*

  * 48a5597 Merge pull request `#19323`_ from jacksontj/aes_cleanup
  * 687012b Pop "aes" from the opts before passing to ext_pillar modules

  * d226ebb Pylint cleanup

  * e37353e Remove sock_dir from crypt.dropfile()

  * deb60fd Make AES key never hit disk on the master

- **PR** `#19396`_: (*cachedout*) These were unused and causing weird recursion errors in unit tests
  @ *2015-01-06T18:04:25Z*

  * 170ce2a Merge pull request `#19396`_ from cachedout/remove_unused_import_in_cp
  * c706ed2 These were unused and causing weird recursion errors in unit tests

- **PR** `#19303`_: (*cachedout*) Batch ckminions
  @ *2015-01-06T17:37:42Z*

  - **ISSUE** `#18358`_: (*msciciel*) Problem with batch execution
    | refs: `#19303`_
  * 00e9686 Merge pull request `#19303`_ from cachedout/batch_ckminions
  * f44e46d Adjust batch test

  * d406c17 Add expr form logic

  * d4d4a12 Just use ckminions in batch mode.

- **PR** `#19388`_: (*lorengordon*) Update vcredist version, fixes saltstack/salt`#19387`_
  @ *2015-01-06T17:25:05Z*

  - **ISSUE** `#19387`_: (*lorengordon*) Update version of vcredist in Windows installer
  * 8915ee4 Merge pull request `#19388`_ from lorengordon/develop
  * a1d7868 Update vcredist version, fixes saltstack/salt`#19387`_

- **PR** `#19385`_: (*ajacoutot*) openbsdrcctl: fix code to match new rcctl(8) syntax.
  @ *2015-01-06T17:24:44Z*

  * 1a04c83 Merge pull request `#19385`_ from ajacoutot/develop
  * 7b99eeb openbsdrcctl: turn badvar into a tuple and fix lint warnings

  * 113c56a openbsdrcctl: fix code to match new rcctl(8) syntax.

- **PR** `#19372`_: (*cvrebert*) rename log setup funcs for PEP8 compliance
  @ *2015-01-06T17:23:43Z*

  * 04733d3 Merge pull request `#19372`_ from hulu/log-setup-naming
  * 5304e27 rename log setup funcs for PEP8 compliance

- **PR** `#19371`_: (*cvrebert*) minor cleanup of Django auth
  @ *2015-01-06T17:23:28Z*

  * 6218e98 Merge pull request `#19371`_ from hulu/auth-django
  * 12b4260 minor cleanup of Django auth

- **PR** `#19370`_: (*Seveland12*) fixed typo in tests/consist.py
  @ *2015-01-06T17:22:55Z*

  * a7a5362 Merge pull request `#19370`_ from Seveland12/develop
  * 8eb6de4 fixed typo in tests/consist.py

- **PR** `#19366`_: (*cachedout*) Fix typo in jboss7 module.
  @ *2015-01-06T17:21:45Z*

  - **ISSUE** `#18598`_: (*cvrebert*) Bug in modules.jboss7_cli.__is_assignment()
    | refs: `#19366`_
  * 4ce4a63 Merge pull request `#19366`_ from cachedout/issue_18598
  * ef567a9 Fix typo in jboss7 module.

- **PR** `#19344`_: (*RobertFach*) Svn export fix issue 19343
  @ *2015-01-06T17:15:27Z*

  - **ISSUE** `#19343`_: (*RobertFach*) svn.export fails with module svn
    | refs: `#19344`_
  * 13c0885 Merge pull request `#19344`_ from RobertFach/svn-export-fix-issue-19343
  * d6389c8 fixed identation problem

  * 2b4caaa changed salt call to modules/svn.py svn.export function, added revision field to function call argument list

  * 4cb4c7d changed salt call to modules/svn.py svn.export function, added revision field to function call argument list

- **PR** `#19390`_: (*thatch45*) Merge `#19342`_
  @ *2015-01-06T17:14:49Z*

  - **PR** `#19342`_: (*jayeshka*) adding apache unit test case
    | refs: `#19390`_
  * 40aec9d Merge pull request `#19390`_ from thatch45/jayeshka-apache_unit_test
  * b01ac59 fix bad lint error

  * ab0b432 Merge branch 'apache_unit_test' of https://github.com/jayeshka/salt into jayeshka-apache_unit_test

  * e200766 adding apache unit test case

- **PR** `#19315`_: (*ShadNygren*) Fix salt cloud volumes
  @ *2015-01-06T04:02:18Z*

  * adbcb96 Merge pull request `#19315`_ from Melrok/fix-salt-cloud-volumes
  * 9993366 Changed from using type() to isinstance() per pull request comment

  * 4b335b5 Fix TypeError: string indices must be integers, not str in ec2.py create_attach_volumes()

  * 773d426 Fix AttributeError: 'list' object has no attribute 'items' in cloud.py run_func_until_ret_arg()

- **PR** `#19359`_: (*rallytime*) Pylint fix for develop
  @ *2015-01-05T22:20:13Z*

  * 927290f Merge pull request `#19359`_ from rallytime/pylint_fix
  * 6d26bd4 Pylint fix for develop

- **PR** `#19351`_: (*jfindlay*) win_firewall: fix disable, enable and add delete_rule
  @ *2015-01-05T20:28:45Z*

  * 5fcb742 Merge pull request `#19351`_ from jfindlay/win_firewall
  * 18d52d1 fixup win_firewall {en|dis}able

  * ae83af0 adding firewall.delete_rule function

- **PR** `#19347`_: (*mens*) Update states/augeas.py. Fix index error.
  @ *2015-01-05T20:27:45Z*

  * 9cc1af7 Merge pull request `#19347`_ from mens/patch-1
  * 2615177 Update states/augeas.py. Fix index error.

- **PR** `#19346`_: (*garethgreenaway*) Additions to pkg state module
  @ *2015-01-05T20:27:26Z*

  - **ISSUE** `#19291`_: (*gfa*) pkg module could accept version: latest
    | refs: `#19346`_
  * 23935b9 Merge pull request `#19346`_ from garethgreenaway/19291_pkg_state_version_latest
  * fe39aad Allow the version argument for the pkg state to accept the "latest" as a value.  If specified then the latest version available will be installed.  Per `#19291`_

- **PR** `#19345`_: (*cachedout*) Catch all Django errors and some PEP8 cleanup.
  @ *2015-01-05T20:27:04Z*

  * 3de7cfc Merge pull request `#19345`_ from cachedout/django_cleanup
  * cfc76d5 Catch all Django errors and some PEP8 cleanup.

- **PR** `#19339`_: (*rynemccall*) Support messages containing non-ascii characters
  @ *2015-01-05T20:26:40Z*

  - **ISSUE** `#19338`_: (*rynemccall*) State output containing non-ascii characters produces UnicodeEncodeError
    | refs: `#19339`_
  * 27c5392 Merge pull request `#19339`_ from rynemccall/support-non-ascii-output
  * a0e2f09 Support messages containing non-ascii characters

- **PR** `#19341`_: (*Lacrymology*) fix docstring for pillar.get
  @ *2015-01-05T20:24:43Z*

  * 6f13509 Merge pull request `#19341`_ from Lacrymology/safe-pillar-get
  * 1f8def0 fix docstring

- **PR** `#19328`_: (*jmdcal*) load checking
  @ *2015-01-05T20:22:41Z*

  - **ISSUE** `#19264`_: (*jmdcal*) Trying to load invalid module produces a confusing error message
    | refs: `#19328`_
  * 8bfa8f8 Merge pull request `#19328`_ from jmdcal/load_checking
  * 5d72c52 load checking

- **PR** `#19322`_: (*garethgreenaway*) Adding a simple notification function to the test module.
  @ *2015-01-05T20:17:24Z*

  - **ISSUE** `#19132`_: (*syphernl*) Allow content to be added to highstate result
    | refs: `#19322`_
  * 3a1cffd Merge pull request `#19322`_ from garethgreenaway/19132_simple_state_notification
  * 6a3c15a Adding a simple notification function to the test module.

- **PR** `#19307`_: (*blueicefield*) Feature : Adding functions to Mongodb module for the management of user roles
  @ *2015-01-05T20:13:29Z*

  - **ISSUE** `#8933`_: (*thaddeusmt*) mongodb_user not creating users
  * dd4fd3a Merge pull request `#19307`_ from blueicefield/feature_mongodb-roles
  * 5705ed5 Improved code readability

  * d129b5d fix errors to pass lint test

  * f688667 Fixed issue `#8933`_ by improving database connection error handling

  * 78bda20 Trivial refactoring of the function mongodb.user_roles_exists

  * 7c12294 Added user_roles_exists function and improving user_grant_roles and user_revoke_roles in Mongodb module

  * 03cbe6c Adding functions user_grant_roles and user_revoke_roles to Mongodb module

- **PR** `#19340`_: (*nmadhok*) Adding unit tests for salt.modules.zpool
  @ *2015-01-05T17:11:46Z*

  * f01ce36 Merge pull request `#19340`_ from nmadhok/zpool-unit-test
  * c21c7c9 Changing return to match zpool list instead of zfs list

  * 2c53cbe Replacing zfs with zpool

  * 6d8aa5f Adding unit tests for salt.modules.zpool

- **PR** `#19335`_: (*rallytime*) Fix develop pylint
  @ *2015-01-04T11:56:20Z*

  * 0452b43 Merge pull request `#19335`_ from rallytime/pylint_develop
  * fb9bc7d Fix develop pylint

- **PR** `#19273`_: (*jayeshka*) adding extfs unit test
  @ *2015-01-04T03:20:09Z*

  * 621bcee Merge pull request `#19273`_ from jayeshka/extfs_unit_tests
  * 2928d87 resolved lint errors in extfs unit test

  * b71372d adding extfs unit test

- **PR** `#19320`_: (*clan*) add 'state_output_profile' option for profile output
  @ *2015-01-02T17:39:22Z*

  * e2dd4b9 Merge pull request `#19320`_ from clan/opt_profile
  * d46b6b6 sate_output_profile default to True

  * 3fce994 fix type: statei -> state

  * 8217f5f add 'state_output_profile' option for profile output

- **PR** `#19314`_: (*dawsonbotsford*) Spelling correction automated from Dawson's Spelling Bee
  @ *2014-12-31T23:39:07Z*

  * c316c11 Merge pull request `#19314`_ from dawsonbotsford/develop
  * adcf77c Spelling correction automated from Dawson's Spelling Bee

- **PR** `#19305`_: (*TaiSHiNet*) Fixes droplet listing past page 1
  @ *2014-12-30T22:59:00Z*

  - **ISSUE** `#19304`_: (*TaiSHiNet*) DigitalOcean API v2 cannot delete VMs on 2nd page
    | refs: `#19305`_
  * d773041 Merge pull request `#19305`_ from TaiSHiNet/patch-1
  * 213641e Fixes droplet listing past page 1

- **PR** `#19298`_: (*manonthemat*) added note about Arch Linux's default transport
  @ *2014-12-30T19:39:27Z*

  * e94462e Merge pull request `#19298`_ from manonthemat/develop
  * a1625ef added note about Arch Linux's default transport

- **PR** `#19293`_: (*DmitryKuzmenko*) Support joined, allowed, alived and reaped runners.
  | refs: `#21691`_
  @ *2014-12-30T19:27:27Z*

  * 0487834 Merge pull request `#19293`_ from DSRCompany/raet_presence_requests
  * 4dc2fbf Support joined, allowed, alived and reaped runners.

- **PR** `#19275`_: (*salekseev*) Adding a new log handler to support fluent protocol.
  @ *2014-12-30T19:11:22Z*

  * 74db7a1 Merge pull request `#19275`_ from salekseev/feature_log-handler-fluentd
  * 4cf3f05 Adding Stas Alekseev to AUTHORS

  * 2ba8227 Fixing some lint.

  * 5ba28e4 Adding a new log handler to support fluent protocol.

- **PR** `#19274`_: (*rupeshta*) implimented code for drac module
  @ *2014-12-30T19:10:51Z*

  * 0e9c7ec Merge pull request `#19274`_ from rupeshta/drac_unit_tests
  * 722b431 implimented code for drac module

- **PR** `#19296`_: (*cachedout*) MongoDB lint
  @ *2014-12-30T19:07:10Z*

  * 3c44658 Merge pull request `#19296`_ from cachedout/mongodb_lint
  * 739254a MongoDB lint

- **PR** `#19246`_: (*cachedout*) More cleanup
  @ *2014-12-30T18:50:12Z*

  * 7d3a37d Merge pull request `#19246`_ from cachedout/more_cleanup
  * 4b1862f Bad logic error on my part

  * 9303e48 Change mysql pillar test to use updated class name

  * 59fe484 Collapse no-op matching

  * de414c3 Remove extra check for None because we can compare str to None.

  * 72337dd Import logging

  * 50e5426 Helper function is no longer used at all

  * 0b97810 Remove pylint resulting in no-op overhead

  * b9db75f This appears to be a no-op

  * f4fa704 Collapse empty pass statements

  * 9f7a13f Captalize class names please

  * a076da7 No print statements in exec modules please

- **PR** `#19290`_: (*jayeshka*) adding useradd unit test case.
  @ *2014-12-30T18:33:26Z*

  * fcd0ade Merge pull request `#19290`_ from jayeshka/user-add-unit-test
  * f14cfa9 adding useradd unit test case.

- **PR** `#19286`_: (*cachedout*) There is no support for ECDSA on OpenSSH < 5.7.
  @ *2014-12-30T02:10:24Z*

  * d9ad877 Merge pull request `#19286`_ from cachedout/change_test_enc
  * 0f6e94a There is no support for ECDSA on OpenSSH < 5.7.

- **PR** `#19287`_: (*cachedout*) Linting
  @ *2014-12-30T01:06:46Z*

  * 765ef4e Merge pull request `#19287`_ from cachedout/lint
  * a44737f Linting

- **PR** `#19256`_: (*keesbos*) Use regular expression syntax in SaltEvent.get_event() for tag matching
  @ *2014-12-29T23:00:23Z*

  * 0c5ac08 Merge pull request `#19256`_ from keesbos/event-regex
  * c04215b Removed timing tests for CacheRegex

  * 2d6cda3 String format needs indexes in py26

  * ce1477f Alternative match functions for class SaltEvent (including regex)

  * 6156c5a PEP8

- **PR** `#19278`_: (*blueicefield*) Fixed the function user_list of mongodb module to work properly with MongoDB 2.6
  @ *2014-12-29T22:48:18Z*

  * 075ee5b Merge pull request `#19278`_ from blueicefield/fixed-mongodb.user_list
  * 2702a7f Fixed the function user_list of mongodb module to work properly with MongoDB 2.6

  * bfe77e8 Fixed the function user_list of mongodb module to work properly with MongoDB 2.6

- **PR** `#19265`_: (*jfindlay*) add color option to console logger
  @ *2014-12-29T22:43:35Z*

  * 4274a33 Merge pull request `#19265`_ from jfindlay/log_color
  * 13dca45 fix utils unit test

  * e8d4882 remove misleading unicode message

  * feb3049 pylint again (why was this not caught the first time?)

  * 415f078 pylint fixes

  * 2d93867 add color to console logger

  * 751e0c7 update color name consistency

  * 32f5f24 finally remove global, unused color declarations

  * 4723853 add full support for ANSI SGR escape sequences

- **PR** `#19259`_: (*thepauleh*) 13197 - pkg.install can use sources for yumpkg
  @ *2014-12-29T22:43:06Z*

  * 5ad225b Merge pull request `#19259`_ from thepauleh/yum-salt-sources-13197
  * 38d40da 13197 - pkg.install can use sources for yumpkg

- **PR** `#19283`_: (*cachedout*) Check kmod ioerror
  @ *2014-12-29T19:42:53Z*

  * e4d96cd Merge pull request `#19283`_ from cachedout/check_kmod_ioerror
  * 5b02fd1 Don't patch path existence

  * 852e0cd Error checking in file open for kmod mod

- **PR** `#19281`_: (*twellspring*) Install remaining core components: salt-cloud, ...
  @ *2014-12-29T18:40:44Z*

  * 0a48095 Merge pull request `#19281`_ from twellspring/patch-1
  * 43aa429 Install remaining core components: salt-cloud, ...

- **PR** `#19282`_: (*cachedout*) Holiday lint
  @ *2014-12-29T18:27:38Z*

  * d080293 Merge pull request `#19282`_ from cachedout/lint
  * 845546c Holiday lint

- **PR** `#19280`_: (*cachedout*) Attempt to fix inconsintent VT test by preventing a spin
  @ *2014-12-29T17:27:42Z*

  * 893d174 Merge pull request `#19280`_ from cachedout/attempt_at_vt_fix
  * e5fb819 Attempt to fix inconsintent VT test by preventing a spin

- **PR** `#19279`_: (*cachedout*) Fix typo in highstate outputter
  @ *2014-12-29T17:05:01Z*

  * d8221e6 Merge pull request `#19279`_ from cachedout/highstate_output_bug
  * 9d8a80e Fix typo in highstate outputter

- **PR** `#19267`_: (*jfindlay*) move requirements files into requirements dir
  @ *2014-12-28T20:50:03Z*

  * 2b09c75 Merge pull request `#19267`_ from jfindlay/ref_req
  * ad33589 move requirements files into requirements dir

- **PR** `#19261`_: (*manonthemat*) documentation fix: environ.set -> environ.setenv
  @ *2014-12-28T20:47:45Z*

  * 846c78e Merge pull request `#19261`_ from manonthemat/develop
  * cd47b6d environ.set -> environ.setenv

- **PR** `#19254`_: (*jacksontj*) Fix for:  TypeError: pub() got multiple values for keyword argument 'user'
  @ *2014-12-28T20:42:16Z*

  * 7c85a70 Merge pull request `#19254`_ from jacksontj/multi_syndic
  * 74aa626 Fix a seeming merge-conflict in syndic

- **PR** `#19247`_: (*Nikerabbit*) Fix execution order with "names" in relation to other states
  @ *2014-12-28T20:38:13Z*

  - **ISSUE** `#13312`_: (*KevinTsai*) Out of order the execute sequence when use the 'names' parameters in states.
    | refs: `#19247`_
  * e098828 Merge pull request `#19247`_ from Nikerabbit/ordering
  * cd74eb8 Fix execution order with "names"

- **PR** `#19241`_: (*jacksontj*) Python3 compat iterator
  @ *2014-12-28T20:31:47Z*

  - **PR** `#19221`_: (*jacksontj*) Re-submit `#19112`_
    | refs: `#19241`_
  * 35bdc30 Merge pull request `#19241`_ from jacksontj/develop
  * e709e66 Convert last remaining cases of generating JID manually with utils function

  * ee82031 Python 3 compat iterator

- **PR** `#19217`_: (*jayeshka*) Hosts unit tests
  @ *2014-12-28T20:06:47Z*

  * 763c0f6 Merge pull request `#19217`_ from jayeshka/hosts_unit_tests
  * 92f36aa adding hosts unit test

  * 050e454 adding hosts unit test case

- **PR** `#19211`_: (*garethgreenaway*) Fixes to returner __init__.py
  @ *2014-12-28T20:01:39Z*

  * 7896cee Merge pull request `#19211`_ from garethgreenaway/returner_with_profile_fix
  * cbdccb9 Only look for a profile in the cfg dict or function if one has been passed.

- **PR** `#19174`_: (*jayeshka*) adding kmod module unit tests
  @ *2014-12-28T20:00:18Z*

  * 845e123 Merge pull request `#19174`_ from jayeshka/kmod_unit_tests
  * f53666d error resolved in kmod unit test case

  * 4b7faa4 adding kmod module unit tests

- **PR** `#19168`_: (*bechtoldt*) Enhance ssh.user_keys to skip private key file exports
  @ *2014-12-28T19:58:54Z*

  * adfc818 Merge pull request `#19168`_ from bechtoldt/user_keys_skip_file
  * 04c48d4 fixing lint error PEP8 E712

  * de22630 Enhance ssh.user_keys to skip private key file exports

- **PR** `#19165`_: (*thatch45*) Color themes
  @ *2014-12-28T19:57:54Z*

  - **ISSUE** `#3511`_: (*madduck*) Color schemes / configurable color
    | refs: `#19165`_
  * 2e24a4f Merge pull request `#19165`_ from thatch45/color_themes
  * 1fe2ba8 lint

  * ab94b51 also pad in the rest of the escape, making the config easier

  * 2fa2af5 we need to prepend the color escape in python

  * d3ea40f Add color_theme calls out of opts into the outputters

  * dbf0464 Add core capability to load a color theme per `#3511`_

- **PR** `#19245`_: (*manonthemat*) update States Tutorial part 2
  @ *2014-12-25T04:39:39Z*

  * be85f50 Merge pull request `#19245`_ from manonthemat/develop
  * d8af90c update States Tutorial part 2

* 719cda1 Merge remote-tracking branch 'upstream/2015.2' into develop


* 051693c Merge branch '2015.2' into develop


- **PR** `#19221`_: (*jacksontj*) Re-submit `#19112`_
  | refs: `#19241`_
  @ *2014-12-23T18:30:44Z*

  - **ISSUE** `#16564`_: (*jacksontj*) Reactor is VERY PID hungry
    | refs: `#18254`_
  - **PR** `#19112`_: (*jacksontj*) Fixup reactor in develop.
  - **PR** `#19095`_: (*basepi*) Fix some mistakes from the merge forward
    | refs: `#19112`_
  - **PR** `#19004`_: (*jacksontj*) Fix for new threaded reactor
    | refs: `#19112`_
  - **PR** `#18762`_: (*jacksontj*)  Move reactor master-clients to threads
    | refs: `#19112`_ `#19004`_
  - **PR** `#18741`_: (*terminalmage*) Revert `#18254`_
    | refs: `#18762`_
  - **PR** `#18254`_: (*jacksontj*) Move reactor master-clients to threads
    | refs: `#18762`_ `#18762`_
  * cc48140 Merge pull request `#19221`_ from jacksontj/develop
  * 328f39a Re-submit `#19112`_

  * 6b81e2a Fixed reference. Someone moved where the Minion daemon class was defined

  * ae1728e Update documentation to include how to set a static IP within the VPC for aws/ec2


.. _`#1`: https://github.com/saltstack/salt/issues/1
.. _`#10`: https://github.com/saltstack/salt/issues/10
.. _`#10141`: https://github.com/saltstack/salt/issues/10141
.. _`#10258`: https://github.com/saltstack/salt/issues/10258
.. _`#11`: https://github.com/saltstack/salt/issues/11
.. _`#11453`: https://github.com/saltstack/salt/issues/11453
.. _`#11630`: https://github.com/saltstack/salt/issues/11630
.. _`#11727`: https://github.com/saltstack/salt/issues/11727
.. _`#11879`: https://github.com/saltstack/salt/issues/11879
.. _`#11898`: https://github.com/saltstack/salt/pull/11898
.. _`#11996`: https://github.com/saltstack/salt/issues/11996
.. _`#12`: https://github.com/saltstack/salt/issues/12
.. _`#12006`: https://github.com/saltstack/salt/pull/12006
.. _`#12327`: https://github.com/saltstack/salt/pull/12327
.. _`#12487`: https://github.com/saltstack/salt/issues/12487
.. _`#13`: https://github.com/saltstack/salt/issues/13
.. _`#13312`: https://github.com/saltstack/salt/issues/13312
.. _`#13755`: https://github.com/saltstack/salt/issues/13755
.. _`#13876`: https://github.com/saltstack/salt/issues/13876
.. _`#13943`: https://github.com/saltstack/salt/issues/13943
.. _`#14`: https://github.com/saltstack/salt/issues/14
.. _`#14231`: https://github.com/saltstack/salt/issues/14231
.. _`#14363`: https://github.com/saltstack/salt/issues/14363
.. _`#14628`: https://github.com/saltstack/salt/issues/14628
.. _`#14634`: https://github.com/saltstack/salt/issues/14634
.. _`#14666`: https://github.com/saltstack/salt/issues/14666
.. _`#14791`: https://github.com/saltstack/salt/issues/14791
.. _`#14888`: https://github.com/saltstack/salt/issues/14888
.. _`#14924`: https://github.com/saltstack/salt/pull/14924
.. _`#15`: https://github.com/saltstack/salt/issues/15
.. _`#15209`: https://github.com/saltstack/salt/issues/15209
.. _`#15759`: https://github.com/saltstack/salt/issues/15759
.. _`#15846`: https://github.com/saltstack/salt/issues/15846
.. _`#15862`: https://github.com/saltstack/salt/issues/15862
.. _`#15912`: https://github.com/saltstack/salt/pull/15912
.. _`#15959`: https://github.com/saltstack/salt/issues/15959
.. _`#15960`: https://github.com/saltstack/salt/issues/15960
.. _`#15984`: https://github.com/saltstack/salt/issues/15984
.. _`#16`: https://github.com/saltstack/salt/issues/16
.. _`#16044`: https://github.com/saltstack/salt/pull/16044
.. _`#16188`: https://github.com/saltstack/salt/issues/16188
.. _`#16227`: https://github.com/saltstack/salt/issues/16227
.. _`#16508`: https://github.com/saltstack/salt/issues/16508
.. _`#16564`: https://github.com/saltstack/salt/issues/16564
.. _`#16711`: https://github.com/saltstack/salt/issues/16711
.. _`#16969`: https://github.com/saltstack/salt/issues/16969
.. _`#17`: https://github.com/saltstack/salt/issues/17
.. _`#17198`: https://github.com/saltstack/salt/issues/17198
.. _`#17283`: https://github.com/saltstack/salt/pull/17283
.. _`#17883`: https://github.com/saltstack/salt/pull/17883
.. _`#18`: https://github.com/saltstack/salt/issues/18
.. _`#18073`: https://github.com/saltstack/salt/issues/18073
.. _`#18254`: https://github.com/saltstack/salt/pull/18254
.. _`#18256`: https://github.com/saltstack/salt/issues/18256
.. _`#18355`: https://github.com/saltstack/salt/issues/18355
.. _`#18358`: https://github.com/saltstack/salt/issues/18358
.. _`#18368`: https://github.com/saltstack/salt/pull/18368
.. _`#18447`: https://github.com/saltstack/salt/issues/18447
.. _`#18457`: https://github.com/saltstack/salt/issues/18457
.. _`#1846`: https://github.com/saltstack/salt/issues/1846
.. _`#18508`: https://github.com/saltstack/salt/issues/18508
.. _`#18593`: https://github.com/saltstack/salt/issues/18593
.. _`#18598`: https://github.com/saltstack/salt/issues/18598
.. _`#18600`: https://github.com/saltstack/salt/issues/18600
.. _`#18673`: https://github.com/saltstack/salt/issues/18673
.. _`#18741`: https://github.com/saltstack/salt/pull/18741
.. _`#18745`: https://github.com/saltstack/salt/issues/18745
.. _`#18762`: https://github.com/saltstack/salt/pull/18762
.. _`#18808`: https://github.com/saltstack/salt/issues/18808
.. _`#18822`: https://github.com/saltstack/salt/issues/18822
.. _`#18880`: https://github.com/saltstack/salt/issues/18880
.. _`#18910`: https://github.com/saltstack/salt/issues/18910
.. _`#18911`: https://github.com/saltstack/salt/pull/18911
.. _`#18919`: https://github.com/saltstack/salt/issues/18919
.. _`#18952`: https://github.com/saltstack/salt/pull/18952
.. _`#19004`: https://github.com/saltstack/salt/pull/19004
.. _`#19058`: https://github.com/saltstack/salt/pull/19058
.. _`#19080`: https://github.com/saltstack/salt/issues/19080
.. _`#19084`: https://github.com/saltstack/salt/issues/19084
.. _`#19087`: https://github.com/saltstack/salt/issues/19087
.. _`#19095`: https://github.com/saltstack/salt/pull/19095
.. _`#19112`: https://github.com/saltstack/salt/pull/19112
.. _`#19130`: https://github.com/saltstack/salt/issues/19130
.. _`#19132`: https://github.com/saltstack/salt/issues/19132
.. _`#19155`: https://github.com/saltstack/salt/pull/19155
.. _`#19161`: https://github.com/saltstack/salt/pull/19161
.. _`#19162`: https://github.com/saltstack/salt/issues/19162
.. _`#19165`: https://github.com/saltstack/salt/pull/19165
.. _`#19168`: https://github.com/saltstack/salt/pull/19168
.. _`#19174`: https://github.com/saltstack/salt/pull/19174
.. _`#19211`: https://github.com/saltstack/salt/pull/19211
.. _`#19217`: https://github.com/saltstack/salt/pull/19217
.. _`#19221`: https://github.com/saltstack/salt/pull/19221
.. _`#19238`: https://github.com/saltstack/salt/pull/19238
.. _`#19241`: https://github.com/saltstack/salt/pull/19241
.. _`#19245`: https://github.com/saltstack/salt/pull/19245
.. _`#19246`: https://github.com/saltstack/salt/pull/19246
.. _`#19247`: https://github.com/saltstack/salt/pull/19247
.. _`#19253`: https://github.com/saltstack/salt/pull/19253
.. _`#19254`: https://github.com/saltstack/salt/pull/19254
.. _`#19256`: https://github.com/saltstack/salt/pull/19256
.. _`#19259`: https://github.com/saltstack/salt/pull/19259
.. _`#19261`: https://github.com/saltstack/salt/pull/19261
.. _`#19262`: https://github.com/saltstack/salt/issues/19262
.. _`#19264`: https://github.com/saltstack/salt/issues/19264
.. _`#19265`: https://github.com/saltstack/salt/pull/19265
.. _`#19267`: https://github.com/saltstack/salt/pull/19267
.. _`#19273`: https://github.com/saltstack/salt/pull/19273
.. _`#19274`: https://github.com/saltstack/salt/pull/19274
.. _`#19275`: https://github.com/saltstack/salt/pull/19275
.. _`#19278`: https://github.com/saltstack/salt/pull/19278
.. _`#19279`: https://github.com/saltstack/salt/pull/19279
.. _`#19280`: https://github.com/saltstack/salt/pull/19280
.. _`#19281`: https://github.com/saltstack/salt/pull/19281
.. _`#19282`: https://github.com/saltstack/salt/pull/19282
.. _`#19283`: https://github.com/saltstack/salt/pull/19283
.. _`#19286`: https://github.com/saltstack/salt/pull/19286
.. _`#19287`: https://github.com/saltstack/salt/pull/19287
.. _`#19288`: https://github.com/saltstack/salt/issues/19288
.. _`#19290`: https://github.com/saltstack/salt/pull/19290
.. _`#19291`: https://github.com/saltstack/salt/issues/19291
.. _`#19293`: https://github.com/saltstack/salt/pull/19293
.. _`#19296`: https://github.com/saltstack/salt/pull/19296
.. _`#19298`: https://github.com/saltstack/salt/pull/19298
.. _`#19303`: https://github.com/saltstack/salt/pull/19303
.. _`#19304`: https://github.com/saltstack/salt/issues/19304
.. _`#19305`: https://github.com/saltstack/salt/pull/19305
.. _`#19306`: https://github.com/saltstack/salt/issues/19306
.. _`#19307`: https://github.com/saltstack/salt/pull/19307
.. _`#19314`: https://github.com/saltstack/salt/pull/19314
.. _`#19315`: https://github.com/saltstack/salt/pull/19315
.. _`#19318`: https://github.com/saltstack/salt/pull/19318
.. _`#19320`: https://github.com/saltstack/salt/pull/19320
.. _`#19322`: https://github.com/saltstack/salt/pull/19322
.. _`#19323`: https://github.com/saltstack/salt/pull/19323
.. _`#19326`: https://github.com/saltstack/salt/issues/19326
.. _`#19327`: https://github.com/saltstack/salt/pull/19327
.. _`#19328`: https://github.com/saltstack/salt/pull/19328
.. _`#19329`: https://github.com/saltstack/salt/issues/19329
.. _`#19335`: https://github.com/saltstack/salt/pull/19335
.. _`#19338`: https://github.com/saltstack/salt/issues/19338
.. _`#19339`: https://github.com/saltstack/salt/pull/19339
.. _`#19340`: https://github.com/saltstack/salt/pull/19340
.. _`#19341`: https://github.com/saltstack/salt/pull/19341
.. _`#19342`: https://github.com/saltstack/salt/pull/19342
.. _`#19343`: https://github.com/saltstack/salt/issues/19343
.. _`#19344`: https://github.com/saltstack/salt/pull/19344
.. _`#19345`: https://github.com/saltstack/salt/pull/19345
.. _`#19346`: https://github.com/saltstack/salt/pull/19346
.. _`#19347`: https://github.com/saltstack/salt/pull/19347
.. _`#19351`: https://github.com/saltstack/salt/pull/19351
.. _`#19359`: https://github.com/saltstack/salt/pull/19359
.. _`#19366`: https://github.com/saltstack/salt/pull/19366
.. _`#19368`: https://github.com/saltstack/salt/pull/19368
.. _`#19370`: https://github.com/saltstack/salt/pull/19370
.. _`#19371`: https://github.com/saltstack/salt/pull/19371
.. _`#19372`: https://github.com/saltstack/salt/pull/19372
.. _`#19374`: https://github.com/saltstack/salt/issues/19374
.. _`#19377`: https://github.com/saltstack/salt/pull/19377
.. _`#19380`: https://github.com/saltstack/salt/pull/19380
.. _`#19385`: https://github.com/saltstack/salt/pull/19385
.. _`#19387`: https://github.com/saltstack/salt/issues/19387
.. _`#19388`: https://github.com/saltstack/salt/pull/19388
.. _`#19390`: https://github.com/saltstack/salt/pull/19390
.. _`#19396`: https://github.com/saltstack/salt/pull/19396
.. _`#19403`: https://github.com/saltstack/salt/pull/19403
.. _`#19406`: https://github.com/saltstack/salt/pull/19406
.. _`#19407`: https://github.com/saltstack/salt/pull/19407
.. _`#19408`: https://github.com/saltstack/salt/pull/19408
.. _`#19409`: https://github.com/saltstack/salt/pull/19409
.. _`#19410`: https://github.com/saltstack/salt/issues/19410
.. _`#19412`: https://github.com/saltstack/salt/pull/19412
.. _`#19414`: https://github.com/saltstack/salt/pull/19414
.. _`#19415`: https://github.com/saltstack/salt/issues/19415
.. _`#19418`: https://github.com/saltstack/salt/pull/19418
.. _`#19421`: https://github.com/saltstack/salt/pull/19421
.. _`#19422`: https://github.com/saltstack/salt/pull/19422
.. _`#19423`: https://github.com/saltstack/salt/pull/19423
.. _`#19424`: https://github.com/saltstack/salt/pull/19424
.. _`#19427`: https://github.com/saltstack/salt/pull/19427
.. _`#19429`: https://github.com/saltstack/salt/pull/19429
.. _`#19431`: https://github.com/saltstack/salt/pull/19431
.. _`#19432`: https://github.com/saltstack/salt/pull/19432
.. _`#19441`: https://github.com/saltstack/salt/pull/19441
.. _`#19442`: https://github.com/saltstack/salt/pull/19442
.. _`#19443`: https://github.com/saltstack/salt/pull/19443
.. _`#19445`: https://github.com/saltstack/salt/pull/19445
.. _`#19446`: https://github.com/saltstack/salt/pull/19446
.. _`#19447`: https://github.com/saltstack/salt/pull/19447
.. _`#19449`: https://github.com/saltstack/salt/pull/19449
.. _`#19471`: https://github.com/saltstack/salt/pull/19471
.. _`#19481`: https://github.com/saltstack/salt/pull/19481
.. _`#19482`: https://github.com/saltstack/salt/pull/19482
.. _`#19486`: https://github.com/saltstack/salt/pull/19486
.. _`#19489`: https://github.com/saltstack/salt/pull/19489
.. _`#19490`: https://github.com/saltstack/salt/pull/19490
.. _`#19495`: https://github.com/saltstack/salt/pull/19495
.. _`#19500`: https://github.com/saltstack/salt/pull/19500
.. _`#19506`: https://github.com/saltstack/salt/pull/19506
.. _`#19507`: https://github.com/saltstack/salt/pull/19507
.. _`#19510`: https://github.com/saltstack/salt/pull/19510
.. _`#19511`: https://github.com/saltstack/salt/pull/19511
.. _`#19517`: https://github.com/saltstack/salt/pull/19517
.. _`#19518`: https://github.com/saltstack/salt/issues/19518
.. _`#19523`: https://github.com/saltstack/salt/pull/19523
.. _`#19526`: https://github.com/saltstack/salt/pull/19526
.. _`#19529`: https://github.com/saltstack/salt/pull/19529
.. _`#19531`: https://github.com/saltstack/salt/pull/19531
.. _`#19536`: https://github.com/saltstack/salt/pull/19536
.. _`#19544`: https://github.com/saltstack/salt/pull/19544
.. _`#19545`: https://github.com/saltstack/salt/pull/19545
.. _`#19550`: https://github.com/saltstack/salt/pull/19550
.. _`#19553`: https://github.com/saltstack/salt/pull/19553
.. _`#19555`: https://github.com/saltstack/salt/pull/19555
.. _`#19557`: https://github.com/saltstack/salt/pull/19557
.. _`#19558`: https://github.com/saltstack/salt/pull/19558
.. _`#19561`: https://github.com/saltstack/salt/pull/19561
.. _`#19562`: https://github.com/saltstack/salt/pull/19562
.. _`#19566`: https://github.com/saltstack/salt/pull/19566
.. _`#19569`: https://github.com/saltstack/salt/issues/19569
.. _`#19574`: https://github.com/saltstack/salt/pull/19574
.. _`#19576`: https://github.com/saltstack/salt/pull/19576
.. _`#19578`: https://github.com/saltstack/salt/pull/19578
.. _`#19580`: https://github.com/saltstack/salt/pull/19580
.. _`#19581`: https://github.com/saltstack/salt/pull/19581
.. _`#19582`: https://github.com/saltstack/salt/pull/19582
.. _`#19583`: https://github.com/saltstack/salt/pull/19583
.. _`#19585`: https://github.com/saltstack/salt/pull/19585
.. _`#19592`: https://github.com/saltstack/salt/issues/19592
.. _`#19593`: https://github.com/saltstack/salt/pull/19593
.. _`#19594`: https://github.com/saltstack/salt/pull/19594
.. _`#19595`: https://github.com/saltstack/salt/pull/19595
.. _`#19598`: https://github.com/saltstack/salt/issues/19598
.. _`#19599`: https://github.com/saltstack/salt/pull/19599
.. _`#19600`: https://github.com/saltstack/salt/pull/19600
.. _`#19601`: https://github.com/saltstack/salt/pull/19601
.. _`#19605`: https://github.com/saltstack/salt/pull/19605
.. _`#19608`: https://github.com/saltstack/salt/issues/19608
.. _`#19614`: https://github.com/saltstack/salt/pull/19614
.. _`#19615`: https://github.com/saltstack/salt/pull/19615
.. _`#19621`: https://github.com/saltstack/salt/pull/19621
.. _`#19633`: https://github.com/saltstack/salt/pull/19633
.. _`#19634`: https://github.com/saltstack/salt/pull/19634
.. _`#19637`: https://github.com/saltstack/salt/pull/19637
.. _`#19640`: https://github.com/saltstack/salt/pull/19640
.. _`#19641`: https://github.com/saltstack/salt/pull/19641
.. _`#19643`: https://github.com/saltstack/salt/issues/19643
.. _`#19655`: https://github.com/saltstack/salt/pull/19655
.. _`#19662`: https://github.com/saltstack/salt/pull/19662
.. _`#19665`: https://github.com/saltstack/salt/pull/19665
.. _`#19667`: https://github.com/saltstack/salt/pull/19667
.. _`#19671`: https://github.com/saltstack/salt/issues/19671
.. _`#19674`: https://github.com/saltstack/salt/issues/19674
.. _`#19675`: https://github.com/saltstack/salt/pull/19675
.. _`#19677`: https://github.com/saltstack/salt/pull/19677
.. _`#19680`: https://github.com/saltstack/salt/pull/19680
.. _`#19684`: https://github.com/saltstack/salt/pull/19684
.. _`#19685`: https://github.com/saltstack/salt/pull/19685
.. _`#19687`: https://github.com/saltstack/salt/pull/19687
.. _`#19688`: https://github.com/saltstack/salt/pull/19688
.. _`#19693`: https://github.com/saltstack/salt/pull/19693
.. _`#19695`: https://github.com/saltstack/salt/pull/19695
.. _`#19696`: https://github.com/saltstack/salt/pull/19696
.. _`#19704`: https://github.com/saltstack/salt/pull/19704
.. _`#19707`: https://github.com/saltstack/salt/issues/19707
.. _`#19713`: https://github.com/saltstack/salt/pull/19713
.. _`#19717`: https://github.com/saltstack/salt/pull/19717
.. _`#19723`: https://github.com/saltstack/salt/pull/19723
.. _`#19724`: https://github.com/saltstack/salt/pull/19724
.. _`#19725`: https://github.com/saltstack/salt/pull/19725
.. _`#19729`: https://github.com/saltstack/salt/pull/19729
.. _`#19733`: https://github.com/saltstack/salt/pull/19733
.. _`#19735`: https://github.com/saltstack/salt/pull/19735
.. _`#19737`: https://github.com/saltstack/salt/issues/19737
.. _`#19739`: https://github.com/saltstack/salt/issues/19739
.. _`#19744`: https://github.com/saltstack/salt/pull/19744
.. _`#19746`: https://github.com/saltstack/salt/pull/19746
.. _`#19749`: https://github.com/saltstack/salt/issues/19749
.. _`#19750`: https://github.com/saltstack/salt/pull/19750
.. _`#19759`: https://github.com/saltstack/salt/pull/19759
.. _`#19760`: https://github.com/saltstack/salt/pull/19760
.. _`#19762`: https://github.com/saltstack/salt/pull/19762
.. _`#19764`: https://github.com/saltstack/salt/issues/19764
.. _`#19765`: https://github.com/saltstack/salt/pull/19765
.. _`#19768`: https://github.com/saltstack/salt/pull/19768
.. _`#19774`: https://github.com/saltstack/salt/pull/19774
.. _`#19778`: https://github.com/saltstack/salt/pull/19778
.. _`#19779`: https://github.com/saltstack/salt/pull/19779
.. _`#19780`: https://github.com/saltstack/salt/pull/19780
.. _`#19782`: https://github.com/saltstack/salt/pull/19782
.. _`#19783`: https://github.com/saltstack/salt/pull/19783
.. _`#19786`: https://github.com/saltstack/salt/pull/19786
.. _`#19790`: https://github.com/saltstack/salt/pull/19790
.. _`#19792`: https://github.com/saltstack/salt/pull/19792
.. _`#19793`: https://github.com/saltstack/salt/pull/19793
.. _`#19803`: https://github.com/saltstack/salt/pull/19803
.. _`#19806`: https://github.com/saltstack/salt/pull/19806
.. _`#19808`: https://github.com/saltstack/salt/pull/19808
.. _`#19810`: https://github.com/saltstack/salt/pull/19810
.. _`#19812`: https://github.com/saltstack/salt/pull/19812
.. _`#19814`: https://github.com/saltstack/salt/pull/19814
.. _`#19817`: https://github.com/saltstack/salt/pull/19817
.. _`#19819`: https://github.com/saltstack/salt/pull/19819
.. _`#19821`: https://github.com/saltstack/salt/pull/19821
.. _`#19822`: https://github.com/saltstack/salt/pull/19822
.. _`#19829`: https://github.com/saltstack/salt/pull/19829
.. _`#19830`: https://github.com/saltstack/salt/issues/19830
.. _`#19831`: https://github.com/saltstack/salt/pull/19831
.. _`#19837`: https://github.com/saltstack/salt/pull/19837
.. _`#19841`: https://github.com/saltstack/salt/pull/19841
.. _`#19843`: https://github.com/saltstack/salt/pull/19843
.. _`#19844`: https://github.com/saltstack/salt/pull/19844
.. _`#19851`: https://github.com/saltstack/salt/pull/19851
.. _`#19855`: https://github.com/saltstack/salt/pull/19855
.. _`#19857`: https://github.com/saltstack/salt/pull/19857
.. _`#19858`: https://github.com/saltstack/salt/pull/19858
.. _`#19859`: https://github.com/saltstack/salt/pull/19859
.. _`#19863`: https://github.com/saltstack/salt/pull/19863
.. _`#19867`: https://github.com/saltstack/salt/pull/19867
.. _`#19868`: https://github.com/saltstack/salt/pull/19868
.. _`#19871`: https://github.com/saltstack/salt/issues/19871
.. _`#19874`: https://github.com/saltstack/salt/pull/19874
.. _`#19877`: https://github.com/saltstack/salt/pull/19877
.. _`#19882`: https://github.com/saltstack/salt/pull/19882
.. _`#19883`: https://github.com/saltstack/salt/pull/19883
.. _`#19888`: https://github.com/saltstack/salt/pull/19888
.. _`#19890`: https://github.com/saltstack/salt/pull/19890
.. _`#19891`: https://github.com/saltstack/salt/pull/19891
.. _`#19892`: https://github.com/saltstack/salt/issues/19892
.. _`#19893`: https://github.com/saltstack/salt/pull/19893
.. _`#19894`: https://github.com/saltstack/salt/pull/19894
.. _`#19895`: https://github.com/saltstack/salt/pull/19895
.. _`#19896`: https://github.com/saltstack/salt/pull/19896
.. _`#19898`: https://github.com/saltstack/salt/issues/19898
.. _`#19900`: https://github.com/saltstack/salt/pull/19900
.. _`#19903`: https://github.com/saltstack/salt/pull/19903
.. _`#19915`: https://github.com/saltstack/salt/pull/19915
.. _`#19916`: https://github.com/saltstack/salt/issues/19916
.. _`#19918`: https://github.com/saltstack/salt/pull/19918
.. _`#19925`: https://github.com/saltstack/salt/pull/19925
.. _`#19929`: https://github.com/saltstack/salt/pull/19929
.. _`#19931`: https://github.com/saltstack/salt/pull/19931
.. _`#19933`: https://github.com/saltstack/salt/pull/19933
.. _`#19940`: https://github.com/saltstack/salt/pull/19940
.. _`#19941`: https://github.com/saltstack/salt/pull/19941
.. _`#19943`: https://github.com/saltstack/salt/pull/19943
.. _`#19950`: https://github.com/saltstack/salt/pull/19950
.. _`#19951`: https://github.com/saltstack/salt/pull/19951
.. _`#19952`: https://github.com/saltstack/salt/pull/19952
.. _`#19953`: https://github.com/saltstack/salt/issues/19953
.. _`#19955`: https://github.com/saltstack/salt/pull/19955
.. _`#19956`: https://github.com/saltstack/salt/pull/19956
.. _`#19965`: https://github.com/saltstack/salt/pull/19965
.. _`#19966`: https://github.com/saltstack/salt/pull/19966
.. _`#19967`: https://github.com/saltstack/salt/pull/19967
.. _`#19976`: https://github.com/saltstack/salt/pull/19976
.. _`#19979`: https://github.com/saltstack/salt/pull/19979
.. _`#19984`: https://github.com/saltstack/salt/pull/19984
.. _`#19985`: https://github.com/saltstack/salt/pull/19985
.. _`#19986`: https://github.com/saltstack/salt/pull/19986
.. _`#19987`: https://github.com/saltstack/salt/pull/19987
.. _`#19989`: https://github.com/saltstack/salt/pull/19989
.. _`#19994`: https://github.com/saltstack/salt/issues/19994
.. _`#19995`: https://github.com/saltstack/salt/pull/19995
.. _`#2`: https://github.com/saltstack/salt/issues/2
.. _`#20002`: https://github.com/saltstack/salt/pull/20002
.. _`#20007`: https://github.com/saltstack/salt/pull/20007
.. _`#20008`: https://github.com/saltstack/salt/pull/20008
.. _`#20011`: https://github.com/saltstack/salt/pull/20011
.. _`#20014`: https://github.com/saltstack/salt/issues/20014
.. _`#20016`: https://github.com/saltstack/salt/issues/20016
.. _`#20017`: https://github.com/saltstack/salt/pull/20017
.. _`#20018`: https://github.com/saltstack/salt/pull/20018
.. _`#20020`: https://github.com/saltstack/salt/pull/20020
.. _`#20026`: https://github.com/saltstack/salt/pull/20026
.. _`#20028`: https://github.com/saltstack/salt/pull/20028
.. _`#20029`: https://github.com/saltstack/salt/pull/20029
.. _`#20031`: https://github.com/saltstack/salt/pull/20031
.. _`#20032`: https://github.com/saltstack/salt/pull/20032
.. _`#20033`: https://github.com/saltstack/salt/issues/20033
.. _`#20035`: https://github.com/saltstack/salt/pull/20035
.. _`#20037`: https://github.com/saltstack/salt/pull/20037
.. _`#20038`: https://github.com/saltstack/salt/pull/20038
.. _`#20039`: https://github.com/saltstack/salt/pull/20039
.. _`#20042`: https://github.com/saltstack/salt/pull/20042
.. _`#20052`: https://github.com/saltstack/salt/pull/20052
.. _`#20054`: https://github.com/saltstack/salt/pull/20054
.. _`#20058`: https://github.com/saltstack/salt/pull/20058
.. _`#20059`: https://github.com/saltstack/salt/pull/20059
.. _`#20062`: https://github.com/saltstack/salt/pull/20062
.. _`#20064`: https://github.com/saltstack/salt/pull/20064
.. _`#20073`: https://github.com/saltstack/salt/pull/20073
.. _`#20077`: https://github.com/saltstack/salt/issues/20077
.. _`#20081`: https://github.com/saltstack/salt/pull/20081
.. _`#20083`: https://github.com/saltstack/salt/pull/20083
.. _`#20094`: https://github.com/saltstack/salt/pull/20094
.. _`#20095`: https://github.com/saltstack/salt/pull/20095
.. _`#20099`: https://github.com/saltstack/salt/pull/20099
.. _`#20103`: https://github.com/saltstack/salt/pull/20103
.. _`#20104`: https://github.com/saltstack/salt/pull/20104
.. _`#20107`: https://github.com/saltstack/salt/issues/20107
.. _`#20114`: https://github.com/saltstack/salt/pull/20114
.. _`#20115`: https://github.com/saltstack/salt/pull/20115
.. _`#20117`: https://github.com/saltstack/salt/pull/20117
.. _`#20118`: https://github.com/saltstack/salt/pull/20118
.. _`#20120`: https://github.com/saltstack/salt/issues/20120
.. _`#20121`: https://github.com/saltstack/salt/pull/20121
.. _`#20122`: https://github.com/saltstack/salt/pull/20122
.. _`#20123`: https://github.com/saltstack/salt/pull/20123
.. _`#20124`: https://github.com/saltstack/salt/pull/20124
.. _`#20125`: https://github.com/saltstack/salt/pull/20125
.. _`#20126`: https://github.com/saltstack/salt/pull/20126
.. _`#20127`: https://github.com/saltstack/salt/pull/20127
.. _`#20130`: https://github.com/saltstack/salt/pull/20130
.. _`#20133`: https://github.com/saltstack/salt/pull/20133
.. _`#20134`: https://github.com/saltstack/salt/pull/20134
.. _`#20139`: https://github.com/saltstack/salt/pull/20139
.. _`#20140`: https://github.com/saltstack/salt/pull/20140
.. _`#20142`: https://github.com/saltstack/salt/pull/20142
.. _`#20144`: https://github.com/saltstack/salt/pull/20144
.. _`#20146`: https://github.com/saltstack/salt/pull/20146
.. _`#20147`: https://github.com/saltstack/salt/pull/20147
.. _`#2015`: https://github.com/saltstack/salt/pull/2015
.. _`#20153`: https://github.com/saltstack/salt/pull/20153
.. _`#20161`: https://github.com/saltstack/salt/pull/20161
.. _`#20166`: https://github.com/saltstack/salt/pull/20166
.. _`#20170`: https://github.com/saltstack/salt/issues/20170
.. _`#20171`: https://github.com/saltstack/salt/pull/20171
.. _`#20172`: https://github.com/saltstack/salt/pull/20172
.. _`#20175`: https://github.com/saltstack/salt/pull/20175
.. _`#20178`: https://github.com/saltstack/salt/pull/20178
.. _`#20179`: https://github.com/saltstack/salt/pull/20179
.. _`#20180`: https://github.com/saltstack/salt/pull/20180
.. _`#20181`: https://github.com/saltstack/salt/pull/20181
.. _`#20183`: https://github.com/saltstack/salt/pull/20183
.. _`#20184`: https://github.com/saltstack/salt/issues/20184
.. _`#20186`: https://github.com/saltstack/salt/pull/20186
.. _`#20189`: https://github.com/saltstack/salt/pull/20189
.. _`#20198`: https://github.com/saltstack/salt/issues/20198
.. _`#20202`: https://github.com/saltstack/salt/pull/20202
.. _`#20213`: https://github.com/saltstack/salt/pull/20213
.. _`#20216`: https://github.com/saltstack/salt/pull/20216
.. _`#20221`: https://github.com/saltstack/salt/pull/20221
.. _`#20222`: https://github.com/saltstack/salt/pull/20222
.. _`#20227`: https://github.com/saltstack/salt/issues/20227
.. _`#20230`: https://github.com/saltstack/salt/pull/20230
.. _`#20232`: https://github.com/saltstack/salt/pull/20232
.. _`#20235`: https://github.com/saltstack/salt/issues/20235
.. _`#20236`: https://github.com/saltstack/salt/pull/20236
.. _`#20239`: https://github.com/saltstack/salt/issues/20239
.. _`#20247`: https://github.com/saltstack/salt/pull/20247
.. _`#20248`: https://github.com/saltstack/salt/pull/20248
.. _`#20249`: https://github.com/saltstack/salt/pull/20249
.. _`#20251`: https://github.com/saltstack/salt/pull/20251
.. _`#20252`: https://github.com/saltstack/salt/pull/20252
.. _`#20253`: https://github.com/saltstack/salt/pull/20253
.. _`#20257`: https://github.com/saltstack/salt/pull/20257
.. _`#20262`: https://github.com/saltstack/salt/pull/20262
.. _`#20263`: https://github.com/saltstack/salt/pull/20263
.. _`#20264`: https://github.com/saltstack/salt/pull/20264
.. _`#20265`: https://github.com/saltstack/salt/pull/20265
.. _`#20266`: https://github.com/saltstack/salt/pull/20266
.. _`#20269`: https://github.com/saltstack/salt/pull/20269
.. _`#20270`: https://github.com/saltstack/salt/pull/20270
.. _`#20272`: https://github.com/saltstack/salt/pull/20272
.. _`#20274`: https://github.com/saltstack/salt/pull/20274
.. _`#20277`: https://github.com/saltstack/salt/pull/20277
.. _`#20281`: https://github.com/saltstack/salt/pull/20281
.. _`#20283`: https://github.com/saltstack/salt/pull/20283
.. _`#20286`: https://github.com/saltstack/salt/pull/20286
.. _`#20287`: https://github.com/saltstack/salt/pull/20287
.. _`#20292`: https://github.com/saltstack/salt/pull/20292
.. _`#20294`: https://github.com/saltstack/salt/pull/20294
.. _`#20302`: https://github.com/saltstack/salt/pull/20302
.. _`#20310`: https://github.com/saltstack/salt/pull/20310
.. _`#20311`: https://github.com/saltstack/salt/pull/20311
.. _`#20313`: https://github.com/saltstack/salt/pull/20313
.. _`#20315`: https://github.com/saltstack/salt/pull/20315
.. _`#20317`: https://github.com/saltstack/salt/issues/20317
.. _`#20319`: https://github.com/saltstack/salt/pull/20319
.. _`#20320`: https://github.com/saltstack/salt/pull/20320
.. _`#20321`: https://github.com/saltstack/salt/pull/20321
.. _`#20322`: https://github.com/saltstack/salt/issues/20322
.. _`#20323`: https://github.com/saltstack/salt/pull/20323
.. _`#20324`: https://github.com/saltstack/salt/pull/20324
.. _`#20325`: https://github.com/saltstack/salt/pull/20325
.. _`#20326`: https://github.com/saltstack/salt/pull/20326
.. _`#20327`: https://github.com/saltstack/salt/pull/20327
.. _`#20330`: https://github.com/saltstack/salt/pull/20330
.. _`#20331`: https://github.com/saltstack/salt/pull/20331
.. _`#20332`: https://github.com/saltstack/salt/pull/20332
.. _`#20333`: https://github.com/saltstack/salt/pull/20333
.. _`#20338`: https://github.com/saltstack/salt/pull/20338
.. _`#20339`: https://github.com/saltstack/salt/pull/20339
.. _`#20340`: https://github.com/saltstack/salt/issues/20340
.. _`#20343`: https://github.com/saltstack/salt/pull/20343
.. _`#20348`: https://github.com/saltstack/salt/pull/20348
.. _`#20349`: https://github.com/saltstack/salt/pull/20349
.. _`#20350`: https://github.com/saltstack/salt/pull/20350
.. _`#20354`: https://github.com/saltstack/salt/pull/20354
.. _`#20357`: https://github.com/saltstack/salt/pull/20357
.. _`#20359`: https://github.com/saltstack/salt/pull/20359
.. _`#20367`: https://github.com/saltstack/salt/pull/20367
.. _`#20371`: https://github.com/saltstack/salt/pull/20371
.. _`#20374`: https://github.com/saltstack/salt/pull/20374
.. _`#20375`: https://github.com/saltstack/salt/pull/20375
.. _`#20380`: https://github.com/saltstack/salt/pull/20380
.. _`#20382`: https://github.com/saltstack/salt/pull/20382
.. _`#20384`: https://github.com/saltstack/salt/issues/20384
.. _`#20386`: https://github.com/saltstack/salt/pull/20386
.. _`#20395`: https://github.com/saltstack/salt/pull/20395
.. _`#20400`: https://github.com/saltstack/salt/pull/20400
.. _`#20402`: https://github.com/saltstack/salt/pull/20402
.. _`#20413`: https://github.com/saltstack/salt/pull/20413
.. _`#20414`: https://github.com/saltstack/salt/pull/20414
.. _`#20415`: https://github.com/saltstack/salt/pull/20415
.. _`#20427`: https://github.com/saltstack/salt/pull/20427
.. _`#20429`: https://github.com/saltstack/salt/pull/20429
.. _`#20431`: https://github.com/saltstack/salt/pull/20431
.. _`#20441`: https://github.com/saltstack/salt/issues/20441
.. _`#20443`: https://github.com/saltstack/salt/pull/20443
.. _`#20444`: https://github.com/saltstack/salt/pull/20444
.. _`#20446`: https://github.com/saltstack/salt/pull/20446
.. _`#20452`: https://github.com/saltstack/salt/pull/20452
.. _`#20454`: https://github.com/saltstack/salt/pull/20454
.. _`#20455`: https://github.com/saltstack/salt/pull/20455
.. _`#20456`: https://github.com/saltstack/salt/pull/20456
.. _`#20457`: https://github.com/saltstack/salt/pull/20457
.. _`#20458`: https://github.com/saltstack/salt/pull/20458
.. _`#20459`: https://github.com/saltstack/salt/pull/20459
.. _`#20461`: https://github.com/saltstack/salt/pull/20461
.. _`#20463`: https://github.com/saltstack/salt/pull/20463
.. _`#20469`: https://github.com/saltstack/salt/pull/20469
.. _`#20470`: https://github.com/saltstack/salt/pull/20470
.. _`#20473`: https://github.com/saltstack/salt/pull/20473
.. _`#20474`: https://github.com/saltstack/salt/pull/20474
.. _`#20476`: https://github.com/saltstack/salt/pull/20476
.. _`#20477`: https://github.com/saltstack/salt/pull/20477
.. _`#20478`: https://github.com/saltstack/salt/pull/20478
.. _`#20481`: https://github.com/saltstack/salt/pull/20481
.. _`#20482`: https://github.com/saltstack/salt/pull/20482
.. _`#20486`: https://github.com/saltstack/salt/pull/20486
.. _`#20490`: https://github.com/saltstack/salt/issues/20490
.. _`#20491`: https://github.com/saltstack/salt/pull/20491
.. _`#20495`: https://github.com/saltstack/salt/pull/20495
.. _`#20496`: https://github.com/saltstack/salt/issues/20496
.. _`#20497`: https://github.com/saltstack/salt/pull/20497
.. _`#20501`: https://github.com/saltstack/salt/pull/20501
.. _`#20503`: https://github.com/saltstack/salt/issues/20503
.. _`#20513`: https://github.com/saltstack/salt/pull/20513
.. _`#20514`: https://github.com/saltstack/salt/pull/20514
.. _`#20515`: https://github.com/saltstack/salt/pull/20515
.. _`#20516`: https://github.com/saltstack/salt/pull/20516
.. _`#20517`: https://github.com/saltstack/salt/pull/20517
.. _`#20519`: https://github.com/saltstack/salt/pull/20519
.. _`#20520`: https://github.com/saltstack/salt/pull/20520
.. _`#20521`: https://github.com/saltstack/salt/pull/20521
.. _`#20524`: https://github.com/saltstack/salt/pull/20524
.. _`#20525`: https://github.com/saltstack/salt/pull/20525
.. _`#20537`: https://github.com/saltstack/salt/pull/20537
.. _`#20538`: https://github.com/saltstack/salt/pull/20538
.. _`#20539`: https://github.com/saltstack/salt/issues/20539
.. _`#20541`: https://github.com/saltstack/salt/pull/20541
.. _`#20542`: https://github.com/saltstack/salt/pull/20542
.. _`#20543`: https://github.com/saltstack/salt/pull/20543
.. _`#20553`: https://github.com/saltstack/salt/pull/20553
.. _`#20556`: https://github.com/saltstack/salt/pull/20556
.. _`#20559`: https://github.com/saltstack/salt/pull/20559
.. _`#20561`: https://github.com/saltstack/salt/pull/20561
.. _`#20562`: https://github.com/saltstack/salt/pull/20562
.. _`#20563`: https://github.com/saltstack/salt/pull/20563
.. _`#20564`: https://github.com/saltstack/salt/issues/20564
.. _`#20566`: https://github.com/saltstack/salt/pull/20566
.. _`#20567`: https://github.com/saltstack/salt/pull/20567
.. _`#20568`: https://github.com/saltstack/salt/pull/20568
.. _`#20569`: https://github.com/saltstack/salt/pull/20569
.. _`#20571`: https://github.com/saltstack/salt/pull/20571
.. _`#20572`: https://github.com/saltstack/salt/pull/20572
.. _`#20573`: https://github.com/saltstack/salt/pull/20573
.. _`#20577`: https://github.com/saltstack/salt/pull/20577
.. _`#20580`: https://github.com/saltstack/salt/pull/20580
.. _`#20582`: https://github.com/saltstack/salt/pull/20582
.. _`#20584`: https://github.com/saltstack/salt/pull/20584
.. _`#20586`: https://github.com/saltstack/salt/pull/20586
.. _`#20587`: https://github.com/saltstack/salt/issues/20587
.. _`#20589`: https://github.com/saltstack/salt/pull/20589
.. _`#20593`: https://github.com/saltstack/salt/pull/20593
.. _`#20594`: https://github.com/saltstack/salt/pull/20594
.. _`#20598`: https://github.com/saltstack/salt/pull/20598
.. _`#20600`: https://github.com/saltstack/salt/pull/20600
.. _`#20602`: https://github.com/saltstack/salt/pull/20602
.. _`#20605`: https://github.com/saltstack/salt/pull/20605
.. _`#20606`: https://github.com/saltstack/salt/pull/20606
.. _`#20607`: https://github.com/saltstack/salt/pull/20607
.. _`#20608`: https://github.com/saltstack/salt/pull/20608
.. _`#20609`: https://github.com/saltstack/salt/pull/20609
.. _`#20617`: https://github.com/saltstack/salt/pull/20617
.. _`#20618`: https://github.com/saltstack/salt/pull/20618
.. _`#20621`: https://github.com/saltstack/salt/issues/20621
.. _`#20622`: https://github.com/saltstack/salt/pull/20622
.. _`#20623`: https://github.com/saltstack/salt/pull/20623
.. _`#20624`: https://github.com/saltstack/salt/pull/20624
.. _`#20627`: https://github.com/saltstack/salt/pull/20627
.. _`#20628`: https://github.com/saltstack/salt/issues/20628
.. _`#20636`: https://github.com/saltstack/salt/pull/20636
.. _`#20644`: https://github.com/saltstack/salt/pull/20644
.. _`#20645`: https://github.com/saltstack/salt/pull/20645
.. _`#20647`: https://github.com/saltstack/salt/issues/20647
.. _`#20649`: https://github.com/saltstack/salt/pull/20649
.. _`#20652`: https://github.com/saltstack/salt/issues/20652
.. _`#20653`: https://github.com/saltstack/salt/pull/20653
.. _`#20654`: https://github.com/saltstack/salt/pull/20654
.. _`#20655`: https://github.com/saltstack/salt/pull/20655
.. _`#20657`: https://github.com/saltstack/salt/issues/20657
.. _`#20658`: https://github.com/saltstack/salt/pull/20658
.. _`#20659`: https://github.com/saltstack/salt/pull/20659
.. _`#20665`: https://github.com/saltstack/salt/pull/20665
.. _`#20666`: https://github.com/saltstack/salt/pull/20666
.. _`#20667`: https://github.com/saltstack/salt/pull/20667
.. _`#20668`: https://github.com/saltstack/salt/pull/20668
.. _`#20674`: https://github.com/saltstack/salt/pull/20674
.. _`#20675`: https://github.com/saltstack/salt/pull/20675
.. _`#20676`: https://github.com/saltstack/salt/pull/20676
.. _`#20679`: https://github.com/saltstack/salt/pull/20679
.. _`#20692`: https://github.com/saltstack/salt/pull/20692
.. _`#20693`: https://github.com/saltstack/salt/pull/20693
.. _`#20694`: https://github.com/saltstack/salt/pull/20694
.. _`#20698`: https://github.com/saltstack/salt/pull/20698
.. _`#20699`: https://github.com/saltstack/salt/pull/20699
.. _`#20700`: https://github.com/saltstack/salt/pull/20700
.. _`#20706`: https://github.com/saltstack/salt/pull/20706
.. _`#20707`: https://github.com/saltstack/salt/pull/20707
.. _`#20708`: https://github.com/saltstack/salt/issues/20708
.. _`#20709`: https://github.com/saltstack/salt/pull/20709
.. _`#20710`: https://github.com/saltstack/salt/pull/20710
.. _`#20711`: https://github.com/saltstack/salt/issues/20711
.. _`#20712`: https://github.com/saltstack/salt/pull/20712
.. _`#20713`: https://github.com/saltstack/salt/pull/20713
.. _`#20714`: https://github.com/saltstack/salt/pull/20714
.. _`#20715`: https://github.com/saltstack/salt/pull/20715
.. _`#20717`: https://github.com/saltstack/salt/pull/20717
.. _`#20721`: https://github.com/saltstack/salt/pull/20721
.. _`#20722`: https://github.com/saltstack/salt/pull/20722
.. _`#20723`: https://github.com/saltstack/salt/pull/20723
.. _`#20725`: https://github.com/saltstack/salt/pull/20725
.. _`#20726`: https://github.com/saltstack/salt/pull/20726
.. _`#20728`: https://github.com/saltstack/salt/pull/20728
.. _`#20730`: https://github.com/saltstack/salt/pull/20730
.. _`#20731`: https://github.com/saltstack/salt/pull/20731
.. _`#20733`: https://github.com/saltstack/salt/pull/20733
.. _`#20738`: https://github.com/saltstack/salt/pull/20738
.. _`#20741`: https://github.com/saltstack/salt/pull/20741
.. _`#20744`: https://github.com/saltstack/salt/pull/20744
.. _`#20745`: https://github.com/saltstack/salt/pull/20745
.. _`#20746`: https://github.com/saltstack/salt/pull/20746
.. _`#20751`: https://github.com/saltstack/salt/pull/20751
.. _`#20752`: https://github.com/saltstack/salt/pull/20752
.. _`#20753`: https://github.com/saltstack/salt/pull/20753
.. _`#20754`: https://github.com/saltstack/salt/pull/20754
.. _`#20755`: https://github.com/saltstack/salt/pull/20755
.. _`#20756`: https://github.com/saltstack/salt/pull/20756
.. _`#20758`: https://github.com/saltstack/salt/pull/20758
.. _`#20760`: https://github.com/saltstack/salt/pull/20760
.. _`#20768`: https://github.com/saltstack/salt/pull/20768
.. _`#20769`: https://github.com/saltstack/salt/pull/20769
.. _`#20770`: https://github.com/saltstack/salt/pull/20770
.. _`#20771`: https://github.com/saltstack/salt/pull/20771
.. _`#20772`: https://github.com/saltstack/salt/pull/20772
.. _`#20774`: https://github.com/saltstack/salt/pull/20774
.. _`#20776`: https://github.com/saltstack/salt/pull/20776
.. _`#20779`: https://github.com/saltstack/salt/pull/20779
.. _`#20780`: https://github.com/saltstack/salt/pull/20780
.. _`#20782`: https://github.com/saltstack/salt/pull/20782
.. _`#20784`: https://github.com/saltstack/salt/pull/20784
.. _`#20787`: https://github.com/saltstack/salt/issues/20787
.. _`#20792`: https://github.com/saltstack/salt/pull/20792
.. _`#20796`: https://github.com/saltstack/salt/pull/20796
.. _`#20798`: https://github.com/saltstack/salt/pull/20798
.. _`#20799`: https://github.com/saltstack/salt/pull/20799
.. _`#20803`: https://github.com/saltstack/salt/pull/20803
.. _`#20804`: https://github.com/saltstack/salt/pull/20804
.. _`#20808`: https://github.com/saltstack/salt/pull/20808
.. _`#20814`: https://github.com/saltstack/salt/issues/20814
.. _`#20815`: https://github.com/saltstack/salt/pull/20815
.. _`#20817`: https://github.com/saltstack/salt/pull/20817
.. _`#20818`: https://github.com/saltstack/salt/issues/20818
.. _`#20819`: https://github.com/saltstack/salt/pull/20819
.. _`#20820`: https://github.com/saltstack/salt/pull/20820
.. _`#20821`: https://github.com/saltstack/salt/pull/20821
.. _`#20822`: https://github.com/saltstack/salt/pull/20822
.. _`#20825`: https://github.com/saltstack/salt/pull/20825
.. _`#20826`: https://github.com/saltstack/salt/issues/20826
.. _`#20827`: https://github.com/saltstack/salt/pull/20827
.. _`#20829`: https://github.com/saltstack/salt/pull/20829
.. _`#20830`: https://github.com/saltstack/salt/pull/20830
.. _`#20832`: https://github.com/saltstack/salt/pull/20832
.. _`#20835`: https://github.com/saltstack/salt/pull/20835
.. _`#20837`: https://github.com/saltstack/salt/pull/20837
.. _`#20843`: https://github.com/saltstack/salt/pull/20843
.. _`#20853`: https://github.com/saltstack/salt/pull/20853
.. _`#20861`: https://github.com/saltstack/salt/pull/20861
.. _`#20869`: https://github.com/saltstack/salt/issues/20869
.. _`#20870`: https://github.com/saltstack/salt/pull/20870
.. _`#20885`: https://github.com/saltstack/salt/issues/20885
.. _`#20888`: https://github.com/saltstack/salt/pull/20888
.. _`#20889`: https://github.com/saltstack/salt/pull/20889
.. _`#20891`: https://github.com/saltstack/salt/pull/20891
.. _`#20892`: https://github.com/saltstack/salt/pull/20892
.. _`#20893`: https://github.com/saltstack/salt/pull/20893
.. _`#20898`: https://github.com/saltstack/salt/issues/20898
.. _`#20899`: https://github.com/saltstack/salt/pull/20899
.. _`#20901`: https://github.com/saltstack/salt/pull/20901
.. _`#20905`: https://github.com/saltstack/salt/pull/20905
.. _`#20908`: https://github.com/saltstack/salt/issues/20908
.. _`#20910`: https://github.com/saltstack/salt/issues/20910
.. _`#20913`: https://github.com/saltstack/salt/pull/20913
.. _`#20914`: https://github.com/saltstack/salt/pull/20914
.. _`#20917`: https://github.com/saltstack/salt/pull/20917
.. _`#20919`: https://github.com/saltstack/salt/pull/20919
.. _`#20927`: https://github.com/saltstack/salt/pull/20927
.. _`#20929`: https://github.com/saltstack/salt/issues/20929
.. _`#20930`: https://github.com/saltstack/salt/pull/20930
.. _`#20932`: https://github.com/saltstack/salt/issues/20932
.. _`#20935`: https://github.com/saltstack/salt/pull/20935
.. _`#20936`: https://github.com/saltstack/salt/issues/20936
.. _`#20938`: https://github.com/saltstack/salt/pull/20938
.. _`#20940`: https://github.com/saltstack/salt/pull/20940
.. _`#20942`: https://github.com/saltstack/salt/pull/20942
.. _`#20943`: https://github.com/saltstack/salt/pull/20943
.. _`#20946`: https://github.com/saltstack/salt/pull/20946
.. _`#20948`: https://github.com/saltstack/salt/pull/20948
.. _`#20959`: https://github.com/saltstack/salt/pull/20959
.. _`#20962`: https://github.com/saltstack/salt/issues/20962
.. _`#20963`: https://github.com/saltstack/salt/pull/20963
.. _`#20966`: https://github.com/saltstack/salt/pull/20966
.. _`#20968`: https://github.com/saltstack/salt/pull/20968
.. _`#20969`: https://github.com/saltstack/salt/issues/20969
.. _`#20972`: https://github.com/saltstack/salt/pull/20972
.. _`#20974`: https://github.com/saltstack/salt/pull/20974
.. _`#20975`: https://github.com/saltstack/salt/pull/20975
.. _`#20980`: https://github.com/saltstack/salt/issues/20980
.. _`#20981`: https://github.com/saltstack/salt/pull/20981
.. _`#20987`: https://github.com/saltstack/salt/pull/20987
.. _`#20994`: https://github.com/saltstack/salt/pull/20994
.. _`#20995`: https://github.com/saltstack/salt/pull/20995
.. _`#20996`: https://github.com/saltstack/salt/pull/20996
.. _`#20999`: https://github.com/saltstack/salt/pull/20999
.. _`#21005`: https://github.com/saltstack/salt/pull/21005
.. _`#21006`: https://github.com/saltstack/salt/pull/21006
.. _`#21007`: https://github.com/saltstack/salt/pull/21007
.. _`#21018`: https://github.com/saltstack/salt/pull/21018
.. _`#21019`: https://github.com/saltstack/salt/pull/21019
.. _`#21020`: https://github.com/saltstack/salt/pull/21020
.. _`#21024`: https://github.com/saltstack/salt/pull/21024
.. _`#21026`: https://github.com/saltstack/salt/pull/21026
.. _`#21030`: https://github.com/saltstack/salt/pull/21030
.. _`#21031`: https://github.com/saltstack/salt/pull/21031
.. _`#21033`: https://github.com/saltstack/salt/pull/21033
.. _`#21037`: https://github.com/saltstack/salt/pull/21037
.. _`#21038`: https://github.com/saltstack/salt/pull/21038
.. _`#21040`: https://github.com/saltstack/salt/pull/21040
.. _`#21041`: https://github.com/saltstack/salt/issues/21041
.. _`#21042`: https://github.com/saltstack/salt/pull/21042
.. _`#21044`: https://github.com/saltstack/salt/pull/21044
.. _`#21046`: https://github.com/saltstack/salt/pull/21046
.. _`#21056`: https://github.com/saltstack/salt/pull/21056
.. _`#21060`: https://github.com/saltstack/salt/issues/21060
.. _`#21061`: https://github.com/saltstack/salt/pull/21061
.. _`#21062`: https://github.com/saltstack/salt/pull/21062
.. _`#21072`: https://github.com/saltstack/salt/pull/21072
.. _`#21086`: https://github.com/saltstack/salt/pull/21086
.. _`#21087`: https://github.com/saltstack/salt/pull/21087
.. _`#21088`: https://github.com/saltstack/salt/pull/21088
.. _`#21090`: https://github.com/saltstack/salt/pull/21090
.. _`#21099`: https://github.com/saltstack/salt/pull/21099
.. _`#21100`: https://github.com/saltstack/salt/pull/21100
.. _`#21101`: https://github.com/saltstack/salt/pull/21101
.. _`#21102`: https://github.com/saltstack/salt/pull/21102
.. _`#21105`: https://github.com/saltstack/salt/issues/21105
.. _`#21106`: https://github.com/saltstack/salt/pull/21106
.. _`#21111`: https://github.com/saltstack/salt/pull/21111
.. _`#21113`: https://github.com/saltstack/salt/issues/21113
.. _`#21115`: https://github.com/saltstack/salt/pull/21115
.. _`#21128`: https://github.com/saltstack/salt/pull/21128
.. _`#21129`: https://github.com/saltstack/salt/pull/21129
.. _`#21131`: https://github.com/saltstack/salt/pull/21131
.. _`#21132`: https://github.com/saltstack/salt/pull/21132
.. _`#21134`: https://github.com/saltstack/salt/issues/21134
.. _`#21140`: https://github.com/saltstack/salt/issues/21140
.. _`#21141`: https://github.com/saltstack/salt/pull/21141
.. _`#21142`: https://github.com/saltstack/salt/pull/21142
.. _`#21143`: https://github.com/saltstack/salt/pull/21143
.. _`#21148`: https://github.com/saltstack/salt/pull/21148
.. _`#21153`: https://github.com/saltstack/salt/pull/21153
.. _`#21155`: https://github.com/saltstack/salt/pull/21155
.. _`#21157`: https://github.com/saltstack/salt/pull/21157
.. _`#21158`: https://github.com/saltstack/salt/pull/21158
.. _`#21159`: https://github.com/saltstack/salt/pull/21159
.. _`#21163`: https://github.com/saltstack/salt/pull/21163
.. _`#21166`: https://github.com/saltstack/salt/pull/21166
.. _`#21168`: https://github.com/saltstack/salt/issues/21168
.. _`#21171`: https://github.com/saltstack/salt/pull/21171
.. _`#21173`: https://github.com/saltstack/salt/pull/21173
.. _`#21186`: https://github.com/saltstack/salt/pull/21186
.. _`#21195`: https://github.com/saltstack/salt/pull/21195
.. _`#21208`: https://github.com/saltstack/salt/pull/21208
.. _`#21210`: https://github.com/saltstack/salt/pull/21210
.. _`#21217`: https://github.com/saltstack/salt/issues/21217
.. _`#21229`: https://github.com/saltstack/salt/pull/21229
.. _`#21230`: https://github.com/saltstack/salt/pull/21230
.. _`#21234`: https://github.com/saltstack/salt/pull/21234
.. _`#21235`: https://github.com/saltstack/salt/pull/21235
.. _`#21241`: https://github.com/saltstack/salt/issues/21241
.. _`#21243`: https://github.com/saltstack/salt/pull/21243
.. _`#21247`: https://github.com/saltstack/salt/pull/21247
.. _`#21255`: https://github.com/saltstack/salt/pull/21255
.. _`#21267`: https://github.com/saltstack/salt/issues/21267
.. _`#21273`: https://github.com/saltstack/salt/pull/21273
.. _`#21274`: https://github.com/saltstack/salt/issues/21274
.. _`#21279`: https://github.com/saltstack/salt/pull/21279
.. _`#21280`: https://github.com/saltstack/salt/issues/21280
.. _`#21283`: https://github.com/saltstack/salt/pull/21283
.. _`#21285`: https://github.com/saltstack/salt/pull/21285
.. _`#21286`: https://github.com/saltstack/salt/pull/21286
.. _`#21290`: https://github.com/saltstack/salt/pull/21290
.. _`#21291`: https://github.com/saltstack/salt/pull/21291
.. _`#21293`: https://github.com/saltstack/salt/issues/21293
.. _`#21295`: https://github.com/saltstack/salt/pull/21295
.. _`#21297`: https://github.com/saltstack/salt/pull/21297
.. _`#21306`: https://github.com/saltstack/salt/pull/21306
.. _`#21314`: https://github.com/saltstack/salt/pull/21314
.. _`#21319`: https://github.com/saltstack/salt/pull/21319
.. _`#21321`: https://github.com/saltstack/salt/pull/21321
.. _`#21322`: https://github.com/saltstack/salt/pull/21322
.. _`#21323`: https://github.com/saltstack/salt/pull/21323
.. _`#21324`: https://github.com/saltstack/salt/pull/21324
.. _`#21327`: https://github.com/saltstack/salt/pull/21327
.. _`#21328`: https://github.com/saltstack/salt/pull/21328
.. _`#21330`: https://github.com/saltstack/salt/pull/21330
.. _`#21331`: https://github.com/saltstack/salt/pull/21331
.. _`#21334`: https://github.com/saltstack/salt/pull/21334
.. _`#21335`: https://github.com/saltstack/salt/pull/21335
.. _`#21338`: https://github.com/saltstack/salt/pull/21338
.. _`#21339`: https://github.com/saltstack/salt/pull/21339
.. _`#21340`: https://github.com/saltstack/salt/pull/21340
.. _`#21342`: https://github.com/saltstack/salt/issues/21342
.. _`#21347`: https://github.com/saltstack/salt/pull/21347
.. _`#21349`: https://github.com/saltstack/salt/issues/21349
.. _`#21351`: https://github.com/saltstack/salt/pull/21351
.. _`#21356`: https://github.com/saltstack/salt/pull/21356
.. _`#21357`: https://github.com/saltstack/salt/pull/21357
.. _`#21358`: https://github.com/saltstack/salt/pull/21358
.. _`#21364`: https://github.com/saltstack/salt/pull/21364
.. _`#21368`: https://github.com/saltstack/salt/pull/21368
.. _`#21371`: https://github.com/saltstack/salt/pull/21371
.. _`#21375`: https://github.com/saltstack/salt/pull/21375
.. _`#21386`: https://github.com/saltstack/salt/pull/21386
.. _`#21388`: https://github.com/saltstack/salt/issues/21388
.. _`#21396`: https://github.com/saltstack/salt/pull/21396
.. _`#21399`: https://github.com/saltstack/salt/issues/21399
.. _`#21400`: https://github.com/saltstack/salt/pull/21400
.. _`#21409`: https://github.com/saltstack/salt/pull/21409
.. _`#21410`: https://github.com/saltstack/salt/pull/21410
.. _`#21412`: https://github.com/saltstack/salt/pull/21412
.. _`#21416`: https://github.com/saltstack/salt/pull/21416
.. _`#21419`: https://github.com/saltstack/salt/pull/21419
.. _`#21420`: https://github.com/saltstack/salt/pull/21420
.. _`#21421`: https://github.com/saltstack/salt/pull/21421
.. _`#21423`: https://github.com/saltstack/salt/issues/21423
.. _`#21424`: https://github.com/saltstack/salt/pull/21424
.. _`#21428`: https://github.com/saltstack/salt/pull/21428
.. _`#21429`: https://github.com/saltstack/salt/pull/21429
.. _`#21430`: https://github.com/saltstack/salt/pull/21430
.. _`#21433`: https://github.com/saltstack/salt/pull/21433
.. _`#21436`: https://github.com/saltstack/salt/pull/21436
.. _`#21442`: https://github.com/saltstack/salt/issues/21442
.. _`#21443`: https://github.com/saltstack/salt/pull/21443
.. _`#21445`: https://github.com/saltstack/salt/pull/21445
.. _`#21447`: https://github.com/saltstack/salt/pull/21447
.. _`#21455`: https://github.com/saltstack/salt/pull/21455
.. _`#21459`: https://github.com/saltstack/salt/pull/21459
.. _`#21461`: https://github.com/saltstack/salt/pull/21461
.. _`#21464`: https://github.com/saltstack/salt/pull/21464
.. _`#21466`: https://github.com/saltstack/salt/pull/21466
.. _`#21467`: https://github.com/saltstack/salt/pull/21467
.. _`#21468`: https://github.com/saltstack/salt/pull/21468
.. _`#21469`: https://github.com/saltstack/salt/pull/21469
.. _`#21471`: https://github.com/saltstack/salt/pull/21471
.. _`#21472`: https://github.com/saltstack/salt/pull/21472
.. _`#21473`: https://github.com/saltstack/salt/pull/21473
.. _`#21476`: https://github.com/saltstack/salt/pull/21476
.. _`#21478`: https://github.com/saltstack/salt/pull/21478
.. _`#21486`: https://github.com/saltstack/salt/pull/21486
.. _`#21489`: https://github.com/saltstack/salt/pull/21489
.. _`#21490`: https://github.com/saltstack/salt/issues/21490
.. _`#21491`: https://github.com/saltstack/salt/issues/21491
.. _`#21493`: https://github.com/saltstack/salt/pull/21493
.. _`#21494`: https://github.com/saltstack/salt/pull/21494
.. _`#21502`: https://github.com/saltstack/salt/pull/21502
.. _`#21505`: https://github.com/saltstack/salt/pull/21505
.. _`#21507`: https://github.com/saltstack/salt/issues/21507
.. _`#21513`: https://github.com/saltstack/salt/pull/21513
.. _`#21516`: https://github.com/saltstack/salt/pull/21516
.. _`#21517`: https://github.com/saltstack/salt/pull/21517
.. _`#21518`: https://github.com/saltstack/salt/pull/21518
.. _`#21526`: https://github.com/saltstack/salt/pull/21526
.. _`#21529`: https://github.com/saltstack/salt/pull/21529
.. _`#21531`: https://github.com/saltstack/salt/pull/21531
.. _`#21532`: https://github.com/saltstack/salt/pull/21532
.. _`#21533`: https://github.com/saltstack/salt/issues/21533
.. _`#21534`: https://github.com/saltstack/salt/pull/21534
.. _`#21539`: https://github.com/saltstack/salt/pull/21539
.. _`#21541`: https://github.com/saltstack/salt/pull/21541
.. _`#21547`: https://github.com/saltstack/salt/issues/21547
.. _`#21549`: https://github.com/saltstack/salt/pull/21549
.. _`#21553`: https://github.com/saltstack/salt/pull/21553
.. _`#21554`: https://github.com/saltstack/salt/pull/21554
.. _`#21563`: https://github.com/saltstack/salt/pull/21563
.. _`#21566`: https://github.com/saltstack/salt/pull/21566
.. _`#21571`: https://github.com/saltstack/salt/pull/21571
.. _`#21573`: https://github.com/saltstack/salt/pull/21573
.. _`#21575`: https://github.com/saltstack/salt/pull/21575
.. _`#21576`: https://github.com/saltstack/salt/pull/21576
.. _`#21581`: https://github.com/saltstack/salt/pull/21581
.. _`#21586`: https://github.com/saltstack/salt/pull/21586
.. _`#21589`: https://github.com/saltstack/salt/issues/21589
.. _`#21590`: https://github.com/saltstack/salt/pull/21590
.. _`#21594`: https://github.com/saltstack/salt/pull/21594
.. _`#21595`: https://github.com/saltstack/salt/pull/21595
.. _`#21599`: https://github.com/saltstack/salt/pull/21599
.. _`#21604`: https://github.com/saltstack/salt/pull/21604
.. _`#21608`: https://github.com/saltstack/salt/pull/21608
.. _`#21610`: https://github.com/saltstack/salt/issues/21610
.. _`#21612`: https://github.com/saltstack/salt/pull/21612
.. _`#21614`: https://github.com/saltstack/salt/pull/21614
.. _`#21616`: https://github.com/saltstack/salt/pull/21616
.. _`#21617`: https://github.com/saltstack/salt/issues/21617
.. _`#21622`: https://github.com/saltstack/salt/pull/21622
.. _`#21623`: https://github.com/saltstack/salt/pull/21623
.. _`#21627`: https://github.com/saltstack/salt/pull/21627
.. _`#21634`: https://github.com/saltstack/salt/pull/21634
.. _`#21638`: https://github.com/saltstack/salt/issues/21638
.. _`#21640`: https://github.com/saltstack/salt/issues/21640
.. _`#21643`: https://github.com/saltstack/salt/pull/21643
.. _`#21644`: https://github.com/saltstack/salt/pull/21644
.. _`#21646`: https://github.com/saltstack/salt/pull/21646
.. _`#21649`: https://github.com/saltstack/salt/pull/21649
.. _`#21651`: https://github.com/saltstack/salt/issues/21651
.. _`#21652`: https://github.com/saltstack/salt/pull/21652
.. _`#21653`: https://github.com/saltstack/salt/pull/21653
.. _`#21659`: https://github.com/saltstack/salt/pull/21659
.. _`#21660`: https://github.com/saltstack/salt/pull/21660
.. _`#21665`: https://github.com/saltstack/salt/pull/21665
.. _`#21666`: https://github.com/saltstack/salt/pull/21666
.. _`#21671`: https://github.com/saltstack/salt/issues/21671
.. _`#21672`: https://github.com/saltstack/salt/pull/21672
.. _`#21673`: https://github.com/saltstack/salt/pull/21673
.. _`#21674`: https://github.com/saltstack/salt/pull/21674
.. _`#21675`: https://github.com/saltstack/salt/pull/21675
.. _`#21676`: https://github.com/saltstack/salt/pull/21676
.. _`#21681`: https://github.com/saltstack/salt/pull/21681
.. _`#21682`: https://github.com/saltstack/salt/pull/21682
.. _`#21684`: https://github.com/saltstack/salt/pull/21684
.. _`#21685`: https://github.com/saltstack/salt/pull/21685
.. _`#21689`: https://github.com/saltstack/salt/pull/21689
.. _`#21690`: https://github.com/saltstack/salt/pull/21690
.. _`#21691`: https://github.com/saltstack/salt/pull/21691
.. _`#21692`: https://github.com/saltstack/salt/pull/21692
.. _`#21693`: https://github.com/saltstack/salt/pull/21693
.. _`#21695`: https://github.com/saltstack/salt/pull/21695
.. _`#21697`: https://github.com/saltstack/salt/pull/21697
.. _`#21715`: https://github.com/saltstack/salt/pull/21715
.. _`#21721`: https://github.com/saltstack/salt/issues/21721
.. _`#21725`: https://github.com/saltstack/salt/pull/21725
.. _`#21729`: https://github.com/saltstack/salt/pull/21729
.. _`#21730`: https://github.com/saltstack/salt/pull/21730
.. _`#21731`: https://github.com/saltstack/salt/pull/21731
.. _`#21733`: https://github.com/saltstack/salt/pull/21733
.. _`#21735`: https://github.com/saltstack/salt/pull/21735
.. _`#21736`: https://github.com/saltstack/salt/pull/21736
.. _`#21738`: https://github.com/saltstack/salt/pull/21738
.. _`#21739`: https://github.com/saltstack/salt/pull/21739
.. _`#21742`: https://github.com/saltstack/salt/pull/21742
.. _`#21745`: https://github.com/saltstack/salt/pull/21745
.. _`#21750`: https://github.com/saltstack/salt/pull/21750
.. _`#21752`: https://github.com/saltstack/salt/pull/21752
.. _`#21753`: https://github.com/saltstack/salt/pull/21753
.. _`#21754`: https://github.com/saltstack/salt/pull/21754
.. _`#21759`: https://github.com/saltstack/salt/pull/21759
.. _`#21761`: https://github.com/saltstack/salt/pull/21761
.. _`#21763`: https://github.com/saltstack/salt/pull/21763
.. _`#21767`: https://github.com/saltstack/salt/pull/21767
.. _`#21768`: https://github.com/saltstack/salt/pull/21768
.. _`#21769`: https://github.com/saltstack/salt/pull/21769
.. _`#21771`: https://github.com/saltstack/salt/pull/21771
.. _`#21772`: https://github.com/saltstack/salt/pull/21772
.. _`#21778`: https://github.com/saltstack/salt/pull/21778
.. _`#21792`: https://github.com/saltstack/salt/pull/21792
.. _`#21793`: https://github.com/saltstack/salt/pull/21793
.. _`#21798`: https://github.com/saltstack/salt/pull/21798
.. _`#21800`: https://github.com/saltstack/salt/pull/21800
.. _`#21804`: https://github.com/saltstack/salt/pull/21804
.. _`#21805`: https://github.com/saltstack/salt/pull/21805
.. _`#21806`: https://github.com/saltstack/salt/pull/21806
.. _`#21808`: https://github.com/saltstack/salt/pull/21808
.. _`#21810`: https://github.com/saltstack/salt/issues/21810
.. _`#21815`: https://github.com/saltstack/salt/pull/21815
.. _`#21819`: https://github.com/saltstack/salt/pull/21819
.. _`#21825`: https://github.com/saltstack/salt/pull/21825
.. _`#21830`: https://github.com/saltstack/salt/pull/21830
.. _`#21833`: https://github.com/saltstack/salt/pull/21833
.. _`#21834`: https://github.com/saltstack/salt/pull/21834
.. _`#21836`: https://github.com/saltstack/salt/pull/21836
.. _`#21840`: https://github.com/saltstack/salt/issues/21840
.. _`#21841`: https://github.com/saltstack/salt/pull/21841
.. _`#21842`: https://github.com/saltstack/salt/pull/21842
.. _`#21844`: https://github.com/saltstack/salt/pull/21844
.. _`#21853`: https://github.com/saltstack/salt/pull/21853
.. _`#21856`: https://github.com/saltstack/salt/pull/21856
.. _`#21862`: https://github.com/saltstack/salt/pull/21862
.. _`#21868`: https://github.com/saltstack/salt/pull/21868
.. _`#21874`: https://github.com/saltstack/salt/pull/21874
.. _`#21877`: https://github.com/saltstack/salt/pull/21877
.. _`#21878`: https://github.com/saltstack/salt/pull/21878
.. _`#21879`: https://github.com/saltstack/salt/issues/21879
.. _`#21880`: https://github.com/saltstack/salt/pull/21880
.. _`#21881`: https://github.com/saltstack/salt/issues/21881
.. _`#21882`: https://github.com/saltstack/salt/pull/21882
.. _`#21884`: https://github.com/saltstack/salt/issues/21884
.. _`#21885`: https://github.com/saltstack/salt/pull/21885
.. _`#21889`: https://github.com/saltstack/salt/pull/21889
.. _`#21890`: https://github.com/saltstack/salt/issues/21890
.. _`#21891`: https://github.com/saltstack/salt/pull/21891
.. _`#21895`: https://github.com/saltstack/salt/pull/21895
.. _`#21900`: https://github.com/saltstack/salt/pull/21900
.. _`#21906`: https://github.com/saltstack/salt/pull/21906
.. _`#21908`: https://github.com/saltstack/salt/pull/21908
.. _`#21911`: https://github.com/saltstack/salt/pull/21911
.. _`#21912`: https://github.com/saltstack/salt/issues/21912
.. _`#21914`: https://github.com/saltstack/salt/pull/21914
.. _`#21915`: https://github.com/saltstack/salt/pull/21915
.. _`#21920`: https://github.com/saltstack/salt/pull/21920
.. _`#21924`: https://github.com/saltstack/salt/pull/21924
.. _`#21925`: https://github.com/saltstack/salt/pull/21925
.. _`#21930`: https://github.com/saltstack/salt/pull/21930
.. _`#21937`: https://github.com/saltstack/salt/pull/21937
.. _`#21942`: https://github.com/saltstack/salt/pull/21942
.. _`#21945`: https://github.com/saltstack/salt/pull/21945
.. _`#21947`: https://github.com/saltstack/salt/pull/21947
.. _`#21950`: https://github.com/saltstack/salt/pull/21950
.. _`#21951`: https://github.com/saltstack/salt/pull/21951
.. _`#21956`: https://github.com/saltstack/salt/issues/21956
.. _`#21959`: https://github.com/saltstack/salt/pull/21959
.. _`#21964`: https://github.com/saltstack/salt/pull/21964
.. _`#21966`: https://github.com/saltstack/salt/pull/21966
.. _`#21970`: https://github.com/saltstack/salt/pull/21970
.. _`#21973`: https://github.com/saltstack/salt/pull/21973
.. _`#21976`: https://github.com/saltstack/salt/pull/21976
.. _`#21988`: https://github.com/saltstack/salt/pull/21988
.. _`#21993`: https://github.com/saltstack/salt/pull/21993
.. _`#21995`: https://github.com/saltstack/salt/pull/21995
.. _`#21996`: https://github.com/saltstack/salt/pull/21996
.. _`#21999`: https://github.com/saltstack/salt/pull/21999
.. _`#22004`: https://github.com/saltstack/salt/issues/22004
.. _`#22008`: https://github.com/saltstack/salt/pull/22008
.. _`#22013`: https://github.com/saltstack/salt/pull/22013
.. _`#22028`: https://github.com/saltstack/salt/pull/22028
.. _`#22030`: https://github.com/saltstack/salt/pull/22030
.. _`#22036`: https://github.com/saltstack/salt/pull/22036
.. _`#22045`: https://github.com/saltstack/salt/pull/22045
.. _`#22054`: https://github.com/saltstack/salt/pull/22054
.. _`#22057`: https://github.com/saltstack/salt/pull/22057
.. _`#22060`: https://github.com/saltstack/salt/pull/22060
.. _`#22062`: https://github.com/saltstack/salt/pull/22062
.. _`#22068`: https://github.com/saltstack/salt/pull/22068
.. _`#22070`: https://github.com/saltstack/salt/pull/22070
.. _`#22073`: https://github.com/saltstack/salt/pull/22073
.. _`#22078`: https://github.com/saltstack/salt/pull/22078
.. _`#22079`: https://github.com/saltstack/salt/pull/22079
.. _`#22080`: https://github.com/saltstack/salt/issues/22080
.. _`#22085`: https://github.com/saltstack/salt/pull/22085
.. _`#22086`: https://github.com/saltstack/salt/pull/22086
.. _`#22092`: https://github.com/saltstack/salt/pull/22092
.. _`#22094`: https://github.com/saltstack/salt/pull/22094
.. _`#22096`: https://github.com/saltstack/salt/pull/22096
.. _`#22107`: https://github.com/saltstack/salt/pull/22107
.. _`#22114`: https://github.com/saltstack/salt/pull/22114
.. _`#22118`: https://github.com/saltstack/salt/pull/22118
.. _`#22120`: https://github.com/saltstack/salt/pull/22120
.. _`#22123`: https://github.com/saltstack/salt/pull/22123
.. _`#22125`: https://github.com/saltstack/salt/pull/22125
.. _`#22127`: https://github.com/saltstack/salt/pull/22127
.. _`#22129`: https://github.com/saltstack/salt/pull/22129
.. _`#22133`: https://github.com/saltstack/salt/pull/22133
.. _`#22134`: https://github.com/saltstack/salt/pull/22134
.. _`#22135`: https://github.com/saltstack/salt/pull/22135
.. _`#22139`: https://github.com/saltstack/salt/pull/22139
.. _`#22140`: https://github.com/saltstack/salt/pull/22140
.. _`#22143`: https://github.com/saltstack/salt/pull/22143
.. _`#2215`: https://github.com/saltstack/salt/issues/2215
.. _`#22151`: https://github.com/saltstack/salt/pull/22151
.. _`#22154`: https://github.com/saltstack/salt/pull/22154
.. _`#22157`: https://github.com/saltstack/salt/pull/22157
.. _`#22162`: https://github.com/saltstack/salt/pull/22162
.. _`#22163`: https://github.com/saltstack/salt/pull/22163
.. _`#22165`: https://github.com/saltstack/salt/pull/22165
.. _`#22166`: https://github.com/saltstack/salt/pull/22166
.. _`#22169`: https://github.com/saltstack/salt/pull/22169
.. _`#22175`: https://github.com/saltstack/salt/pull/22175
.. _`#22176`: https://github.com/saltstack/salt/pull/22176
.. _`#22180`: https://github.com/saltstack/salt/pull/22180
.. _`#22185`: https://github.com/saltstack/salt/pull/22185
.. _`#22186`: https://github.com/saltstack/salt/pull/22186
.. _`#22187`: https://github.com/saltstack/salt/pull/22187
.. _`#22188`: https://github.com/saltstack/salt/pull/22188
.. _`#22189`: https://github.com/saltstack/salt/pull/22189
.. _`#22190`: https://github.com/saltstack/salt/pull/22190
.. _`#22193`: https://github.com/saltstack/salt/pull/22193
.. _`#22194`: https://github.com/saltstack/salt/pull/22194
.. _`#22197`: https://github.com/saltstack/salt/pull/22197
.. _`#22198`: https://github.com/saltstack/salt/pull/22198
.. _`#22202`: https://github.com/saltstack/salt/pull/22202
.. _`#22203`: https://github.com/saltstack/salt/pull/22203
.. _`#22204`: https://github.com/saltstack/salt/issues/22204
.. _`#22213`: https://github.com/saltstack/salt/pull/22213
.. _`#22226`: https://github.com/saltstack/salt/pull/22226
.. _`#22229`: https://github.com/saltstack/salt/pull/22229
.. _`#22231`: https://github.com/saltstack/salt/pull/22231
.. _`#22237`: https://github.com/saltstack/salt/pull/22237
.. _`#22241`: https://github.com/saltstack/salt/issues/22241
.. _`#22242`: https://github.com/saltstack/salt/pull/22242
.. _`#22243`: https://github.com/saltstack/salt/pull/22243
.. _`#22245`: https://github.com/saltstack/salt/pull/22245
.. _`#22248`: https://github.com/saltstack/salt/pull/22248
.. _`#22249`: https://github.com/saltstack/salt/pull/22249
.. _`#22250`: https://github.com/saltstack/salt/pull/22250
.. _`#22251`: https://github.com/saltstack/salt/pull/22251
.. _`#22257`: https://github.com/saltstack/salt/issues/22257
.. _`#22258`: https://github.com/saltstack/salt/pull/22258
.. _`#22259`: https://github.com/saltstack/salt/pull/22259
.. _`#22260`: https://github.com/saltstack/salt/pull/22260
.. _`#22262`: https://github.com/saltstack/salt/pull/22262
.. _`#22263`: https://github.com/saltstack/salt/pull/22263
.. _`#22264`: https://github.com/saltstack/salt/pull/22264
.. _`#22267`: https://github.com/saltstack/salt/pull/22267
.. _`#22271`: https://github.com/saltstack/salt/pull/22271
.. _`#22273`: https://github.com/saltstack/salt/issues/22273
.. _`#22274`: https://github.com/saltstack/salt/issues/22274
.. _`#22277`: https://github.com/saltstack/salt/pull/22277
.. _`#22278`: https://github.com/saltstack/salt/pull/22278
.. _`#22281`: https://github.com/saltstack/salt/pull/22281
.. _`#22282`: https://github.com/saltstack/salt/pull/22282
.. _`#22283`: https://github.com/saltstack/salt/pull/22283
.. _`#22289`: https://github.com/saltstack/salt/pull/22289
.. _`#22291`: https://github.com/saltstack/salt/pull/22291
.. _`#22292`: https://github.com/saltstack/salt/pull/22292
.. _`#22293`: https://github.com/saltstack/salt/pull/22293
.. _`#22299`: https://github.com/saltstack/salt/pull/22299
.. _`#22303`: https://github.com/saltstack/salt/pull/22303
.. _`#22305`: https://github.com/saltstack/salt/pull/22305
.. _`#22306`: https://github.com/saltstack/salt/issues/22306
.. _`#22307`: https://github.com/saltstack/salt/pull/22307
.. _`#22309`: https://github.com/saltstack/salt/pull/22309
.. _`#22310`: https://github.com/saltstack/salt/pull/22310
.. _`#22323`: https://github.com/saltstack/salt/pull/22323
.. _`#22324`: https://github.com/saltstack/salt/pull/22324
.. _`#22325`: https://github.com/saltstack/salt/pull/22325
.. _`#22326`: https://github.com/saltstack/salt/pull/22326
.. _`#22327`: https://github.com/saltstack/salt/issues/22327
.. _`#22330`: https://github.com/saltstack/salt/pull/22330
.. _`#22331`: https://github.com/saltstack/salt/pull/22331
.. _`#22333`: https://github.com/saltstack/salt/pull/22333
.. _`#22334`: https://github.com/saltstack/salt/pull/22334
.. _`#22336`: https://github.com/saltstack/salt/pull/22336
.. _`#22338`: https://github.com/saltstack/salt/pull/22338
.. _`#22339`: https://github.com/saltstack/salt/issues/22339
.. _`#22340`: https://github.com/saltstack/salt/pull/22340
.. _`#22346`: https://github.com/saltstack/salt/issues/22346
.. _`#22347`: https://github.com/saltstack/salt/pull/22347
.. _`#22348`: https://github.com/saltstack/salt/pull/22348
.. _`#22351`: https://github.com/saltstack/salt/pull/22351
.. _`#22354`: https://github.com/saltstack/salt/pull/22354
.. _`#22355`: https://github.com/saltstack/salt/pull/22355
.. _`#22362`: https://github.com/saltstack/salt/pull/22362
.. _`#22363`: https://github.com/saltstack/salt/pull/22363
.. _`#22364`: https://github.com/saltstack/salt/issues/22364
.. _`#22367`: https://github.com/saltstack/salt/pull/22367
.. _`#22369`: https://github.com/saltstack/salt/pull/22369
.. _`#22371`: https://github.com/saltstack/salt/pull/22371
.. _`#22373`: https://github.com/saltstack/salt/pull/22373
.. _`#22382`: https://github.com/saltstack/salt/issues/22382
.. _`#22384`: https://github.com/saltstack/salt/pull/22384
.. _`#22391`: https://github.com/saltstack/salt/issues/22391
.. _`#22394`: https://github.com/saltstack/salt/pull/22394
.. _`#22397`: https://github.com/saltstack/salt/pull/22397
.. _`#22398`: https://github.com/saltstack/salt/pull/22398
.. _`#22399`: https://github.com/saltstack/salt/pull/22399
.. _`#22406`: https://github.com/saltstack/salt/pull/22406
.. _`#22413`: https://github.com/saltstack/salt/pull/22413
.. _`#22414`: https://github.com/saltstack/salt/pull/22414
.. _`#22415`: https://github.com/saltstack/salt/issues/22415
.. _`#22421`: https://github.com/saltstack/salt/pull/22421
.. _`#22422`: https://github.com/saltstack/salt/pull/22422
.. _`#22423`: https://github.com/saltstack/salt/pull/22423
.. _`#22424`: https://github.com/saltstack/salt/pull/22424
.. _`#22428`: https://github.com/saltstack/salt/pull/22428
.. _`#22429`: https://github.com/saltstack/salt/pull/22429
.. _`#22430`: https://github.com/saltstack/salt/pull/22430
.. _`#22432`: https://github.com/saltstack/salt/pull/22432
.. _`#22437`: https://github.com/saltstack/salt/pull/22437
.. _`#22438`: https://github.com/saltstack/salt/pull/22438
.. _`#22453`: https://github.com/saltstack/salt/pull/22453
.. _`#22458`: https://github.com/saltstack/salt/pull/22458
.. _`#22465`: https://github.com/saltstack/salt/pull/22465
.. _`#22469`: https://github.com/saltstack/salt/pull/22469
.. _`#22478`: https://github.com/saltstack/salt/pull/22478
.. _`#22479`: https://github.com/saltstack/salt/pull/22479
.. _`#22480`: https://github.com/saltstack/salt/pull/22480
.. _`#22481`: https://github.com/saltstack/salt/pull/22481
.. _`#22483`: https://github.com/saltstack/salt/pull/22483
.. _`#22485`: https://github.com/saltstack/salt/pull/22485
.. _`#22486`: https://github.com/saltstack/salt/pull/22486
.. _`#22489`: https://github.com/saltstack/salt/pull/22489
.. _`#22508`: https://github.com/saltstack/salt/pull/22508
.. _`#22512`: https://github.com/saltstack/salt/issues/22512
.. _`#22515`: https://github.com/saltstack/salt/pull/22515
.. _`#22519`: https://github.com/saltstack/salt/pull/22519
.. _`#22524`: https://github.com/saltstack/salt/pull/22524
.. _`#22527`: https://github.com/saltstack/salt/issues/22527
.. _`#22531`: https://github.com/saltstack/salt/issues/22531
.. _`#22537`: https://github.com/saltstack/salt/issues/22537
.. _`#22538`: https://github.com/saltstack/salt/pull/22538
.. _`#22539`: https://github.com/saltstack/salt/pull/22539
.. _`#22545`: https://github.com/saltstack/salt/pull/22545
.. _`#22546`: https://github.com/saltstack/salt/pull/22546
.. _`#22548`: https://github.com/saltstack/salt/pull/22548
.. _`#22551`: https://github.com/saltstack/salt/pull/22551
.. _`#22554`: https://github.com/saltstack/salt/pull/22554
.. _`#22556`: https://github.com/saltstack/salt/pull/22556
.. _`#22559`: https://github.com/saltstack/salt/issues/22559
.. _`#22560`: https://github.com/saltstack/salt/pull/22560
.. _`#22561`: https://github.com/saltstack/salt/issues/22561
.. _`#22562`: https://github.com/saltstack/salt/pull/22562
.. _`#22563`: https://github.com/saltstack/salt/pull/22563
.. _`#22565`: https://github.com/saltstack/salt/pull/22565
.. _`#22567`: https://github.com/saltstack/salt/pull/22567
.. _`#22572`: https://github.com/saltstack/salt/pull/22572
.. _`#22573`: https://github.com/saltstack/salt/pull/22573
.. _`#22574`: https://github.com/saltstack/salt/issues/22574
.. _`#22575`: https://github.com/saltstack/salt/pull/22575
.. _`#22577`: https://github.com/saltstack/salt/pull/22577
.. _`#22581`: https://github.com/saltstack/salt/pull/22581
.. _`#22587`: https://github.com/saltstack/salt/pull/22587
.. _`#22588`: https://github.com/saltstack/salt/pull/22588
.. _`#22591`: https://github.com/saltstack/salt/pull/22591
.. _`#22595`: https://github.com/saltstack/salt/issues/22595
.. _`#22600`: https://github.com/saltstack/salt/pull/22600
.. _`#22609`: https://github.com/saltstack/salt/issues/22609
.. _`#22611`: https://github.com/saltstack/salt/pull/22611
.. _`#22613`: https://github.com/saltstack/salt/pull/22613
.. _`#22614`: https://github.com/saltstack/salt/pull/22614
.. _`#22616`: https://github.com/saltstack/salt/pull/22616
.. _`#22618`: https://github.com/saltstack/salt/issues/22618
.. _`#22619`: https://github.com/saltstack/salt/pull/22619
.. _`#22620`: https://github.com/saltstack/salt/pull/22620
.. _`#22622`: https://github.com/saltstack/salt/pull/22622
.. _`#22627`: https://github.com/saltstack/salt/pull/22627
.. _`#22628`: https://github.com/saltstack/salt/pull/22628
.. _`#22629`: https://github.com/saltstack/salt/pull/22629
.. _`#22630`: https://github.com/saltstack/salt/issues/22630
.. _`#22632`: https://github.com/saltstack/salt/pull/22632
.. _`#22634`: https://github.com/saltstack/salt/issues/22634
.. _`#22635`: https://github.com/saltstack/salt/pull/22635
.. _`#22646`: https://github.com/saltstack/salt/pull/22646
.. _`#22648`: https://github.com/saltstack/salt/pull/22648
.. _`#22657`: https://github.com/saltstack/salt/pull/22657
.. _`#22659`: https://github.com/saltstack/salt/pull/22659
.. _`#22665`: https://github.com/saltstack/salt/pull/22665
.. _`#22668`: https://github.com/saltstack/salt/pull/22668
.. _`#22671`: https://github.com/saltstack/salt/pull/22671
.. _`#22672`: https://github.com/saltstack/salt/pull/22672
.. _`#22673`: https://github.com/saltstack/salt/pull/22673
.. _`#22675`: https://github.com/saltstack/salt/pull/22675
.. _`#22680`: https://github.com/saltstack/salt/pull/22680
.. _`#22687`: https://github.com/saltstack/salt/pull/22687
.. _`#22689`: https://github.com/saltstack/salt/pull/22689
.. _`#22691`: https://github.com/saltstack/salt/pull/22691
.. _`#22695`: https://github.com/saltstack/salt/pull/22695
.. _`#22710`: https://github.com/saltstack/salt/pull/22710
.. _`#22713`: https://github.com/saltstack/salt/issues/22713
.. _`#22715`: https://github.com/saltstack/salt/pull/22715
.. _`#22720`: https://github.com/saltstack/salt/issues/22720
.. _`#22722`: https://github.com/saltstack/salt/pull/22722
.. _`#22726`: https://github.com/saltstack/salt/pull/22726
.. _`#22728`: https://github.com/saltstack/salt/pull/22728
.. _`#22729`: https://github.com/saltstack/salt/pull/22729
.. _`#22730`: https://github.com/saltstack/salt/pull/22730
.. _`#22736`: https://github.com/saltstack/salt/pull/22736
.. _`#22737`: https://github.com/saltstack/salt/pull/22737
.. _`#22750`: https://github.com/saltstack/salt/pull/22750
.. _`#22755`: https://github.com/saltstack/salt/issues/22755
.. _`#22757`: https://github.com/saltstack/salt/pull/22757
.. _`#22758`: https://github.com/saltstack/salt/pull/22758
.. _`#22763`: https://github.com/saltstack/salt/pull/22763
.. _`#22764`: https://github.com/saltstack/salt/pull/22764
.. _`#22765`: https://github.com/saltstack/salt/pull/22765
.. _`#22773`: https://github.com/saltstack/salt/pull/22773
.. _`#22776`: https://github.com/saltstack/salt/pull/22776
.. _`#22781`: https://github.com/saltstack/salt/pull/22781
.. _`#22783`: https://github.com/saltstack/salt/pull/22783
.. _`#22784`: https://github.com/saltstack/salt/pull/22784
.. _`#22785`: https://github.com/saltstack/salt/pull/22785
.. _`#22788`: https://github.com/saltstack/salt/pull/22788
.. _`#22789`: https://github.com/saltstack/salt/pull/22789
.. _`#22792`: https://github.com/saltstack/salt/issues/22792
.. _`#22793`: https://github.com/saltstack/salt/pull/22793
.. _`#22798`: https://github.com/saltstack/salt/pull/22798
.. _`#22799`: https://github.com/saltstack/salt/pull/22799
.. _`#22801`: https://github.com/saltstack/salt/pull/22801
.. _`#22805`: https://github.com/saltstack/salt/pull/22805
.. _`#22806`: https://github.com/saltstack/salt/pull/22806
.. _`#22812`: https://github.com/saltstack/salt/pull/22812
.. _`#22814`: https://github.com/saltstack/salt/issues/22814
.. _`#22817`: https://github.com/saltstack/salt/pull/22817
.. _`#22820`: https://github.com/saltstack/salt/issues/22820
.. _`#22824`: https://github.com/saltstack/salt/pull/22824
.. _`#22826`: https://github.com/saltstack/salt/pull/22826
.. _`#22829`: https://github.com/saltstack/salt/pull/22829
.. _`#22830`: https://github.com/saltstack/salt/pull/22830
.. _`#22832`: https://github.com/saltstack/salt/pull/22832
.. _`#22835`: https://github.com/saltstack/salt/pull/22835
.. _`#22836`: https://github.com/saltstack/salt/pull/22836
.. _`#22837`: https://github.com/saltstack/salt/pull/22837
.. _`#22838`: https://github.com/saltstack/salt/pull/22838
.. _`#22839`: https://github.com/saltstack/salt/issues/22839
.. _`#22841`: https://github.com/saltstack/salt/pull/22841
.. _`#22858`: https://github.com/saltstack/salt/pull/22858
.. _`#22860`: https://github.com/saltstack/salt/pull/22860
.. _`#22862`: https://github.com/saltstack/salt/pull/22862
.. _`#22864`: https://github.com/saltstack/salt/pull/22864
.. _`#22874`: https://github.com/saltstack/salt/issues/22874
.. _`#22875`: https://github.com/saltstack/salt/pull/22875
.. _`#22886`: https://github.com/saltstack/salt/pull/22886
.. _`#22895`: https://github.com/saltstack/salt/pull/22895
.. _`#22900`: https://github.com/saltstack/salt/pull/22900
.. _`#22908`: https://github.com/saltstack/salt/issues/22908
.. _`#22909`: https://github.com/saltstack/salt/pull/22909
.. _`#22913`: https://github.com/saltstack/salt/pull/22913
.. _`#22915`: https://github.com/saltstack/salt/pull/22915
.. _`#22916`: https://github.com/saltstack/salt/pull/22916
.. _`#22920`: https://github.com/saltstack/salt/pull/22920
.. _`#22922`: https://github.com/saltstack/salt/pull/22922
.. _`#22923`: https://github.com/saltstack/salt/pull/22923
.. _`#22926`: https://github.com/saltstack/salt/pull/22926
.. _`#22927`: https://github.com/saltstack/salt/pull/22927
.. _`#22928`: https://github.com/saltstack/salt/pull/22928
.. _`#22948`: https://github.com/saltstack/salt/pull/22948
.. _`#22949`: https://github.com/saltstack/salt/pull/22949
.. _`#22953`: https://github.com/saltstack/salt/pull/22953
.. _`#22962`: https://github.com/saltstack/salt/pull/22962
.. _`#22963`: https://github.com/saltstack/salt/pull/22963
.. _`#22965`: https://github.com/saltstack/salt/pull/22965
.. _`#22966`: https://github.com/saltstack/salt/pull/22966
.. _`#22967`: https://github.com/saltstack/salt/pull/22967
.. _`#22969`: https://github.com/saltstack/salt/pull/22969
.. _`#22971`: https://github.com/saltstack/salt/pull/22971
.. _`#22986`: https://github.com/saltstack/salt/pull/22986
.. _`#22992`: https://github.com/saltstack/salt/pull/22992
.. _`#22995`: https://github.com/saltstack/salt/pull/22995
.. _`#22996`: https://github.com/saltstack/salt/pull/22996
.. _`#22998`: https://github.com/saltstack/salt/pull/22998
.. _`#23003`: https://github.com/saltstack/salt/pull/23003
.. _`#23005`: https://github.com/saltstack/salt/pull/23005
.. _`#23011`: https://github.com/saltstack/salt/pull/23011
.. _`#23024`: https://github.com/saltstack/salt/pull/23024
.. _`#23030`: https://github.com/saltstack/salt/pull/23030
.. _`#23033`: https://github.com/saltstack/salt/pull/23033
.. _`#23036`: https://github.com/saltstack/salt/pull/23036
.. _`#23037`: https://github.com/saltstack/salt/pull/23037
.. _`#23056`: https://github.com/saltstack/salt/pull/23056
.. _`#23058`: https://github.com/saltstack/salt/pull/23058
.. _`#23060`: https://github.com/saltstack/salt/pull/23060
.. _`#23062`: https://github.com/saltstack/salt/pull/23062
.. _`#23064`: https://github.com/saltstack/salt/pull/23064
.. _`#23065`: https://github.com/saltstack/salt/pull/23065
.. _`#23068`: https://github.com/saltstack/salt/issues/23068
.. _`#23069`: https://github.com/saltstack/salt/pull/23069
.. _`#23071`: https://github.com/saltstack/salt/pull/23071
.. _`#23074`: https://github.com/saltstack/salt/pull/23074
.. _`#23075`: https://github.com/saltstack/salt/pull/23075
.. _`#23077`: https://github.com/saltstack/salt/pull/23077
.. _`#23085`: https://github.com/saltstack/salt/issues/23085
.. _`#23088`: https://github.com/saltstack/salt/issues/23088
.. _`#23089`: https://github.com/saltstack/salt/pull/23089
.. _`#23092`: https://github.com/saltstack/salt/pull/23092
.. _`#23096`: https://github.com/saltstack/salt/pull/23096
.. _`#23097`: https://github.com/saltstack/salt/pull/23097
.. _`#23099`: https://github.com/saltstack/salt/pull/23099
.. _`#23101`: https://github.com/saltstack/salt/issues/23101
.. _`#23102`: https://github.com/saltstack/salt/issues/23102
.. _`#23105`: https://github.com/saltstack/salt/pull/23105
.. _`#23109`: https://github.com/saltstack/salt/pull/23109
.. _`#23110`: https://github.com/saltstack/salt/issues/23110
.. _`#23121`: https://github.com/saltstack/salt/pull/23121
.. _`#23124`: https://github.com/saltstack/salt/pull/23124
.. _`#23125`: https://github.com/saltstack/salt/issues/23125
.. _`#23127`: https://github.com/saltstack/salt/pull/23127
.. _`#23136`: https://github.com/saltstack/salt/pull/23136
.. _`#23138`: https://github.com/saltstack/salt/pull/23138
.. _`#23150`: https://github.com/saltstack/salt/pull/23150
.. _`#23152`: https://github.com/saltstack/salt/pull/23152
.. _`#23155`: https://github.com/saltstack/salt/pull/23155
.. _`#23156`: https://github.com/saltstack/salt/pull/23156
.. _`#23160`: https://github.com/saltstack/salt/pull/23160
.. _`#23162`: https://github.com/saltstack/salt/issues/23162
.. _`#23163`: https://github.com/saltstack/salt/pull/23163
.. _`#23164`: https://github.com/saltstack/salt/pull/23164
.. _`#23170`: https://github.com/saltstack/salt/pull/23170
.. _`#23171`: https://github.com/saltstack/salt/pull/23171
.. _`#23174`: https://github.com/saltstack/salt/pull/23174
.. _`#23175`: https://github.com/saltstack/salt/pull/23175
.. _`#23178`: https://github.com/saltstack/salt/pull/23178
.. _`#23182`: https://github.com/saltstack/salt/pull/23182
.. _`#23187`: https://github.com/saltstack/salt/pull/23187
.. _`#23189`: https://github.com/saltstack/salt/pull/23189
.. _`#23197`: https://github.com/saltstack/salt/pull/23197
.. _`#23199`: https://github.com/saltstack/salt/pull/23199
.. _`#23202`: https://github.com/saltstack/salt/pull/23202
.. _`#23203`: https://github.com/saltstack/salt/pull/23203
.. _`#23210`: https://github.com/saltstack/salt/issues/23210
.. _`#23212`: https://github.com/saltstack/salt/pull/23212
.. _`#23213`: https://github.com/saltstack/salt/issues/23213
.. _`#23216`: https://github.com/saltstack/salt/pull/23216
.. _`#23217`: https://github.com/saltstack/salt/pull/23217
.. _`#23219`: https://github.com/saltstack/salt/pull/23219
.. _`#23225`: https://github.com/saltstack/salt/pull/23225
.. _`#23229`: https://github.com/saltstack/salt/pull/23229
.. _`#23230`: https://github.com/saltstack/salt/pull/23230
.. _`#23231`: https://github.com/saltstack/salt/issues/23231
.. _`#23234`: https://github.com/saltstack/salt/pull/23234
.. _`#23235`: https://github.com/saltstack/salt/pull/23235
.. _`#23236`: https://github.com/saltstack/salt/pull/23236
.. _`#23238`: https://github.com/saltstack/salt/pull/23238
.. _`#23240`: https://github.com/saltstack/salt/issues/23240
.. _`#23243`: https://github.com/saltstack/salt/pull/23243
.. _`#23247`: https://github.com/saltstack/salt/issues/23247
.. _`#23248`: https://github.com/saltstack/salt/pull/23248
.. _`#23249`: https://github.com/saltstack/salt/pull/23249
.. _`#23251`: https://github.com/saltstack/salt/pull/23251
.. _`#23252`: https://github.com/saltstack/salt/pull/23252
.. _`#23253`: https://github.com/saltstack/salt/pull/23253
.. _`#23255`: https://github.com/saltstack/salt/pull/23255
.. _`#23260`: https://github.com/saltstack/salt/pull/23260
.. _`#23262`: https://github.com/saltstack/salt/issues/23262
.. _`#23264`: https://github.com/saltstack/salt/issues/23264
.. _`#23265`: https://github.com/saltstack/salt/pull/23265
.. _`#23266`: https://github.com/saltstack/salt/pull/23266
.. _`#23267`: https://github.com/saltstack/salt/pull/23267
.. _`#23268`: https://github.com/saltstack/salt/pull/23268
.. _`#23273`: https://github.com/saltstack/salt/pull/23273
.. _`#23275`: https://github.com/saltstack/salt/pull/23275
.. _`#23276`: https://github.com/saltstack/salt/pull/23276
.. _`#23277`: https://github.com/saltstack/salt/issues/23277
.. _`#23282`: https://github.com/saltstack/salt/pull/23282
.. _`#23283`: https://github.com/saltstack/salt/pull/23283
.. _`#23285`: https://github.com/saltstack/salt/pull/23285
.. _`#23287`: https://github.com/saltstack/salt/pull/23287
.. _`#23289`: https://github.com/saltstack/salt/issues/23289
.. _`#23291`: https://github.com/saltstack/salt/pull/23291
.. _`#23296`: https://github.com/saltstack/salt/pull/23296
.. _`#23299`: https://github.com/saltstack/salt/pull/23299
.. _`#23300`: https://github.com/saltstack/salt/pull/23300
.. _`#23301`: https://github.com/saltstack/salt/issues/23301
.. _`#23305`: https://github.com/saltstack/salt/pull/23305
.. _`#23306`: https://github.com/saltstack/salt/pull/23306
.. _`#23308`: https://github.com/saltstack/salt/pull/23308
.. _`#23309`: https://github.com/saltstack/salt/pull/23309
.. _`#23312`: https://github.com/saltstack/salt/issues/23312
.. _`#23314`: https://github.com/saltstack/salt/pull/23314
.. _`#23322`: https://github.com/saltstack/salt/pull/23322
.. _`#23323`: https://github.com/saltstack/salt/issues/23323
.. _`#23328`: https://github.com/saltstack/salt/pull/23328
.. _`#23333`: https://github.com/saltstack/salt/pull/23333
.. _`#23340`: https://github.com/saltstack/salt/issues/23340
.. _`#23345`: https://github.com/saltstack/salt/pull/23345
.. _`#23346`: https://github.com/saltstack/salt/pull/23346
.. _`#23348`: https://github.com/saltstack/salt/pull/23348
.. _`#23351`: https://github.com/saltstack/salt/pull/23351
.. _`#23353`: https://github.com/saltstack/salt/pull/23353
.. _`#23354`: https://github.com/saltstack/salt/pull/23354
.. _`#23357`: https://github.com/saltstack/salt/pull/23357
.. _`#23359`: https://github.com/saltstack/salt/issues/23359
.. _`#23360`: https://github.com/saltstack/salt/issues/23360
.. _`#23364`: https://github.com/saltstack/salt/issues/23364
.. _`#23366`: https://github.com/saltstack/salt/pull/23366
.. _`#23367`: https://github.com/saltstack/salt/pull/23367
.. _`#23372`: https://github.com/saltstack/salt/pull/23372
.. _`#23373`: https://github.com/saltstack/salt/issues/23373
.. _`#23374`: https://github.com/saltstack/salt/pull/23374
.. _`#23375`: https://github.com/saltstack/salt/pull/23375
.. _`#23378`: https://github.com/saltstack/salt/pull/23378
.. _`#23381`: https://github.com/saltstack/salt/pull/23381
.. _`#23382`: https://github.com/saltstack/salt/pull/23382
.. _`#23383`: https://github.com/saltstack/salt/pull/23383
.. _`#23386`: https://github.com/saltstack/salt/pull/23386
.. _`#23387`: https://github.com/saltstack/salt/pull/23387
.. _`#23388`: https://github.com/saltstack/salt/pull/23388
.. _`#23389`: https://github.com/saltstack/salt/pull/23389
.. _`#23392`: https://github.com/saltstack/salt/pull/23392
.. _`#23394`: https://github.com/saltstack/salt/pull/23394
.. _`#23398`: https://github.com/saltstack/salt/pull/23398
.. _`#23399`: https://github.com/saltstack/salt/pull/23399
.. _`#23400`: https://github.com/saltstack/salt/issues/23400
.. _`#23408`: https://github.com/saltstack/salt/issues/23408
.. _`#23421`: https://github.com/saltstack/salt/pull/23421
.. _`#23424`: https://github.com/saltstack/salt/pull/23424
.. _`#23428`: https://github.com/saltstack/salt/pull/23428
.. _`#23430`: https://github.com/saltstack/salt/pull/23430
.. _`#23436`: https://github.com/saltstack/salt/pull/23436
.. _`#23437`: https://github.com/saltstack/salt/pull/23437
.. _`#23441`: https://github.com/saltstack/salt/pull/23441
.. _`#23442`: https://github.com/saltstack/salt/pull/23442
.. _`#23443`: https://github.com/saltstack/salt/pull/23443
.. _`#23445`: https://github.com/saltstack/salt/pull/23445
.. _`#23446`: https://github.com/saltstack/salt/issues/23446
.. _`#23453`: https://github.com/saltstack/salt/issues/23453
.. _`#23455`: https://github.com/saltstack/salt/pull/23455
.. _`#23456`: https://github.com/saltstack/salt/pull/23456
.. _`#23459`: https://github.com/saltstack/salt/pull/23459
.. _`#23462`: https://github.com/saltstack/salt/pull/23462
.. _`#23465`: https://github.com/saltstack/salt/pull/23465
.. _`#23471`: https://github.com/saltstack/salt/pull/23471
.. _`#23472`: https://github.com/saltstack/salt/pull/23472
.. _`#23475`: https://github.com/saltstack/salt/pull/23475
.. _`#23481`: https://github.com/saltstack/salt/pull/23481
.. _`#23482`: https://github.com/saltstack/salt/pull/23482
.. _`#23484`: https://github.com/saltstack/salt/pull/23484
.. _`#23486`: https://github.com/saltstack/salt/issues/23486
.. _`#23487`: https://github.com/saltstack/salt/pull/23487
.. _`#23496`: https://github.com/saltstack/salt/pull/23496
.. _`#23497`: https://github.com/saltstack/salt/pull/23497
.. _`#23498`: https://github.com/saltstack/salt/pull/23498
.. _`#23499`: https://github.com/saltstack/salt/pull/23499
.. _`#23501`: https://github.com/saltstack/salt/issues/23501
.. _`#23510`: https://github.com/saltstack/salt/pull/23510
.. _`#23511`: https://github.com/saltstack/salt/pull/23511
.. _`#23515`: https://github.com/saltstack/salt/pull/23515
.. _`#23519`: https://github.com/saltstack/salt/pull/23519
.. _`#23521`: https://github.com/saltstack/salt/pull/23521
.. _`#23527`: https://github.com/saltstack/salt/pull/23527
.. _`#23529`: https://github.com/saltstack/salt/issues/23529
.. _`#23541`: https://github.com/saltstack/salt/pull/23541
.. _`#23542`: https://github.com/saltstack/salt/pull/23542
.. _`#23545`: https://github.com/saltstack/salt/pull/23545
.. _`#23549`: https://github.com/saltstack/salt/pull/23549
.. _`#23555`: https://github.com/saltstack/salt/pull/23555
.. _`#23557`: https://github.com/saltstack/salt/pull/23557
.. _`#23559`: https://github.com/saltstack/salt/pull/23559
.. _`#23560`: https://github.com/saltstack/salt/pull/23560
.. _`#23561`: https://github.com/saltstack/salt/pull/23561
.. _`#23562`: https://github.com/saltstack/salt/pull/23562
.. _`#23563`: https://github.com/saltstack/salt/issues/23563
.. _`#23568`: https://github.com/saltstack/salt/pull/23568
.. _`#23571`: https://github.com/saltstack/salt/pull/23571
.. _`#23574`: https://github.com/saltstack/salt/issues/23574
.. _`#23577`: https://github.com/saltstack/salt/pull/23577
.. _`#23578`: https://github.com/saltstack/salt/pull/23578
.. _`#23584`: https://github.com/saltstack/salt/pull/23584
.. _`#23586`: https://github.com/saltstack/salt/pull/23586
.. _`#23591`: https://github.com/saltstack/salt/pull/23591
.. _`#23596`: https://github.com/saltstack/salt/pull/23596
.. _`#23604`: https://github.com/saltstack/salt/issues/23604
.. _`#23607`: https://github.com/saltstack/salt/pull/23607
.. _`#23608`: https://github.com/saltstack/salt/issues/23608
.. _`#23609`: https://github.com/saltstack/salt/pull/23609
.. _`#23613`: https://github.com/saltstack/salt/issues/23613
.. _`#23614`: https://github.com/saltstack/salt/pull/23614
.. _`#23620`: https://github.com/saltstack/salt/pull/23620
.. _`#23625`: https://github.com/saltstack/salt/pull/23625
.. _`#23626`: https://github.com/saltstack/salt/issues/23626
.. _`#23629`: https://github.com/saltstack/salt/issues/23629
.. _`#23632`: https://github.com/saltstack/salt/pull/23632
.. _`#23633`: https://github.com/saltstack/salt/pull/23633
.. _`#23634`: https://github.com/saltstack/salt/pull/23634
.. _`#23635`: https://github.com/saltstack/salt/pull/23635
.. _`#23645`: https://github.com/saltstack/salt/pull/23645
.. _`#23656`: https://github.com/saltstack/salt/pull/23656
.. _`#23657`: https://github.com/saltstack/salt/issues/23657
.. _`#23658`: https://github.com/saltstack/salt/issues/23658
.. _`#23660`: https://github.com/saltstack/salt/pull/23660
.. _`#23665`: https://github.com/saltstack/salt/pull/23665
.. _`#23668`: https://github.com/saltstack/salt/pull/23668
.. _`#23671`: https://github.com/saltstack/salt/pull/23671
.. _`#23676`: https://github.com/saltstack/salt/pull/23676
.. _`#23684`: https://github.com/saltstack/salt/pull/23684
.. _`#23691`: https://github.com/saltstack/salt/pull/23691
.. _`#23692`: https://github.com/saltstack/salt/pull/23692
.. _`#23693`: https://github.com/saltstack/salt/pull/23693
.. _`#23695`: https://github.com/saltstack/salt/issues/23695
.. _`#23696`: https://github.com/saltstack/salt/issues/23696
.. _`#23697`: https://github.com/saltstack/salt/pull/23697
.. _`#23701`: https://github.com/saltstack/salt/pull/23701
.. _`#23713`: https://github.com/saltstack/salt/issues/23713
.. _`#23715`: https://github.com/saltstack/salt/issues/23715
.. _`#23716`: https://github.com/saltstack/salt/pull/23716
.. _`#23717`: https://github.com/saltstack/salt/pull/23717
.. _`#23719`: https://github.com/saltstack/salt/pull/23719
.. _`#23721`: https://github.com/saltstack/salt/pull/23721
.. _`#23726`: https://github.com/saltstack/salt/pull/23726
.. _`#23729`: https://github.com/saltstack/salt/pull/23729
.. _`#23732`: https://github.com/saltstack/salt/pull/23732
.. _`#23734`: https://github.com/saltstack/salt/issues/23734
.. _`#23737`: https://github.com/saltstack/salt/pull/23737
.. _`#23738`: https://github.com/saltstack/salt/issues/23738
.. _`#23739`: https://github.com/saltstack/salt/pull/23739
.. _`#23746`: https://github.com/saltstack/salt/issues/23746
.. _`#23747`: https://github.com/saltstack/salt/pull/23747
.. _`#23749`: https://github.com/saltstack/salt/pull/23749
.. _`#23750`: https://github.com/saltstack/salt/pull/23750
.. _`#23754`: https://github.com/saltstack/salt/pull/23754
.. _`#23755`: https://github.com/saltstack/salt/pull/23755
.. _`#23756`: https://github.com/saltstack/salt/pull/23756
.. _`#23757`: https://github.com/saltstack/salt/pull/23757
.. _`#23764`: https://github.com/saltstack/salt/issues/23764
.. _`#23772`: https://github.com/saltstack/salt/issues/23772
.. _`#23773`: https://github.com/saltstack/salt/pull/23773
.. _`#23777`: https://github.com/saltstack/salt/pull/23777
.. _`#23784`: https://github.com/saltstack/salt/pull/23784
.. _`#23786`: https://github.com/saltstack/salt/pull/23786
.. _`#23790`: https://github.com/saltstack/salt/pull/23790
.. _`#23803`: https://github.com/saltstack/salt/pull/23803
.. _`#23804`: https://github.com/saltstack/salt/pull/23804
.. _`#23806`: https://github.com/saltstack/salt/pull/23806
.. _`#23807`: https://github.com/saltstack/salt/pull/23807
.. _`#23808`: https://github.com/saltstack/salt/pull/23808
.. _`#23813`: https://github.com/saltstack/salt/pull/23813
.. _`#23818`: https://github.com/saltstack/salt/issues/23818
.. _`#23822`: https://github.com/saltstack/salt/issues/23822
.. _`#23824`: https://github.com/saltstack/salt/issues/23824
.. _`#23825`: https://github.com/saltstack/salt/pull/23825
.. _`#23826`: https://github.com/saltstack/salt/issues/23826
.. _`#23827`: https://github.com/saltstack/salt/pull/23827
.. _`#23833`: https://github.com/saltstack/salt/issues/23833
.. _`#23834`: https://github.com/saltstack/salt/pull/23834
.. _`#23836`: https://github.com/saltstack/salt/pull/23836
.. _`#23837`: https://github.com/saltstack/salt/pull/23837
.. _`#23838`: https://github.com/saltstack/salt/pull/23838
.. _`#23839`: https://github.com/saltstack/salt/issues/23839
.. _`#23841`: https://github.com/saltstack/salt/pull/23841
.. _`#23846`: https://github.com/saltstack/salt/pull/23846
.. _`#23847`: https://github.com/saltstack/salt/issues/23847
.. _`#23848`: https://github.com/saltstack/salt/pull/23848
.. _`#23849`: https://github.com/saltstack/salt/pull/23849
.. _`#23851`: https://github.com/saltstack/salt/pull/23851
.. _`#23856`: https://github.com/saltstack/salt/issues/23856
.. _`#23857`: https://github.com/saltstack/salt/pull/23857
.. _`#23865`: https://github.com/saltstack/salt/pull/23865
.. _`#23867`: https://github.com/saltstack/salt/pull/23867
.. _`#23869`: https://github.com/saltstack/salt/pull/23869
.. _`#23870`: https://github.com/saltstack/salt/pull/23870
.. _`#23877`: https://github.com/saltstack/salt/pull/23877
.. _`#23878`: https://github.com/saltstack/salt/pull/23878
.. _`#23880`: https://github.com/saltstack/salt/pull/23880
.. _`#23883`: https://github.com/saltstack/salt/issues/23883
.. _`#23893`: https://github.com/saltstack/salt/pull/23893
.. _`#23896`: https://github.com/saltstack/salt/pull/23896
.. _`#23897`: https://github.com/saltstack/salt/pull/23897
.. _`#23898`: https://github.com/saltstack/salt/pull/23898
.. _`#23902`: https://github.com/saltstack/salt/pull/23902
.. _`#23906`: https://github.com/saltstack/salt/pull/23906
.. _`#23908`: https://github.com/saltstack/salt/pull/23908
.. _`#23911`: https://github.com/saltstack/salt/issues/23911
.. _`#23912`: https://github.com/saltstack/salt/pull/23912
.. _`#23913`: https://github.com/saltstack/salt/pull/23913
.. _`#23915`: https://github.com/saltstack/salt/pull/23915
.. _`#23918`: https://github.com/saltstack/salt/issues/23918
.. _`#23919`: https://github.com/saltstack/salt/pull/23919
.. _`#23920`: https://github.com/saltstack/salt/pull/23920
.. _`#23923`: https://github.com/saltstack/salt/pull/23923
.. _`#23926`: https://github.com/saltstack/salt/pull/23926
.. _`#23930`: https://github.com/saltstack/salt/pull/23930
.. _`#23934`: https://github.com/saltstack/salt/pull/23934
.. _`#23937`: https://github.com/saltstack/salt/pull/23937
.. _`#23938`: https://github.com/saltstack/salt/pull/23938
.. _`#23944`: https://github.com/saltstack/salt/pull/23944
.. _`#23949`: https://github.com/saltstack/salt/pull/23949
.. _`#23950`: https://github.com/saltstack/salt/issues/23950
.. _`#23951`: https://github.com/saltstack/salt/pull/23951
.. _`#23953`: https://github.com/saltstack/salt/issues/23953
.. _`#23954`: https://github.com/saltstack/salt/pull/23954
.. _`#23959`: https://github.com/saltstack/salt/pull/23959
.. _`#23962`: https://github.com/saltstack/salt/pull/23962
.. _`#23964`: https://github.com/saltstack/salt/pull/23964
.. _`#23968`: https://github.com/saltstack/salt/pull/23968
.. _`#23972`: https://github.com/saltstack/salt/pull/23972
.. _`#23974`: https://github.com/saltstack/salt/pull/23974
.. _`#23975`: https://github.com/saltstack/salt/pull/23975
.. _`#23977`: https://github.com/saltstack/salt/pull/23977
.. _`#23978`: https://github.com/saltstack/salt/pull/23978
.. _`#23980`: https://github.com/saltstack/salt/pull/23980
.. _`#23981`: https://github.com/saltstack/salt/pull/23981
.. _`#23982`: https://github.com/saltstack/salt/pull/23982
.. _`#23984`: https://github.com/saltstack/salt/pull/23984
.. _`#23990`: https://github.com/saltstack/salt/pull/23990
.. _`#23991`: https://github.com/saltstack/salt/pull/23991
.. _`#23999`: https://github.com/saltstack/salt/pull/23999
.. _`#24000`: https://github.com/saltstack/salt/pull/24000
.. _`#24007`: https://github.com/saltstack/salt/pull/24007
.. _`#24011`: https://github.com/saltstack/salt/pull/24011
.. _`#24012`: https://github.com/saltstack/salt/issues/24012
.. _`#24013`: https://github.com/saltstack/salt/pull/24013
.. _`#24014`: https://github.com/saltstack/salt/pull/24014
.. _`#24015`: https://github.com/saltstack/salt/pull/24015
.. _`#24026`: https://github.com/saltstack/salt/pull/24026
.. _`#24027`: https://github.com/saltstack/salt/pull/24027
.. _`#24041`: https://github.com/saltstack/salt/pull/24041
.. _`#24051`: https://github.com/saltstack/salt/pull/24051
.. _`#24053`: https://github.com/saltstack/salt/pull/24053
.. _`#24054`: https://github.com/saltstack/salt/pull/24054
.. _`#24055`: https://github.com/saltstack/salt/pull/24055
.. _`#24056`: https://github.com/saltstack/salt/issues/24056
.. _`#24061`: https://github.com/saltstack/salt/pull/24061
.. _`#24065`: https://github.com/saltstack/salt/pull/24065
.. _`#24066`: https://github.com/saltstack/salt/pull/24066
.. _`#24067`: https://github.com/saltstack/salt/pull/24067
.. _`#24069`: https://github.com/saltstack/salt/pull/24069
.. _`#24072`: https://github.com/saltstack/salt/pull/24072
.. _`#24073`: https://github.com/saltstack/salt/issues/24073
.. _`#24075`: https://github.com/saltstack/salt/pull/24075
.. _`#24076`: https://github.com/saltstack/salt/pull/24076
.. _`#24079`: https://github.com/saltstack/salt/pull/24079
.. _`#24080`: https://github.com/saltstack/salt/pull/24080
.. _`#24081`: https://github.com/saltstack/salt/pull/24081
.. _`#24082`: https://github.com/saltstack/salt/issues/24082
.. _`#24083`: https://github.com/saltstack/salt/pull/24083
.. _`#24084`: https://github.com/saltstack/salt/pull/24084
.. _`#24085`: https://github.com/saltstack/salt/issues/24085
.. _`#24087`: https://github.com/saltstack/salt/pull/24087
.. _`#24091`: https://github.com/saltstack/salt/pull/24091
.. _`#24096`: https://github.com/saltstack/salt/issues/24096
.. _`#24103`: https://github.com/saltstack/salt/pull/24103
.. _`#24104`: https://github.com/saltstack/salt/pull/24104
.. _`#24105`: https://github.com/saltstack/salt/pull/24105
.. _`#24116`: https://github.com/saltstack/salt/pull/24116
.. _`#24118`: https://github.com/saltstack/salt/pull/24118
.. _`#24124`: https://github.com/saltstack/salt/pull/24124
.. _`#24129`: https://github.com/saltstack/salt/pull/24129
.. _`#24143`: https://github.com/saltstack/salt/pull/24143
.. _`#24151`: https://github.com/saltstack/salt/issues/24151
.. _`#24152`: https://github.com/saltstack/salt/pull/24152
.. _`#24155`: https://github.com/saltstack/salt/pull/24155
.. _`#24157`: https://github.com/saltstack/salt/pull/24157
.. _`#24168`: https://github.com/saltstack/salt/pull/24168
.. _`#2417`: https://github.com/saltstack/salt/issues/2417
.. _`#24170`: https://github.com/saltstack/salt/pull/24170
.. _`#24173`: https://github.com/saltstack/salt/pull/24173
.. _`#24176`: https://github.com/saltstack/salt/issues/24176
.. _`#24182`: https://github.com/saltstack/salt/pull/24182
.. _`#24186`: https://github.com/saltstack/salt/pull/24186
.. _`#24187`: https://github.com/saltstack/salt/pull/24187
.. _`#24188`: https://github.com/saltstack/salt/pull/24188
.. _`#24205`: https://github.com/saltstack/salt/pull/24205
.. _`#24210`: https://github.com/saltstack/salt/issues/24210
.. _`#24218`: https://github.com/saltstack/salt/pull/24218
.. _`#24220`: https://github.com/saltstack/salt/pull/24220
.. _`#24221`: https://github.com/saltstack/salt/pull/24221
.. _`#24223`: https://github.com/saltstack/salt/pull/24223
.. _`#24224`: https://github.com/saltstack/salt/pull/24224
.. _`#24228`: https://github.com/saltstack/salt/pull/24228
.. _`#24230`: https://github.com/saltstack/salt/pull/24230
.. _`#24236`: https://github.com/saltstack/salt/pull/24236
.. _`#24242`: https://github.com/saltstack/salt/pull/24242
.. _`#24244`: https://github.com/saltstack/salt/pull/24244
.. _`#24248`: https://github.com/saltstack/salt/pull/24248
.. _`#24249`: https://github.com/saltstack/salt/pull/24249
.. _`#24256`: https://github.com/saltstack/salt/pull/24256
.. _`#24261`: https://github.com/saltstack/salt/pull/24261
.. _`#24263`: https://github.com/saltstack/salt/pull/24263
.. _`#24264`: https://github.com/saltstack/salt/pull/24264
.. _`#24265`: https://github.com/saltstack/salt/pull/24265
.. _`#24266`: https://github.com/saltstack/salt/pull/24266
.. _`#24267`: https://github.com/saltstack/salt/pull/24267
.. _`#24270`: https://github.com/saltstack/salt/pull/24270
.. _`#24271`: https://github.com/saltstack/salt/pull/24271
.. _`#24272`: https://github.com/saltstack/salt/issues/24272
.. _`#24278`: https://github.com/saltstack/salt/pull/24278
.. _`#24282`: https://github.com/saltstack/salt/pull/24282
.. _`#24285`: https://github.com/saltstack/salt/pull/24285
.. _`#24293`: https://github.com/saltstack/salt/pull/24293
.. _`#24295`: https://github.com/saltstack/salt/issues/24295
.. _`#24300`: https://github.com/saltstack/salt/pull/24300
.. _`#24301`: https://github.com/saltstack/salt/issues/24301
.. _`#24306`: https://github.com/saltstack/salt/pull/24306
.. _`#24307`: https://github.com/saltstack/salt/pull/24307
.. _`#24311`: https://github.com/saltstack/salt/issues/24311
.. _`#24315`: https://github.com/saltstack/salt/pull/24315
.. _`#24316`: https://github.com/saltstack/salt/pull/24316
.. _`#24321`: https://github.com/saltstack/salt/pull/24321
.. _`#24323`: https://github.com/saltstack/salt/issues/24323
.. _`#24324`: https://github.com/saltstack/salt/pull/24324
.. _`#24325`: https://github.com/saltstack/salt/pull/24325
.. _`#24329`: https://github.com/saltstack/salt/pull/24329
.. _`#24331`: https://github.com/saltstack/salt/pull/24331
.. _`#24332`: https://github.com/saltstack/salt/pull/24332
.. _`#24333`: https://github.com/saltstack/salt/pull/24333
.. _`#24335`: https://github.com/saltstack/salt/pull/24335
.. _`#24339`: https://github.com/saltstack/salt/pull/24339
.. _`#24341`: https://github.com/saltstack/salt/pull/24341
.. _`#24347`: https://github.com/saltstack/salt/pull/24347
.. _`#24353`: https://github.com/saltstack/salt/pull/24353
.. _`#24356`: https://github.com/saltstack/salt/pull/24356
.. _`#24357`: https://github.com/saltstack/salt/pull/24357
.. _`#24360`: https://github.com/saltstack/salt/pull/24360
.. _`#24361`: https://github.com/saltstack/salt/pull/24361
.. _`#24362`: https://github.com/saltstack/salt/pull/24362
.. _`#24364`: https://github.com/saltstack/salt/pull/24364
.. _`#24370`: https://github.com/saltstack/salt/issues/24370
.. _`#24373`: https://github.com/saltstack/salt/pull/24373
.. _`#24377`: https://github.com/saltstack/salt/pull/24377
.. _`#24391`: https://github.com/saltstack/salt/issues/24391
.. _`#24392`: https://github.com/saltstack/salt/pull/24392
.. _`#24393`: https://github.com/saltstack/salt/pull/24393
.. _`#24404`: https://github.com/saltstack/salt/pull/24404
.. _`#24407`: https://github.com/saltstack/salt/issues/24407
.. _`#24410`: https://github.com/saltstack/salt/pull/24410
.. _`#24411`: https://github.com/saltstack/salt/issues/24411
.. _`#24414`: https://github.com/saltstack/salt/pull/24414
.. _`#24415`: https://github.com/saltstack/salt/pull/24415
.. _`#24417`: https://github.com/saltstack/salt/pull/24417
.. _`#24418`: https://github.com/saltstack/salt/pull/24418
.. _`#24420`: https://github.com/saltstack/salt/pull/24420
.. _`#24421`: https://github.com/saltstack/salt/pull/24421
.. _`#24422`: https://github.com/saltstack/salt/pull/24422
.. _`#24423`: https://github.com/saltstack/salt/pull/24423
.. _`#24424`: https://github.com/saltstack/salt/pull/24424
.. _`#24425`: https://github.com/saltstack/salt/pull/24425
.. _`#24431`: https://github.com/saltstack/salt/pull/24431
.. _`#24432`: https://github.com/saltstack/salt/pull/24432
.. _`#24433`: https://github.com/saltstack/salt/issues/24433
.. _`#24441`: https://github.com/saltstack/salt/pull/24441
.. _`#24442`: https://github.com/saltstack/salt/pull/24442
.. _`#24444`: https://github.com/saltstack/salt/issues/24444
.. _`#24448`: https://github.com/saltstack/salt/pull/24448
.. _`#24450`: https://github.com/saltstack/salt/pull/24450
.. _`#24453`: https://github.com/saltstack/salt/pull/24453
.. _`#24454`: https://github.com/saltstack/salt/pull/24454
.. _`#24459`: https://github.com/saltstack/salt/pull/24459
.. _`#24470`: https://github.com/saltstack/salt/pull/24470
.. _`#24476`: https://github.com/saltstack/salt/pull/24476
.. _`#24478`: https://github.com/saltstack/salt/pull/24478
.. _`#24480`: https://github.com/saltstack/salt/issues/24480
.. _`#24487`: https://github.com/saltstack/salt/pull/24487
.. _`#24489`: https://github.com/saltstack/salt/pull/24489
.. _`#24492`: https://github.com/saltstack/salt/pull/24492
.. _`#24494`: https://github.com/saltstack/salt/issues/24494
.. _`#24499`: https://github.com/saltstack/salt/pull/24499
.. _`#24500`: https://github.com/saltstack/salt/pull/24500
.. _`#24503`: https://github.com/saltstack/salt/pull/24503
.. _`#24505`: https://github.com/saltstack/salt/pull/24505
.. _`#24507`: https://github.com/saltstack/salt/pull/24507
.. _`#24508`: https://github.com/saltstack/salt/pull/24508
.. _`#24509`: https://github.com/saltstack/salt/pull/24509
.. _`#24511`: https://github.com/saltstack/salt/pull/24511
.. _`#24514`: https://github.com/saltstack/salt/pull/24514
.. _`#24516`: https://github.com/saltstack/salt/pull/24516
.. _`#24518`: https://github.com/saltstack/salt/pull/24518
.. _`#24519`: https://github.com/saltstack/salt/pull/24519
.. _`#24520`: https://github.com/saltstack/salt/issues/24520
.. _`#24531`: https://github.com/saltstack/salt/pull/24531
.. _`#24532`: https://github.com/saltstack/salt/pull/24532
.. _`#24534`: https://github.com/saltstack/salt/pull/24534
.. _`#24536`: https://github.com/saltstack/salt/pull/24536
.. _`#24539`: https://github.com/saltstack/salt/pull/24539
.. _`#24542`: https://github.com/saltstack/salt/pull/24542
.. _`#24543`: https://github.com/saltstack/salt/pull/24543
.. _`#24544`: https://github.com/saltstack/salt/pull/24544
.. _`#24545`: https://github.com/saltstack/salt/pull/24545
.. _`#24549`: https://github.com/saltstack/salt/pull/24549
.. _`#24550`: https://github.com/saltstack/salt/pull/24550
.. _`#24552`: https://github.com/saltstack/salt/pull/24552
.. _`#24557`: https://github.com/saltstack/salt/pull/24557
.. _`#24559`: https://github.com/saltstack/salt/issues/24559
.. _`#24569`: https://github.com/saltstack/salt/pull/24569
.. _`#24570`: https://github.com/saltstack/salt/pull/24570
.. _`#24576`: https://github.com/saltstack/salt/pull/24576
.. _`#24582`: https://github.com/saltstack/salt/pull/24582
.. _`#24584`: https://github.com/saltstack/salt/pull/24584
.. _`#24590`: https://github.com/saltstack/salt/pull/24590
.. _`#24591`: https://github.com/saltstack/salt/pull/24591
.. _`#24597`: https://github.com/saltstack/salt/pull/24597
.. _`#24599`: https://github.com/saltstack/salt/pull/24599
.. _`#24602`: https://github.com/saltstack/salt/pull/24602
.. _`#24606`: https://github.com/saltstack/salt/pull/24606
.. _`#24610`: https://github.com/saltstack/salt/pull/24610
.. _`#24612`: https://github.com/saltstack/salt/issues/24612
.. _`#24614`: https://github.com/saltstack/salt/pull/24614
.. _`#24615`: https://github.com/saltstack/salt/pull/24615
.. _`#24618`: https://github.com/saltstack/salt/pull/24618
.. _`#24625`: https://github.com/saltstack/salt/pull/24625
.. _`#24629`: https://github.com/saltstack/salt/pull/24629
.. _`#24633`: https://github.com/saltstack/salt/pull/24633
.. _`#24634`: https://github.com/saltstack/salt/pull/24634
.. _`#24635`: https://github.com/saltstack/salt/pull/24635
.. _`#24636`: https://github.com/saltstack/salt/pull/24636
.. _`#24640`: https://github.com/saltstack/salt/pull/24640
.. _`#24641`: https://github.com/saltstack/salt/pull/24641
.. _`#24645`: https://github.com/saltstack/salt/pull/24645
.. _`#24647`: https://github.com/saltstack/salt/issues/24647
.. _`#24652`: https://github.com/saltstack/salt/pull/24652
.. _`#24656`: https://github.com/saltstack/salt/pull/24656
.. _`#24657`: https://github.com/saltstack/salt/pull/24657
.. _`#24662`: https://github.com/saltstack/salt/pull/24662
.. _`#24665`: https://github.com/saltstack/salt/issues/24665
.. _`#24668`: https://github.com/saltstack/salt/pull/24668
.. _`#24672`: https://github.com/saltstack/salt/pull/24672
.. _`#24675`: https://github.com/saltstack/salt/pull/24675
.. _`#24678`: https://github.com/saltstack/salt/pull/24678
.. _`#24679`: https://github.com/saltstack/salt/pull/24679
.. _`#24681`: https://github.com/saltstack/salt/pull/24681
.. _`#24682`: https://github.com/saltstack/salt/pull/24682
.. _`#24684`: https://github.com/saltstack/salt/pull/24684
.. _`#24685`: https://github.com/saltstack/salt/pull/24685
.. _`#24686`: https://github.com/saltstack/salt/pull/24686
.. _`#24691`: https://github.com/saltstack/salt/pull/24691
.. _`#24692`: https://github.com/saltstack/salt/pull/24692
.. _`#24700`: https://github.com/saltstack/salt/pull/24700
.. _`#24703`: https://github.com/saltstack/salt/pull/24703
.. _`#24705`: https://github.com/saltstack/salt/pull/24705
.. _`#24706`: https://github.com/saltstack/salt/pull/24706
.. _`#24707`: https://github.com/saltstack/salt/pull/24707
.. _`#24709`: https://github.com/saltstack/salt/pull/24709
.. _`#24710`: https://github.com/saltstack/salt/pull/24710
.. _`#24715`: https://github.com/saltstack/salt/pull/24715
.. _`#24717`: https://github.com/saltstack/salt/pull/24717
.. _`#24720`: https://github.com/saltstack/salt/pull/24720
.. _`#24725`: https://github.com/saltstack/salt/pull/24725
.. _`#24726`: https://github.com/saltstack/salt/pull/24726
.. _`#24728`: https://github.com/saltstack/salt/pull/24728
.. _`#24729`: https://github.com/saltstack/salt/pull/24729
.. _`#24734`: https://github.com/saltstack/salt/pull/24734
.. _`#24735`: https://github.com/saltstack/salt/pull/24735
.. _`#24737`: https://github.com/saltstack/salt/pull/24737
.. _`#24741`: https://github.com/saltstack/salt/pull/24741
.. _`#24742`: https://github.com/saltstack/salt/pull/24742
.. _`#24743`: https://github.com/saltstack/salt/pull/24743
.. _`#24749`: https://github.com/saltstack/salt/pull/24749
.. _`#24756`: https://github.com/saltstack/salt/pull/24756
.. _`#24757`: https://github.com/saltstack/salt/pull/24757
.. _`#24760`: https://github.com/saltstack/salt/pull/24760
.. _`#24762`: https://github.com/saltstack/salt/pull/24762
.. _`#24763`: https://github.com/saltstack/salt/pull/24763
.. _`#24764`: https://github.com/saltstack/salt/pull/24764
.. _`#24765`: https://github.com/saltstack/salt/pull/24765
.. _`#24767`: https://github.com/saltstack/salt/pull/24767
.. _`#24772`: https://github.com/saltstack/salt/pull/24772
.. _`#24776`: https://github.com/saltstack/salt/issues/24776
.. _`#24777`: https://github.com/saltstack/salt/pull/24777
.. _`#24778`: https://github.com/saltstack/salt/pull/24778
.. _`#24779`: https://github.com/saltstack/salt/pull/24779
.. _`#24785`: https://github.com/saltstack/salt/pull/24785
.. _`#24786`: https://github.com/saltstack/salt/pull/24786
.. _`#24787`: https://github.com/saltstack/salt/issues/24787
.. _`#24788`: https://github.com/saltstack/salt/pull/24788
.. _`#24794`: https://github.com/saltstack/salt/pull/24794
.. _`#24796`: https://github.com/saltstack/salt/pull/24796
.. _`#24798`: https://github.com/saltstack/salt/pull/24798
.. _`#24799`: https://github.com/saltstack/salt/issues/24799
.. _`#24801`: https://github.com/saltstack/salt/pull/24801
.. _`#24804`: https://github.com/saltstack/salt/pull/24804
.. _`#24805`: https://github.com/saltstack/salt/pull/24805
.. _`#24806`: https://github.com/saltstack/salt/pull/24806
.. _`#24807`: https://github.com/saltstack/salt/pull/24807
.. _`#24808`: https://github.com/saltstack/salt/pull/24808
.. _`#24810`: https://github.com/saltstack/salt/pull/24810
.. _`#24811`: https://github.com/saltstack/salt/pull/24811
.. _`#24812`: https://github.com/saltstack/salt/pull/24812
.. _`#24815`: https://github.com/saltstack/salt/pull/24815
.. _`#24817`: https://github.com/saltstack/salt/pull/24817
.. _`#24825`: https://github.com/saltstack/salt/pull/24825
.. _`#24827`: https://github.com/saltstack/salt/issues/24827
.. _`#24831`: https://github.com/saltstack/salt/pull/24831
.. _`#24833`: https://github.com/saltstack/salt/pull/24833
.. _`#24835`: https://github.com/saltstack/salt/pull/24835
.. _`#24837`: https://github.com/saltstack/salt/pull/24837
.. _`#24838`: https://github.com/saltstack/salt/pull/24838
.. _`#24839`: https://github.com/saltstack/salt/pull/24839
.. _`#24840`: https://github.com/saltstack/salt/pull/24840
.. _`#24843`: https://github.com/saltstack/salt/pull/24843
.. _`#24844`: https://github.com/saltstack/salt/pull/24844
.. _`#24845`: https://github.com/saltstack/salt/pull/24845
.. _`#24847`: https://github.com/saltstack/salt/pull/24847
.. _`#24848`: https://github.com/saltstack/salt/pull/24848
.. _`#24857`: https://github.com/saltstack/salt/pull/24857
.. _`#24864`: https://github.com/saltstack/salt/pull/24864
.. _`#24866`: https://github.com/saltstack/salt/pull/24866
.. _`#24867`: https://github.com/saltstack/salt/pull/24867
.. _`#24868`: https://github.com/saltstack/salt/pull/24868
.. _`#24876`: https://github.com/saltstack/salt/issues/24876
.. _`#24877`: https://github.com/saltstack/salt/pull/24877
.. _`#24881`: https://github.com/saltstack/salt/pull/24881
.. _`#24883`: https://github.com/saltstack/salt/pull/24883
.. _`#24887`: https://github.com/saltstack/salt/pull/24887
.. _`#24889`: https://github.com/saltstack/salt/pull/24889
.. _`#24890`: https://github.com/saltstack/salt/pull/24890
.. _`#24894`: https://github.com/saltstack/salt/pull/24894
.. _`#24896`: https://github.com/saltstack/salt/pull/24896
.. _`#24904`: https://github.com/saltstack/salt/issues/24904
.. _`#24908`: https://github.com/saltstack/salt/pull/24908
.. _`#24911`: https://github.com/saltstack/salt/pull/24911
.. _`#24912`: https://github.com/saltstack/salt/issues/24912
.. _`#24913`: https://github.com/saltstack/salt/pull/24913
.. _`#24916`: https://github.com/saltstack/salt/pull/24916
.. _`#24917`: https://github.com/saltstack/salt/pull/24917
.. _`#24922`: https://github.com/saltstack/salt/pull/24922
.. _`#24927`: https://github.com/saltstack/salt/pull/24927
.. _`#24928`: https://github.com/saltstack/salt/pull/24928
.. _`#24931`: https://github.com/saltstack/salt/pull/24931
.. _`#24932`: https://github.com/saltstack/salt/pull/24932
.. _`#24933`: https://github.com/saltstack/salt/pull/24933
.. _`#24937`: https://github.com/saltstack/salt/pull/24937
.. _`#24946`: https://github.com/saltstack/salt/pull/24946
.. _`#24952`: https://github.com/saltstack/salt/pull/24952
.. _`#24954`: https://github.com/saltstack/salt/pull/24954
.. _`#24957`: https://github.com/saltstack/salt/pull/24957
.. _`#24963`: https://github.com/saltstack/salt/pull/24963
.. _`#24967`: https://github.com/saltstack/salt/pull/24967
.. _`#24970`: https://github.com/saltstack/salt/pull/24970
.. _`#24971`: https://github.com/saltstack/salt/pull/24971
.. _`#24972`: https://github.com/saltstack/salt/pull/24972
.. _`#24973`: https://github.com/saltstack/salt/pull/24973
.. _`#24974`: https://github.com/saltstack/salt/pull/24974
.. _`#24976`: https://github.com/saltstack/salt/pull/24976
.. _`#24979`: https://github.com/saltstack/salt/issues/24979
.. _`#24980`: https://github.com/saltstack/salt/pull/24980
.. _`#24982`: https://github.com/saltstack/salt/pull/24982
.. _`#24984`: https://github.com/saltstack/salt/pull/24984
.. _`#24989`: https://github.com/saltstack/salt/pull/24989
.. _`#24993`: https://github.com/saltstack/salt/pull/24993
.. _`#24998`: https://github.com/saltstack/salt/pull/24998
.. _`#25001`: https://github.com/saltstack/salt/pull/25001
.. _`#25008`: https://github.com/saltstack/salt/pull/25008
.. _`#25009`: https://github.com/saltstack/salt/pull/25009
.. _`#25012`: https://github.com/saltstack/salt/pull/25012
.. _`#25015`: https://github.com/saltstack/salt/pull/25015
.. _`#25016`: https://github.com/saltstack/salt/issues/25016
.. _`#25017`: https://github.com/saltstack/salt/pull/25017
.. _`#25019`: https://github.com/saltstack/salt/pull/25019
.. _`#25020`: https://github.com/saltstack/salt/pull/25020
.. _`#25021`: https://github.com/saltstack/salt/pull/25021
.. _`#25023`: https://github.com/saltstack/salt/pull/25023
.. _`#25032`: https://github.com/saltstack/salt/pull/25032
.. _`#25034`: https://github.com/saltstack/salt/pull/25034
.. _`#25035`: https://github.com/saltstack/salt/pull/25035
.. _`#25037`: https://github.com/saltstack/salt/pull/25037
.. _`#25039`: https://github.com/saltstack/salt/pull/25039
.. _`#25043`: https://github.com/saltstack/salt/issues/25043
.. _`#25044`: https://github.com/saltstack/salt/pull/25044
.. _`#25046`: https://github.com/saltstack/salt/pull/25046
.. _`#25048`: https://github.com/saltstack/salt/pull/25048
.. _`#25050`: https://github.com/saltstack/salt/pull/25050
.. _`#25054`: https://github.com/saltstack/salt/issues/25054
.. _`#25055`: https://github.com/saltstack/salt/pull/25055
.. _`#25056`: https://github.com/saltstack/salt/pull/25056
.. _`#25059`: https://github.com/saltstack/salt/pull/25059
.. _`#25066`: https://github.com/saltstack/salt/pull/25066
.. _`#25069`: https://github.com/saltstack/salt/pull/25069
.. _`#25071`: https://github.com/saltstack/salt/pull/25071
.. _`#25072`: https://github.com/saltstack/salt/pull/25072
.. _`#25074`: https://github.com/saltstack/salt/pull/25074
.. _`#25080`: https://github.com/saltstack/salt/pull/25080
.. _`#25081`: https://github.com/saltstack/salt/pull/25081
.. _`#25082`: https://github.com/saltstack/salt/pull/25082
.. _`#25086`: https://github.com/saltstack/salt/pull/25086
.. _`#25087`: https://github.com/saltstack/salt/pull/25087
.. _`#25088`: https://github.com/saltstack/salt/pull/25088
.. _`#25092`: https://github.com/saltstack/salt/pull/25092
.. _`#25093`: https://github.com/saltstack/salt/pull/25093
.. _`#25102`: https://github.com/saltstack/salt/pull/25102
.. _`#25103`: https://github.com/saltstack/salt/pull/25103
.. _`#25106`: https://github.com/saltstack/salt/pull/25106
.. _`#25114`: https://github.com/saltstack/salt/pull/25114
.. _`#25117`: https://github.com/saltstack/salt/pull/25117
.. _`#25120`: https://github.com/saltstack/salt/pull/25120
.. _`#25126`: https://github.com/saltstack/salt/pull/25126
.. _`#25128`: https://github.com/saltstack/salt/pull/25128
.. _`#25129`: https://github.com/saltstack/salt/pull/25129
.. _`#25130`: https://github.com/saltstack/salt/pull/25130
.. _`#25131`: https://github.com/saltstack/salt/pull/25131
.. _`#25140`: https://github.com/saltstack/salt/pull/25140
.. _`#25145`: https://github.com/saltstack/salt/pull/25145
.. _`#25149`: https://github.com/saltstack/salt/pull/25149
.. _`#25151`: https://github.com/saltstack/salt/pull/25151
.. _`#25158`: https://github.com/saltstack/salt/pull/25158
.. _`#25161`: https://github.com/saltstack/salt/pull/25161
.. _`#25166`: https://github.com/saltstack/salt/pull/25166
.. _`#25170`: https://github.com/saltstack/salt/pull/25170
.. _`#25171`: https://github.com/saltstack/salt/pull/25171
.. _`#25172`: https://github.com/saltstack/salt/pull/25172
.. _`#25173`: https://github.com/saltstack/salt/pull/25173
.. _`#25175`: https://github.com/saltstack/salt/pull/25175
.. _`#25179`: https://github.com/saltstack/salt/pull/25179
.. _`#25180`: https://github.com/saltstack/salt/pull/25180
.. _`#25181`: https://github.com/saltstack/salt/pull/25181
.. _`#25182`: https://github.com/saltstack/salt/pull/25182
.. _`#25184`: https://github.com/saltstack/salt/pull/25184
.. _`#25185`: https://github.com/saltstack/salt/pull/25185
.. _`#25187`: https://github.com/saltstack/salt/pull/25187
.. _`#25188`: https://github.com/saltstack/salt/pull/25188
.. _`#25189`: https://github.com/saltstack/salt/pull/25189
.. _`#25191`: https://github.com/saltstack/salt/pull/25191
.. _`#25194`: https://github.com/saltstack/salt/pull/25194
.. _`#25196`: https://github.com/saltstack/salt/pull/25196
.. _`#25201`: https://github.com/saltstack/salt/pull/25201
.. _`#25203`: https://github.com/saltstack/salt/pull/25203
.. _`#25205`: https://github.com/saltstack/salt/pull/25205
.. _`#25206`: https://github.com/saltstack/salt/issues/25206
.. _`#25213`: https://github.com/saltstack/salt/issues/25213
.. _`#25214`: https://github.com/saltstack/salt/pull/25214
.. _`#25216`: https://github.com/saltstack/salt/pull/25216
.. _`#25219`: https://github.com/saltstack/salt/pull/25219
.. _`#25222`: https://github.com/saltstack/salt/pull/25222
.. _`#25223`: https://github.com/saltstack/salt/issues/25223
.. _`#25225`: https://github.com/saltstack/salt/pull/25225
.. _`#25226`: https://github.com/saltstack/salt/pull/25226
.. _`#25228`: https://github.com/saltstack/salt/issues/25228
.. _`#25234`: https://github.com/saltstack/salt/pull/25234
.. _`#25238`: https://github.com/saltstack/salt/pull/25238
.. _`#25240`: https://github.com/saltstack/salt/pull/25240
.. _`#25241`: https://github.com/saltstack/salt/issues/25241
.. _`#25242`: https://github.com/saltstack/salt/pull/25242
.. _`#25244`: https://github.com/saltstack/salt/pull/25244
.. _`#25248`: https://github.com/saltstack/salt/pull/25248
.. _`#25250`: https://github.com/saltstack/salt/issues/25250
.. _`#25252`: https://github.com/saltstack/salt/pull/25252
.. _`#25253`: https://github.com/saltstack/salt/pull/25253
.. _`#25254`: https://github.com/saltstack/salt/pull/25254
.. _`#25256`: https://github.com/saltstack/salt/pull/25256
.. _`#25257`: https://github.com/saltstack/salt/pull/25257
.. _`#25259`: https://github.com/saltstack/salt/issues/25259
.. _`#25263`: https://github.com/saltstack/salt/pull/25263
.. _`#25264`: https://github.com/saltstack/salt/pull/25264
.. _`#25265`: https://github.com/saltstack/salt/issues/25265
.. _`#25266`: https://github.com/saltstack/salt/pull/25266
.. _`#25268`: https://github.com/saltstack/salt/issues/25268
.. _`#25269`: https://github.com/saltstack/salt/pull/25269
.. _`#25270`: https://github.com/saltstack/salt/issues/25270
.. _`#25271`: https://github.com/saltstack/salt/pull/25271
.. _`#25272`: https://github.com/saltstack/salt/pull/25272
.. _`#25274`: https://github.com/saltstack/salt/pull/25274
.. _`#25275`: https://github.com/saltstack/salt/issues/25275
.. _`#25277`: https://github.com/saltstack/salt/issues/25277
.. _`#25278`: https://github.com/saltstack/salt/pull/25278
.. _`#25279`: https://github.com/saltstack/salt/pull/25279
.. _`#25280`: https://github.com/saltstack/salt/pull/25280
.. _`#25281`: https://github.com/saltstack/salt/issues/25281
.. _`#25283`: https://github.com/saltstack/salt/pull/25283
.. _`#25285`: https://github.com/saltstack/salt/pull/25285
.. _`#25289`: https://github.com/saltstack/salt/pull/25289
.. _`#25290`: https://github.com/saltstack/salt/pull/25290
.. _`#25294`: https://github.com/saltstack/salt/issues/25294
.. _`#25296`: https://github.com/saltstack/salt/pull/25296
.. _`#25298`: https://github.com/saltstack/salt/pull/25298
.. _`#25299`: https://github.com/saltstack/salt/pull/25299
.. _`#25300`: https://github.com/saltstack/salt/pull/25300
.. _`#25301`: https://github.com/saltstack/salt/pull/25301
.. _`#25308`: https://github.com/saltstack/salt/pull/25308
.. _`#25309`: https://github.com/saltstack/salt/pull/25309
.. _`#25310`: https://github.com/saltstack/salt/pull/25310
.. _`#25311`: https://github.com/saltstack/salt/pull/25311
.. _`#25312`: https://github.com/saltstack/salt/pull/25312
.. _`#25315`: https://github.com/saltstack/salt/pull/25315
.. _`#25319`: https://github.com/saltstack/salt/pull/25319
.. _`#25320`: https://github.com/saltstack/salt/issues/25320
.. _`#25322`: https://github.com/saltstack/salt/pull/25322
.. _`#25323`: https://github.com/saltstack/salt/issues/25323
.. _`#25324`: https://github.com/saltstack/salt/pull/25324
.. _`#25326`: https://github.com/saltstack/salt/pull/25326
.. _`#25327`: https://github.com/saltstack/salt/pull/25327
.. _`#25328`: https://github.com/saltstack/salt/pull/25328
.. _`#25329`: https://github.com/saltstack/salt/pull/25329
.. _`#25334`: https://github.com/saltstack/salt/pull/25334
.. _`#25336`: https://github.com/saltstack/salt/pull/25336
.. _`#25337`: https://github.com/saltstack/salt/issues/25337
.. _`#25339`: https://github.com/saltstack/salt/pull/25339
.. _`#25346`: https://github.com/saltstack/salt/pull/25346
.. _`#25350`: https://github.com/saltstack/salt/pull/25350
.. _`#25355`: https://github.com/saltstack/salt/pull/25355
.. _`#25358`: https://github.com/saltstack/salt/pull/25358
.. _`#25368`: https://github.com/saltstack/salt/issues/25368
.. _`#25369`: https://github.com/saltstack/salt/pull/25369
.. _`#25372`: https://github.com/saltstack/salt/pull/25372
.. _`#25375`: https://github.com/saltstack/salt/pull/25375
.. _`#25379`: https://github.com/saltstack/salt/pull/25379
.. _`#25383`: https://github.com/saltstack/salt/pull/25383
.. _`#25384`: https://github.com/saltstack/salt/issues/25384
.. _`#25386`: https://github.com/saltstack/salt/pull/25386
.. _`#25387`: https://github.com/saltstack/salt/pull/25387
.. _`#25389`: https://github.com/saltstack/salt/pull/25389
.. _`#25392`: https://github.com/saltstack/salt/pull/25392
.. _`#25393`: https://github.com/saltstack/salt/pull/25393
.. _`#25394`: https://github.com/saltstack/salt/pull/25394
.. _`#25395`: https://github.com/saltstack/salt/pull/25395
.. _`#25397`: https://github.com/saltstack/salt/pull/25397
.. _`#25398`: https://github.com/saltstack/salt/pull/25398
.. _`#25399`: https://github.com/saltstack/salt/pull/25399
.. _`#25401`: https://github.com/saltstack/salt/issues/25401
.. _`#25406`: https://github.com/saltstack/salt/pull/25406
.. _`#25407`: https://github.com/saltstack/salt/pull/25407
.. _`#25408`: https://github.com/saltstack/salt/pull/25408
.. _`#25409`: https://github.com/saltstack/salt/pull/25409
.. _`#25411`: https://github.com/saltstack/salt/pull/25411
.. _`#25412`: https://github.com/saltstack/salt/pull/25412
.. _`#25415`: https://github.com/saltstack/salt/pull/25415
.. _`#25416`: https://github.com/saltstack/salt/pull/25416
.. _`#25417`: https://github.com/saltstack/salt/pull/25417
.. _`#25418`: https://github.com/saltstack/salt/pull/25418
.. _`#25420`: https://github.com/saltstack/salt/pull/25420
.. _`#25421`: https://github.com/saltstack/salt/pull/25421
.. _`#25426`: https://github.com/saltstack/salt/pull/25426
.. _`#25427`: https://github.com/saltstack/salt/pull/25427
.. _`#25428`: https://github.com/saltstack/salt/pull/25428
.. _`#25430`: https://github.com/saltstack/salt/pull/25430
.. _`#25431`: https://github.com/saltstack/salt/issues/25431
.. _`#25432`: https://github.com/saltstack/salt/issues/25432
.. _`#25433`: https://github.com/saltstack/salt/pull/25433
.. _`#25437`: https://github.com/saltstack/salt/issues/25437
.. _`#25438`: https://github.com/saltstack/salt/pull/25438
.. _`#25439`: https://github.com/saltstack/salt/pull/25439
.. _`#25448`: https://github.com/saltstack/salt/issues/25448
.. _`#25449`: https://github.com/saltstack/salt/pull/25449
.. _`#25451`: https://github.com/saltstack/salt/pull/25451
.. _`#25454`: https://github.com/saltstack/salt/issues/25454
.. _`#25456`: https://github.com/saltstack/salt/issues/25456
.. _`#25457`: https://github.com/saltstack/salt/pull/25457
.. _`#25459`: https://github.com/saltstack/salt/pull/25459
.. _`#25461`: https://github.com/saltstack/salt/pull/25461
.. _`#25462`: https://github.com/saltstack/salt/pull/25462
.. _`#25464`: https://github.com/saltstack/salt/pull/25464
.. _`#25465`: https://github.com/saltstack/salt/pull/25465
.. _`#25467`: https://github.com/saltstack/salt/pull/25467
.. _`#25468`: https://github.com/saltstack/salt/pull/25468
.. _`#25475`: https://github.com/saltstack/salt/issues/25475
.. _`#25477`: https://github.com/saltstack/salt/issues/25477
.. _`#25479`: https://github.com/saltstack/salt/issues/25479
.. _`#25482`: https://github.com/saltstack/salt/pull/25482
.. _`#25483`: https://github.com/saltstack/salt/pull/25483
.. _`#25485`: https://github.com/saltstack/salt/pull/25485
.. _`#25486`: https://github.com/saltstack/salt/issues/25486
.. _`#25487`: https://github.com/saltstack/salt/pull/25487
.. _`#25491`: https://github.com/saltstack/salt/pull/25491
.. _`#25493`: https://github.com/saltstack/salt/issues/25493
.. _`#25498`: https://github.com/saltstack/salt/pull/25498
.. _`#25501`: https://github.com/saltstack/salt/pull/25501
.. _`#25506`: https://github.com/saltstack/salt/pull/25506
.. _`#25508`: https://github.com/saltstack/salt/pull/25508
.. _`#25511`: https://github.com/saltstack/salt/issues/25511
.. _`#25513`: https://github.com/saltstack/salt/pull/25513
.. _`#25514`: https://github.com/saltstack/salt/pull/25514
.. _`#25515`: https://github.com/saltstack/salt/pull/25515
.. _`#25516`: https://github.com/saltstack/salt/pull/25516
.. _`#25517`: https://github.com/saltstack/salt/pull/25517
.. _`#25519`: https://github.com/saltstack/salt/pull/25519
.. _`#25521`: https://github.com/saltstack/salt/pull/25521
.. _`#25525`: https://github.com/saltstack/salt/pull/25525
.. _`#25528`: https://github.com/saltstack/salt/pull/25528
.. _`#25529`: https://github.com/saltstack/salt/pull/25529
.. _`#25530`: https://github.com/saltstack/salt/pull/25530
.. _`#25531`: https://github.com/saltstack/salt/pull/25531
.. _`#25532`: https://github.com/saltstack/salt/issues/25532
.. _`#25533`: https://github.com/saltstack/salt/pull/25533
.. _`#25538`: https://github.com/saltstack/salt/issues/25538
.. _`#25542`: https://github.com/saltstack/salt/pull/25542
.. _`#25543`: https://github.com/saltstack/salt/pull/25543
.. _`#25546`: https://github.com/saltstack/salt/pull/25546
.. _`#25547`: https://github.com/saltstack/salt/pull/25547
.. _`#25548`: https://github.com/saltstack/salt/pull/25548
.. _`#25549`: https://github.com/saltstack/salt/pull/25549
.. _`#25551`: https://github.com/saltstack/salt/pull/25551
.. _`#25552`: https://github.com/saltstack/salt/pull/25552
.. _`#25553`: https://github.com/saltstack/salt/pull/25553
.. _`#25554`: https://github.com/saltstack/salt/pull/25554
.. _`#25556`: https://github.com/saltstack/salt/pull/25556
.. _`#25558`: https://github.com/saltstack/salt/pull/25558
.. _`#25559`: https://github.com/saltstack/salt/pull/25559
.. _`#25560`: https://github.com/saltstack/salt/issues/25560
.. _`#25561`: https://github.com/saltstack/salt/pull/25561
.. _`#25563`: https://github.com/saltstack/salt/pull/25563
.. _`#25564`: https://github.com/saltstack/salt/pull/25564
.. _`#25566`: https://github.com/saltstack/salt/pull/25566
.. _`#25568`: https://github.com/saltstack/salt/pull/25568
.. _`#25570`: https://github.com/saltstack/salt/pull/25570
.. _`#25572`: https://github.com/saltstack/salt/pull/25572
.. _`#25573`: https://github.com/saltstack/salt/pull/25573
.. _`#25575`: https://github.com/saltstack/salt/pull/25575
.. _`#25576`: https://github.com/saltstack/salt/pull/25576
.. _`#25578`: https://github.com/saltstack/salt/pull/25578
.. _`#25580`: https://github.com/saltstack/salt/pull/25580
.. _`#25583`: https://github.com/saltstack/salt/pull/25583
.. _`#25584`: https://github.com/saltstack/salt/pull/25584
.. _`#25587`: https://github.com/saltstack/salt/pull/25587
.. _`#25588`: https://github.com/saltstack/salt/pull/25588
.. _`#25589`: https://github.com/saltstack/salt/pull/25589
.. _`#25590`: https://github.com/saltstack/salt/pull/25590
.. _`#25591`: https://github.com/saltstack/salt/pull/25591
.. _`#25595`: https://github.com/saltstack/salt/pull/25595
.. _`#25596`: https://github.com/saltstack/salt/pull/25596
.. _`#25598`: https://github.com/saltstack/salt/pull/25598
.. _`#25599`: https://github.com/saltstack/salt/pull/25599
.. _`#25601`: https://github.com/saltstack/salt/pull/25601
.. _`#25603`: https://github.com/saltstack/salt/pull/25603
.. _`#25604`: https://github.com/saltstack/salt/pull/25604
.. _`#25609`: https://github.com/saltstack/salt/pull/25609
.. _`#25610`: https://github.com/saltstack/salt/pull/25610
.. _`#25619`: https://github.com/saltstack/salt/pull/25619
.. _`#25626`: https://github.com/saltstack/salt/pull/25626
.. _`#25627`: https://github.com/saltstack/salt/pull/25627
.. _`#25628`: https://github.com/saltstack/salt/pull/25628
.. _`#25631`: https://github.com/saltstack/salt/pull/25631
.. _`#25639`: https://github.com/saltstack/salt/pull/25639
.. _`#3`: https://github.com/saltstack/salt/issues/3
.. _`#3511`: https://github.com/saltstack/salt/issues/3511
.. _`#3817`: https://github.com/saltstack/salt/issues/3817
.. _`#4`: https://github.com/saltstack/salt/issues/4
.. _`#455`: https://github.com/saltstack/salt/issues/455
.. _`#5`: https://github.com/saltstack/salt/issues/5
.. _`#5504`: https://github.com/saltstack/salt/issues/5504
.. _`#598`: https://github.com/saltstack/salt/issues/598
.. _`#6`: https://github.com/saltstack/salt/issues/6
.. _`#602`: https://github.com/saltstack/salt/pull/602
.. _`#606`: https://github.com/saltstack/salt/pull/606
.. _`#607`: https://github.com/saltstack/salt/issues/607
.. _`#611`: https://github.com/saltstack/salt/issues/611
.. _`#621`: https://github.com/saltstack/salt/pull/621
.. _`#624`: https://github.com/saltstack/salt/pull/624
.. _`#625`: https://github.com/saltstack/salt/issues/625
.. _`#627`: https://github.com/saltstack/salt/pull/627
.. _`#630`: https://github.com/saltstack/salt/issues/630
.. _`#6608`: https://github.com/saltstack/salt/pull/6608
.. _`#6815`: https://github.com/saltstack/salt/issues/6815
.. _`#6859`: https://github.com/saltstack/salt/issues/6859
.. _`#7`: https://github.com/saltstack/salt/issues/7
.. _`#7772`: https://github.com/saltstack/salt/issues/7772
.. _`#7885`: https://github.com/saltstack/salt/pull/7885
.. _`#7990`: https://github.com/saltstack/salt/issues/7990
.. _`#8`: https://github.com/saltstack/salt/issues/8
.. _`#8240`: https://github.com/saltstack/salt/issues/8240
.. _`#8539`: https://github.com/saltstack/salt/issues/8539
.. _`#8754`: https://github.com/saltstack/salt/issues/8754
.. _`#8933`: https://github.com/saltstack/salt/issues/8933
.. _`#9`: https://github.com/saltstack/salt/issues/9
.. _`#9028`: https://github.com/saltstack/salt/issues/9028
.. _`#9444`: https://github.com/saltstack/salt/issues/9444
.. _`#9960`: https://github.com/saltstack/salt/issues/9960
.. _`bp-20972`: https://github.com/saltstack/salt/pull/20972
.. _`bp-23236`: https://github.com/saltstack/salt/pull/23236
.. _`bp-24054`: https://github.com/saltstack/salt/pull/24054
.. _`bp-24422`: https://github.com/saltstack/salt/pull/24422
.. _`bp-24982`: https://github.com/saltstack/salt/pull/24982
.. _`bp-25001`: https://github.com/saltstack/salt/pull/25001
.. _`bp-25019`: https://github.com/saltstack/salt/pull/25019
.. _`bp-25020`: https://github.com/saltstack/salt/pull/25020
.. _`bp-25059`: https://github.com/saltstack/salt/pull/25059
.. _`bp-25088`: https://github.com/saltstack/salt/pull/25088
.. _`bp-25102`: https://github.com/saltstack/salt/pull/25102
.. _`bp-25126`: https://github.com/saltstack/salt/pull/25126
.. _`bp-25128`: https://github.com/saltstack/salt/pull/25128
.. _`bp-25219`: https://github.com/saltstack/salt/pull/25219
.. _`bp-25256`: https://github.com/saltstack/salt/pull/25256
.. _`bp-25289`: https://github.com/saltstack/salt/pull/25289
.. _`bp-25290`: https://github.com/saltstack/salt/pull/25290
.. _`bp-25309`: https://github.com/saltstack/salt/pull/25309
.. _`bp-25355`: https://github.com/saltstack/salt/pull/25355
.. _`bp-25389`: https://github.com/saltstack/salt/pull/25389
.. _`bp-25399`: https://github.com/saltstack/salt/pull/25399
.. _`bp-25464`: https://github.com/saltstack/salt/pull/25464
.. _`bp-25483`: https://github.com/saltstack/salt/pull/25483
.. _`bp-25485`: https://github.com/saltstack/salt/pull/25485
.. _`bp-25529`: https://github.com/saltstack/salt/pull/25529
.. _`bp-25530`: https://github.com/saltstack/salt/pull/25530
.. _`bp-25570`: https://github.com/saltstack/salt/pull/25570
.. _`fix-2015`: https://github.com/saltstack/salt/pull/2015
.. _`fix-21491`: https://github.com/saltstack/salt/issues/21491
.. _`fix-22306`: https://github.com/saltstack/salt/issues/22306
.. _`fix-22537`: https://github.com/saltstack/salt/issues/22537
.. _`fix-23085`: https://github.com/saltstack/salt/issues/23085
.. _`fix-23210`: https://github.com/saltstack/salt/issues/23210
.. _`fix-23364`: https://github.com/saltstack/salt/issues/23364
.. _`fix-23738`: https://github.com/saltstack/salt/issues/23738
.. _`fix-24272`: https://github.com/saltstack/salt/issues/24272
.. _`fix-24912`: https://github.com/saltstack/salt/issues/24912
.. _`fix-25228`: https://github.com/saltstack/salt/issues/25228
.. _`fix-25431`: https://github.com/saltstack/salt/issues/25431
